package DBIx::MyParsePP::Symbols;
1;
$symbols = {
             '' => undef,
             'JOIN' => 'JOIN_SYM',
             'SERIALIZABLE' => 'SERIALIZABLE_SYM',
             'REPEAT' => 'REPEAT_SYM',
             'REPLACE' => 'REPLACE',
             'CONTAINS' => 'CONTAINS_SYM',
             'INSENSITIVE' => 'INSENSITIVE_SYM',
             'CURRENT_TIMESTAMP' => 'NOW_SYM',
             'RETURNS' => 'RETURNS_SYM',
             'UNICODE' => 'UNICODE_SYM',
             'NCHAR' => 'NCHAR_SYM',
             'MASTER_SSL_CA' => 'MASTER_SSL_CA_SYM',
             'INVOKER' => 'INVOKER_SYM',
             'COLUMNS' => 'COLUMNS',
             'WORK' => 'WORK_SYM',
             'DATETIME' => 'DATETIME',
             'MODE' => 'MODE_SYM',
             'OPEN' => 'OPEN_SYM',
             'INTEGER' => 'INT_SYM',
             'VALUE' => 'VALUE_SYM',
             'ESCAPE' => 'ESCAPE_SYM',
             'SQL_BIG_RESULT' => 'SQL_BIG_RESULT',
             'DROP' => 'DROP',
             'MONTH' => 'MONTH_SYM',
             'EVENTS' => 'EVENTS_SYM',
             'TINYINT' => 'TINYINT',
             'REGEXP' => 'REGEXP',
             'PROFILES' => 'PROFILES_SYM',
             'DUPLICATE' => 'DUPLICATE_SYM',
             'UNLOCK' => 'UNLOCK_SYM',
             'REPLICATION' => 'REPLICATION',
             'INNODB' => 'INNOBASE_SYM',
             'YEAR_MONTH' => 'YEAR_MONTH_SYM',
             'SOURCE' => 'SOURCE_SYM',
             'WEEK' => 'WEEK_SYM',
             'SUBJECT' => 'SUBJECT_SYM',
             'PREPARE' => 'PREPARE_SYM',
             'LOCK' => 'LOCK_SYM',
             'NDB' => 'NDBCLUSTER_SYM',
             'CHECK' => 'CHECK_SYM',
             'INT4' => 'INT_SYM',
             'FULL' => 'FULL',
             'BY' => 'BY',
             'READS' => 'READS_SYM',
             'NO' => 'NO_SYM',
             'POLYGON' => 'POLYGON',
             'MINUTE' => 'MINUTE_SYM',
             'DAY' => 'DAY_SYM',
             'DATA' => 'DATA_SYM',
             'SHARE' => 'SHARE_SYM',
             'REAL' => 'REAL',
             'RAID_CHUNKSIZE' => 'RAID_CHUNKSIZE',
             'SEPARATOR' => 'SEPARATOR_SYM',
             'LINESTRING' => 'LINESTRING',
             'DELETE' => 'DELETE_SYM',
             'ON' => 'ON',
             'CONNECTION' => 'CONNECTION_SYM',
             'CHANGED' => 'CHANGED',
             'CLOSE' => 'CLOSE_SYM',
             'X509' => 'X509_SYM',
             'USE' => 'USE_SYM',
             'WHERE' => 'WHERE',
             'PRIVILEGES' => 'PRIVILEGES',
             'TIMESTAMPDIFF' => 'TIMESTAMP_DIFF',
             'SPATIAL' => 'SPATIAL_SYM',
             'SUPER' => 'SUPER_SYM',
             'SQL_BUFFER_RESULT' => 'SQL_BUFFER_RESULT',
             'MEDIUMBLOB' => 'MEDIUMBLOB',
             'IGNORE' => 'IGNORE_SYM',
             'SECOND_MICROSECOND' => 'SECOND_MICROSECOND_SYM',
             'QUICK' => 'QUICK',
             'SIGNED' => 'SIGNED_SYM',
             '=' => 'EQ',
             'SECURITY' => 'SECURITY_SYM',
             'NDBCLUSTER' => 'NDBCLUSTER_SYM',
             'FALSE' => 'FALSE_SYM',
             'LEVEL' => 'LEVEL_SYM',
             'FORCE' => 'FORCE_SYM',
             'BINARY' => 'BINARY',
             'TO' => 'TO_SYM',
             'CHANGE' => 'CHANGE',
             'POINT' => 'POINT_SYM',
             'CURRENT_USER' => 'CURRENT_USER',
             'HOUR_MINUTE' => 'HOUR_MINUTE_SYM',
             '<=' => 'LE',
             'UPDATE' => 'UPDATE_SYM',
             'INTO' => 'INTO',
             'VARYING' => 'VARYING',
             'HOUR_SECOND' => 'HOUR_SECOND_SYM',
             'SWITCHES' => 'SWITCHES_SYM',
             'CUBE' => 'CUBE_SYM',
             'ROLLBACK' => 'ROLLBACK_SYM',
             'GEOMETRYCOLLECTION' => 'GEOMETRYCOLLECTION',
             'TIMESTAMP' => 'TIMESTAMP',
             'RTREE' => 'RTREE_SYM',
             'PROCEDURE' => 'PROCEDURE',
             'IMPORT' => 'IMPORT',
             'AGAINST' => 'AGAINST',
             'CHECKSUM' => 'CHECKSUM_SYM',
             'THEN' => 'THEN_SYM',
             'SQL_TSI_QUARTER' => 'QUARTER_SYM',
             'INSERT' => 'INSERT',
             'SQL_TSI_HOUR' => 'HOUR_SYM',
             'HANDLER' => 'HANDLER_SYM',
             'ENGINES' => 'ENGINES_SYM',
             'DAY_SECOND' => 'DAY_SECOND_SYM',
             'EXISTS' => 'EXISTS',
             'MUTEX' => 'MUTEX_SYM',
             'SENSITIVE' => 'SENSITIVE_SYM',
             'RELEASE' => 'RELEASE_SYM',
             'BOOLEAN' => 'BOOLEAN_SYM',
             'TINYTEXT' => 'TINYTEXT',
             'MOD' => 'MOD_SYM',
             'DEFAULT' => 'DEFAULT',
             'TYPE' => 'TYPE_SYM',
             'SQLEXCEPTION' => 'SQLEXCEPTION_SYM',
             'NO_WRITE_TO_BINLOG' => 'NO_WRITE_TO_BINLOG',
             'OPTIMIZE' => 'OPTIMIZE',
             'SQLSTATE' => 'SQLSTATE_SYM',
             '<=>' => 'EQUAL_SYM',
             'RESET' => 'RESET_SYM',
             'ITERATE' => 'ITERATE_SYM',
             'DO' => 'DO_SYM',
             'BIGINT' => 'BIGINT',
             'SET' => 'SET',
             'ISSUER' => 'ISSUER_SYM',
             'DATE' => 'DATE_SYM',
             'STATUS' => 'STATUS_SYM',
             'FULLTEXT' => 'FULLTEXT_SYM',
             'COMMENT' => 'COMMENT_SYM',
             'MASTER_CONNECT_RETRY' => 'MASTER_CONNECT_RETRY_SYM',
             'INNER' => 'INNER_SYM',
             'STOP' => 'STOP_SYM',
             'PRECISION' => 'PRECISION',
             'MASTER_LOG_FILE' => 'MASTER_LOG_FILE_SYM',
             'TRAILING' => 'TRAILING',
             'REQUIRE' => 'REQUIRE_SYM',
             'PHASE' => 'PHASE_SYM',
             'OLD_PASSWORD' => 'OLD_PASSWORD',
             'LONG' => 'LONG_SYM',
             'OPTION' => 'OPTION',
             'SQL_TSI_DAY' => 'DAY_SYM',
             '||' => 'OR_OR_SYM',
             'ELSE' => 'ELSE',
             'IO_THREAD' => 'RELAY_THREAD',
             'INOUT' => 'INOUT_SYM',
             'CASE' => 'CASE_SYM',
             'DEALLOCATE' => 'DEALLOCATE_SYM',
             'CIPHER' => 'CIPHER_SYM',
             'OUT' => 'OUT_SYM',
             'FROM' => 'FROM',
             'CONTINUE' => 'CONTINUE_SYM',
             'MULTIPOLYGON' => 'MULTIPOLYGON',
             'READ' => 'READ_SYM',
             'DAY_MICROSECOND' => 'DAY_MICROSECOND_SYM',
             'LEFT' => 'LEFT',
             'MINUTE_SECOND' => 'MINUTE_SECOND_SYM',
             'ELSEIF' => 'ELSEIF_SYM',
             'MASTER_SSL_CAPATH' => 'MASTER_SSL_CAPATH_SYM',
             'COMPACT' => 'COMPACT_SYM',
             'RESTORE' => 'RESTORE_SYM',
             'DEC' => 'DECIMAL_SYM',
             'FOR' => 'FOR_SYM',
             'WARNINGS' => 'WARNINGS',
             'MIN_ROWS' => 'MIN_ROWS',
             'HOUR_MICROSECOND' => 'HOUR_MICROSECOND_SYM',
             'STRING' => 'STRING_SYM',
             'CONDITION' => 'CONDITION_SYM',
             'TEXT' => 'TEXT_SYM',
             'FUNCTION' => 'FUNCTION_SYM',
             'ENCLOSED' => 'ENCLOSED',
             'AGGREGATE' => 'AGGREGATE_SYM',
             'FLOAT' => 'FLOAT_SYM',
             'FIELDS' => 'COLUMNS',
             'CHARSET' => 'CHARSET',
             'INT3' => 'MEDIUMINT',
             'LONGTEXT' => 'LONGTEXT',
             'AVG_ROW_LENGTH' => 'AVG_ROW_LENGTH',
             'ADD' => 'ADD',
             'KILL' => 'KILL_SYM',
             'FLOAT4' => 'FLOAT_SYM',
             'DETERMINISTIC' => 'DETERMINISTIC_SYM',
             'TABLESPACE' => 'TABLESPACE',
             'STRIPED' => 'RAID_STRIPED_SYM',
             'VIEW' => 'VIEW_SYM',
             'RESUME' => 'RESUME_SYM',
             'ALGORITHM' => 'ALGORITHM_SYM',
             'REPEATABLE' => 'REPEATABLE_SYM',
             'INFILE' => 'INFILE',
             'ORDER' => 'ORDER_SYM',
             'USING' => 'USING',
             'XOR' => 'XOR',
             'MIDDLEINT' => 'MEDIUMINT',
             'GRANT' => 'GRANT',
             'IO' => 'IO_SYM',
             'UNSIGNED' => 'UNSIGNED',
             'DECIMAL' => 'DECIMAL_SYM',
             '<<' => 'SHIFT_LEFT',
             '<' => 'LT',
             'INDEXES' => 'INDEXES',
             'SQL_TSI_WEEK' => 'WEEK_SYM',
             'FOREIGN' => 'FOREIGN',
             'CACHE' => 'CACHE_SYM',
             'ASCII' => 'ASCII_SYM',
             'HOSTS' => 'HOSTS_SYM',
             'COMMIT' => 'COMMIT_SYM',
             'DIV' => 'DIV_SYM',
             'SCHEMAS' => 'DATABASES',
             'LEADING' => 'LEADING',
             'SNAPSHOT' => 'SNAPSHOT_SYM',
             'GEOMETRY' => 'GEOMETRY_SYM',
             'DECLARE' => 'DECLARE_SYM',
             'MIGRATE' => 'MIGRATE_SYM',
             'LOCALTIMESTAMP' => 'NOW_SYM',
             'LOAD' => 'LOAD',
             'SQL_CACHE' => 'SQL_CACHE_SYM',
             'CONVERT' => 'CONVERT_SYM',
             'DYNAMIC' => 'DYNAMIC_SYM',
             'COLLATE' => 'COLLATE_SYM',
             'SMALLINT' => 'SMALLINT',
             'NEW' => 'NEW_SYM',
             'BYTE' => 'BYTE_SYM',
             'GLOBAL' => 'GLOBAL_SYM',
             'WHEN' => 'WHEN_SYM',
             'BERKELEYDB' => 'BERKELEY_DB_SYM',
             'FAULTS' => 'FAULTS_SYM',
             'HAVING' => 'HAVING',
             'AS' => 'AS',
             'STARTING' => 'STARTING',
             'SOME' => 'ANY_SYM',
             'RELOAD' => 'RELOAD',
             'AUTO_INCREMENT' => 'AUTO_INC',
             'SQL_TSI_YEAR' => 'YEAR_SYM',
             'CURRENT_TIME' => 'CURTIME',
             'REVOKE' => 'REVOKE',
             'GRANTS' => 'GRANTS',
             'OUTER' => 'OUTER',
             'MEDIUMINT' => 'MEDIUMINT',
             'EXPLAIN' => 'DESCRIBE',
             'WITH' => 'WITH',
             'VARCHAR' => 'VARCHAR',
             'AFTER' => 'AFTER_SYM',
             'DISABLE' => 'DISABLE_SYM',
             'ROLLUP' => 'ROLLUP_SYM',
             'OUTFILE' => 'OUTFILE',
             'LOW_PRIORITY' => 'LOW_PRIORITY',
             'BDB' => 'BERKELEY_DB_SYM',
             'FILE' => 'FILE_SYM',
             'SCHEMA' => 'DATABASE',
             'ROW' => 'ROW_SYM',
             'MODIFIES' => 'MODIFIES_SYM',
             'SONAME' => 'UDF_SONAME_SYM',
             'DUAL' => 'DUAL_SYM',
             'INDEX' => 'INDEX_SYM',
             'BACKUP' => 'BACKUP_SYM',
             'DEFINER' => 'DEFINER_SYM',
             'EXTENDED' => 'EXTENDED_SYM',
             'HASH' => 'HASH_SYM',
             'CROSS' => 'CROSS',
             '>=' => 'GE',
             'NATIONAL' => 'NATIONAL_SYM',
             'GROUP' => 'GROUP',
             'LONGBLOB' => 'LONGBLOB',
             'UNDO' => 'UNDO_SYM',
             'EACH' => 'EACH_SYM',
             'ZEROFILL' => 'ZEROFILL',
             'CLIENT' => 'CLIENT_SYM',
             'SPECIFIC' => 'SPECIFIC_SYM',
             'MASTER_PASSWORD' => 'MASTER_PASSWORD_SYM',
             'UNDEFINED' => 'UNDEFINED_SYM',
             'RELAY_LOG_FILE' => 'RELAY_LOG_FILE_SYM',
             'TRUE' => 'TRUE_SYM',
             'CHARACTER' => 'CHAR_SYM',
             'MASTER_USER' => 'MASTER_USER_SYM',
             'TABLE' => 'TABLE_SYM',
             'ENGINE' => 'ENGINE_SYM',
             'INSERT_METHOD' => 'INSERT_METHOD',
             'VARBINARY' => 'VARBINARY',
             'CASCADE' => 'CASCADE',
             'SQL_CALC_FOUND_ROWS' => 'SQL_CALC_FOUND_ROWS',
             'RELAY_LOG_POS' => 'RELAY_LOG_POS_SYM',
             'UNION' => 'UNION_SYM',
             'LEAVE' => 'LEAVE_SYM',
             'MODIFY' => 'MODIFY_SYM',
             'MATCH' => 'MATCH',
             'DESC' => 'DESC',
             'DISTINCTROW' => 'DISTINCT',
             'DOUBLE' => 'DOUBLE_SYM',
             'MASTER_LOG_POS' => 'MASTER_LOG_POS_SYM',
             'TIME' => 'TIME_SYM',
             '&&' => 'AND_AND_SYM',
             'FRAC_SECOND' => 'FRAC_SECOND_SYM',
             'NUMERIC' => 'NUMERIC_SYM',
             'EXPANSION' => 'EXPANSION_SYM',
             'CODE' => 'CODE_SYM',
             'CURSOR' => 'CURSOR_SYM',
             'CURRENT_DATE' => 'CURDATE',
             'RAID_CHUNKS' => 'RAID_CHUNKS',
             'CHAIN' => 'CHAIN_SYM',
             'CREATE' => 'CREATE',
             'FLUSH' => 'FLUSH_SYM',
             'DESCRIBE' => 'DESCRIBE',
             'MAX_UPDATES_PER_HOUR' => 'MAX_UPDATES_PER_HOUR',
             'INT2' => 'SMALLINT',
             'SQLWARNING' => 'SQLWARNING_SYM',
             'PROCESSLIST' => 'PROCESSLIST_SYM',
             'RECOVER' => 'RECOVER_SYM',
             'LOGS' => 'LOGS_SYM',
             'CASCADED' => 'CASCADED',
             'DISCARD' => 'DISCARD',
             'SOUNDS' => 'SOUNDS_SYM',
             'BETWEEN' => 'BETWEEN_SYM',
             'IPC' => 'IPC_SYM',
             'REPAIR' => 'REPAIR',
             'PACK_KEYS' => 'PACK_KEYS_SYM',
             'VALUES' => 'VALUES',
             'CALL' => 'CALL_SYM',
             'FAST' => 'FAST_SYM',
             'VARCHARACTER' => 'VARCHAR',
             'LOOP' => 'LOOP_SYM',
             'TRUNCATE' => 'TRUNCATE_SYM',
             'TIMESTAMPADD' => 'TIMESTAMP_ADD',
             'BEFORE' => 'BEFORE_SYM',
             'SQL_TSI_SECOND' => 'SECOND_SYM',
             'SHOW' => 'SHOW',
             'REDUNDANT' => 'REDUNDANT_SYM',
             'ALL' => 'ALL',
             'USER_RESOURCES' => 'RESOURCES',
             'PARTIAL' => 'PARTIAL',
             'BINLOG' => 'BINLOG_SYM',
             'END' => 'END',
             'SECOND' => 'SECOND_SYM',
             'AND' => 'AND_SYM',
             'FLOAT8' => 'DOUBLE_SYM',
             'PREV' => 'PREV_SYM',
             'HOUR' => 'HOUR_SYM',
             'SELECT' => 'SELECT_SYM',
             'OR' => 'OR_SYM',
             'DATABASES' => 'DATABASES',
             'IDENTIFIED' => 'IDENTIFIED_SYM',
             'TEMPTABLE' => 'TEMPTABLE_SYM',
             'MASTER_SSL_CIPHER' => 'MASTER_SSL_CIPHER_SYM',
             'BOTH' => 'BOTH',
             'BOOL' => 'BOOL_SYM',
             'LANGUAGE' => 'LANGUAGE_SYM',
             'YEAR' => 'YEAR_SYM',
             'MASTER_PORT' => 'MASTER_PORT_SYM',
             'CONCURRENT' => 'CONCURRENT',
             'UNIQUE' => 'UNIQUE_SYM',
             'HELP' => 'HELP_SYM',
             'TRIGGERS' => 'TRIGGERS_SYM',
             'CONSISTENT' => 'CONSISTENT_SYM',
             'MASTER_SSL' => 'MASTER_SSL_SYM',
             'SQL_TSI_MONTH' => 'MONTH_SYM',
             'MAX_CONNECTIONS_PER_HOUR' => 'MAX_CONNECTIONS_PER_HOUR',
             'LEAVES' => 'LEAVES',
             'SIMPLE' => 'SIMPLE_SYM',
             'LIKE' => 'LIKE',
             'MULTIPOINT' => 'MULTIPOINT',
             '>>' => 'SHIFT_RIGHT',
             'FETCH' => 'FETCH_SYM',
             'SQL' => 'SQL_SYM',
             'AVG' => 'AVG_SYM',
             'COLUMN' => 'COLUMN_SYM',
             'IN' => 'IN_SYM',
             'QUARTER' => 'QUARTER_SYM',
             'DUMPFILE' => 'DUMPFILE',
             'USAGE' => 'USAGE',
             'MEMORY' => 'MEMORY_SYM',
             'EXECUTE' => 'EXECUTE_SYM',
             'UNKNOWN' => 'UNKNOWN_SYM',
             'RELAY_THREAD' => 'RELAY_THREAD',
             'CONTEXT' => 'CONTEXT_SYM',
             'QUERY' => 'QUERY_SYM',
             'SUSPEND' => 'SUSPEND_SYM',
             'MASTER_HOST' => 'MASTER_HOST_SYM',
             'ROUTINE' => 'ROUTINE_SYM',
             'LINES' => 'LINES',
             'SQL_THREAD' => 'SQL_THREAD',
             'FOUND' => 'FOUND_SYM',
             'UTC_TIME' => 'UTC_TIME_SYM',
             'MINUTE_MICROSECOND' => 'MINUTE_MICROSECOND_SYM',
             'MAX_QUERIES_PER_HOUR' => 'MAX_QUERIES_PER_HOUR',
             'ANY' => 'ANY_SYM',
             'SWAPS' => 'SWAPS_SYM',
             'MASTER_SSL_CERT' => 'MASTER_SSL_CERT_SYM',
             'TRANSACTION' => 'TRANSACTION_SYM',
             'DAY_MINUTE' => 'DAY_MINUTE_SYM',
             'NAMES' => 'NAMES_SYM',
             'RENAME' => 'RENAME',
             'INT1' => 'TINYINT',
             'RIGHT' => 'RIGHT',
             'MAX_ROWS' => 'MAX_ROWS',
             'ALTER' => 'ALTER',
             'STRAIGHT_JOIN' => 'STRAIGHT_JOIN',
             'NATURAL' => 'NATURAL',
             'MULTILINESTRING' => 'MULTILINESTRING',
             'VARIABLES' => 'VARIABLES',
             'ESCAPED' => 'ESCAPED',
             'LOCALTIME' => 'NOW_SYM',
             'BLOB' => 'BLOB_SYM',
             'RAID_TYPE' => 'RAID_TYPE',
             'PASSWORD' => 'PASSWORD',
             'OFFSET' => 'OFFSET_SYM',
             'CHAR' => 'CHAR_SYM',
             'ONE' => 'ONE_SYM',
             'NEXT' => 'NEXT_SYM',
             'UTC_DATE' => 'UTC_DATE_SYM',
             'TEMPORARY' => 'TEMPORARY',
             'ERRORS' => 'ERRORS',
             'SQL_SMALL_RESULT' => 'SQL_SMALL_RESULT',
             'COMMITTED' => 'COMMITTED_SYM',
             'UPGRADE' => 'UPGRADE_SYM',
             'BIT' => 'BIT_SYM',
             'XA' => 'XA_SYM',
             'DELAY_KEY_WRITE' => 'DELAY_KEY_WRITE_SYM',
             'ASENSITIVE' => 'ASENSITIVE_SYM',
             'BEGIN' => 'BEGIN_SYM',
             'PROFILE' => 'PROFILE_SYM',
             'MEDIUM' => 'MEDIUM_SYM',
             'INTERVAL' => 'INTERVAL_SYM',
             'SSL' => 'SSL_SYM',
             'BLOCK' => 'BLOCK_SYM',
             'NAME' => 'NAME_SYM',
             'DAY_HOUR' => 'DAY_HOUR_SYM',
             'UTC_TIMESTAMP' => 'UTC_TIMESTAMP_SYM',
             'REFERENCES' => 'REFERENCES',
             'CPU' => 'CPU_SYM',
             'STORAGE' => 'STORAGE_SYM',
             'ISOLATION' => 'ISOLATION',
             'INT8' => 'BIGINT',
             'RESTRICT' => 'RESTRICT',
             'UNCOMMITTED' => 'UNCOMMITTED_SYM',
             'GET_FORMAT' => 'GET_FORMAT',
             'IS' => 'IS',
             'NOT' => 'NOT_SYM',
             'TINYBLOB' => 'TINYBLOB',
             'SQL_TSI_MINUTE' => 'MINUTE_SYM',
             'DES_KEY_FILE' => 'DES_KEY_FILE',
             'COMPRESSED' => 'COMPRESSED_SYM',
             'START' => 'START_SYM',
             'SAVEPOINT' => 'SAVEPOINT_SYM',
             'IF' => 'IF',
             'ROWS' => 'ROWS_SYM',
             'PRIMARY' => 'PRIMARY_SYM',
             'PURGE' => 'PURGE',
             'USER' => 'USER',
             'INNOBASE' => 'INNOBASE_SYM',
             'LAST' => 'LAST_SYM',
             'PAGE' => 'PAGE_SYM',
             'EXIT' => 'EXIT_SYM',
             'KEYS' => 'KEYS',
             'LIMIT' => 'LIMIT',
             'KEY' => 'KEY_SYM',
             'MERGE' => 'MERGE_SYM',
             'UNTIL' => 'UNTIL_SYM',
             'SQL_NO_CACHE' => 'SQL_NO_CACHE_SYM',
             'SQL_TSI_FRAC_SECOND' => 'FRAC_SECOND_SYM',
             'DELAYED' => 'DELAYED_SYM',
             '>' => 'GT_SYM',
             'MICROSECOND' => 'MICROSECOND_SYM',
             'ANALYZE' => 'ANALYZE_SYM',
             'CONSTRAINT' => 'CONSTRAINT',
             'SERIAL' => 'SERIAL_SYM',
             'ACTION' => 'ACTION',
             'WRITE' => 'WRITE_SYM',
             'SESSION' => 'SESSION_SYM',
             'DATABASE' => 'DATABASE',
             'ENUM' => 'ENUM',
             'NULL' => 'NULL_SYM',
             'USE_FRM' => 'USE_FRM',
             'TERMINATED' => 'TERMINATED',
             'SLAVE' => 'SLAVE',
             'NVARCHAR' => 'NVARCHAR_SYM',
             'MEDIUMTEXT' => 'MEDIUMTEXT',
             'LOCKS' => 'LOCKS_SYM',
             'ASC' => 'ASC',
             'RETURN' => 'RETURN_SYM',
             'OPTIONALLY' => 'OPTIONALLY',
             'ENABLE' => 'ENABLE_SYM',
             'DIRECTORY' => 'DIRECTORY_SYM',
             '!=' => 'NE',
             'WHILE' => 'WHILE_SYM',
             'MAX_USER_CONNECTIONS' => 'MAX_USER_CONNECTIONS_SYM',
             'DISTINCT' => 'DISTINCT',
             'LOCAL' => 'LOCAL_SYM',
             'MASTER_SSL_KEY' => 'MASTER_SSL_KEY_SYM',
             'NONE' => 'NONE_SYM',
             'MASTER_SERVER_ID' => 'MASTER_SERVER_ID_SYM',
             'TABLES' => 'TABLES',
             'ONE_SHOT' => 'ONE_SHOT_SYM',
             'INT' => 'INT_SYM',
             '<>' => 'NE',
             'RLIKE' => 'REGEXP',
             'TRIGGER' => 'TRIGGER_SYM',
             'SHUTDOWN' => 'SHUTDOWN',
             'COLLATION' => 'COLLATION_SYM',
             'HIGH_PRIORITY' => 'HIGH_PRIORITY',
             'BTREE' => 'BTREE_SYM',
             'FIRST' => 'FIRST_SYM',
             'TYPES' => 'TYPES_SYM',
             'RAID0' => 'RAID_0_SYM',
             'FIXED' => 'FIXED_SYM',
             'MASTER' => 'MASTER_SYM',
             'ROW_FORMAT' => 'ROW_FORMAT_SYM'
           };
$functions = {
               'MIN' => 'MIN_SYM',
               'HEX' => 'FUNC_ARG1',
               'STDDEV_SAMP' => 'STDDEV_SAMP_SYM',
               'SRID' => 'FUNC_ARG1',
               'VARIANCE' => 'VARIANCE_SYM',
               'UNCOMPRESSED_LENGTH' => 'FUNC_ARG1',
               'SUBTIME' => 'FUNC_ARG2',
               'MLINEFROMWKB' => 'GEOMFROMWKB',
               'LOG2' => 'FUNC_ARG1',
               'POW' => 'FUNC_ARG2',
               'VAR_SAMP' => 'VAR_SAMP_SYM',
               'MULTIPOINTFROMWKB' => 'GEOMFROMWKB',
               'MULTIPOINTFROMTEXT' => 'MPOINTFROMTEXT',
               'CONCAT' => 'CONCAT',
               'NOW' => 'NOW_SYM',
               'INSTR' => 'FUNC_ARG2',
               'MULTILINESTRINGFROMWKB' => 'GEOMFROMWKB',
               'EXP' => 'FUNC_ARG1',
               'LOWER' => 'FUNC_ARG1',
               'SHA' => 'FUNC_ARG1',
               'ASWKT' => 'FUNC_ARG1',
               'GEOMETRYCOLLECTIONFROMWKB' => 'GEOMFROMWKB',
               'POINTN' => 'FUNC_ARG2',
               'SYSDATE' => 'SYSDATE',
               'SUM' => 'SUM_SYM',
               'OCT' => 'FUNC_ARG1',
               'MASTER_POS_WAIT' => 'MASTER_POS_WAIT',
               'ISCLOSED' => 'FUNC_ARG1',
               'ASBINARY' => 'FUNC_ARG1',
               'MAKEDATE' => 'FUNC_ARG2',
               'MBROVERLAPS' => 'FUNC_ARG2',
               'SOUNDEX' => 'FUNC_ARG1',
               'WITHIN' => 'FUNC_ARG2',
               'MBRTOUCHES' => 'FUNC_ARG2',
               'TO_DAYS' => 'FUNC_ARG1',
               'ASWKB' => 'FUNC_ARG1',
               'MID' => 'SUBSTRING',
               'UUID' => 'FUNC_ARG0',
               'SLEEP' => 'FUNC_ARG1',
               'CONNECTION_ID' => 'FUNC_ARG0',
               'X' => 'FUNC_ARG1',
               'SYSTEM_USER' => 'USER',
               'ROUND' => 'ROUND',
               'NULLIF' => 'FUNC_ARG2',
               'FOUND_ROWS' => 'FUNC_ARG0',
               'CROSSES' => 'FUNC_ARG2',
               'BIT_XOR' => 'BIT_XOR',
               'TIMEDIFF' => 'FUNC_ARG2',
               'GEOMETRYCOLLECTIONFROMTEXT' => 'GEOMCOLLFROMTEXT',
               'AREA' => 'FUNC_ARG1',
               'LINEFROMTEXT' => 'LINEFROMTEXT',
               'ADDTIME' => 'FUNC_ARG2',
               'UPPER' => 'FUNC_ARG1',
               'FROM_UNIXTIME' => 'FROM_UNIXTIME',
               'STDDEV_POP' => 'STD_SYM',
               'IFNULL' => 'FUNC_ARG2',
               'SUBSTRING' => 'SUBSTRING',
               'LEAST' => 'LEAST_SYM',
               'ISEMPTY' => 'FUNC_ARG1',
               'LTRIM' => 'FUNC_ARG1',
               'REVERSE' => 'FUNC_ARG1',
               'ISNULL' => 'FUNC_ARG1',
               'MULTILINESTRINGFROMTEXT' => 'MLINEFROMTEXT',
               'POLYGONFROMWKB' => 'GEOMFROMWKB',
               'INTERSECTS' => 'FUNC_ARG2',
               'MBRDISJOINT' => 'FUNC_ARG2',
               'SUBSTRING_INDEX' => 'SUBSTRING_INDEX',
               'ENCODE' => 'ENCODE_SYM',
               'LCASE' => 'FUNC_ARG1',
               'GREATEST' => 'GREATEST_SYM',
               'BIT_AND' => 'BIT_AND',
               'ATAN2' => 'ATAN',
               'MBRCONTAINS' => 'FUNC_ARG2',
               'GROUP_UNIQUE_USERS' => 'GROUP_UNIQUE_USERS',
               'ABS' => 'FUNC_ARG1',
               'COT' => 'FUNC_ARG1',
               'LOAD_FILE' => 'FUNC_ARG1',
               'POINTFROMTEXT' => 'POINTFROMTEXT',
               'GROUP_CONCAT' => 'GROUP_CONCAT_SYM',
               'POLYFROMWKB' => 'GEOMFROMWKB',
               'BENCHMARK' => 'BENCHMARK_SYM',
               'DATE_FORMAT' => 'FUNC_ARG2',
               'SPACE' => 'FUNC_ARG1',
               'NAME_CONST' => 'FUNC_ARG2',
               'RELEASE_LOCK' => 'FUNC_ARG1',
               'MAX' => 'MAX_SYM',
               'WEEKDAY' => 'FUNC_ARG1',
               'TIME_TO_SEC' => 'FUNC_ARG1',
               'CONVERT_TZ' => 'CONVERT_TZ_SYM',
               'EXPORT_SET' => 'EXPORT_SET',
               'DES_DECRYPT' => 'DES_DECRYPT_SYM',
               'COMPRESS' => 'FUNC_ARG1',
               'ENDPOINT' => 'FUNC_ARG1',
               'COUNT' => 'COUNT_SYM',
               'CAST' => 'CAST_SYM',
               'DATE_ADD' => 'DATE_ADD_INTERVAL',
               'PERIOD_DIFF' => 'FUNC_ARG2',
               'MLINEFROMTEXT' => 'MLINEFROMTEXT',
               'GEOMCOLLFROMWKB' => 'GEOMFROMWKB',
               'MBRWITHIN' => 'FUNC_ARG2',
               'DECODE' => 'DECODE_SYM',
               'SESSION_USER' => 'USER',
               'QUOTE' => 'FUNC_ARG1',
               'POSITION' => 'POSITION_SYM',
               'GET_LOCK' => 'FUNC_ARG2',
               'UCASE' => 'FUNC_ARG1',
               'IS_USED_LOCK' => 'FUNC_ARG1',
               'POLYFROMTEXT' => 'POLYFROMTEXT',
               'MPOLYFROMWKB' => 'GEOMFROMWKB',
               'DES_ENCRYPT' => 'DES_ENCRYPT_SYM',
               'CHAR_LENGTH' => 'FUNC_ARG1',
               'CEIL' => 'FUNC_ARG1',
               'CURTIME' => 'CURTIME',
               'LENGTH' => 'FUNC_ARG1',
               'CONV' => 'FUNC_ARG3',
               'STR_TO_DATE' => 'FUNC_ARG2',
               'UNIQUE_USERS' => 'UNIQUE_USERS',
               'Y' => 'FUNC_ARG1',
               'NUMINTERIORRINGS' => 'FUNC_ARG1',
               'EXTRACT' => 'EXTRACT_SYM',
               'INTERIORRINGN' => 'FUNC_ARG2',
               'ENCRYPT' => 'ENCRYPT',
               'MULTIPOLYGONFROMWKB' => 'GEOMFROMWKB',
               'FORMAT' => 'FORMAT_SYM',
               'STDDEV' => 'STD_SYM',
               'DATE_SUB' => 'DATE_SUB_INTERVAL',
               'PERIOD_ADD' => 'FUNC_ARG2',
               'GEOMETRYFROMWKB' => 'GEOMFROMWKB',
               'BIT_LENGTH' => 'FUNC_ARG1',
               'GEOMFROMTEXT' => 'GEOMFROMTEXT',
               'DATEDIFF' => 'FUNC_ARG2',
               'EXTERIORRING' => 'FUNC_ARG1',
               'GEOMFROMWKB' => 'GEOMFROMWKB',
               'TIME_FORMAT' => 'FUNC_ARG2',
               'BIN' => 'FUNC_ARG1',
               'RAND' => 'RAND',
               'SHA1' => 'FUNC_ARG1',
               'RPAD' => 'FUNC_ARG3',
               'MPOINTFROMTEXT' => 'MPOINTFROMTEXT',
               'SUBSTR' => 'SUBSTRING',
               'VAR_POP' => 'VARIANCE_SYM',
               'ELT' => 'ELT_FUNC',
               'DIMENSION' => 'FUNC_ARG1',
               'CONCAT_WS' => 'CONCAT_WS',
               'ROW_COUNT' => 'ROW_COUNT_SYM',
               'ASIN' => 'FUNC_ARG1',
               'SIGN' => 'FUNC_ARG1',
               'EQUALS' => 'FUNC_ARG2',
               'SEC_TO_TIME' => 'FUNC_ARG1',
               'LOCATE' => 'LOCATE',
               'CENTROID' => 'FUNC_ARG1',
               'FROM_DAYS' => 'FUNC_ARG1',
               'SUBDATE' => 'SUBDATE_SYM',
               'BIT_COUNT' => 'FUNC_ARG1',
               'DAYOFYEAR' => 'FUNC_ARG1',
               'OCTET_LENGTH' => 'FUNC_ARG1',
               'DISJOINT' => 'FUNC_ARG2',
               'AES_ENCRYPT' => 'FUNC_ARG2',
               'ASTEXT' => 'FUNC_ARG1',
               'LPAD' => 'FUNC_ARG3',
               'INET_NTOA' => 'FUNC_ARG1',
               'ACOS' => 'FUNC_ARG1',
               'SIN' => 'FUNC_ARG1',
               'OVERLAPS' => 'FUNC_ARG2',
               'CEILING' => 'FUNC_ARG1',
               'DAYOFWEEK' => 'FUNC_ARG1',
               'NUMGEOMETRIES' => 'FUNC_ARG1',
               'MONTHNAME' => 'FUNC_ARG1',
               'CHARACTER_LENGTH' => 'FUNC_ARG1',
               'MBREQUAL' => 'FUNC_ARG2',
               'LINEFROMWKB' => 'GEOMFROMWKB',
               'GEOMETRYTYPE' => 'FUNC_ARG1',
               'TRIM' => 'TRIM',
               'LINESTRINGFROMTEXT' => 'LINEFROMTEXT',
               'CRC32' => 'FUNC_ARG1',
               'STARTPOINT' => 'FUNC_ARG1',
               'MPOLYFROMTEXT' => 'MPOLYFROMTEXT',
               'YEARWEEK' => 'YEARWEEK',
               'BIT_OR' => 'BIT_OR',
               'MBRINTERSECTS' => 'FUNC_ARG2',
               'LOG10' => 'FUNC_ARG1',
               'SQRT' => 'FUNC_ARG1',
               'GEOMETRYN' => 'FUNC_ARG2',
               'GEOMETRYFROMTEXT' => 'GEOMFROMTEXT',
               'MD5' => 'FUNC_ARG1',
               'MPOINTFROMWKB' => 'GEOMFROMWKB',
               'UNIX_TIMESTAMP' => 'UNIX_TIMESTAMP',
               'DAYOFMONTH' => 'FUNC_ARG1',
               'NUMPOINTS' => 'FUNC_ARG1',
               'FIELD' => 'FIELD_FUNC',
               'MAKETIME' => 'FUNC_ARG3',
               'CURDATE' => 'CURDATE',
               'ADDDATE' => 'ADDDATE_SYM',
               'POLYGONFROMTEXT' => 'POLYFROMTEXT',
               'ORD' => 'FUNC_ARG1',
               'POWER' => 'FUNC_ARG2',
               'POINTFROMWKB' => 'GEOMFROMWKB',
               'ENVELOPE' => 'FUNC_ARG1',
               'ATAN' => 'ATAN',
               'IS_FREE_LOCK' => 'FUNC_ARG1',
               'STRCMP' => 'FUNC_ARG2',
               'LINESTRINGFROMWKB' => 'GEOMFROMWKB',
               'LN' => 'FUNC_ARG1',
               'TOUCHES' => 'FUNC_ARG2',
               'LOG' => 'LOG_SYM',
               'UNCOMPRESS' => 'FUNC_ARG1',
               'INET_ATON' => 'FUNC_ARG1',
               'AES_DECRYPT' => 'FUNC_ARG2',
               'ISSIMPLE' => 'FUNC_ARG1',
               'GEOMCOLLFROMTEXT' => 'GEOMCOLLFROMTEXT',
               'DAYNAME' => 'FUNC_ARG1',
               'COERCIBILITY' => 'FUNC_ARG1',
               'LAST_INSERT_ID' => 'LAST_INSERT_ID',
               'LAST_DAY' => 'FUNC_ARG1',
               'RTRIM' => 'FUNC_ARG1',
               'FLOOR' => 'FUNC_ARG1',
               'GLENGTH' => 'FUNC_ARG1',
               'RADIANS' => 'FUNC_ARG1',
               'DEGREES' => 'FUNC_ARG1',
               'UNHEX' => 'FUNC_ARG1',
               'STD' => 'STD_SYM',
               'COS' => 'FUNC_ARG1',
               'COALESCE' => 'COALESCE',
               'VERSION' => 'FUNC_ARG0',
               'TAN' => 'FUNC_ARG1',
               'PI' => 'FUNC_ARG0',
               'MULTIPOLYGONFROMTEXT' => 'MPOLYFROMTEXT',
               'MAKE_SET' => 'MAKE_SET_SYM',
               'WEEKOFYEAR' => 'FUNC_ARG1',
               'FIND_IN_SET' => 'FUNC_ARG2'
             };

1;
