####################################################################
#
#    This file was generated using Parse::Yapp version 1.05.
#
#        Don't edit this file, use source file instead.
#
#             ANY CHANGE MADE HERE WILL BE LOST !
#
####################################################################
package DBIx::MyParsePP::Parser;
use vars qw ( @ISA );
use strict;
use Parse::Yapp::Driver;

@ISA= qw ( Parse::Yapp::Driver );

sub new {
        my($class)=shift;
        ref($class)
    and $class=ref($class);

    my($self)=$class->SUPER::new( yyversion => '1.05',
                                  yystates =>
[
	{#State 0
		ACTIONS => {
			'SET' => 1,
			'CHECK_SYM' => 50,
			'REPLACE' => 2,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'FLUSH_SYM' => 4,
			'ANALYZE_SYM' => 56,
			'COMMIT_SYM' => 5,
			'REPAIR' => 57,
			'CALL_SYM' => 8,
			'PURGE' => 59,
			'CHANGE' => 61,
			'HANDLER_SYM' => 60,
			'SHOW' => 63,
			'ROLLBACK_SYM' => 62,
			'EXECUTE_SYM' => 65,
			'DROP' => 16,
			'RESET_SYM' => 17,
			'RENAME' => 18,
			'DO_SYM' => 67,
			'USE_SYM' => 66,
			'ALTER' => 19,
			"(" => 70,
			'LOAD' => 72,
			'LOCK_SYM' => 74,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'TRUNCATE_SYM' => 26,
			'HELP_SYM' => 79,
			'SLAVE' => 78,
			'SAVEPOINT_SYM' => 27,
			'KILL_SYM' => 28,
			'UPDATE_SYM' => 30,
			'SELECT_SYM' => 81,
			'BEGIN_SYM' => 31,
			'INSERT' => 87,
			'RESTORE_SYM' => 92,
			'DEALLOCATE_SYM' => 33,
			'DESC' => 37,
			'REVOKE' => 94,
			'RELEASE_SYM' => 38,
			'UNLOCK_SYM' => 95,
			'CACHE_SYM' => 39,
			'XA_SYM' => 41,
			'OPTIMIZE' => 97,
			'PREPARE_SYM' => 100,
			'CHECKSUM_SYM' => 101,
			'STOP_SYM' => 46,
			'CREATE' => 47,
			'END_OF_INPUT' => 104,
			'DESCRIBE' => 48
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'rename' => 6,
			'checksum' => 7,
			'statement' => 9,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'deallocate_or_drop' => 13,
			'show' => 64,
			'unlock' => 14,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'grant' => 75,
			'start' => 23,
			'do' => 24,
			'drop' => 25,
			'verb_clause' => 29,
			'rollback' => 80,
			'use' => 84,
			'reset' => 83,
			'check' => 82,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'call' => 90,
			'begin' => 89,
			'purge' => 88,
			'backup' => 32,
			'select' => 93,
			'set' => 34,
			'prepare' => 35,
			'create' => 36,
			'query' => 96,
			'truncate' => 40,
			'release' => 42,
			'describe_command' => 43,
			'repair' => 44,
			'analyze' => 98,
			'deallocate' => 99,
			'execute' => 45,
			'handler' => 103,
			'keycache' => 102,
			'optimize' => 105,
			'update' => 49
		}
	},
	{#State 1
		ACTIONS => {
			'OPTION' => 106
		},
		DEFAULT => -1660,
		GOTOS => {
			'opt_option' => 107
		}
	},
	{#State 2
		ACTIONS => {
			'DELAYED_SYM' => 108,
			'LOW_PRIORITY' => 111
		},
		DEFAULT => -1157,
		GOTOS => {
			'opt_low_priority' => 110,
			'replace_lock_option' => 109
		}
	},
	{#State 3
		DEFAULT => -24
	},
	{#State 4
		ACTIONS => {
			'NO_WRITE_TO_BINLOG' => 113,
			'LOCAL_SYM' => 114
		},
		DEFAULT => -571,
		GOTOS => {
			'opt_no_write_to_binlog' => 112
		}
	},
	{#State 5
		ACTIONS => {
			'WORK_SYM' => 115
		},
		DEFAULT => -1815,
		GOTOS => {
			'opt_work' => 116
		}
	},
	{#State 6
		DEFAULT => -34
	},
	{#State 7
		DEFAULT => -11
	},
	{#State 8
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'NATIONAL_SYM' => 249,
			'UNCOMMITTED_SYM' => 250,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'COMPRESSED_SYM' => 256,
			'INSERT_METHOD' => 257,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'MIGRATE_SYM' => 280,
			'ROW_FORMAT_SYM' => 281,
			'ROLLBACK_SYM' => 282,
			'NVARCHAR_SYM' => 283,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'DELAY_KEY_WRITE_SYM' => 303,
			'MULTIPOINT' => 304,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'MASTER_SSL_CA_SYM' => 333,
			'PASSWORD' => 334,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 337,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'HASH_SYM' => 350,
			'SECOND_SYM' => 351,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'SIGNED_SYM' => 381,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 311,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 9
		DEFAULT => -3
	},
	{#State 10
		DEFAULT => -41
	},
	{#State 11
		DEFAULT => -45
	},
	{#State 12
		DEFAULT => -26
	},
	{#State 13
		ACTIONS => {
			'PREPARE_SYM' => 386
		}
	},
	{#State 14
		DEFAULT => -48
	},
	{#State 15
		DEFAULT => -9
	},
	{#State 16
		ACTIONS => {
			'FUNCTION_SYM' => 395,
			'DATABASE' => 393,
			'INDEX_SYM' => 388,
			'TEMPORARY' => 390,
			'PROCEDURE' => 389,
			'PREPARE_SYM' => -54,
			'VIEW_SYM' => 392,
			'USER' => 391,
			'TRIGGER_SYM' => 387
		},
		DEFAULT => -1109,
		GOTOS => {
			'opt_temporary' => 394
		}
	},
	{#State 17
		ACTIONS => {
			'MASTER_SYM' => 397,
			'QUERY_SYM' => 399,
			'SLAVE' => 400
		},
		GOTOS => {
			'reset_option' => 396,
			'reset_options' => 398
		}
	},
	{#State 18
		ACTIONS => {
			'TABLE_SYM' => 401,
			'TABLES' => 404,
			'USER' => 403
		},
		GOTOS => {
			'table_or_tables' => 402
		}
	},
	{#State 19
		ACTIONS => {
			'FUNCTION_SYM' => 411,
			'DATABASE' => 410,
			'IGNORE_SYM' => 408,
			'PROCEDURE' => 406,
			'ALGORITHM_SYM' => 409,
			'TABLE_SYM' => -515
		},
		DEFAULT => -1861,
		GOTOS => {
			'opt_ignore' => 407,
			'view_algorithm_opt' => 412,
			'view_algorithm' => 405
		}
	},
	{#State 20
		DEFAULT => -12
	},
	{#State 21
		DEFAULT => -20
	},
	{#State 22
		DEFAULT => -15
	},
	{#State 23
		DEFAULT => -46
	},
	{#State 24
		DEFAULT => -17
	},
	{#State 25
		DEFAULT => -18
	},
	{#State 26
		ACTIONS => {
			'TABLE_SYM' => 413
		},
		DEFAULT => -1175,
		GOTOS => {
			'opt_table_sym' => 414
		}
	},
	{#State 27
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 415
		}
	},
	{#State 28
		ACTIONS => {
			'CONNECTION_SYM' => 416,
			'QUERY_SYM' => 417
		},
		DEFAULT => -1292,
		GOTOS => {
			'kill_option' => 418
		}
	},
	{#State 29
		ACTIONS => {
			'END_OF_INPUT' => 419
		}
	},
	{#State 30
		ACTIONS => {
			'LOW_PRIORITY' => 111
		},
		DEFAULT => -1157,
		GOTOS => {
			'opt_low_priority' => 420
		}
	},
	{#State 31
		ACTIONS => {
			'WORK_SYM' => 115
		},
		DEFAULT => -1815,
		GOTOS => {
			'opt_work' => 421
		}
	},
	{#State 32
		DEFAULT => -7
	},
	{#State 33
		DEFAULT => -53
	},
	{#State 34
		DEFAULT => -43
	},
	{#State 35
		DEFAULT => -31
	},
	{#State 36
		DEFAULT => -13
	},
	{#State 37
		DEFAULT => -1258
	},
	{#State 38
		ACTIONS => {
			'SAVEPOINT_SYM' => 422
		}
	},
	{#State 39
		ACTIONS => {
			'INDEX_SYM' => 423
		}
	},
	{#State 40
		DEFAULT => -47
	},
	{#State 41
		ACTIONS => {
			'START_SYM' => 431,
			'COMMIT_SYM' => 430,
			'PREPARE_SYM' => 426,
			'ROLLBACK_SYM' => 428,
			'BEGIN_SYM' => 424,
			'RECOVER_SYM' => 425,
			'END' => 429
		},
		GOTOS => {
			'begin_or_start' => 427
		}
	},
	{#State 42
		DEFAULT => -33
	},
	{#State 43
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 434,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -1260,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'opt_extended_describe' => 432,
			'table_ident' => 433,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 44
		DEFAULT => -35
	},
	{#State 45
		DEFAULT => -19
	},
	{#State 46
		ACTIONS => {
			'SLAVE' => 437
		}
	},
	{#State 47
		ACTIONS => {
			'DATABASE' => 453,
			'TEMPORARY' => 448,
			'ALGORITHM_SYM' => 409,
			'SPATIAL_SYM' => 449,
			'UNIQUE_SYM' => 450,
			'USER' => 451,
			'OR_SYM' => 443,
			'INDEX_SYM' => -462,
			'TABLE_SYM' => -223,
			'FULLTEXT_SYM' => 441,
			'DEFINER_SYM' => 454
		},
		DEFAULT => -1852,
		GOTOS => {
			'view_replace' => 445,
			'table_options' => 440,
			'opt_unique_or_fulltext' => 438,
			'view_replace_or_algorithm' => 447,
			'table_option' => 442,
			'view_or_trigger_or_sp' => 446,
			'opt_table_options' => 444,
			'definer' => 452,
			'view_algorithm' => 439
		}
	},
	{#State 48
		DEFAULT => -1259
	},
	{#State 49
		DEFAULT => -49
	},
	{#State 50
		ACTIONS => {
			'TABLE_SYM' => 401,
			'TABLES' => 404
		},
		GOTOS => {
			'table_or_tables' => 455
		}
	},
	{#State 51
		DEFAULT => -27
	},
	{#State 52
		DEFAULT => -38
	},
	{#State 53
		ACTIONS => {
			'TABLE_SYM' => 401,
			'TABLES' => 404
		},
		GOTOS => {
			'table_or_tables' => 456
		}
	},
	{#State 54
		DEFAULT => -25
	},
	{#State 55
		DEFAULT => -89,
		GOTOS => {
			'clear_privileges' => 457
		}
	},
	{#State 56
		ACTIONS => {
			'LOCAL_SYM' => 114,
			'NO_WRITE_TO_BINLOG' => 113
		},
		DEFAULT => -571,
		GOTOS => {
			'opt_no_write_to_binlog' => 458
		}
	},
	{#State 57
		ACTIONS => {
			'LOCAL_SYM' => 114,
			'NO_WRITE_TO_BINLOG' => 113
		},
		DEFAULT => -571,
		GOTOS => {
			'opt_no_write_to_binlog' => 459
		}
	},
	{#State 58
		DEFAULT => -5
	},
	{#State 59
		ACTIONS => {
			'MASTER_SYM' => 461,
			'BINARY' => 460
		},
		GOTOS => {
			'master_or_binary' => 462,
			'purge_options' => 463
		}
	},
	{#State 60
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 465,
			'IDENT_sys' => 297,
			'table_ident_nodb' => 464,
			'ident' => 466
		}
	},
	{#State 61
		ACTIONS => {
			'MASTER_SYM' => 467
		}
	},
	{#State 62
		ACTIONS => {
			'WORK_SYM' => 115
		},
		DEFAULT => -1815,
		GOTOS => {
			'opt_work' => 468
		}
	},
	{#State 63
		ACTIONS => {
			'PROFILE_SYM' => 501,
			'BINLOG_SYM' => 486,
			'BINARY' => 460,
			'COUNT_SYM' => 469,
			'STORAGE_SYM' => 478,
			'KEYS' => 506,
			'INDEXES' => 492,
			'OPEN_SYM' => 479,
			'NEW_SYM' => 502,
			'MUTEX_SYM' => 480,
			'STATUS_SYM' => -1671,
			'INDEX_SYM' => 471,
			'BERKELEY_DB_SYM' => 472,
			'MASTER_SYM' => 482,
			'SESSION_SYM' => 507,
			'LOGS_SYM' => 499,
			'DATABASES' => 500,
			'VARIABLES' => -1671,
			'CHAR_SYM' => 473,
			'GLOBAL_SYM' => 488,
			'WARNINGS' => 489,
			'SLAVE' => 508,
			'FULL' => 474,
			'ERRORS' => 503,
			'PROCEDURE' => 483,
			'INNOBASE_SYM' => 504,
			'COLLATION_SYM' => 475,
			'ENGINE_SYM' => 505,
			'ENGINES_SYM' => -1241,
			'FUNCTION_SYM' => 509,
			'CHARSET' => 490,
			'COLUMN_SYM' => 493,
			'PROFILES_SYM' => 476,
			'GRANTS' => 494,
			'LOCAL_SYM' => 495,
			'TABLE_SYM' => 496,
			'CREATE' => 498,
			'PRIVILEGES' => 477
		},
		DEFAULT => -1245,
		GOTOS => {
			'master_or_binary' => 487,
			'opt_storage' => 485,
			'opt_full' => 481,
			'opt_var_type' => 470,
			'charset' => 497,
			'show_param' => 491,
			'keys_or_index' => 484
		}
	},
	{#State 64
		DEFAULT => -44
	},
	{#State 65
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 510
		}
	},
	{#State 66
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 511
		}
	},
	{#State 67
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 532,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 68
		DEFAULT => -16
	},
	{#State 69
		DEFAULT => -596
	},
	{#State 70
		ACTIONS => {
			"(" => 688,
			'SELECT_SYM' => 689
		},
		GOTOS => {
			'select_paren' => 687
		}
	},
	{#State 71
		DEFAULT => -36
	},
	{#State 72
		ACTIONS => {
			'TABLE_SYM' => 692,
			'INDEX_SYM' => 690,
			'DATA_SYM' => 691
		}
	},
	{#State 73
		DEFAULT => -30
	},
	{#State 74
		ACTIONS => {
			'TABLE_SYM' => 401,
			'TABLES' => 404
		},
		GOTOS => {
			'table_or_tables' => 693
		}
	},
	{#State 75
		DEFAULT => -21
	},
	{#State 76
		ACTIONS => {
			'QUICK' => 694,
			'LOW_PRIORITY' => 696,
			'IGNORE_SYM' => 697
		},
		DEFAULT => -1169,
		GOTOS => {
			'opt_delete_options' => 698,
			'opt_delete_option' => 695
		}
	},
	{#State 77
		ACTIONS => {
			'TRANSACTION_SYM' => 699,
			'SLAVE' => 700
		}
	},
	{#State 78
		ACTIONS => {
			'START_SYM' => 702,
			'STOP_SYM' => 701
		}
	},
	{#State 79
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 705,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'ident' => 706
		}
	},
	{#State 80
		DEFAULT => -40
	},
	{#State 81
		ACTIONS => {
			'SQL_BIG_RESULT' => 708,
			'SQL_BUFFER_RESULT' => 709,
			'SQL_NO_CACHE_SYM' => 710,
			'SQL_CALC_FOUND_ROWS' => 713,
			'SQL_CACHE_SYM' => 714,
			'ALL' => 716,
			'STRAIGHT_JOIN' => 717,
			'SQL_SMALL_RESULT' => 719,
			'DISTINCT' => 721,
			'HIGH_PRIORITY' => 722
		},
		DEFAULT => -610,
		GOTOS => {
			'select_option' => 715,
			'select_options' => 718,
			'select_option_list' => 720,
			'select_init2' => 712,
			'select_part2' => 711
		}
	},
	{#State 82
		DEFAULT => -10
	},
	{#State 83
		DEFAULT => -37
	},
	{#State 84
		DEFAULT => -50
	},
	{#State 85
		DEFAULT => -51
	},
	{#State 86
		DEFAULT => -23
	},
	{#State 87
		ACTIONS => {
			'DELAYED_SYM' => 724,
			'LOW_PRIORITY' => 725,
			'HIGH_PRIORITY' => 726
		},
		DEFAULT => -1113,
		GOTOS => {
			'insert_lock_option' => 723
		}
	},
	{#State 88
		DEFAULT => -32
	},
	{#State 89
		DEFAULT => -4
	},
	{#State 90
		DEFAULT => -8
	},
	{#State 91
		DEFAULT => -39
	},
	{#State 92
		ACTIONS => {
			'TABLE_SYM' => 401,
			'TABLES' => 404
		},
		GOTOS => {
			'table_or_tables' => 727
		}
	},
	{#State 93
		DEFAULT => -42
	},
	{#State 94
		DEFAULT => -89,
		GOTOS => {
			'clear_privileges' => 728
		}
	},
	{#State 95
		ACTIONS => {
			'TABLE_SYM' => 401,
			'TABLES' => 404
		},
		GOTOS => {
			'table_or_tables' => 729
		}
	},
	{#State 96
		ACTIONS => {
			'' => 730
		}
	},
	{#State 97
		ACTIONS => {
			'LOCAL_SYM' => 114,
			'NO_WRITE_TO_BINLOG' => 113
		},
		DEFAULT => -571,
		GOTOS => {
			'opt_no_write_to_binlog' => 731
		}
	},
	{#State 98
		DEFAULT => -6
	},
	{#State 99
		DEFAULT => -14
	},
	{#State 100
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 732
		}
	},
	{#State 101
		ACTIONS => {
			'TABLE_SYM' => 401,
			'TABLES' => 404
		},
		GOTOS => {
			'table_or_tables' => 733
		}
	},
	{#State 102
		DEFAULT => -29
	},
	{#State 103
		DEFAULT => -22
	},
	{#State 104
		DEFAULT => -1
	},
	{#State 105
		DEFAULT => -28
	},
	{#State 106
		DEFAULT => -1661
	},
	{#State 107
		ACTIONS => {
			'GLOBAL_SYM' => 735,
			'LOCAL_SYM' => 737,
			'ONE_SHOT_SYM' => 739,
			'SESSION_SYM' => 743
		},
		DEFAULT => -1669,
		GOTOS => {
			'ext_option_value' => 738,
			'option_type_value' => 734,
			'option_value_list' => 742,
			'sys_option_value' => 741,
			'option_type' => 740,
			'option_type2' => 736
		}
	},
	{#State 108
		DEFAULT => -1118
	},
	{#State 109
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'INTO' => 745,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 748,
			'insert_table' => 744,
			'ident' => 435,
			'keyword_sp' => 287,
			'insert2' => 747,
			'IDENT_sys' => 297,
			'table_name' => 746
		}
	},
	{#State 110
		DEFAULT => -1117
	},
	{#State 111
		DEFAULT => -1158
	},
	{#State 112
		ACTIONS => {
			'TABLES' => 761,
			'HOSTS_SYM' => 757,
			'STATUS_SYM' => 753,
			'QUERY_SYM' => 755,
			'SLAVE' => 760,
			'MASTER_SYM' => 752,
			'DES_KEY_FILE' => 759,
			'TABLE_SYM' => 401,
			'PRIVILEGES' => 751,
			'LOGS_SYM' => 756,
			'RESOURCES' => 749
		},
		GOTOS => {
			'table_or_tables' => 754,
			'flush_option' => 758,
			'flush_options' => 750
		}
	},
	{#State 113
		DEFAULT => -572
	},
	{#State 114
		DEFAULT => -573
	},
	{#State 115
		DEFAULT => -1816
	},
	{#State 116
		ACTIONS => {
			'AND_SYM' => 763
		},
		DEFAULT => -1817,
		GOTOS => {
			'opt_chain' => 762
		}
	},
	{#State 117
		DEFAULT => -1566
	},
	{#State 118
		DEFAULT => -1381
	},
	{#State 119
		DEFAULT => -1463
	},
	{#State 120
		DEFAULT => -1457
	},
	{#State 121
		DEFAULT => -1397
	},
	{#State 122
		DEFAULT => -1647
	},
	{#State 123
		DEFAULT => -1526
	},
	{#State 124
		DEFAULT => -1468
	},
	{#State 125
		DEFAULT => -1658
	},
	{#State 126
		DEFAULT => -1536
	},
	{#State 127
		DEFAULT => -1443
	},
	{#State 128
		DEFAULT => -1593
	},
	{#State 129
		DEFAULT => -1527
	},
	{#State 130
		DEFAULT => -1597
	},
	{#State 131
		DEFAULT => -1570
	},
	{#State 132
		DEFAULT => -1598
	},
	{#State 133
		DEFAULT => -1435
	},
	{#State 134
		DEFAULT => -1492
	},
	{#State 135
		DEFAULT => -1490
	},
	{#State 136
		DEFAULT => -1576
	},
	{#State 137
		DEFAULT => -1456
	},
	{#State 138
		DEFAULT => -1399
	},
	{#State 139
		DEFAULT => -1615
	},
	{#State 140
		DEFAULT => -1405
	},
	{#State 141
		DEFAULT => -1646
	},
	{#State 142
		DEFAULT => -1588
	},
	{#State 143
		DEFAULT => -1519
	},
	{#State 144
		DEFAULT => -1514
	},
	{#State 145
		DEFAULT => -1582
	},
	{#State 146
		DEFAULT => -1452
	},
	{#State 147
		DEFAULT => -1625
	},
	{#State 148
		DEFAULT => -1578
	},
	{#State 149
		DEFAULT => -1577
	},
	{#State 150
		DEFAULT => -1618
	},
	{#State 151
		DEFAULT => -1641
	},
	{#State 152
		DEFAULT => -1424
	},
	{#State 153
		DEFAULT => -1585
	},
	{#State 154
		DEFAULT => -1633
	},
	{#State 155
		DEFAULT => -1382
	},
	{#State 156
		DEFAULT => -1653
	},
	{#State 157
		DEFAULT => -1459
	},
	{#State 158
		DEFAULT => -1622
	},
	{#State 159
		DEFAULT => -1546
	},
	{#State 160
		DEFAULT => -1417
	},
	{#State 161
		DEFAULT => -1413
	},
	{#State 162
		DEFAULT => -1558
	},
	{#State 163
		DEFAULT => -1556
	},
	{#State 164
		DEFAULT => -1560
	},
	{#State 165
		DEFAULT => -1504
	},
	{#State 166
		DEFAULT => -1628
	},
	{#State 167
		DEFAULT => -1505
	},
	{#State 168
		DEFAULT => -1524
	},
	{#State 169
		DEFAULT => -1407
	},
	{#State 170
		DEFAULT => -1619
	},
	{#State 171
		DEFAULT => -1498
	},
	{#State 172
		DEFAULT => -1600
	},
	{#State 173
		DEFAULT => -1637
	},
	{#State 174
		DEFAULT => -1525
	},
	{#State 175
		DEFAULT => -1451
	},
	{#State 176
		DEFAULT => -1507
	},
	{#State 177
		DEFAULT => -1436
	},
	{#State 178
		DEFAULT => -1594
	},
	{#State 179
		DEFAULT => -1432
	},
	{#State 180
		DEFAULT => -1624
	},
	{#State 181
		DEFAULT => -1403
	},
	{#State 182
		DEFAULT => -1591
	},
	{#State 183
		DEFAULT => -1569
	},
	{#State 184
		DEFAULT => -1561
	},
	{#State 185
		DEFAULT => -1412
	},
	{#State 186
		DEFAULT => -1596
	},
	{#State 187
		DEFAULT => -1629
	},
	{#State 188
		DEFAULT => -1592
	},
	{#State 189
		DEFAULT => -1580
	},
	{#State 190
		DEFAULT => -1444
	},
	{#State 191
		DEFAULT => -1567
	},
	{#State 192
		DEFAULT => -1496
	},
	{#State 193
		DEFAULT => -1606
	},
	{#State 194
		DEFAULT => -1642
	},
	{#State 195
		DEFAULT => -1583
	},
	{#State 196
		DEFAULT => -1602
	},
	{#State 197
		DEFAULT => -1555
	},
	{#State 198
		DEFAULT => -1521
	},
	{#State 199
		DEFAULT => -1449
	},
	{#State 200
		DEFAULT => -1654
	},
	{#State 201
		DEFAULT => -1501
	},
	{#State 202
		DEFAULT => -1549
	},
	{#State 203
		DEFAULT => -1415
	},
	{#State 204
		DEFAULT => -1605
	},
	{#State 205
		DEFAULT => -1611
	},
	{#State 206
		DEFAULT => -1636
	},
	{#State 207
		DEFAULT => -1635
	},
	{#State 208
		DEFAULT => -1402
	},
	{#State 209
		DEFAULT => -1510
	},
	{#State 210
		DEFAULT => -1441
	},
	{#State 211
		DEFAULT => -1462
	},
	{#State 212
		DEFAULT => -1631
	},
	{#State 213
		DEFAULT => -1656
	},
	{#State 214
		DEFAULT => -1516
	},
	{#State 215
		DEFAULT => -1398
	},
	{#State 216
		DEFAULT => -1488
	},
	{#State 217
		DEFAULT => -1467
	},
	{#State 218
		DEFAULT => -1508
	},
	{#State 219
		DEFAULT => -1411
	},
	{#State 220
		DEFAULT => -1621
	},
	{#State 221
		DEFAULT => -1655
	},
	{#State 222
		DEFAULT => -1639
	},
	{#State 223
		DEFAULT => -1564
	},
	{#State 224
		DEFAULT => -1465
	},
	{#State 225
		DEFAULT => -1466
	},
	{#State 226
		DEFAULT => -1453
	},
	{#State 227
		DEFAULT => -1542
	},
	{#State 228
		DEFAULT => -1445
	},
	{#State 229
		DEFAULT => -1538
	},
	{#State 230
		DEFAULT => -1414
	},
	{#State 231
		DEFAULT => -1614
	},
	{#State 232
		DEFAULT => -1455
	},
	{#State 233
		DEFAULT => -1595
	},
	{#State 234
		DEFAULT => -1484
	},
	{#State 235
		DEFAULT => -1495
	},
	{#State 236
		DEFAULT => -1640
	},
	{#State 237
		DEFAULT => -1481
	},
	{#State 238
		DEFAULT => -1612
	},
	{#State 239
		DEFAULT => -1643
	},
	{#State 240
		DEFAULT => -1404
	},
	{#State 241
		DEFAULT => -1500
	},
	{#State 242
		DEFAULT => -1657
	},
	{#State 243
		DEFAULT => -1418
	},
	{#State 244
		DEFAULT => -1520
	},
	{#State 245
		DEFAULT => -1448
	},
	{#State 246
		DEFAULT => -1574
	},
	{#State 247
		DEFAULT => -1446
	},
	{#State 248
		DEFAULT => -1518
	},
	{#State 249
		DEFAULT => -1559
	},
	{#State 250
		DEFAULT => -1645
	},
	{#State 251
		DEFAULT => -1400
	},
	{#State 252
		DEFAULT => -1420
	},
	{#State 253
		DEFAULT => -1550
	},
	{#State 254
		DEFAULT => -1623
	},
	{#State 255
		DEFAULT => -1648
	},
	{#State 256
		DEFAULT => -1460
	},
	{#State 257
		DEFAULT => -1512
	},
	{#State 258
		DEFAULT => -1416
	},
	{#State 259
		DEFAULT => -1438
	},
	{#State 260
		DEFAULT => -1469
	},
	{#State 261
		DEFAULT => -1487
	},
	{#State 262
		DEFAULT => -1442
	},
	{#State 263
		DEFAULT => -1543
	},
	{#State 264
		DEFAULT => -1447
	},
	{#State 265
		DEFAULT => -1617
	},
	{#State 266
		DEFAULT => -1584
	},
	{#State 267
		DEFAULT => -1431
	},
	{#State 268
		DEFAULT => -1587
	},
	{#State 269
		DEFAULT => -1537
	},
	{#State 270
		DEFAULT => -1477
	},
	{#State 271
		DEFAULT => -1541
	},
	{#State 272
		DEFAULT => -1599
	},
	{#State 273
		DEFAULT => -1450
	},
	{#State 274
		DEFAULT => -1586
	},
	{#State 275
		DEFAULT => -1475
	},
	{#State 276
		DEFAULT => -1575
	},
	{#State 277
		DEFAULT => -1568
	},
	{#State 278
		DEFAULT => -1419
	},
	{#State 279
		DEFAULT => -1531
	},
	{#State 280
		DEFAULT => -1547
	},
	{#State 281
		DEFAULT => -1604
	},
	{#State 282
		DEFAULT => -1422
	},
	{#State 283
		DEFAULT => -1565
	},
	{#State 284
		DEFAULT => -1572
	},
	{#State 285
		DEFAULT => -1491
	},
	{#State 286
		DEFAULT => -1410
	},
	{#State 287
		DEFAULT => -1396
	},
	{#State 288
		DEFAULT => -1434
	},
	{#State 289
		DEFAULT => -1464
	},
	{#State 290
		DEFAULT => -1522
	},
	{#State 291
		DEFAULT => -1528
	},
	{#State 292
		DEFAULT => -1489
	},
	{#State 293
		DEFAULT => -1461
	},
	{#State 294
		DEFAULT => -1557
	},
	{#State 295
		DEFAULT => -1437
	},
	{#State 296
		DEFAULT => -1513
	},
	{#State 297
		DEFAULT => -1386
	},
	{#State 298
		DEFAULT => -1579
	},
	{#State 299
		DEFAULT => -1548
	},
	{#State 300
		DEFAULT => -1517
	},
	{#State 301
		DEFAULT => -1539
	},
	{#State 302
		DEFAULT => -1545
	},
	{#State 303
		DEFAULT => -1472
	},
	{#State 304
		DEFAULT => -1554
	},
	{#State 305
		DEFAULT => -1503
	},
	{#State 306
		DEFAULT => -1603
	},
	{#State 307
		DEFAULT => -1476
	},
	{#State 308
		DEFAULT => -1571
	},
	{#State 309
		DEFAULT => -1515
	},
	{#State 310
		DEFAULT => -1506
	},
	{#State 311
		ACTIONS => {
			"(" => 764
		},
		DEFAULT => -111,
		GOTOS => {
			'opt_sp_cparam_list' => 765
		}
	},
	{#State 312
		DEFAULT => -1483
	},
	{#State 313
		DEFAULT => -1470
	},
	{#State 314
		DEFAULT => -1581
	},
	{#State 315
		DEFAULT => -1627
	},
	{#State 316
		DEFAULT => -1439
	},
	{#State 317
		DEFAULT => -1529
	},
	{#State 318
		DEFAULT => -1535
	},
	{#State 319
		DEFAULT => -1406
	},
	{#State 320
		DEFAULT => -1620
	},
	{#State 321
		DEFAULT => -1562
	},
	{#State 322
		DEFAULT => -1540
	},
	{#State 323
		DEFAULT => -1563
	},
	{#State 324
		DEFAULT => -1486
	},
	{#State 325
		DEFAULT => -1493
	},
	{#State 326
		ACTIONS => {
			"." => 766
		},
		DEFAULT => -91
	},
	{#State 327
		DEFAULT => -1523
	},
	{#State 328
		DEFAULT => -1544
	},
	{#State 329
		DEFAULT => -1589
	},
	{#State 330
		DEFAULT => -1553
	},
	{#State 331
		DEFAULT => -1651
	},
	{#State 332
		DEFAULT => -1387
	},
	{#State 333
		DEFAULT => -1534
	},
	{#State 334
		DEFAULT => -1573
	},
	{#State 335
		DEFAULT => -1590
	},
	{#State 336
		DEFAULT => -1626
	},
	{#State 337
		DEFAULT => -1429
	},
	{#State 338
		DEFAULT => -1482
	},
	{#State 339
		DEFAULT => -1423
	},
	{#State 340
		DEFAULT => -1632
	},
	{#State 341
		DEFAULT => -1454
	},
	{#State 342
		DEFAULT => -1511
	},
	{#State 343
		DEFAULT => -1616
	},
	{#State 344
		DEFAULT => -1480
	},
	{#State 345
		DEFAULT => -1601
	},
	{#State 346
		DEFAULT => -1408
	},
	{#State 347
		DEFAULT => -1497
	},
	{#State 348
		DEFAULT => -1401
	},
	{#State 349
		DEFAULT => -1532
	},
	{#State 350
		DEFAULT => -1502
	},
	{#State 351
		DEFAULT => -1607
	},
	{#State 352
		DEFAULT => -1608
	},
	{#State 353
		DEFAULT => -1533
	},
	{#State 354
		DEFAULT => -1509
	},
	{#State 355
		DEFAULT => -1428
	},
	{#State 356
		DEFAULT => -1499
	},
	{#State 357
		DEFAULT => -1440
	},
	{#State 358
		DEFAULT => -1478
	},
	{#State 359
		DEFAULT => -1473
	},
	{#State 360
		DEFAULT => -1634
	},
	{#State 361
		DEFAULT => -1638
	},
	{#State 362
		DEFAULT => -1649
	},
	{#State 363
		DEFAULT => -1474
	},
	{#State 364
		DEFAULT => -1458
	},
	{#State 365
		DEFAULT => -1409
	},
	{#State 366
		DEFAULT => -1652
	},
	{#State 367
		DEFAULT => -1433
	},
	{#State 368
		DEFAULT => -1610
	},
	{#State 369
		DEFAULT => -1530
	},
	{#State 370
		DEFAULT => -1609
	},
	{#State 371
		DEFAULT => -1427
	},
	{#State 372
		DEFAULT => -1479
	},
	{#State 373
		DEFAULT => -1552
	},
	{#State 374
		DEFAULT => -1650
	},
	{#State 375
		DEFAULT => -1426
	},
	{#State 376
		DEFAULT => -1430
	},
	{#State 377
		DEFAULT => -1421
	},
	{#State 378
		DEFAULT => -1494
	},
	{#State 379
		DEFAULT => -1644
	},
	{#State 380
		DEFAULT => -1630
	},
	{#State 381
		DEFAULT => -1425
	},
	{#State 382
		DEFAULT => -1613
	},
	{#State 383
		DEFAULT => -1551
	},
	{#State 384
		DEFAULT => -1485
	},
	{#State 385
		DEFAULT => -1471
	},
	{#State 386
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 767
		}
	},
	{#State 387
		ACTIONS => {
			'IF' => 768
		},
		DEFAULT => -1107,
		GOTOS => {
			'if_exists' => 769
		}
	},
	{#State 388
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 770
		}
	},
	{#State 389
		ACTIONS => {
			'IF' => 768
		},
		DEFAULT => -1107,
		GOTOS => {
			'if_exists' => 771
		}
	},
	{#State 390
		DEFAULT => -1110
	},
	{#State 391
		DEFAULT => -89,
		GOTOS => {
			'clear_privileges' => 772
		}
	},
	{#State 392
		ACTIONS => {
			'IF' => 768
		},
		DEFAULT => -1107,
		GOTOS => {
			'if_exists' => 773
		}
	},
	{#State 393
		ACTIONS => {
			'IF' => 768
		},
		DEFAULT => -1107,
		GOTOS => {
			'if_exists' => 774
		}
	},
	{#State 394
		ACTIONS => {
			'TABLE_SYM' => 401,
			'TABLES' => 404
		},
		GOTOS => {
			'table_or_tables' => 775
		}
	},
	{#State 395
		ACTIONS => {
			'IF' => 768
		},
		DEFAULT => -1107,
		GOTOS => {
			'if_exists' => 776
		}
	},
	{#State 396
		DEFAULT => -1283
	},
	{#State 397
		DEFAULT => -1285
	},
	{#State 398
		ACTIONS => {
			"," => 777
		},
		DEFAULT => -1281
	},
	{#State 399
		ACTIONS => {
			'CACHE_SYM' => 778
		}
	},
	{#State 400
		DEFAULT => -1284
	},
	{#State 401
		DEFAULT => -1706
	},
	{#State 402
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 781,
			'IDENT_sys' => 297,
			'table_to_table' => 780,
			'table_to_table_list' => 779,
			'ident' => 435
		}
	},
	{#State 403
		DEFAULT => -89,
		GOTOS => {
			'clear_privileges' => 782
		}
	},
	{#State 404
		DEFAULT => -1707
	},
	{#State 405
		DEFAULT => -1862
	},
	{#State 406
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 783,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 407
		ACTIONS => {
			'TABLE_SYM' => 784
		}
	},
	{#State 408
		DEFAULT => -516
	},
	{#State 409
		ACTIONS => {
			'EQ' => 785
		}
	},
	{#State 410
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -487,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident_or_empty' => 786,
			'ident' => 787
		}
	},
	{#State 411
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 788,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 412
		ACTIONS => {
			'DEFINER_SYM' => 454
		},
		DEFAULT => -1852,
		GOTOS => {
			'definer' => 789
		}
	},
	{#State 413
		DEFAULT => -1176
	},
	{#State 414
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'IDENT_sys' => 297,
			'table_name' => 790,
			'ident' => 435
		}
	},
	{#State 415
		DEFAULT => -1828
	},
	{#State 416
		DEFAULT => -1293
	},
	{#State 417
		DEFAULT => -1294
	},
	{#State 418
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 791,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 419
		DEFAULT => -2
	},
	{#State 420
		ACTIONS => {
			'IGNORE_SYM' => 408
		},
		DEFAULT => -515,
		GOTOS => {
			'opt_ignore' => 792
		}
	},
	{#State 421
		DEFAULT => -1814
	},
	{#State 422
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 793
		}
	},
	{#State 423
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 796,
			'IDENT_sys' => 297,
			'keycache_list' => 794,
			'ident' => 435,
			'assign_to_keycache' => 795
		}
	},
	{#State 424
		DEFAULT => -1890
	},
	{#State 425
		DEFAULT => -1886
	},
	{#State 426
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 799,
			'TEXT_STRING_literal' => 801,
			'xid' => 797
		}
	},
	{#State 427
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 799,
			'TEXT_STRING_literal' => 801,
			'xid' => 802
		}
	},
	{#State 428
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 799,
			'TEXT_STRING_literal' => 801,
			'xid' => 803
		}
	},
	{#State 429
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 799,
			'TEXT_STRING_literal' => 801,
			'xid' => 804
		}
	},
	{#State 430
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 799,
			'TEXT_STRING_literal' => 801,
			'xid' => 805
		}
	},
	{#State 431
		DEFAULT => -1891
	},
	{#State 432
		ACTIONS => {
			"(" => 70,
			'SELECT_SYM' => 81
		},
		GOTOS => {
			'select' => 806,
			'select_init' => 69
		}
	},
	{#State 433
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 798,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 554,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 800,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -1262,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'text_string' => 808,
			'IDENT_sys' => 297,
			'TEXT_STRING_literal' => 801,
			'opt_describe_column' => 807,
			'ident' => 809
		}
	},
	{#State 434
		ACTIONS => {
			"(" => -1261,
			'SELECT_SYM' => -1261
		},
		DEFAULT => -1486
	},
	{#State 435
		ACTIONS => {
			"." => 810
		},
		DEFAULT => -1377
	},
	{#State 436
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 811
		}
	},
	{#State 437
		ACTIONS => {
			'SQL_THREAD' => 815,
			'RELAY_THREAD' => 814
		},
		DEFAULT => -537,
		GOTOS => {
			'slave_thread_opt' => 816,
			'slave_thread_opt_list' => 812,
			'slave_thread_opts' => 813
		}
	},
	{#State 438
		ACTIONS => {
			'INDEX_SYM' => 817
		}
	},
	{#State 439
		DEFAULT => -1856
	},
	{#State 440
		DEFAULT => -224
	},
	{#State 441
		DEFAULT => -464
	},
	{#State 442
		ACTIONS => {
			'TEMPORARY' => 448
		},
		DEFAULT => -225,
		GOTOS => {
			'table_options' => 818,
			'table_option' => 442
		}
	},
	{#State 443
		ACTIONS => {
			'REPLACE' => 819
		}
	},
	{#State 444
		ACTIONS => {
			'TABLE_SYM' => 820
		}
	},
	{#State 445
		ACTIONS => {
			'ALGORITHM_SYM' => 409
		},
		DEFAULT => -1854,
		GOTOS => {
			'view_algorithm' => 821
		}
	},
	{#State 446
		DEFAULT => -87
	},
	{#State 447
		ACTIONS => {
			'DEFINER_SYM' => 454
		},
		DEFAULT => -1852,
		GOTOS => {
			'definer' => 822
		}
	},
	{#State 448
		DEFAULT => -227
	},
	{#State 449
		DEFAULT => -465
	},
	{#State 450
		DEFAULT => -463
	},
	{#State 451
		DEFAULT => -89,
		GOTOS => {
			'clear_privileges' => 823
		}
	},
	{#State 452
		ACTIONS => {
			'AGGREGATE_SYM' => 830,
			'VIEW_SYM' => -1863,
			'SQL_SYM' => 833,
			'PROCEDURE' => 826,
			'TRIGGER_SYM' => 824
		},
		DEFAULT => -277,
		GOTOS => {
			'view_or_trigger_or_sp_tail' => 831,
			'view_suid' => 829,
			'sp_tail' => 832,
			'udf_func_type' => 827,
			'view_tail' => 828,
			'trigger_tail' => 825
		}
	},
	{#State 453
		ACTIONS => {
			'IF' => 835
		},
		DEFAULT => -228,
		GOTOS => {
			'opt_if_not_exists' => 834
		}
	},
	{#State 454
		ACTIONS => {
			'EQ' => 836
		}
	},
	{#State 455
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'table_list' => 838,
			'IDENT_sys' => 297,
			'table_name' => 837,
			'ident' => 435
		}
	},
	{#State 456
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'table_list' => 839,
			'IDENT_sys' => 297,
			'table_name' => 837,
			'ident' => 435
		}
	},
	{#State 457
		ACTIONS => {
			'DELETE_SYM' => 863,
			'SUPER_SYM' => 861,
			'GRANT' => 848,
			'UPDATE_SYM' => 843,
			'SELECT_SYM' => 857,
			'PROCESS' => 856,
			'INSERT' => 846,
			'RELOAD' => 851,
			'SHOW' => 854,
			'EXECUTE_SYM' => 849,
			'ALL' => 855,
			'DROP' => 840,
			'INDEX_SYM' => 841,
			'REFERENCES' => 862,
			'FILE_SYM' => 859,
			'ALTER' => 860,
			'SHUTDOWN' => 864,
			'CREATE' => 853,
			'REPLICATION' => 842,
			'USAGE' => 858,
			'LOCK_SYM' => 845
		},
		GOTOS => {
			'object_privilege' => 850,
			'grant_privileges' => 844,
			'object_privilege_list' => 852,
			'grant_command' => 847
		}
	},
	{#State 458
		ACTIONS => {
			'TABLE_SYM' => 401,
			'TABLES' => 404
		},
		GOTOS => {
			'table_or_tables' => 865
		}
	},
	{#State 459
		ACTIONS => {
			'TABLE_SYM' => 401,
			'TABLES' => 404
		},
		GOTOS => {
			'table_or_tables' => 866
		}
	},
	{#State 460
		DEFAULT => -1240
	},
	{#State 461
		DEFAULT => -1239
	},
	{#State 462
		ACTIONS => {
			'LOGS_SYM' => 867
		}
	},
	{#State 463
		DEFAULT => -1287
	},
	{#State 464
		ACTIONS => {
			'READ_SYM' => 868,
			'CLOSE_SYM' => 869
		}
	},
	{#State 465
		ACTIONS => {
			'OPEN_SYM' => 870
		}
	},
	{#State 466
		ACTIONS => {
			"." => 810,
			'OPEN_SYM' => -1377
		},
		DEFAULT => -1380
	},
	{#State 467
		ACTIONS => {
			'TO_SYM' => 871
		}
	},
	{#State 468
		ACTIONS => {
			'TO_SYM' => 872,
			'AND_SYM' => 763
		},
		DEFAULT => -1817,
		GOTOS => {
			'opt_chain' => 873
		}
	},
	{#State 469
		ACTIONS => {
			"(" => 874
		}
	},
	{#State 470
		ACTIONS => {
			'STATUS_SYM' => 875,
			'VARIABLES' => 876
		}
	},
	{#State 471
		DEFAULT => -460
	},
	{#State 472
		ACTIONS => {
			'LOGS_SYM' => 877
		}
	},
	{#State 473
		ACTIONS => {
			'SET' => 878
		}
	},
	{#State 474
		DEFAULT => -1246
	},
	{#State 475
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 880
		}
	},
	{#State 476
		DEFAULT => -1213
	},
	{#State 477
		DEFAULT => -1208
	},
	{#State 478
		DEFAULT => -1242
	},
	{#State 479
		ACTIONS => {
			'TABLES' => 882
		}
	},
	{#State 480
		ACTIONS => {
			'STATUS_SYM' => 883
		}
	},
	{#State 481
		ACTIONS => {
			'TRIGGERS_SYM' => 886,
			'TABLES' => 887,
			'COLUMNS' => 884,
			'PROCESSLIST_SYM' => 885
		}
	},
	{#State 482
		ACTIONS => {
			'STATUS_SYM' => 888
		},
		DEFAULT => -1239
	},
	{#State 483
		ACTIONS => {
			'CODE_SYM' => 890,
			'STATUS_SYM' => 889
		}
	},
	{#State 484
		ACTIONS => {
			'FROM' => 892,
			'IN_SYM' => 893
		},
		GOTOS => {
			'from_or_in' => 891
		}
	},
	{#State 485
		ACTIONS => {
			'ENGINES_SYM' => 894
		}
	},
	{#State 486
		ACTIONS => {
			'EVENTS_SYM' => 895
		}
	},
	{#State 487
		ACTIONS => {
			'LOGS_SYM' => 896
		}
	},
	{#State 488
		DEFAULT => -1672
	},
	{#State 489
		ACTIONS => {
			'LIMIT' => 899
		},
		DEFAULT => -1054,
		GOTOS => {
			'opt_limit_clause_init' => 897,
			'limit_clause' => 898
		}
	},
	{#State 490
		DEFAULT => -399
	},
	{#State 491
		DEFAULT => -1192
	},
	{#State 492
		DEFAULT => -461
	},
	{#State 493
		ACTIONS => {
			'TYPES_SYM' => 900
		}
	},
	{#State 494
		ACTIONS => {
			'FOR_SYM' => 901
		},
		DEFAULT => -1224
	},
	{#State 495
		DEFAULT => -1673
	},
	{#State 496
		ACTIONS => {
			'STATUS_SYM' => 903,
			'TYPES_SYM' => 902
		}
	},
	{#State 497
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 904
		}
	},
	{#State 498
		ACTIONS => {
			'FUNCTION_SYM' => 909,
			'DATABASE' => 908,
			'TABLE_SYM' => 906,
			'VIEW_SYM' => 907,
			'PROCEDURE' => 905
		}
	},
	{#State 499
		DEFAULT => -1223
	},
	{#State 500
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 910
		}
	},
	{#State 501
		ACTIONS => {
			'ALL' => 917,
			'SWAPS_SYM' => 912,
			'BLOCK_SYM' => 914,
			'CPU_SYM' => 913,
			'SOURCE_SYM' => 922,
			'MEMORY_SYM' => 920,
			'CONTEXT_SYM' => 918,
			'PAGE_SYM' => 919,
			'IPC_SYM' => 911
		},
		DEFAULT => -1177,
		GOTOS => {
			'profile_def' => 916,
			'profile_defs' => 915,
			'opt_profile_defs' => 921
		}
	},
	{#State 502
		ACTIONS => {
			'MASTER_SYM' => 923
		}
	},
	{#State 503
		ACTIONS => {
			'LIMIT' => 899
		},
		DEFAULT => -1054,
		GOTOS => {
			'opt_limit_clause_init' => 924,
			'limit_clause' => 898
		}
	},
	{#State 504
		ACTIONS => {
			'STATUS_SYM' => 925
		}
	},
	{#State 505
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 927,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'storage_engines' => 926,
			'ident' => 706
		}
	},
	{#State 506
		DEFAULT => -459
	},
	{#State 507
		DEFAULT => -1674
	},
	{#State 508
		ACTIONS => {
			'HOSTS_SYM' => 929,
			'STATUS_SYM' => 928
		}
	},
	{#State 509
		ACTIONS => {
			'CODE_SYM' => 931,
			'STATUS_SYM' => 930
		}
	},
	{#State 510
		ACTIONS => {
			'USING' => 933
		},
		DEFAULT => -59,
		GOTOS => {
			'execute_using' => 932
		}
	},
	{#State 511
		DEFAULT => -1295
	},
	{#State 512
		ACTIONS => {
			"(" => 934
		}
	},
	{#State 513
		ACTIONS => {
			"(" => 935
		}
	},
	{#State 514
		ACTIONS => {
			"(" => 936
		}
	},
	{#State 515
		ACTIONS => {
			"(" => 937
		}
	},
	{#State 516
		ACTIONS => {
			"(" => 938
		}
	},
	{#State 517
		ACTIONS => {
			"(" => 939
		},
		DEFAULT => -1397
	},
	{#State 518
		ACTIONS => {
			"(" => 940
		}
	},
	{#State 519
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'bool_factor' => 941,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 520
		ACTIONS => {
			'XOR' => 943
		},
		DEFAULT => -643,
		GOTOS => {
			'bool_or_expr' => 942
		}
	},
	{#State 521
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 944,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'geometry_function' => 685
		}
	},
	{#State 522
		ACTIONS => {
			"(" => 945
		},
		DEFAULT => -1658
	},
	{#State 523
		ACTIONS => {
			"(" => 946
		}
	},
	{#State 524
		ACTIONS => {
			"(" => 947
		}
	},
	{#State 525
		ACTIONS => {
			'TEXT_STRING' => 554
		},
		DEFAULT => -1344,
		GOTOS => {
			'TEXT_STRING_literal' => 948
		}
	},
	{#State 526
		ACTIONS => {
			"(" => 949
		}
	},
	{#State 527
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 950,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'geometry_function' => 685
		}
	},
	{#State 528
		ACTIONS => {
			"(" => 951
		}
	},
	{#State 529
		ACTIONS => {
			"(" => 952
		},
		DEFAULT => -1576
	},
	{#State 530
		ACTIONS => {
			"(" => 953
		},
		DEFAULT => -1456
	},
	{#State 531
		DEFAULT => -715
	},
	{#State 532
		DEFAULT => -1095
	},
	{#State 533
		ACTIONS => {
			"(" => 954
		},
		DEFAULT => -1519
	},
	{#State 534
		ACTIONS => {
			"(" => 955
		}
	},
	{#State 535
		ACTIONS => {
			"(" => 956
		}
	},
	{#State 536
		ACTIONS => {
			"(" => 957
		}
	},
	{#State 537
		ACTIONS => {
			"(" => 958
		}
	},
	{#State 538
		ACTIONS => {
			'SHIFT_LEFT' => 959,
			'SHIFT_RIGHT' => 960
		},
		DEFAULT => -681
	},
	{#State 539
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 961,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'geometry_function' => 685
		}
	},
	{#State 540
		ACTIONS => {
			"(" => 962
		},
		DEFAULT => -640,
		GOTOS => {
			'optional_braces' => 963
		}
	},
	{#State 541
		ACTIONS => {
			"(" => 964
		},
		DEFAULT => -1546
	},
	{#State 542
		ACTIONS => {
			"(" => 965
		}
	},
	{#State 543
		ACTIONS => {
			"(" => 962
		},
		DEFAULT => -640,
		GOTOS => {
			'optional_braces' => 966
		}
	},
	{#State 544
		ACTIONS => {
			"(" => 967
		},
		DEFAULT => -1504
	},
	{#State 545
		ACTIONS => {
			'TEXT_STRING' => 969,
			'BIN_NUM' => 970,
			'HEX_NUM' => 968
		}
	},
	{#State 546
		ACTIONS => {
			"(" => 971
		}
	},
	{#State 547
		ACTIONS => {
			"(" => 972
		},
		DEFAULT => -1407
	},
	{#State 548
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 973,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 976,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 974,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'subselect' => 975,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 549
		ACTIONS => {
			"(" => 977
		}
	},
	{#State 550
		ACTIONS => {
			"(" => 978
		},
		DEFAULT => -1498
	},
	{#State 551
		DEFAULT => -1349
	},
	{#State 552
		ACTIONS => {
			'UNDERSCORE_CHARSET' => 980,
			"(" => 981,
			'TEXT_STRING' => 554,
			'NCHAR_STRING' => 652
		},
		DEFAULT => -1637,
		GOTOS => {
			'text_literal' => 979,
			'TEXT_STRING_literal' => 653
		}
	},
	{#State 553
		ACTIONS => {
			"^" => 982
		},
		DEFAULT => -695
	},
	{#State 554
		DEFAULT => -1384
	},
	{#State 555
		ACTIONS => {
			"(" => 983
		}
	},
	{#State 556
		DEFAULT => -647,
		GOTOS => {
			'bool_and_expr' => 984
		}
	},
	{#State 557
		ACTIONS => {
			"(" => 985
		}
	},
	{#State 558
		ACTIONS => {
			"(" => 986
		}
	},
	{#State 559
		ACTIONS => {
			"(" => 987
		}
	},
	{#State 560
		ACTIONS => {
			'OR_OR_SYM' => 988,
			'COLLATE_SYM' => 989
		},
		DEFAULT => -697
	},
	{#State 561
		ACTIONS => {
			"(" => 990
		}
	},
	{#State 562
		ACTIONS => {
			"(" => 991
		},
		DEFAULT => -1624
	},
	{#State 563
		DEFAULT => -1357
	},
	{#State 564
		ACTIONS => {
			"&" => 992
		},
		DEFAULT => -679
	},
	{#State 565
		ACTIONS => {
			"(" => 993
		},
		DEFAULT => -640,
		GOTOS => {
			'optional_braces' => 994
		}
	},
	{#State 566
		DEFAULT => -718
	},
	{#State 567
		ACTIONS => {
			"(" => 995
		}
	},
	{#State 568
		DEFAULT => -704
	},
	{#State 569
		DEFAULT => -1346
	},
	{#State 570
		ACTIONS => {
			"(" => 996
		}
	},
	{#State 571
		ACTIONS => {
			"(" => 997
		}
	},
	{#State 572
		DEFAULT => -650
	},
	{#State 573
		ACTIONS => {
			"(" => 998
		},
		DEFAULT => -1567
	},
	{#State 574
		ACTIONS => {
			"(" => 999
		}
	},
	{#State 575
		ACTIONS => {
			"(" => 1000
		},
		DEFAULT => -1583
	},
	{#State 576
		ACTIONS => {
			"(" => 1001
		}
	},
	{#State 577
		ACTIONS => {
			"(" => 1002
		}
	},
	{#State 578
		ACTIONS => {
			"(" => 1003
		},
		DEFAULT => -1555
	},
	{#State 579
		ACTIONS => {
			"(" => 1004
		}
	},
	{#State 580
		ACTIONS => {
			"(" => 1005
		}
	},
	{#State 581
		ACTIONS => {
			"(" => 1006
		}
	},
	{#State 582
		ACTIONS => {
			"(" => 1007
		},
		DEFAULT => -1605
	},
	{#State 583
		ACTIONS => {
			"(" => 1008
		}
	},
	{#State 584
		ACTIONS => {
			"(" => 1009
		},
		DEFAULT => -1402
	},
	{#State 585
		ACTIONS => {
			'NOT_SYM' => 1010,
			'REGEXP' => 1011,
			'SOUNDS_SYM' => 1012,
			"|" => 1013,
			'BETWEEN_SYM' => 1014,
			'LIKE' => 1015,
			'NOT2_SYM' => 1017,
			'IN_SYM' => 1018
		},
		DEFAULT => -677,
		GOTOS => {
			'not' => 1016
		}
	},
	{#State 586
		DEFAULT => -1367
	},
	{#State 587
		ACTIONS => {
			"(" => 1019
		}
	},
	{#State 588
		ACTIONS => {
			"(" => 1020
		}
	},
	{#State 589
		ACTIONS => {
			"(" => 1021
		}
	},
	{#State 590
		DEFAULT => -1356
	},
	{#State 591
		ACTIONS => {
			"(" => 1022
		}
	},
	{#State 592
		ACTIONS => {
			"(" => 1023
		}
	},
	{#State 593
		ACTIONS => {
			"(" => 1024
		}
	},
	{#State 594
		ACTIONS => {
			"(" => 1025
		}
	},
	{#State 595
		DEFAULT => -1348
	},
	{#State 596
		ACTIONS => {
			"(" => 1026
		},
		DEFAULT => -1655
	},
	{#State 597
		ACTIONS => {
			"(" => 1027
		},
		DEFAULT => -1639
	},
	{#State 598
		ACTIONS => {
			'YEAR_SYM' => 1028,
			'MINUTE_MICROSECOND_SYM' => 1030,
			'MICROSECOND_SYM' => 1031,
			'MINUTE_SECOND_SYM' => 1032,
			'HOUR_SYM' => 1033,
			'DAY_MICROSECOND_SYM' => 1034,
			'HOUR_SECOND_SYM' => 1035,
			'FRAC_SECOND_SYM' => 1036,
			'QUARTER_SYM' => 1037,
			'HOUR_MINUTE_SYM' => 1038,
			'YEAR_MONTH_SYM' => 1039,
			'WEEK_SYM' => 1040,
			'SECOND_MICROSECOND_SYM' => 1041,
			'DAY_MINUTE_SYM' => 1042,
			'MINUTE_SYM' => 1043,
			'DAY_HOUR_SYM' => 1044,
			'DAY_SYM' => 1045,
			'DAY_SECOND_SYM' => 1046,
			'SECOND_SYM' => 1047,
			'MONTH_SYM' => 1049,
			'HOUR_MICROSECOND_SYM' => 1050
		},
		DEFAULT => -790,
		GOTOS => {
			'interval_time_st' => 1029,
			'interval' => 1048
		}
	},
	{#State 599
		ACTIONS => {
			"(" => 1051
		}
	},
	{#State 600
		ACTIONS => {
			"," => 1052
		},
		DEFAULT => -938
	},
	{#State 601
		ACTIONS => {
			"/" => 1053,
			'DIV_SYM' => 1054,
			'MOD_SYM' => 1055,
			"%" => 1056,
			"*" => 1057
		},
		DEFAULT => -689
	},
	{#State 602
		DEFAULT => -1360
	},
	{#State 603
		DEFAULT => -939
	},
	{#State 604
		ACTIONS => {
			'UNDERSCORE_CHARSET' => 980,
			"(" => 1059,
			'TEXT_STRING' => 554,
			'NCHAR_STRING' => 652
		},
		DEFAULT => -1640,
		GOTOS => {
			'text_literal' => 1058,
			'TEXT_STRING_literal' => 653
		}
	},
	{#State 605
		ACTIONS => {
			"(" => 1060
		}
	},
	{#State 606
		DEFAULT => -1340
	},
	{#State 607
		ACTIONS => {
			"(" => 1061
		}
	},
	{#State 608
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 1062,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'geometry_function' => 685
		}
	},
	{#State 609
		ACTIONS => {
			"(" => 1063
		}
	},
	{#State 610
		ACTIONS => {
			"(" => 1064
		}
	},
	{#State 611
		DEFAULT => -1350
	},
	{#State 612
		ACTIONS => {
			"(" => 1065
		}
	},
	{#State 613
		ACTIONS => {
			"(" => 1066
		},
		DEFAULT => -640,
		GOTOS => {
			'optional_braces' => 1067
		}
	},
	{#State 614
		ACTIONS => {
			"(" => 1068
		}
	},
	{#State 615
		ACTIONS => {
			"(" => 1069
		}
	},
	{#State 616
		DEFAULT => -719
	},
	{#State 617
		ACTIONS => {
			"(" => 1070
		}
	},
	{#State 618
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1071,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 619
		ACTIONS => {
			'UNDERSCORE_CHARSET' => 980,
			"(" => 1073,
			'TEXT_STRING' => 554,
			'NCHAR_STRING' => 652
		},
		DEFAULT => -1469,
		GOTOS => {
			'text_literal' => 1072,
			'TEXT_STRING_literal' => 653
		}
	},
	{#State 620
		ACTIONS => {
			"(" => 1074
		},
		DEFAULT => -1442
	},
	{#State 621
		ACTIONS => {
			"(" => 1075
		}
	},
	{#State 622
		DEFAULT => -1347
	},
	{#State 623
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1077,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_list2' => 1079,
			'ident_list_arg' => 1078,
			'ident_list' => 1081,
			'ident' => 1080,
			'simple_ident_q' => 586,
			'keyword_sp' => 287,
			'simple_ident' => 1076,
			'IDENT_sys' => 297
		}
	},
	{#State 624
		ACTIONS => {
			"(" => 1082
		}
	},
	{#State 625
		ACTIONS => {
			"(" => 1083
		}
	},
	{#State 626
		ACTIONS => {
			"(" => 1084
		}
	},
	{#State 627
		ACTIONS => {
			"(" => 1085
		}
	},
	{#State 628
		ACTIONS => {
			"(" => 1086
		}
	},
	{#State 629
		DEFAULT => -1358
	},
	{#State 630
		ACTIONS => {
			"(" => 1087
		},
		DEFAULT => -1575
	},
	{#State 631
		DEFAULT => -717
	},
	{#State 632
		ACTIONS => {
			"(" => 962
		},
		DEFAULT => -640,
		GOTOS => {
			'optional_braces' => 1088
		}
	},
	{#State 633
		ACTIONS => {
			"(" => 1089
		}
	},
	{#State 634
		ACTIONS => {
			"(" => 1090
		}
	},
	{#State 635
		DEFAULT => -720
	},
	{#State 636
		ACTIONS => {
			"(" => 1091
		}
	},
	{#State 637
		ACTIONS => {
			"(" => 1092
		}
	},
	{#State 638
		ACTIONS => {
			"(" => 1093
		},
		DEFAULT => -1434
	},
	{#State 639
		ACTIONS => {
			"+" => 1094,
			"-" => 1095
		},
		DEFAULT => -684
	},
	{#State 640
		ACTIONS => {
			"(" => 1096
		}
	},
	{#State 641
		ACTIONS => {
			"(" => 962
		},
		DEFAULT => -640,
		GOTOS => {
			'optional_braces' => 1097
		}
	},
	{#State 642
		ACTIONS => {
			"(" => 1098
		}
	},
	{#State 643
		ACTIONS => {
			"(" => 1099
		},
		DEFAULT => -1386
	},
	{#State 644
		DEFAULT => -663
	},
	{#State 645
		ACTIONS => {
			"(" => 1100
		},
		DEFAULT => -1548
	},
	{#State 646
		ACTIONS => {
			"(" => 1101
		}
	},
	{#State 647
		ACTIONS => {
			"(" => 1102
		},
		DEFAULT => -1554
	},
	{#State 648
		ACTIONS => {
			'LE' => 1103,
			'EQUAL_SYM' => 1104,
			'EQ' => 1105,
			'LT' => 1106,
			'NE' => 1108,
			'GE' => 1109,
			'GT_SYM' => 1110,
			'IS' => 1111
		},
		DEFAULT => -657,
		GOTOS => {
			'comp_op' => 1107
		}
	},
	{#State 649
		ACTIONS => {
			"(" => 1112
		}
	},
	{#State 650
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			"\@" => 1115,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1114,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'variable_aux' => 1113,
			'ident' => 706
		}
	},
	{#State 651
		ACTIONS => {
			"(" => 1116
		},
		DEFAULT => -1470
	},
	{#State 652
		DEFAULT => -1334
	},
	{#State 653
		DEFAULT => -1333
	},
	{#State 654
		ACTIONS => {
			"(" => 1117
		}
	},
	{#State 655
		ACTIONS => {
			"(" => 1118
		}
	},
	{#State 656
		ACTIONS => {
			"." => 1119
		},
		DEFAULT => -1366
	},
	{#State 657
		ACTIONS => {
			"(" => 1120
		}
	},
	{#State 658
		ACTIONS => {
			"(" => 1121
		}
	},
	{#State 659
		ACTIONS => {
			"(" => 1122
		},
		DEFAULT => -1553
	},
	{#State 660
		ACTIONS => {
			"(" => 1123
		}
	},
	{#State 661
		ACTIONS => {
			"(" => 1124
		},
		DEFAULT => -1573
	},
	{#State 662
		ACTIONS => {
			"(" => 1125
		},
		DEFAULT => -1429
	},
	{#State 663
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1126
		}
	},
	{#State 664
		ACTIONS => {
			"(" => 1127
		},
		DEFAULT => -1607
	},
	{#State 665
		ACTIONS => {
			"(" => 1128
		}
	},
	{#State 666
		ACTIONS => {
			"(" => 1129
		},
		DEFAULT => -1499
	},
	{#State 667
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 1130,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'geometry_function' => 685
		}
	},
	{#State 668
		DEFAULT => -1359
	},
	{#State 669
		ACTIONS => {
			"(" => 1131
		}
	},
	{#State 670
		ACTIONS => {
			"(" => 1132
		}
	},
	{#State 671
		ACTIONS => {
			"(" => 1133
		},
		DEFAULT => -1638
	},
	{#State 672
		ACTIONS => {
			"(" => 1134
		}
	},
	{#State 673
		ACTIONS => {
			"(" => 1135
		},
		DEFAULT => -1649
	},
	{#State 674
		ACTIONS => {
			"(" => 1136
		}
	},
	{#State 675
		ACTIONS => {
			"(" => 1137
		}
	},
	{#State 676
		DEFAULT => -705
	},
	{#State 677
		ACTIONS => {
			"(" => 1138
		},
		DEFAULT => -640,
		GOTOS => {
			'optional_braces' => 1139
		}
	},
	{#State 678
		ACTIONS => {
			"(" => 962
		},
		DEFAULT => -640,
		GOTOS => {
			'optional_braces' => 1140
		}
	},
	{#State 679
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1141
		}
	},
	{#State 680
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -946,
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'opt_expr' => 1142,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1143,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 681
		ACTIONS => {
			"(" => 1144
		}
	},
	{#State 682
		ACTIONS => {
			"(" => 1145
		},
		DEFAULT => -1552
	},
	{#State 683
		ACTIONS => {
			"(" => 1146
		}
	},
	{#State 684
		DEFAULT => -1345
	},
	{#State 685
		DEFAULT => -784
	},
	{#State 686
		ACTIONS => {
			"(" => 1147
		}
	},
	{#State 687
		ACTIONS => {
			")" => 1148
		}
	},
	{#State 688
		ACTIONS => {
			"(" => 688,
			'SELECT_SYM' => 689
		},
		GOTOS => {
			'select_paren' => 1149
		}
	},
	{#State 689
		ACTIONS => {
			'SQL_BIG_RESULT' => 708,
			'SQL_BUFFER_RESULT' => 709,
			'SQL_NO_CACHE_SYM' => 710,
			'SQL_CALC_FOUND_ROWS' => 713,
			'SQL_CACHE_SYM' => 714,
			'ALL' => 716,
			'STRAIGHT_JOIN' => 717,
			'SQL_SMALL_RESULT' => 719,
			'DISTINCT' => 721,
			'HIGH_PRIORITY' => 722
		},
		DEFAULT => -610,
		GOTOS => {
			'select_option' => 715,
			'select_options' => 718,
			'select_option_list' => 720,
			'select_part2' => 1150
		}
	},
	{#State 690
		ACTIONS => {
			'INTO' => 1151
		}
	},
	{#State 691
		ACTIONS => {
			'FROM' => 1153,
			'CONCURRENT' => 1156,
			'LOW_PRIORITY' => 1154
		},
		DEFAULT => -1302,
		GOTOS => {
			'load_data' => 1152,
			'load_data_lock' => 1155
		}
	},
	{#State 692
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1157,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 693
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1160,
			'table_lock_list' => 1158,
			'table_lock' => 1159,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 694
		DEFAULT => -1171
	},
	{#State 695
		ACTIONS => {
			'QUICK' => 694,
			'LOW_PRIORITY' => 696,
			'IGNORE_SYM' => 697
		},
		DEFAULT => -1169,
		GOTOS => {
			'opt_delete_options' => 1161,
			'opt_delete_option' => 695
		}
	},
	{#State 696
		DEFAULT => -1172
	},
	{#State 697
		DEFAULT => -1173
	},
	{#State 698
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'FROM' => 1163,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_wild_one' => 1164,
			'IDENT_sys' => 297,
			'table_wild_list' => 1165,
			'single_multi' => 1162,
			'ident' => 1166
		}
	},
	{#State 699
		ACTIONS => {
			'WITH' => 1167
		},
		DEFAULT => -532,
		GOTOS => {
			'start_transaction_opts' => 1168
		}
	},
	{#State 700
		ACTIONS => {
			'SQL_THREAD' => 815,
			'RELAY_THREAD' => 814
		},
		DEFAULT => -537,
		GOTOS => {
			'slave_thread_opt' => 816,
			'slave_thread_opt_list' => 812,
			'slave_thread_opts' => 1169
		}
	},
	{#State 701
		ACTIONS => {
			'SQL_THREAD' => 815,
			'RELAY_THREAD' => 814
		},
		DEFAULT => -537,
		GOTOS => {
			'slave_thread_opt' => 816,
			'slave_thread_opt_list' => 812,
			'slave_thread_opts' => 1170
		}
	},
	{#State 702
		ACTIONS => {
			'SQL_THREAD' => 815,
			'RELAY_THREAD' => 814
		},
		DEFAULT => -537,
		GOTOS => {
			'slave_thread_opt' => 816,
			'slave_thread_opt_list' => 812,
			'slave_thread_opts' => 1171
		}
	},
	{#State 703
		DEFAULT => -1383
	},
	{#State 704
		DEFAULT => -1391
	},
	{#State 705
		DEFAULT => -64
	},
	{#State 706
		DEFAULT => -1390
	},
	{#State 707
		DEFAULT => -1392
	},
	{#State 708
		DEFAULT => -618
	},
	{#State 709
		DEFAULT => -619
	},
	{#State 710
		DEFAULT => -621
	},
	{#State 711
		ACTIONS => {
			'UNION_SYM' => 1172
		},
		DEFAULT => -1830,
		GOTOS => {
			'union_list' => 1174,
			'union_clause' => 1173
		}
	},
	{#State 712
		DEFAULT => -597
	},
	{#State 713
		DEFAULT => -620
	},
	{#State 714
		DEFAULT => -622
	},
	{#State 715
		DEFAULT => -613
	},
	{#State 716
		DEFAULT => -623
	},
	{#State 717
		DEFAULT => -614
	},
	{#State 718
		ACTIONS => {
			"*" => 1176
		},
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 1178,
			'select_item_list' => 1177,
			'select_item' => 1175
		}
	},
	{#State 719
		DEFAULT => -617
	},
	{#State 720
		ACTIONS => {
			'SQL_BIG_RESULT' => 708,
			'SQL_BUFFER_RESULT' => 709,
			'SQL_NO_CACHE_SYM' => 710,
			'SQL_CALC_FOUND_ROWS' => 713,
			'SQL_CACHE_SYM' => 714,
			'ALL' => 716,
			'STRAIGHT_JOIN' => 717,
			'SQL_SMALL_RESULT' => 719,
			'DISTINCT' => 721,
			'HIGH_PRIORITY' => 722
		},
		DEFAULT => -611,
		GOTOS => {
			'select_option' => 1179
		}
	},
	{#State 721
		DEFAULT => -616
	},
	{#State 722
		DEFAULT => -615
	},
	{#State 723
		ACTIONS => {
			'IGNORE_SYM' => 408
		},
		DEFAULT => -515,
		GOTOS => {
			'opt_ignore' => 1180
		}
	},
	{#State 724
		DEFAULT => -1115
	},
	{#State 725
		DEFAULT => -1114
	},
	{#State 726
		DEFAULT => -1116
	},
	{#State 727
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'table_list' => 1181,
			'IDENT_sys' => 297,
			'table_name' => 837,
			'ident' => 435
		}
	},
	{#State 728
		ACTIONS => {
			'DELETE_SYM' => 863,
			'SUPER_SYM' => 861,
			'GRANT' => 848,
			'UPDATE_SYM' => 843,
			'SELECT_SYM' => 857,
			'PROCESS' => 856,
			'INSERT' => 846,
			'RELOAD' => 851,
			'SHOW' => 854,
			'EXECUTE_SYM' => 849,
			'ALL' => 1184,
			'DROP' => 840,
			'INDEX_SYM' => 841,
			'REFERENCES' => 862,
			'FILE_SYM' => 859,
			'ALTER' => 860,
			'SHUTDOWN' => 864,
			'CREATE' => 853,
			'REPLICATION' => 842,
			'USAGE' => 858,
			'LOCK_SYM' => 845
		},
		GOTOS => {
			'object_privilege' => 850,
			'grant_privileges' => 1182,
			'object_privilege_list' => 852,
			'revoke_command' => 1183
		}
	},
	{#State 729
		DEFAULT => -1715
	},
	{#State 730
		DEFAULT => 0
	},
	{#State 731
		ACTIONS => {
			'TABLE_SYM' => 401,
			'TABLES' => 404
		},
		GOTOS => {
			'table_or_tables' => 1185
		}
	},
	{#State 732
		ACTIONS => {
			'FROM' => 1186
		}
	},
	{#State 733
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'table_list' => 1187,
			'IDENT_sys' => 297,
			'table_name' => 837,
			'ident' => 435
		}
	},
	{#State 734
		DEFAULT => -1662
	},
	{#State 735
		DEFAULT => -1666
	},
	{#State 736
		ACTIONS => {
			'CHAR_SYM' => 473,
			'NAMES_SYM' => 1188,
			'CHARSET' => 490,
			"\@" => 1191,
			'PASSWORD' => 1192
		},
		DEFAULT => -1665,
		GOTOS => {
			'option_value' => 1190,
			'charset' => 1189
		}
	},
	{#State 737
		DEFAULT => -1667
	},
	{#State 738
		DEFAULT => -1664
	},
	{#State 739
		DEFAULT => -1670
	},
	{#State 740
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 1193,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 1194,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'internal_variable_name' => 1195,
			'IDENT_sys' => 297,
			'ident' => 1196
		}
	},
	{#State 741
		DEFAULT => -1679
	},
	{#State 742
		ACTIONS => {
			"," => 1197
		},
		DEFAULT => -1659
	},
	{#State 743
		DEFAULT => -1668
	},
	{#State 744
		DEFAULT => -1120
	},
	{#State 745
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'insert_table' => 1198,
			'IDENT_sys' => 297,
			'table_name' => 746,
			'ident' => 435
		}
	},
	{#State 746
		DEFAULT => -1121
	},
	{#State 747
		ACTIONS => {
			'SET' => 1202,
			"(" => 1200,
			'SELECT_SYM' => 1206,
			'VALUES' => 1204,
			'VALUE_SYM' => 1199
		},
		GOTOS => {
			'create_select' => 1201,
			'insert_values' => 1205,
			'insert_field_spec' => 1203
		}
	},
	{#State 748
		DEFAULT => -1106
	},
	{#State 749
		DEFAULT => -1278
	},
	{#State 750
		ACTIONS => {
			"," => 1207
		},
		DEFAULT => -1265
	},
	{#State 751
		DEFAULT => -1272
	},
	{#State 752
		DEFAULT => -1276
	},
	{#State 753
		DEFAULT => -1274
	},
	{#State 754
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -1279,
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 748,
			'table_list' => 1209,
			'opt_table_list' => 1208,
			'ident' => 435,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'table_name' => 837
		}
	},
	{#State 755
		ACTIONS => {
			'CACHE_SYM' => 1210
		}
	},
	{#State 756
		DEFAULT => -1273
	},
	{#State 757
		DEFAULT => -1271
	},
	{#State 758
		DEFAULT => -1267
	},
	{#State 759
		DEFAULT => -1277
	},
	{#State 760
		DEFAULT => -1275
	},
	{#State 761
		ACTIONS => {
			'WITH' => 1211
		},
		DEFAULT => -1707
	},
	{#State 762
		ACTIONS => {
			'RELEASE_SYM' => 1212,
			'NO_SYM' => 1213
		},
		DEFAULT => -1820,
		GOTOS => {
			'opt_release' => 1214
		}
	},
	{#State 763
		ACTIONS => {
			'NO_SYM' => 1216,
			'CHAIN_SYM' => 1215
		}
	},
	{#State 764
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -113,
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1218,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sp_cparams' => 1219,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564,
			'opt_sp_cparams' => 1217
		}
	},
	{#State 765
		DEFAULT => -110
	},
	{#State 766
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1220
		}
	},
	{#State 767
		DEFAULT => -52
	},
	{#State 768
		ACTIONS => {
			'EXISTS' => 1221
		}
	},
	{#State 769
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 1222,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 770
		ACTIONS => {
			'ON' => 1223
		}
	},
	{#State 771
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 1224,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 772
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident' => 706,
			'user_list' => 1228,
			'keyword_sp' => 287,
			'ident_or_text' => 1227,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1225
		}
	},
	{#State 773
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'table_list' => 1229,
			'IDENT_sys' => 297,
			'table_name' => 837,
			'ident' => 435
		}
	},
	{#State 774
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1230
		}
	},
	{#State 775
		ACTIONS => {
			'IF' => 768
		},
		DEFAULT => -1107,
		GOTOS => {
			'if_exists' => 1231
		}
	},
	{#State 776
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 1232,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 777
		ACTIONS => {
			'MASTER_SYM' => 397,
			'QUERY_SYM' => 399,
			'SLAVE' => 400
		},
		GOTOS => {
			'reset_option' => 1233
		}
	},
	{#State 778
		DEFAULT => -1286
	},
	{#State 779
		ACTIONS => {
			"," => 1234
		},
		DEFAULT => -574
	},
	{#State 780
		DEFAULT => -578
	},
	{#State 781
		ACTIONS => {
			'TO_SYM' => 1235
		}
	},
	{#State 782
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident' => 706,
			'keyword_sp' => 287,
			'ident_or_text' => 1227,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1236,
			'rename_list' => 1237
		}
	},
	{#State 783
		DEFAULT => -94,
		GOTOS => {
			'sp_a_chistics' => 1238
		}
	},
	{#State 784
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1239,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 785
		ACTIONS => {
			'MERGE_SYM' => 1242,
			'TEMPTABLE_SYM' => 1241,
			'UNDEFINED_SYM' => 1240
		}
	},
	{#State 786
		ACTIONS => {
			";" => -217,
			'END_OF_INPUT' => -217,
			'DEFAULT' => 1245
		},
		DEFAULT => -415,
		GOTOS => {
			'default_charset' => 1249,
			'opt_default' => 1243,
			'create_database_options' => 1247,
			'default_collation' => 1248,
			'create_database_option' => 1244,
			'opt_create_database_options' => 1246
		}
	},
	{#State 787
		DEFAULT => -488
	},
	{#State 788
		DEFAULT => -94,
		GOTOS => {
			'sp_a_chistics' => 1250
		}
	},
	{#State 789
		ACTIONS => {
			'SQL_SYM' => 833
		},
		DEFAULT => -1863,
		GOTOS => {
			'view_suid' => 1251
		}
	},
	{#State 790
		DEFAULT => -1174
	},
	{#State 791
		DEFAULT => -1291
	},
	{#State 792
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 1259,
			'derived_table_list' => 1252,
			'ident' => 435,
			'table_factor' => 1261,
			'join_table_list' => 1256,
			'keyword_sp' => 287,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'table_ref' => 1254,
			'join_table' => 1255
		}
	},
	{#State 793
		DEFAULT => -1829
	},
	{#State 794
		ACTIONS => {
			'IN_SYM' => 1263,
			"," => 1262
		}
	},
	{#State 795
		DEFAULT => -582
	},
	{#State 796
		ACTIONS => {
			"(" => -457,
			'KEY_SYM' => 1266,
			'INDEX_SYM' => 1264
		},
		DEFAULT => -592,
		GOTOS => {
			'key_or_index' => 1268,
			'cache_keys_spec' => 1267,
			'cache_key_list_or_empty' => 1265,
			'opt_key_or_index' => 1269
		}
	},
	{#State 797
		DEFAULT => -1883
	},
	{#State 798
		DEFAULT => -1338
	},
	{#State 799
		ACTIONS => {
			"," => 1270
		},
		DEFAULT => -1887
	},
	{#State 800
		DEFAULT => -1339
	},
	{#State 801
		DEFAULT => -1337
	},
	{#State 802
		ACTIONS => {
			'RESUME_SYM' => 1272,
			'JOIN_SYM' => 1271
		},
		DEFAULT => -1892,
		GOTOS => {
			'opt_join_or_resume' => 1273
		}
	},
	{#State 803
		DEFAULT => -1885
	},
	{#State 804
		ACTIONS => {
			'SUSPEND_SYM' => 1274
		},
		DEFAULT => -1897,
		GOTOS => {
			'opt_suspend' => 1275
		}
	},
	{#State 805
		ACTIONS => {
			'ONE_SYM' => 1276
		},
		DEFAULT => -1895,
		GOTOS => {
			'opt_one_phase' => 1277
		}
	},
	{#State 806
		DEFAULT => -1257
	},
	{#State 807
		DEFAULT => -1256
	},
	{#State 808
		DEFAULT => -1263
	},
	{#State 809
		DEFAULT => -1264
	},
	{#State 810
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1278
		}
	},
	{#State 811
		DEFAULT => -1379
	},
	{#State 812
		ACTIONS => {
			"," => 1279
		},
		DEFAULT => -534
	},
	{#State 813
		DEFAULT => -528
	},
	{#State 814
		DEFAULT => -539
	},
	{#State 815
		DEFAULT => -538
	},
	{#State 816
		DEFAULT => -535
	},
	{#State 817
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1280
		}
	},
	{#State 818
		DEFAULT => -226
	},
	{#State 819
		DEFAULT => -1857
	},
	{#State 820
		ACTIONS => {
			'IF' => 835
		},
		DEFAULT => -228,
		GOTOS => {
			'opt_if_not_exists' => 1281
		}
	},
	{#State 821
		DEFAULT => -1855
	},
	{#State 822
		ACTIONS => {
			'SQL_SYM' => 833
		},
		DEFAULT => -1863,
		GOTOS => {
			'view_suid' => 829,
			'view_tail' => 1282
		}
	},
	{#State 823
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'grant_list' => 1285,
			'ident' => 706,
			'grant_user' => 1284,
			'keyword_sp' => 287,
			'ident_or_text' => 1227,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1283
		}
	},
	{#State 824
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 1286
		}
	},
	{#State 825
		DEFAULT => -1850
	},
	{#State 826
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 1287
		}
	},
	{#State 827
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 1288
		}
	},
	{#State 828
		DEFAULT => -1849
	},
	{#State 829
		ACTIONS => {
			'VIEW_SYM' => 1289
		}
	},
	{#State 830
		DEFAULT => -278
	},
	{#State 831
		DEFAULT => -1847
	},
	{#State 832
		DEFAULT => -1851
	},
	{#State 833
		ACTIONS => {
			'SECURITY_SYM' => 1290
		}
	},
	{#State 834
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1291
		}
	},
	{#State 835
		ACTIONS => {
			'NOT_SYM' => 1010,
			'NOT2_SYM' => 1017
		},
		GOTOS => {
			'not' => 1292
		}
	},
	{#State 836
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1227,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1293,
			'ident' => 706
		}
	},
	{#State 837
		DEFAULT => -1104
	},
	{#State 838
		ACTIONS => {
			'EXTENDED_SYM' => 1301,
			"," => 1298,
			'CHANGED' => 1294,
			'FOR_SYM' => 1296,
			'FAST_SYM' => 1299,
			'MEDIUM_SYM' => 1300,
			'QUICK' => 1295
		},
		DEFAULT => -560,
		GOTOS => {
			'mi_check_type' => 1297,
			'mi_check_types' => 1302,
			'opt_mi_check_type' => 1303
		}
	},
	{#State 839
		ACTIONS => {
			'TO_SYM' => 1304,
			"," => 1298
		}
	},
	{#State 840
		DEFAULT => -1759
	},
	{#State 841
		DEFAULT => -1756
	},
	{#State 842
		ACTIONS => {
			'SLAVE' => 1306,
			'CLIENT_SYM' => 1305
		}
	},
	{#State 843
		ACTIONS => {
			"(" => 1307
		},
		DEFAULT => -1795,
		GOTOS => {
			'opt_column_list' => 1308
		}
	},
	{#State 844
		ACTIONS => {
			'ON' => 1309
		}
	},
	{#State 845
		ACTIONS => {
			'TABLES' => 1310
		}
	},
	{#State 846
		ACTIONS => {
			"(" => 1307
		},
		DEFAULT => -1795,
		GOTOS => {
			'opt_column_list' => 1311
		}
	},
	{#State 847
		DEFAULT => -1738
	},
	{#State 848
		ACTIONS => {
			'OPTION' => 1312
		}
	},
	{#State 849
		DEFAULT => -1760
	},
	{#State 850
		DEFAULT => -1748
	},
	{#State 851
		DEFAULT => -1761
	},
	{#State 852
		ACTIONS => {
			"," => 1313
		},
		DEFAULT => -1744
	},
	{#State 853
		ACTIONS => {
			'VIEW_SYM' => 1317,
			'ROUTINE_SYM' => 1314,
			'USER' => 1316,
			'TEMPORARY' => 1315
		},
		DEFAULT => -1758
	},
	{#State 854
		ACTIONS => {
			'VIEW_SYM' => 1319,
			'DATABASES' => 1318
		}
	},
	{#State 855
		ACTIONS => {
			'PRIVILEGES' => 1321
		},
		DEFAULT => -1746,
		GOTOS => {
			'opt_privileges' => 1320
		}
	},
	{#State 856
		DEFAULT => -1763
	},
	{#State 857
		ACTIONS => {
			"(" => 1307
		},
		DEFAULT => -1795,
		GOTOS => {
			'opt_column_list' => 1322
		}
	},
	{#State 858
		DEFAULT => -1755
	},
	{#State 859
		DEFAULT => -1764
	},
	{#State 860
		ACTIONS => {
			'ROUTINE_SYM' => 1323
		},
		DEFAULT => -1757
	},
	{#State 861
		DEFAULT => -1767
	},
	{#State 862
		ACTIONS => {
			"(" => 1307
		},
		DEFAULT => -1795,
		GOTOS => {
			'opt_column_list' => 1324
		}
	},
	{#State 863
		DEFAULT => -1754
	},
	{#State 864
		DEFAULT => -1762
	},
	{#State 865
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'table_list' => 1325,
			'IDENT_sys' => 297,
			'table_name' => 837,
			'ident' => 435
		}
	},
	{#State 866
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'table_list' => 1326,
			'IDENT_sys' => 297,
			'table_name' => 837,
			'ident' => 435
		}
	},
	{#State 867
		ACTIONS => {
			'TO_SYM' => 1328,
			'BEFORE_SYM' => 1329
		},
		GOTOS => {
			'purge_option' => 1327
		}
	},
	{#State 868
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 1331,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 1333,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'handler_scan_function' => 1334,
			'handler_read_or_scan' => 1330,
			'IDENT_sys' => 297,
			'ident' => 1332
		}
	},
	{#State 869
		DEFAULT => -1717
	},
	{#State 870
		ACTIONS => {
			'END_OF_INPUT' => -1025,
			'EQ' => 1335,
			'AS' => 1337,
			";" => -1025
		},
		DEFAULT => -1022,
		GOTOS => {
			'table_alias' => 1338,
			'opt_table_alias' => 1336
		}
	},
	{#State 871
		ACTIONS => {
			'MASTER_SSL_CA_SYM' => 1353,
			'MASTER_SSL_KEY_SYM' => 1346,
			'MASTER_CONNECT_RETRY_SYM' => 1354,
			'MASTER_USER_SYM' => 1351,
			'MASTER_SSL_CAPATH_SYM' => 1352,
			'MASTER_SSL_CERT_SYM' => 1340,
			'MASTER_HOST_SYM' => 1344,
			'RELAY_LOG_FILE_SYM' => 1341,
			'MASTER_SSL_CIPHER_SYM' => 1348,
			'MASTER_SSL_SYM' => 1355,
			'MASTER_LOG_FILE_SYM' => 1342,
			'RELAY_LOG_POS_SYM' => 1345,
			'MASTER_PASSWORD_SYM' => 1356,
			'MASTER_PORT_SYM' => 1339,
			'MASTER_LOG_POS_SYM' => 1350
		},
		GOTOS => {
			'master_def' => 1347,
			'master_defs' => 1349,
			'master_file_def' => 1343
		}
	},
	{#State 872
		ACTIONS => {
			'SAVEPOINT_SYM' => 1358
		},
		DEFAULT => -1823,
		GOTOS => {
			'opt_savepoint' => 1357
		}
	},
	{#State 873
		ACTIONS => {
			'RELEASE_SYM' => 1212,
			'NO_SYM' => 1213
		},
		DEFAULT => -1820,
		GOTOS => {
			'opt_release' => 1359
		}
	},
	{#State 874
		ACTIONS => {
			"*" => 1360
		}
	},
	{#State 875
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 1361
		}
	},
	{#State 876
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 1362
		}
	},
	{#State 877
		DEFAULT => -1222
	},
	{#State 878
		DEFAULT => -398
	},
	{#State 879
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1363,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 880
		DEFAULT => -1221
	},
	{#State 881
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 1364
		}
	},
	{#State 882
		ACTIONS => {
			'FROM' => 892,
			'IN_SYM' => 893
		},
		DEFAULT => -1243,
		GOTOS => {
			'opt_db' => 1366,
			'from_or_in' => 1365
		}
	},
	{#State 883
		DEFAULT => -1217
	},
	{#State 884
		ACTIONS => {
			'FROM' => 892,
			'IN_SYM' => 893
		},
		GOTOS => {
			'from_or_in' => 1367
		}
	},
	{#State 885
		DEFAULT => -1218
	},
	{#State 886
		ACTIONS => {
			'FROM' => 892,
			'IN_SYM' => 893
		},
		DEFAULT => -1243,
		GOTOS => {
			'opt_db' => 1368,
			'from_or_in' => 1365
		}
	},
	{#State 887
		ACTIONS => {
			'FROM' => 892,
			'IN_SYM' => 893
		},
		DEFAULT => -1243,
		GOTOS => {
			'opt_db' => 1369,
			'from_or_in' => 1365
		}
	},
	{#State 888
		DEFAULT => -1229
	},
	{#State 889
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 1370
		}
	},
	{#State 890
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 1371,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 891
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1372,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 892
		DEFAULT => -1247
	},
	{#State 893
		DEFAULT => -1248
	},
	{#State 894
		DEFAULT => -1207
	},
	{#State 895
		ACTIONS => {
			'IN_SYM' => 1374
		},
		DEFAULT => -1249,
		GOTOS => {
			'binlog_in' => 1373
		}
	},
	{#State 896
		DEFAULT => -1201
	},
	{#State 897
		DEFAULT => -1211
	},
	{#State 898
		DEFAULT => -1055
	},
	{#State 899
		ACTIONS => {
			'NUM' => 1378,
			'ULONGLONG_NUM' => 1379,
			'PARAM_MARKER' => 606,
			'LONG_NUM' => 1376
		},
		GOTOS => {
			'param_marker' => 1377,
			'limit_options' => 1375,
			'limit_option' => 1380
		}
	},
	{#State 900
		DEFAULT => -1205
	},
	{#State 901
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1227,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1381,
			'ident' => 706
		}
	},
	{#State 902
		DEFAULT => -1206
	},
	{#State 903
		ACTIONS => {
			'FROM' => 892,
			'IN_SYM' => 893
		},
		DEFAULT => -1243,
		GOTOS => {
			'opt_db' => 1382,
			'from_or_in' => 1365
		}
	},
	{#State 904
		DEFAULT => -1220
	},
	{#State 905
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 1383,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 906
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1384,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 907
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1385,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 908
		ACTIONS => {
			'IF' => 835
		},
		DEFAULT => -228,
		GOTOS => {
			'opt_if_not_exists' => 1386
		}
	},
	{#State 909
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 1387,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 910
		DEFAULT => -1193
	},
	{#State 911
		DEFAULT => -1186
	},
	{#State 912
		DEFAULT => -1187
	},
	{#State 913
		DEFAULT => -1181
	},
	{#State 914
		ACTIONS => {
			'IO_SYM' => 1388
		}
	},
	{#State 915
		ACTIONS => {
			"," => 1389
		},
		DEFAULT => -1178
	},
	{#State 916
		DEFAULT => -1179
	},
	{#State 917
		DEFAULT => -1189
	},
	{#State 918
		ACTIONS => {
			'SWITCHES_SYM' => 1390
		}
	},
	{#State 919
		ACTIONS => {
			'FAULTS_SYM' => 1391
		}
	},
	{#State 920
		DEFAULT => -1182
	},
	{#State 921
		ACTIONS => {
			'FOR_SYM' => 1392
		},
		DEFAULT => -1190,
		GOTOS => {
			'opt_profile_args' => 1393
		}
	},
	{#State 922
		DEFAULT => -1188
	},
	{#State 923
		ACTIONS => {
			'FOR_SYM' => 1394
		}
	},
	{#State 924
		DEFAULT => -1212
	},
	{#State 925
		DEFAULT => -1216
	},
	{#State 926
		ACTIONS => {
			'STATUS_SYM' => 1395,
			'LOGS_SYM' => 1396
		},
		GOTOS => {
			'show_engine_param' => 1397
		}
	},
	{#State 927
		DEFAULT => -262
	},
	{#State 928
		DEFAULT => -1230
	},
	{#State 929
		DEFAULT => -1202
	},
	{#State 930
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 1398
		}
	},
	{#State 931
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 1399,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 932
		DEFAULT => -58
	},
	{#State 933
		ACTIONS => {
			"\@" => 1401
		},
		GOTOS => {
			'execute_var_ident' => 1402,
			'execute_var_list' => 1400
		}
	},
	{#State 934
		ACTIONS => {
			'ALL' => 1405,
			'DISTINCT' => 1406
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1403
		}
	},
	{#State 935
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1407,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 936
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1408,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 937
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1409
		}
	},
	{#State 938
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1410,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 939
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1411,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 940
		ACTIONS => {
			'ALL' => 1405,
			'DISTINCT' => 1414
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1413,
			'in_sum_expr' => 1412
		}
	},
	{#State 941
		DEFAULT => -649
	},
	{#State 942
		ACTIONS => {
			'OR_SYM' => 1415,
			'OR2_SYM' => 1416
		},
		DEFAULT => -642,
		GOTOS => {
			'or' => 1417
		}
	},
	{#State 943
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 1418,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 944
		ACTIONS => {
			'COLLATE_SYM' => 989
		},
		DEFAULT => -725
	},
	{#State 945
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1419,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 946
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1420,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 947
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1421,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 948
		DEFAULT => -1336
	},
	{#State 949
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1422,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 950
		ACTIONS => {
			'COLLATE_SYM' => 989
		},
		DEFAULT => -722
	},
	{#State 951
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1423,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 952
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1424,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 953
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1425,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 954
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1426,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 955
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1427,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 956
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1428,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 957
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1429,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 958
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1430,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 959
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 1431
		}
	},
	{#State 960
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 1432
		}
	},
	{#State 961
		ACTIONS => {
			'COLLATE_SYM' => 989
		},
		DEFAULT => -734
	},
	{#State 962
		ACTIONS => {
			")" => 1433
		}
	},
	{#State 963
		DEFAULT => -851
	},
	{#State 964
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1434,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 965
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1435
		}
	},
	{#State 966
		DEFAULT => -761
	},
	{#State 967
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1436,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 968
		DEFAULT => -1351
	},
	{#State 969
		DEFAULT => -1335
	},
	{#State 970
		DEFAULT => -1352
	},
	{#State 971
		ACTIONS => {
			'TEXT_STRING' => 554,
			'NCHAR_STRING' => 652,
			'UNDERSCORE_CHARSET' => 980
		},
		GOTOS => {
			'text_literal' => 1437,
			'TEXT_STRING_literal' => 653
		}
	},
	{#State 972
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1438,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 973
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 973,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 976,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'subselect_start' => 1439,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 974,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'subselect' => 975,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 974
		ACTIONS => {
			"," => 1440,
			")" => 1441
		}
	},
	{#State 975
		ACTIONS => {
			")" => 1442
		}
	},
	{#State 976
		DEFAULT => -1845,
		GOTOS => {
			'subselect_start' => 1443
		}
	},
	{#State 977
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1444,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 978
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1445,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 979
		ACTIONS => {
			'TEXT_STRING' => 554
		},
		DEFAULT => -1355,
		GOTOS => {
			'TEXT_STRING_literal' => 948
		}
	},
	{#State 980
		ACTIONS => {
			'TEXT_STRING' => 969
		}
	},
	{#State 981
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1446,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 982
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 1447,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'geometry_function' => 685
		}
	},
	{#State 983
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1448,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 984
		ACTIONS => {
			'AND_AND_SYM' => 1449,
			'AND_SYM' => 1451
		},
		DEFAULT => -646,
		GOTOS => {
			'and' => 1450
		}
	},
	{#State 985
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1452,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 986
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1453,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 987
		ACTIONS => {
			"(" => 1454,
			'SELECT_SYM' => 976
		},
		GOTOS => {
			'subselect' => 1455
		}
	},
	{#State 988
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 1456,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'geometry_function' => 685
		}
	},
	{#State 989
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1457,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'ident' => 706
		}
	},
	{#State 990
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'simple_ident' => 1458,
			'ident' => 1080,
			'simple_ident_q' => 586
		}
	},
	{#State 991
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1459,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 992
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 1460,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639
		}
	},
	{#State 993
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			")" => 1433,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1461,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 994
		DEFAULT => -759
	},
	{#State 995
		ACTIONS => {
			'TEXT_STRING' => 554,
			'NCHAR_STRING' => 652,
			'UNDERSCORE_CHARSET' => 980
		},
		GOTOS => {
			'text_literal' => 1462,
			'TEXT_STRING_literal' => 653
		}
	},
	{#State 996
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 1465
		}
	},
	{#State 997
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1470,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 998
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1471,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 999
		ACTIONS => {
			'ALL' => 1405,
			'DISTINCT' => 1473
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1472
		}
	},
	{#State 1000
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1474,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1001
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1475,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1002
		ACTIONS => {
			'ALL' => 1405,
			'DISTINCT' => 1477
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1476
		}
	},
	{#State 1003
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1478,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1004
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1479,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1005
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			")" => 1481,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1480,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1006
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1482,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1007
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1483,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1008
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1484,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1009
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1485,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1010
		DEFAULT => -702
	},
	{#State 1011
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'bit_expr' => 1486,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1012
		ACTIONS => {
			'LIKE' => 1487
		}
	},
	{#State 1013
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 1488
		}
	},
	{#State 1014
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'bit_expr' => 1489,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1015
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 1490,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'geometry_function' => 685
		}
	},
	{#State 1016
		ACTIONS => {
			'REGEXP' => 1491,
			'LIKE' => 1493,
			'IN_SYM' => 1494,
			'BETWEEN_SYM' => 1492
		}
	},
	{#State 1017
		DEFAULT => -703
	},
	{#State 1018
		ACTIONS => {
			"(" => 1495
		}
	},
	{#State 1019
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1496,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1020
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1497,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1021
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1498,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1022
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1499
		}
	},
	{#State 1023
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1500,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1024
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			")" => 1502,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1501,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1025
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1503,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1026
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1504,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1027
		ACTIONS => {
			'DAY_SYM' => 1045,
			'MONTH_SYM' => 1049,
			'HOUR_SYM' => 1033,
			'SECOND_SYM' => 1047,
			'YEAR_SYM' => 1028,
			'WEEK_SYM' => 1040,
			'QUARTER_SYM' => 1037,
			'MINUTE_SYM' => 1043,
			'FRAC_SECOND_SYM' => 1036
		},
		GOTOS => {
			'interval_time_st' => 1505
		}
	},
	{#State 1028
		DEFAULT => -1017
	},
	{#State 1029
		DEFAULT => -996
	},
	{#State 1030
		DEFAULT => -1005
	},
	{#State 1031
		DEFAULT => -1004
	},
	{#State 1032
		DEFAULT => -1006
	},
	{#State 1033
		DEFAULT => -1011
	},
	{#State 1034
		DEFAULT => -998
	},
	{#State 1035
		DEFAULT => -1003
	},
	{#State 1036
		DEFAULT => -1012
	},
	{#State 1037
		DEFAULT => -1015
	},
	{#State 1038
		DEFAULT => -1002
	},
	{#State 1039
		DEFAULT => -1008
	},
	{#State 1040
		DEFAULT => -1010
	},
	{#State 1041
		DEFAULT => -1007
	},
	{#State 1042
		DEFAULT => -999
	},
	{#State 1043
		DEFAULT => -1013
	},
	{#State 1044
		DEFAULT => -997
	},
	{#State 1045
		DEFAULT => -1009
	},
	{#State 1046
		DEFAULT => -1000
	},
	{#State 1047
		DEFAULT => -1016
	},
	{#State 1048
		ACTIONS => {
			"+" => 1506
		}
	},
	{#State 1049
		DEFAULT => -1014
	},
	{#State 1050
		DEFAULT => -1001
	},
	{#State 1051
		ACTIONS => {
			'DAY_SYM' => 1045,
			'MONTH_SYM' => 1049,
			'HOUR_MICROSECOND_SYM' => 1050,
			'DAY_MINUTE_SYM' => 1042,
			'MINUTE_SYM' => 1043,
			'SECOND_MICROSECOND_SYM' => 1041,
			'YEAR_MONTH_SYM' => 1039,
			'MICROSECOND_SYM' => 1031,
			'FRAC_SECOND_SYM' => 1036,
			'DAY_SECOND_SYM' => 1046,
			'MINUTE_SECOND_SYM' => 1032,
			'HOUR_SECOND_SYM' => 1035,
			'HOUR_SYM' => 1033,
			'SECOND_SYM' => 1047,
			'YEAR_SYM' => 1028,
			'QUARTER_SYM' => 1037,
			'WEEK_SYM' => 1040,
			'HOUR_MINUTE_SYM' => 1038,
			'DAY_HOUR_SYM' => 1044,
			'DAY_MICROSECOND_SYM' => 1034,
			'MINUTE_MICROSECOND_SYM' => 1030
		},
		GOTOS => {
			'interval_time_st' => 1029,
			'interval' => 1507
		}
	},
	{#State 1052
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1508,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1053
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'factor' => 1509,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287
		}
	},
	{#State 1054
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'factor' => 1510,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287
		}
	},
	{#State 1055
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'factor' => 1511,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287
		}
	},
	{#State 1056
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'factor' => 1512,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287
		}
	},
	{#State 1057
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'factor' => 1513,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287
		}
	},
	{#State 1058
		ACTIONS => {
			'TEXT_STRING' => 554
		},
		DEFAULT => -1354,
		GOTOS => {
			'TEXT_STRING_literal' => 948
		}
	},
	{#State 1059
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1514,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1060
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1515,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1061
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			")" => 1517,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1516,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1062
		ACTIONS => {
			'COLLATE_SYM' => 989
		},
		DEFAULT => -723
	},
	{#State 1063
		ACTIONS => {
			'DISTINCT' => 1519
		},
		DEFAULT => -918,
		GOTOS => {
			'opt_distinct' => 1518
		}
	},
	{#State 1064
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1520
		}
	},
	{#State 1065
		ACTIONS => {
			")" => 1521
		}
	},
	{#State 1066
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			")" => 1433,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1522,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1067
		DEFAULT => -827
	},
	{#State 1068
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1523,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1069
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1524,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1070
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1525,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1071
		DEFAULT => -714
	},
	{#State 1072
		ACTIONS => {
			'TEXT_STRING' => 554
		},
		DEFAULT => -1353,
		GOTOS => {
			'TEXT_STRING_literal' => 948
		}
	},
	{#State 1073
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1526,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1074
		ACTIONS => {
			'ALL' => 1405,
			'DISTINCT' => 1528
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1527
		}
	},
	{#State 1075
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1529,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1076
		DEFAULT => -944
	},
	{#State 1077
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'simple_ident' => 1076,
			'ident_list2' => 1079,
			'ident_list' => 1530,
			'ident' => 1080,
			'simple_ident_q' => 586
		}
	},
	{#State 1078
		ACTIONS => {
			'AGAINST' => 1531
		}
	},
	{#State 1079
		ACTIONS => {
			"," => 1532
		},
		DEFAULT => -943
	},
	{#State 1080
		ACTIONS => {
			"." => 1533
		},
		DEFAULT => -1366
	},
	{#State 1081
		DEFAULT => -941
	},
	{#State 1082
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1534,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1083
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1535
		}
	},
	{#State 1084
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1536,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1085
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1537,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1086
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1538,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1087
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1539,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1088
		DEFAULT => -849
	},
	{#State 1089
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'simple_ident_nospvar' => 1541,
			'IDENT_sys' => 297,
			'ident' => 1542,
			'simple_ident_q' => 1540
		}
	},
	{#State 1090
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1543,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1091
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1544,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1092
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1545
		}
	},
	{#State 1093
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1546,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1094
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'term' => 1548,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 1547,
			'geometry_function' => 685,
			'keyword_sp' => 287
		}
	},
	{#State 1095
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'term' => 1550,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 1549,
			'geometry_function' => 685,
			'keyword_sp' => 287
		}
	},
	{#State 1096
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1551,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1097
		DEFAULT => -850
	},
	{#State 1098
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1552,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1099
		ACTIONS => {
			")" => -888
		},
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 1557,
			'udf_expr_list' => 1553,
			'udf_expr_list2' => 1556,
			'udf_expr' => 1554,
			'udf_expr_list3' => 1555
		}
	},
	{#State 1100
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1558,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1101
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1559,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1102
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1560,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1103
		DEFAULT => -709
	},
	{#State 1104
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 1561,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1105
		DEFAULT => -706
	},
	{#State 1106
		DEFAULT => -710
	},
	{#State 1107
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'ALL' => 1563,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 1565,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'all_or_any' => 1562,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 1564,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1108
		DEFAULT => -711
	},
	{#State 1109
		DEFAULT => -707
	},
	{#State 1110
		DEFAULT => -708
	},
	{#State 1111
		ACTIONS => {
			'FALSE_SYM' => 1569,
			'NOT_SYM' => 1010,
			'NULL_SYM' => 1567,
			'TRUE_SYM' => 1568,
			'UNKNOWN_SYM' => 1566,
			'NOT2_SYM' => 1017
		},
		GOTOS => {
			'not' => 1570
		}
	},
	{#State 1112
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1571,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1113
		DEFAULT => -914
	},
	{#State 1114
		ACTIONS => {
			'SET_VAR' => 1572
		},
		DEFAULT => -916
	},
	{#State 1115
		ACTIONS => {
			'GLOBAL_SYM' => 1573,
			'LOCAL_SYM' => 1574,
			'SESSION_SYM' => 1575
		},
		DEFAULT => -1675,
		GOTOS => {
			'opt_var_ident_type' => 1576
		}
	},
	{#State 1116
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1577,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1117
		ACTIONS => {
			")" => 1578
		}
	},
	{#State 1118
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1579,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1119
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1580
		}
	},
	{#State 1120
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1581,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1121
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1582,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1122
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1583,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1123
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1584,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1124
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1585,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1125
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1586,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1126
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1587,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1127
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1588,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1128
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'TRAILING' => 1589,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'LEADING' => 1590,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'BOTH' => 1592,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1591,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1129
		ACTIONS => {
			'DATE_SYM' => 1596,
			'DATETIME' => 1593,
			'TIME_SYM' => 1595,
			'TIMESTAMP' => 1594
		},
		GOTOS => {
			'date_time_type' => 1597
		}
	},
	{#State 1130
		ACTIONS => {
			'COLLATE_SYM' => 989
		},
		DEFAULT => -724
	},
	{#State 1131
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1598
		}
	},
	{#State 1132
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1599,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1133
		ACTIONS => {
			'DAY_SYM' => 1045,
			'MONTH_SYM' => 1049,
			'HOUR_SYM' => 1033,
			'SECOND_SYM' => 1047,
			'YEAR_SYM' => 1028,
			'WEEK_SYM' => 1040,
			'QUARTER_SYM' => 1037,
			'MINUTE_SYM' => 1043,
			'FRAC_SECOND_SYM' => 1036
		},
		GOTOS => {
			'interval_time_st' => 1600
		}
	},
	{#State 1134
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1601,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1135
		ACTIONS => {
			")" => 1602
		}
	},
	{#State 1136
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'bit_expr' => 1603,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1137
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1604,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1138
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			")" => 1433,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1605,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1139
		DEFAULT => -806
	},
	{#State 1140
		DEFAULT => -758
	},
	{#State 1141
		ACTIONS => {
			"." => 1606
		}
	},
	{#State 1142
		ACTIONS => {
			'WHEN_SYM' => 1608
		},
		GOTOS => {
			'when_list' => 1607
		}
	},
	{#State 1143
		DEFAULT => -947
	},
	{#State 1144
		ACTIONS => {
			")" => 1609
		}
	},
	{#State 1145
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1610,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1146
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1611,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1147
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1612,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1148
		ACTIONS => {
			'ORDER_SYM' => 1613,
			'UNION_SYM' => 1172,
			'LIMIT' => 899
		},
		DEFAULT => -1833,
		GOTOS => {
			'union_list' => 1616,
			'union_opt' => 1615,
			'order_or_limit' => 1614,
			'order_clause' => 1619,
			'limit_clause' => 1617,
			'union_order_or_limit' => 1618
		}
	},
	{#State 1149
		ACTIONS => {
			")" => 1620
		}
	},
	{#State 1150
		DEFAULT => -599
	},
	{#State 1151
		ACTIONS => {
			'CACHE_SYM' => 1621
		}
	},
	{#State 1152
		DEFAULT => -1296
	},
	{#State 1153
		ACTIONS => {
			'MASTER_SYM' => 1622
		}
	},
	{#State 1154
		DEFAULT => -1304
	},
	{#State 1155
		ACTIONS => {
			'LOCAL_SYM' => 1624
		},
		DEFAULT => -1300,
		GOTOS => {
			'opt_local' => 1623
		}
	},
	{#State 1156
		DEFAULT => -1303
	},
	{#State 1157
		ACTIONS => {
			'FROM' => 1625
		}
	},
	{#State 1158
		ACTIONS => {
			"," => 1626
		},
		DEFAULT => -1705
	},
	{#State 1159
		DEFAULT => -1708
	},
	{#State 1160
		ACTIONS => {
			'READ_SYM' => -1025,
			'WRITE_SYM' => -1025,
			'EQ' => 1335,
			'AS' => 1337,
			'LOW_PRIORITY' => -1025
		},
		DEFAULT => -1022,
		GOTOS => {
			'table_alias' => 1338,
			'opt_table_alias' => 1627
		}
	},
	{#State 1161
		DEFAULT => -1170
	},
	{#State 1162
		DEFAULT => -1159
	},
	{#State 1163
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1629,
			'table_wild_one' => 1164,
			'IDENT_sys' => 297,
			'table_wild_list' => 1628,
			'ident' => 1630
		}
	},
	{#State 1164
		DEFAULT => -1163
	},
	{#State 1165
		ACTIONS => {
			'FROM' => 1631,
			"," => 1632
		}
	},
	{#State 1166
		ACTIONS => {
			"." => 1634
		},
		DEFAULT => -1167,
		GOTOS => {
			'opt_wild' => 1633
		}
	},
	{#State 1167
		ACTIONS => {
			'CONSISTENT_SYM' => 1635
		}
	},
	{#State 1168
		DEFAULT => -531
	},
	{#State 1169
		ACTIONS => {
			'UNTIL_SYM' => 1636
		},
		DEFAULT => -540,
		GOTOS => {
			'slave_until' => 1637
		}
	},
	{#State 1170
		DEFAULT => -530
	},
	{#State 1171
		ACTIONS => {
			'UNTIL_SYM' => 1636
		},
		DEFAULT => -540,
		GOTOS => {
			'slave_until' => 1638
		}
	},
	{#State 1172
		ACTIONS => {
			'ALL' => 1639,
			'DISTINCT' => 1640
		},
		DEFAULT => -1839,
		GOTOS => {
			'union_option' => 1641
		}
	},
	{#State 1173
		DEFAULT => -601
	},
	{#State 1174
		DEFAULT => -1831
	},
	{#State 1175
		DEFAULT => -628
	},
	{#State 1176
		DEFAULT => -629
	},
	{#State 1177
		ACTIONS => {
			"," => 1647,
			'FROM' => 1644,
			'INTO' => 1643,
			'ORDER_SYM' => 1613
		},
		DEFAULT => -1046,
		GOTOS => {
			'select_into' => 1642,
			'select_from' => 1645,
			'into' => 1646,
			'order_clause' => 1649,
			'opt_order_clause' => 1648
		}
	},
	{#State 1178
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1652,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'select_item2' => 1651,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'table_wild' => 1650,
			'ident' => 1653,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1179
		DEFAULT => -612
	},
	{#State 1180
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'INTO' => 745,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 748,
			'insert_table' => 744,
			'ident' => 435,
			'keyword_sp' => 287,
			'insert2' => 1654,
			'IDENT_sys' => 297,
			'table_name' => 746
		}
	},
	{#State 1181
		ACTIONS => {
			'FROM' => 1655,
			"," => 1298
		}
	},
	{#State 1182
		ACTIONS => {
			'ON' => 1656
		}
	},
	{#State 1183
		DEFAULT => -1733
	},
	{#State 1184
		ACTIONS => {
			'PRIVILEGES' => 1321
		},
		DEFAULT => -1746,
		GOTOS => {
			'opt_privileges' => 1657
		}
	},
	{#State 1185
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'table_list' => 1658,
			'IDENT_sys' => 297,
			'table_name' => 837,
			'ident' => 435
		}
	},
	{#State 1186
		ACTIONS => {
			'TEXT_STRING' => 703,
			"\@" => 1661
		},
		GOTOS => {
			'prepare_src' => 1660,
			'TEXT_STRING_sys' => 1659
		}
	},
	{#State 1187
		ACTIONS => {
			'EXTENDED_SYM' => 1664,
			"," => 1298,
			'QUICK' => 1662
		},
		DEFAULT => -547,
		GOTOS => {
			'opt_checksum_type' => 1663
		}
	},
	{#State 1188
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 1665,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 1666,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'EQ' => 1667,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'SET_VAR' => 1668,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1670,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'charset_name' => 1669,
			'charset_name_or_default' => 1671,
			'ident' => 706,
			'equal' => 1672
		}
	},
	{#State 1189
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 1673,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 1674,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1676,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'old_or_new_charset_name_or_default' => 1675,
			'old_or_new_charset_name' => 1677,
			'ident' => 706
		}
	},
	{#State 1190
		DEFAULT => -1680
	},
	{#State 1191
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			"\@" => 1679,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1678,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'ident' => 706
		}
	},
	{#State 1192
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667,
			'FOR_SYM' => 1680
		},
		GOTOS => {
			'equal' => 1681
		}
	},
	{#State 1193
		ACTIONS => {
			"." => 1682
		}
	},
	{#State 1194
		ACTIONS => {
			'ISOLATION' => 1683
		},
		DEFAULT => -1635
	},
	{#State 1195
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		GOTOS => {
			'equal' => 1684
		}
	},
	{#State 1196
		ACTIONS => {
			"." => 1685
		},
		DEFAULT => -1690
	},
	{#State 1197
		ACTIONS => {
			'GLOBAL_SYM' => 735,
			'LOCAL_SYM' => 737,
			'ONE_SHOT_SYM' => 739,
			'SESSION_SYM' => 743
		},
		DEFAULT => -1669,
		GOTOS => {
			'ext_option_value' => 738,
			'option_type_value' => 1686,
			'sys_option_value' => 741,
			'option_type' => 740,
			'option_type2' => 736
		}
	},
	{#State 1198
		DEFAULT => -1119
	},
	{#State 1199
		ACTIONS => {
			"(" => 1687
		},
		GOTOS => {
			'no_braces' => 1689,
			'values_list' => 1688
		}
	},
	{#State 1200
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			")" => 1693,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1206,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'simple_ident_nospvar' => 1694,
			'table_wild' => 1690,
			'ident' => 1696,
			'simple_ident_q' => 1540,
			'insert_ident' => 1691,
			'keyword_sp' => 287,
			'fields' => 1695,
			'IDENT_sys' => 297,
			'create_select' => 1692
		}
	},
	{#State 1201
		ACTIONS => {
			'UNION_SYM' => 1172
		},
		DEFAULT => -1830,
		GOTOS => {
			'union_list' => 1174,
			'union_clause' => 1697
		}
	},
	{#State 1202
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'simple_ident_nospvar' => 1699,
			'ident_eq_value' => 1700,
			'ident' => 1542,
			'simple_ident_q' => 1540,
			'ident_eq_list' => 1698,
			'keyword_sp' => 287,
			'IDENT_sys' => 297
		}
	},
	{#State 1203
		DEFAULT => -1112
	},
	{#State 1204
		ACTIONS => {
			"(" => 1687
		},
		GOTOS => {
			'no_braces' => 1689,
			'values_list' => 1701
		}
	},
	{#State 1205
		DEFAULT => -1122
	},
	{#State 1206
		ACTIONS => {
			'SQL_BIG_RESULT' => 708,
			'SQL_BUFFER_RESULT' => 709,
			'SQL_NO_CACHE_SYM' => 710,
			'SQL_CALC_FOUND_ROWS' => 713,
			'SQL_CACHE_SYM' => 714,
			'ALL' => 716,
			'STRAIGHT_JOIN' => 717,
			'SQL_SMALL_RESULT' => 719,
			'DISTINCT' => 721,
			'HIGH_PRIORITY' => 722
		},
		DEFAULT => -610,
		GOTOS => {
			'select_option' => 715,
			'select_options' => 1702,
			'select_option_list' => 720
		}
	},
	{#State 1207
		ACTIONS => {
			'TABLES' => 761,
			'HOSTS_SYM' => 757,
			'STATUS_SYM' => 753,
			'QUERY_SYM' => 755,
			'SLAVE' => 760,
			'MASTER_SYM' => 752,
			'DES_KEY_FILE' => 759,
			'TABLE_SYM' => 401,
			'PRIVILEGES' => 751,
			'LOGS_SYM' => 756,
			'RESOURCES' => 749
		},
		GOTOS => {
			'table_or_tables' => 754,
			'flush_option' => 1703
		}
	},
	{#State 1208
		DEFAULT => -1268
	},
	{#State 1209
		ACTIONS => {
			"," => 1298
		},
		DEFAULT => -1280
	},
	{#State 1210
		DEFAULT => -1270
	},
	{#State 1211
		ACTIONS => {
			'READ_SYM' => 1704
		}
	},
	{#State 1212
		DEFAULT => -1821
	},
	{#State 1213
		ACTIONS => {
			'RELEASE_SYM' => 1705
		}
	},
	{#State 1214
		DEFAULT => -1825
	},
	{#State 1215
		DEFAULT => -1819
	},
	{#State 1216
		ACTIONS => {
			'CHAIN_SYM' => 1706
		}
	},
	{#State 1217
		ACTIONS => {
			")" => 1707
		}
	},
	{#State 1218
		DEFAULT => -116
	},
	{#State 1219
		ACTIONS => {
			"," => 1708
		},
		DEFAULT => -114
	},
	{#State 1220
		DEFAULT => -90
	},
	{#State 1221
		DEFAULT => -1108
	},
	{#State 1222
		DEFAULT => -1103
	},
	{#State 1223
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1709,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 1224
		DEFAULT => -1100
	},
	{#State 1225
		DEFAULT => -1788
	},
	{#State 1226
		ACTIONS => {
			"(" => 962
		},
		DEFAULT => -640,
		GOTOS => {
			'optional_braces' => 1710
		}
	},
	{#State 1227
		ACTIONS => {
			"\@" => 1711
		},
		DEFAULT => -1393
	},
	{#State 1228
		ACTIONS => {
			"," => 1712
		},
		DEFAULT => -1101
	},
	{#State 1229
		ACTIONS => {
			'RESTRICT' => 1715,
			"," => 1298,
			'CASCADE' => 1714
		},
		DEFAULT => -517,
		GOTOS => {
			'opt_restrict' => 1713
		}
	},
	{#State 1230
		DEFAULT => -1098
	},
	{#State 1231
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'table_list' => 1716,
			'IDENT_sys' => 297,
			'table_name' => 837,
			'ident' => 435
		}
	},
	{#State 1232
		DEFAULT => -1099
	},
	{#State 1233
		DEFAULT => -1282
	},
	{#State 1234
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 781,
			'IDENT_sys' => 297,
			'table_to_table' => 1717,
			'ident' => 435
		}
	},
	{#State 1235
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1718,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 1236
		ACTIONS => {
			'TO_SYM' => 1719
		}
	},
	{#State 1237
		ACTIONS => {
			"," => 1720
		},
		DEFAULT => -575
	},
	{#State 1238
		ACTIONS => {
			'SQL_SYM' => 1729,
			'READS_SYM' => 1725,
			'MODIFIES_SYM' => 1727,
			'NO_SYM' => 1726,
			'LANGUAGE_SYM' => 1724,
			'CONTAINS_SYM' => 1722,
			'COMMENT_SYM' => 1721
		},
		DEFAULT => -484,
		GOTOS => {
			'sp_suid' => 1728,
			'sp_chistic' => 1723
		}
	},
	{#State 1239
		ACTIONS => {
			'FORCE_SYM' => 1739,
			'DISCARD' => 1759,
			'AUTO_INC' => 1769,
			'ORDER_SYM' => 1740,
			'ROW_FORMAT_SYM' => 1760,
			'DATA_SYM' => 1753,
			'CHANGE' => 1741,
			'DROP' => 1730,
			'INDEX_SYM' => 1731,
			'RENAME' => 1763,
			'ENABLE_SYM' => 1761,
			'MODIFY_SYM' => 1755,
			'CONVERT_SYM' => 1732,
			'TYPE_SYM' => 1746,
			'MAX_ROWS' => 1765,
			'ALTER' => 1764,
			'PACK_KEYS_SYM' => 1734,
			'UNION_SYM' => 1742,
			'PASSWORD' => 1767,
			'RAID_TYPE' => 1766,
			";" => -489,
			'INSERT_METHOD' => 1757,
			"," => -489,
			'MIN_ROWS' => 1747,
			'DISABLE_SYM' => 1736,
			'IMPORT' => 1743,
			'ENGINE_SYM' => 1768,
			'COMMENT_SYM' => 1737,
			'RAID_CHUNKSIZE' => 1738,
			'DELAY_KEY_WRITE_SYM' => 1762,
			'DEFAULT' => 1245,
			'ADD' => 1749,
			'AVG_ROW_LENGTH' => 1750,
			'CONNECTION_SYM' => 1752,
			'RAID_CHUNKS' => 1758,
			'CHECKSUM_SYM' => 1744,
			'END_OF_INPUT' => -489
		},
		DEFAULT => -415,
		GOTOS => {
			'opt_default' => 1243,
			'alter_order_clause' => 1745,
			'default_collation' => 1751,
			'create_table_options_space_separated' => 1735,
			'alter_list_item' => 1733,
			'default_charset' => 1756,
			'alter_list' => 1754,
			'add_column' => 1770,
			'create_table_option' => 1748
		}
	},
	{#State 1240
		DEFAULT => -1858
	},
	{#State 1241
		DEFAULT => -1860
	},
	{#State 1242
		DEFAULT => -1859
	},
	{#State 1243
		ACTIONS => {
			'CHARSET' => 490,
			'CHAR_SYM' => 473,
			'COLLATE_SYM' => 1772
		},
		GOTOS => {
			'charset' => 1771
		}
	},
	{#State 1244
		DEFAULT => -219
	},
	{#State 1245
		DEFAULT => -416
	},
	{#State 1246
		DEFAULT => -483
	},
	{#State 1247
		ACTIONS => {
			";" => -218,
			'END_OF_INPUT' => -218,
			'DEFAULT' => 1245
		},
		DEFAULT => -415,
		GOTOS => {
			'default_charset' => 1249,
			'opt_default' => 1243,
			'default_collation' => 1248,
			'create_database_option' => 1773
		}
	},
	{#State 1248
		DEFAULT => -221
	},
	{#State 1249
		DEFAULT => -222
	},
	{#State 1250
		ACTIONS => {
			'SQL_SYM' => 1729,
			'READS_SYM' => 1725,
			'MODIFIES_SYM' => 1727,
			'NO_SYM' => 1726,
			'LANGUAGE_SYM' => 1724,
			'CONTAINS_SYM' => 1722,
			'COMMENT_SYM' => 1721
		},
		DEFAULT => -485,
		GOTOS => {
			'sp_suid' => 1728,
			'sp_chistic' => 1723
		}
	},
	{#State 1251
		ACTIONS => {
			'VIEW_SYM' => 1774
		}
	},
	{#State 1252
		ACTIONS => {
			"," => 1775
		},
		DEFAULT => -954
	},
	{#State 1253
		DEFAULT => -978,
		GOTOS => {
			'get_select_lex' => 1776
		}
	},
	{#State 1254
		ACTIONS => {
			'JOIN_SYM' => 1777,
			'CROSS' => 1779,
			'INNER_SYM' => 1780,
			'RIGHT' => 1781,
			'STRAIGHT_JOIN' => 1782,
			'NATURAL' => 1783,
			'LEFT' => 1778
		},
		DEFAULT => -955,
		GOTOS => {
			'normal_join' => 1784
		}
	},
	{#State 1255
		DEFAULT => -953
	},
	{#State 1256
		ACTIONS => {
			'SET' => 1785
		}
	},
	{#State 1257
		DEFAULT => -978,
		GOTOS => {
			'get_select_lex' => 1786
		}
	},
	{#State 1258
		DEFAULT => -979
	},
	{#State 1259
		ACTIONS => {
			'ON' => -1025,
			'WHERE' => -1025,
			'FORCE_SYM' => -1025,
			'FOR_SYM' => -1025,
			'JOIN_SYM' => -1025,
			'ORDER_SYM' => -1025,
			'USE_SYM' => -1025,
			'INTO' => -1025,
			'UNION_SYM' => -1025,
			'LOCK_SYM' => -1025,
			'PROCEDURE' => -1025,
			'END_OF_INPUT' => -1025,
			'SET' => -1025,
			'LEFT' => -1025,
			"," => -1025,
			'EQ' => 1335,
			'USING' => -1025,
			'HAVING' => -1025,
			'AS' => 1337,
			'WITH' => -1025,
			'CROSS' => -1025,
			'GROUP' => -1025,
			'IGNORE_SYM' => -1025,
			")" => -1025,
			";" => -1025,
			'INNER_SYM' => -1025,
			'RIGHT' => -1025,
			'STRAIGHT_JOIN' => -1025,
			'NATURAL' => -1025,
			'LIMIT' => -1025
		},
		DEFAULT => -1022,
		GOTOS => {
			'table_alias' => 1338,
			'opt_table_alias' => 1787
		}
	},
	{#State 1260
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1788
		}
	},
	{#State 1261
		DEFAULT => -952
	},
	{#State 1262
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 796,
			'IDENT_sys' => 297,
			'ident' => 435,
			'assign_to_keycache' => 1789
		}
	},
	{#State 1263
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 1790,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'key_cache_name' => 1791,
			'ident' => 1792
		}
	},
	{#State 1264
		DEFAULT => -456
	},
	{#State 1265
		DEFAULT => -591
	},
	{#State 1266
		DEFAULT => -455
	},
	{#State 1267
		DEFAULT => -584
	},
	{#State 1268
		DEFAULT => -458
	},
	{#State 1269
		ACTIONS => {
			"(" => 1793
		}
	},
	{#State 1270
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 1794,
			'TEXT_STRING_literal' => 801
		}
	},
	{#State 1271
		DEFAULT => -1893
	},
	{#State 1272
		DEFAULT => -1894
	},
	{#State 1273
		DEFAULT => -1881
	},
	{#State 1274
		ACTIONS => {
			'FOR_SYM' => 1795
		},
		DEFAULT => -1899,
		GOTOS => {
			'opt_migrate' => 1796
		}
	},
	{#State 1275
		DEFAULT => -1882
	},
	{#State 1276
		ACTIONS => {
			'PHASE_SYM' => 1797
		}
	},
	{#State 1277
		DEFAULT => -1884
	},
	{#State 1278
		DEFAULT => -1378
	},
	{#State 1279
		ACTIONS => {
			'SQL_THREAD' => 815,
			'RELAY_THREAD' => 814
		},
		DEFAULT => -537,
		GOTOS => {
			'slave_thread_opt' => 1798
		}
	},
	{#State 1280
		ACTIONS => {
			'USING' => 1801,
			'TYPE_SYM' => 1800
		},
		DEFAULT => -466,
		GOTOS => {
			'key_alg' => 1799
		}
	},
	{#State 1281
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1802,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 1282
		DEFAULT => -1848
	},
	{#State 1283
		ACTIONS => {
			'IDENTIFIED_SYM' => 1803
		},
		DEFAULT => -1794
	},
	{#State 1284
		DEFAULT => -1790
	},
	{#State 1285
		ACTIONS => {
			"," => 1804
		},
		DEFAULT => -88
	},
	{#State 1286
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 1805,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 1287
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 1806,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 1288
		ACTIONS => {
			'FUNCTION_SYM' => 1807
		}
	},
	{#State 1289
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1808,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 1290
		ACTIONS => {
			'INVOKER_SYM' => 1809,
			'DEFINER_SYM' => 1810
		}
	},
	{#State 1291
		ACTIONS => {
			";" => -217,
			'END_OF_INPUT' => -217,
			'DEFAULT' => 1245
		},
		DEFAULT => -415,
		GOTOS => {
			'default_charset' => 1249,
			'opt_default' => 1243,
			'create_database_options' => 1247,
			'default_collation' => 1248,
			'create_database_option' => 1244,
			'opt_create_database_options' => 1811
		}
	},
	{#State 1292
		ACTIONS => {
			'EXISTS' => 1812
		}
	},
	{#State 1293
		DEFAULT => -1853
	},
	{#State 1294
		DEFAULT => -568
	},
	{#State 1295
		DEFAULT => -564
	},
	{#State 1296
		ACTIONS => {
			'UPGRADE_SYM' => 1813
		}
	},
	{#State 1297
		ACTIONS => {
			'EXTENDED_SYM' => 1301,
			'CHANGED' => 1294,
			'FOR_SYM' => 1296,
			'FAST_SYM' => 1299,
			'MEDIUM_SYM' => 1300,
			'QUICK' => 1295
		},
		DEFAULT => -562,
		GOTOS => {
			'mi_check_type' => 1297,
			'mi_check_types' => 1814
		}
	},
	{#State 1298
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'IDENT_sys' => 297,
			'table_name' => 1815,
			'ident' => 435
		}
	},
	{#State 1299
		DEFAULT => -565
	},
	{#State 1300
		DEFAULT => -566
	},
	{#State 1301
		DEFAULT => -567
	},
	{#State 1302
		DEFAULT => -561
	},
	{#State 1303
		DEFAULT => -559
	},
	{#State 1304
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 1816
		}
	},
	{#State 1305
		DEFAULT => -1771
	},
	{#State 1306
		DEFAULT => -1770
	},
	{#State 1307
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'column_list_id' => 1817,
			'column_list' => 1819,
			'ident' => 1818
		}
	},
	{#State 1308
		DEFAULT => -1752
	},
	{#State 1309
		ACTIONS => {
			'PROCEDURE' => 1821,
			'TABLE_SYM' => 1822,
			'FUNCTION_SYM' => 1823
		},
		DEFAULT => -1742,
		GOTOS => {
			'opt_table' => 1820
		}
	},
	{#State 1310
		DEFAULT => -1769
	},
	{#State 1311
		DEFAULT => -1751
	},
	{#State 1312
		DEFAULT => -1765
	},
	{#State 1313
		ACTIONS => {
			'DELETE_SYM' => 863,
			'SUPER_SYM' => 861,
			'GRANT' => 848,
			'UPDATE_SYM' => 843,
			'SELECT_SYM' => 857,
			'PROCESS' => 856,
			'INSERT' => 846,
			'RELOAD' => 851,
			'SHOW' => 854,
			'EXECUTE_SYM' => 849,
			'DROP' => 840,
			'INDEX_SYM' => 841,
			'REFERENCES' => 862,
			'FILE_SYM' => 859,
			'ALTER' => 860,
			'SHUTDOWN' => 864,
			'CREATE' => 853,
			'REPLICATION' => 842,
			'USAGE' => 858,
			'LOCK_SYM' => 845
		},
		GOTOS => {
			'object_privilege' => 1824
		}
	},
	{#State 1314
		DEFAULT => -1774
	},
	{#State 1315
		ACTIONS => {
			'TABLES' => 1825
		}
	},
	{#State 1316
		DEFAULT => -1776
	},
	{#State 1317
		DEFAULT => -1772
	},
	{#State 1318
		DEFAULT => -1766
	},
	{#State 1319
		DEFAULT => -1773
	},
	{#State 1320
		DEFAULT => -1745
	},
	{#State 1321
		DEFAULT => -1747
	},
	{#State 1322
		DEFAULT => -1750
	},
	{#State 1323
		DEFAULT => -1775
	},
	{#State 1324
		DEFAULT => -1753
	},
	{#State 1325
		ACTIONS => {
			'EXTENDED_SYM' => 1301,
			"," => 1298,
			'CHANGED' => 1294,
			'FOR_SYM' => 1296,
			'FAST_SYM' => 1299,
			'MEDIUM_SYM' => 1300,
			'QUICK' => 1295
		},
		DEFAULT => -560,
		GOTOS => {
			'mi_check_type' => 1297,
			'mi_check_types' => 1302,
			'opt_mi_check_type' => 1826
		}
	},
	{#State 1326
		ACTIONS => {
			'EXTENDED_SYM' => 1831,
			'USE_FRM' => 1832,
			"," => 1298,
			'QUICK' => 1827
		},
		DEFAULT => -551,
		GOTOS => {
			'mi_repair_type' => 1830,
			'mi_repair_types' => 1828,
			'opt_mi_repair_type' => 1829
		}
	},
	{#State 1327
		DEFAULT => -1288
	},
	{#State 1328
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 1833
		}
	},
	{#State 1329
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1834,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1330
		ACTIONS => {
			'WHERE' => 1835
		},
		DEFAULT => -1029,
		GOTOS => {
			'where_clause' => 1836
		}
	},
	{#State 1331
		ACTIONS => {
			";" => -1722,
			'WHERE' => -1722,
			'END_OF_INPUT' => -1722,
			'LIMIT' => -1722
		},
		DEFAULT => -1562
	},
	{#State 1332
		ACTIONS => {
			'EQ' => 1840,
			'GE' => 1843,
			'GT_SYM' => 1844,
			'LT' => 1842,
			'LAST_SYM' => 1841,
			'LE' => 1837,
			'PREV_SYM' => 1838,
			'NEXT_SYM' => 1846,
			'FIRST_SYM' => 1847
		},
		GOTOS => {
			'handler_rkey_mode' => 1845,
			'handler_rkey_function' => 1839
		}
	},
	{#State 1333
		ACTIONS => {
			";" => -1721,
			'WHERE' => -1721,
			'END_OF_INPUT' => -1721,
			'LIMIT' => -1721
		},
		DEFAULT => -1494
	},
	{#State 1334
		DEFAULT => -1719
	},
	{#State 1335
		DEFAULT => -1024
	},
	{#State 1336
		DEFAULT => -1716
	},
	{#State 1337
		DEFAULT => -1023
	},
	{#State 1338
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1848
		}
	},
	{#State 1339
		ACTIONS => {
			'EQ' => 1849
		}
	},
	{#State 1340
		ACTIONS => {
			'EQ' => 1850
		}
	},
	{#State 1341
		ACTIONS => {
			'EQ' => 1851
		}
	},
	{#State 1342
		ACTIONS => {
			'EQ' => 1852
		}
	},
	{#State 1343
		DEFAULT => -79
	},
	{#State 1344
		ACTIONS => {
			'EQ' => 1853
		}
	},
	{#State 1345
		ACTIONS => {
			'EQ' => 1854
		}
	},
	{#State 1346
		ACTIONS => {
			'EQ' => 1855
		}
	},
	{#State 1347
		DEFAULT => -66
	},
	{#State 1348
		ACTIONS => {
			'EQ' => 1856
		}
	},
	{#State 1349
		ACTIONS => {
			"," => 1857
		},
		DEFAULT => -65
	},
	{#State 1350
		ACTIONS => {
			'EQ' => 1858
		}
	},
	{#State 1351
		ACTIONS => {
			'EQ' => 1859
		}
	},
	{#State 1352
		ACTIONS => {
			'EQ' => 1860
		}
	},
	{#State 1353
		ACTIONS => {
			'EQ' => 1861
		}
	},
	{#State 1354
		ACTIONS => {
			'EQ' => 1862
		}
	},
	{#State 1355
		ACTIONS => {
			'EQ' => 1863
		}
	},
	{#State 1356
		ACTIONS => {
			'EQ' => 1864
		}
	},
	{#State 1357
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1865
		}
	},
	{#State 1358
		DEFAULT => -1824
	},
	{#State 1359
		DEFAULT => -1826
	},
	{#State 1360
		ACTIONS => {
			")" => 1866
		}
	},
	{#State 1361
		DEFAULT => -1215
	},
	{#State 1362
		DEFAULT => -1219
	},
	{#State 1363
		DEFAULT => -1255
	},
	{#State 1364
		DEFAULT => -1254
	},
	{#State 1365
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1867
		}
	},
	{#State 1366
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 1868
		}
	},
	{#State 1367
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1869,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 1368
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 1870
		}
	},
	{#State 1369
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 1871
		}
	},
	{#State 1370
		DEFAULT => -1233
	},
	{#State 1371
		DEFAULT => -1235
	},
	{#State 1372
		ACTIONS => {
			'FROM' => 892,
			'IN_SYM' => 893
		},
		DEFAULT => -1243,
		GOTOS => {
			'opt_db' => 1872,
			'from_or_in' => 1365
		}
	},
	{#State 1373
		ACTIONS => {
			'FROM' => 1873
		},
		DEFAULT => -1251,
		GOTOS => {
			'binlog_from' => 1874
		}
	},
	{#State 1374
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 1875
		}
	},
	{#State 1375
		DEFAULT => -1058
	},
	{#State 1376
		DEFAULT => -1064
	},
	{#State 1377
		DEFAULT => -1062
	},
	{#State 1378
		DEFAULT => -1065
	},
	{#State 1379
		DEFAULT => -1063
	},
	{#State 1380
		ACTIONS => {
			'OFFSET_SYM' => 1876,
			"," => 1877
		},
		DEFAULT => -1059
	},
	{#State 1381
		DEFAULT => -1225
	},
	{#State 1382
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 1878
		}
	},
	{#State 1383
		DEFAULT => -1231
	},
	{#State 1384
		DEFAULT => -1227
	},
	{#State 1385
		DEFAULT => -1228
	},
	{#State 1386
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1879
		}
	},
	{#State 1387
		DEFAULT => -1232
	},
	{#State 1388
		DEFAULT => -1183
	},
	{#State 1389
		ACTIONS => {
			'ALL' => 917,
			'SWAPS_SYM' => 912,
			'BLOCK_SYM' => 914,
			'CPU_SYM' => 913,
			'MEMORY_SYM' => 920,
			'SOURCE_SYM' => 922,
			'CONTEXT_SYM' => 918,
			'PAGE_SYM' => 919,
			'IPC_SYM' => 911
		},
		GOTOS => {
			'profile_def' => 1880
		}
	},
	{#State 1390
		DEFAULT => -1184
	},
	{#State 1391
		DEFAULT => -1185
	},
	{#State 1392
		ACTIONS => {
			'QUERY_SYM' => 1881
		}
	},
	{#State 1393
		ACTIONS => {
			'LIMIT' => 899
		},
		DEFAULT => -1054,
		GOTOS => {
			'opt_limit_clause_init' => 1882,
			'limit_clause' => 898
		}
	},
	{#State 1394
		ACTIONS => {
			'SLAVE' => 1883
		}
	},
	{#State 1395
		DEFAULT => -1237
	},
	{#State 1396
		DEFAULT => -1238
	},
	{#State 1397
		DEFAULT => -1198
	},
	{#State 1398
		DEFAULT => -1234
	},
	{#State 1399
		DEFAULT => -1236
	},
	{#State 1400
		ACTIONS => {
			"," => 1884
		},
		DEFAULT => -60
	},
	{#State 1401
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1885,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'ident' => 706
		}
	},
	{#State 1402
		DEFAULT => -62
	},
	{#State 1403
		ACTIONS => {
			")" => 1886
		}
	},
	{#State 1404
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1887,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1405
		DEFAULT => -1028
	},
	{#State 1406
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1888
		}
	},
	{#State 1407
		ACTIONS => {
			"," => 1889
		}
	},
	{#State 1408
		ACTIONS => {
			"," => 1890
		}
	},
	{#State 1409
		ACTIONS => {
			")" => 1891
		}
	},
	{#State 1410
		ACTIONS => {
			")" => 1892
		}
	},
	{#State 1411
		ACTIONS => {
			")" => 1893
		}
	},
	{#State 1412
		ACTIONS => {
			")" => 1894
		}
	},
	{#State 1413
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			"*" => 1895,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1887,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1414
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1896,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1415
		DEFAULT => -698
	},
	{#State 1416
		DEFAULT => -699
	},
	{#State 1417
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 1897,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1418
		DEFAULT => -645
	},
	{#State 1419
		ACTIONS => {
			")" => 1898
		}
	},
	{#State 1420
		ACTIONS => {
			'USING' => 1900,
			"," => 1899
		}
	},
	{#State 1421
		ACTIONS => {
			"," => 1901
		}
	},
	{#State 1422
		ACTIONS => {
			'USING' => 1902,
			")" => 1903
		}
	},
	{#State 1423
		ACTIONS => {
			"," => 1904
		}
	},
	{#State 1424
		ACTIONS => {
			")" => 1905
		}
	},
	{#State 1425
		ACTIONS => {
			")" => 1906
		}
	},
	{#State 1426
		ACTIONS => {
			")" => 1907
		}
	},
	{#State 1427
		ACTIONS => {
			"," => 1908,
			")" => 1909
		}
	},
	{#State 1428
		ACTIONS => {
			"," => 1910
		}
	},
	{#State 1429
		ACTIONS => {
			"," => 1911,
			")" => 1912
		}
	},
	{#State 1430
		ACTIONS => {
			"," => 1913,
			")" => 1914
		}
	},
	{#State 1431
		ACTIONS => {
			"+" => 1094,
			"-" => 1095
		},
		DEFAULT => -682
	},
	{#State 1432
		ACTIONS => {
			"+" => 1094,
			"-" => 1095
		},
		DEFAULT => -683
	},
	{#State 1433
		DEFAULT => -641
	},
	{#State 1434
		ACTIONS => {
			")" => 1915
		}
	},
	{#State 1435
		ACTIONS => {
			")" => 1916
		}
	},
	{#State 1436
		ACTIONS => {
			")" => 1917
		}
	},
	{#State 1437
		ACTIONS => {
			'TEXT_STRING' => 554,
			"," => 1918
		},
		GOTOS => {
			'TEXT_STRING_literal' => 948
		}
	},
	{#State 1438
		ACTIONS => {
			"," => 1919
		}
	},
	{#State 1439
		ACTIONS => {
			"(" => 1454,
			'SELECT_SYM' => 976
		},
		GOTOS => {
			'subselect' => 1920
		}
	},
	{#State 1440
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1921,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1441
		DEFAULT => -727
	},
	{#State 1442
		DEFAULT => -726
	},
	{#State 1443
		ACTIONS => {
			'SQL_BIG_RESULT' => 708,
			'SQL_BUFFER_RESULT' => 709,
			'SQL_NO_CACHE_SYM' => 710,
			'SQL_CALC_FOUND_ROWS' => 713,
			'SQL_CACHE_SYM' => 714,
			'ALL' => 716,
			'STRAIGHT_JOIN' => 717,
			'SQL_SMALL_RESULT' => 719,
			'DISTINCT' => 721,
			'HIGH_PRIORITY' => 722
		},
		DEFAULT => -610,
		GOTOS => {
			'select_option' => 715,
			'select_options' => 718,
			'subselect_init' => 1922,
			'select_option_list' => 720,
			'select_init2' => 1923,
			'select_part2' => 711
		}
	},
	{#State 1444
		ACTIONS => {
			")" => 1924
		}
	},
	{#State 1445
		ACTIONS => {
			")" => 1925
		}
	},
	{#State 1446
		ACTIONS => {
			"," => 1926,
			")" => 1927
		}
	},
	{#State 1447
		ACTIONS => {
			'COLLATE_SYM' => 989
		},
		DEFAULT => -696
	},
	{#State 1448
		ACTIONS => {
			"," => 1928
		}
	},
	{#State 1449
		DEFAULT => -701
	},
	{#State 1450
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'bool_factor' => 1929,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1451
		DEFAULT => -700
	},
	{#State 1452
		ACTIONS => {
			"," => 1930
		}
	},
	{#State 1453
		ACTIONS => {
			"," => 1931,
			")" => 1932
		}
	},
	{#State 1454
		DEFAULT => -1845,
		GOTOS => {
			'subselect_start' => 1439
		}
	},
	{#State 1455
		ACTIONS => {
			")" => 1933
		}
	},
	{#State 1456
		ACTIONS => {
			'COLLATE_SYM' => 989
		},
		DEFAULT => -721
	},
	{#State 1457
		DEFAULT => -716
	},
	{#State 1458
		ACTIONS => {
			")" => 1934
		}
	},
	{#State 1459
		ACTIONS => {
			"," => 1935
		}
	},
	{#State 1460
		ACTIONS => {
			'SHIFT_LEFT' => 959,
			'SHIFT_RIGHT' => 960
		},
		DEFAULT => -680
	},
	{#State 1461
		ACTIONS => {
			")" => 1936
		}
	},
	{#State 1462
		ACTIONS => {
			'TEXT_STRING' => 554,
			"," => 1937
		},
		GOTOS => {
			'TEXT_STRING_literal' => 948
		}
	},
	{#State 1463
		DEFAULT => -1069
	},
	{#State 1464
		DEFAULT => -1070
	},
	{#State 1465
		ACTIONS => {
			"," => 1938
		}
	},
	{#State 1466
		DEFAULT => -1068
	},
	{#State 1467
		DEFAULT => -1073
	},
	{#State 1468
		DEFAULT => -1071
	},
	{#State 1469
		DEFAULT => -1072
	},
	{#State 1470
		ACTIONS => {
			"," => 1939,
			")" => 1940
		}
	},
	{#State 1471
		ACTIONS => {
			")" => 1941
		}
	},
	{#State 1472
		ACTIONS => {
			")" => 1942
		}
	},
	{#State 1473
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1943
		}
	},
	{#State 1474
		ACTIONS => {
			")" => 1944
		}
	},
	{#State 1475
		ACTIONS => {
			"," => 1945,
			")" => 1946
		}
	},
	{#State 1476
		ACTIONS => {
			")" => 1947
		}
	},
	{#State 1477
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1948
		}
	},
	{#State 1478
		ACTIONS => {
			")" => 1949
		}
	},
	{#State 1479
		ACTIONS => {
			"," => 1950
		}
	},
	{#State 1480
		ACTIONS => {
			")" => 1951
		}
	},
	{#State 1481
		DEFAULT => -813
	},
	{#State 1482
		ACTIONS => {
			"," => 1952
		}
	},
	{#State 1483
		ACTIONS => {
			"," => 1953
		}
	},
	{#State 1484
		ACTIONS => {
			"," => 1954
		}
	},
	{#State 1485
		ACTIONS => {
			")" => 1955
		}
	},
	{#State 1486
		ACTIONS => {
			"|" => 1013
		},
		DEFAULT => -675
	},
	{#State 1487
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'bit_expr' => 1956,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1488
		ACTIONS => {
			"&" => 992
		},
		DEFAULT => -678
	},
	{#State 1489
		ACTIONS => {
			"|" => 1013,
			'AND_SYM' => 1957
		}
	},
	{#State 1490
		ACTIONS => {
			'OR_OR_SYM' => 988,
			'ESCAPE_SYM' => 1959,
			'COLLATE_SYM' => 989
		},
		DEFAULT => -1034,
		GOTOS => {
			'opt_escape' => 1958
		}
	},
	{#State 1491
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'bit_expr' => 1960,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1492
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'bit_expr' => 1961,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1493
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 1962,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'geometry_function' => 685
		}
	},
	{#State 1494
		ACTIONS => {
			"(" => 1963
		}
	},
	{#State 1495
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 973,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 976,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1964,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'subselect' => 1965,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1496
		ACTIONS => {
			"," => 1966
		}
	},
	{#State 1497
		ACTIONS => {
			"," => 1967
		}
	},
	{#State 1498
		ACTIONS => {
			"," => 1968,
			")" => 1969
		}
	},
	{#State 1499
		ACTIONS => {
			")" => 1970
		}
	},
	{#State 1500
		ACTIONS => {
			"," => 1971,
			")" => 1972
		}
	},
	{#State 1501
		ACTIONS => {
			")" => 1973
		}
	},
	{#State 1502
		DEFAULT => -846
	},
	{#State 1503
		ACTIONS => {
			"," => 1974
		}
	},
	{#State 1504
		ACTIONS => {
			"," => 1975,
			")" => 1976
		}
	},
	{#State 1505
		ACTIONS => {
			"," => 1977
		}
	},
	{#State 1506
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 1978,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1507
		ACTIONS => {
			'FROM' => 1979
		}
	},
	{#State 1508
		DEFAULT => -940
	},
	{#State 1509
		ACTIONS => {
			"^" => 982
		},
		DEFAULT => -691
	},
	{#State 1510
		ACTIONS => {
			"^" => 982
		},
		DEFAULT => -693
	},
	{#State 1511
		ACTIONS => {
			"^" => 982
		},
		DEFAULT => -694
	},
	{#State 1512
		ACTIONS => {
			"^" => 982
		},
		DEFAULT => -692
	},
	{#State 1513
		ACTIONS => {
			"^" => 982
		},
		DEFAULT => -690
	},
	{#State 1514
		ACTIONS => {
			")" => 1980
		}
	},
	{#State 1515
		ACTIONS => {
			"," => 1981,
			")" => 1982
		}
	},
	{#State 1516
		ACTIONS => {
			")" => 1983
		}
	},
	{#State 1517
		DEFAULT => -791
	},
	{#State 1518
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 1984,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1519
		DEFAULT => -919
	},
	{#State 1520
		ACTIONS => {
			")" => 1985
		}
	},
	{#State 1521
		DEFAULT => -741
	},
	{#State 1522
		ACTIONS => {
			")" => 1986
		}
	},
	{#State 1523
		ACTIONS => {
			"," => 1987
		}
	},
	{#State 1524
		ACTIONS => {
			"," => 1988
		}
	},
	{#State 1525
		ACTIONS => {
			"," => 1989
		}
	},
	{#State 1526
		ACTIONS => {
			")" => 1990
		}
	},
	{#State 1527
		ACTIONS => {
			")" => 1991
		}
	},
	{#State 1528
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 1992
		}
	},
	{#State 1529
		ACTIONS => {
			"," => 1993
		}
	},
	{#State 1530
		ACTIONS => {
			")" => 1994
		}
	},
	{#State 1531
		ACTIONS => {
			"(" => 1995
		}
	},
	{#State 1532
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'simple_ident' => 1996,
			'ident' => 1080,
			'simple_ident_q' => 586
		}
	},
	{#State 1533
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1997
		}
	},
	{#State 1534
		ACTIONS => {
			"," => 1998,
			")" => 1999
		}
	},
	{#State 1535
		ACTIONS => {
			")" => 2000
		}
	},
	{#State 1536
		ACTIONS => {
			"," => 2001,
			")" => 2002
		}
	},
	{#State 1537
		ACTIONS => {
			"," => 2003
		}
	},
	{#State 1538
		ACTIONS => {
			'FROM' => 2004,
			"," => 2005
		}
	},
	{#State 1539
		ACTIONS => {
			"," => 2006
		}
	},
	{#State 1540
		DEFAULT => -1369
	},
	{#State 1541
		ACTIONS => {
			")" => 2007
		}
	},
	{#State 1542
		ACTIONS => {
			"." => 1533
		},
		DEFAULT => -1368
	},
	{#State 1543
		ACTIONS => {
			"," => 2008
		}
	},
	{#State 1544
		ACTIONS => {
			'AS' => 2009
		}
	},
	{#State 1545
		ACTIONS => {
			")" => 2010
		}
	},
	{#State 1546
		ACTIONS => {
			"," => 2011
		}
	},
	{#State 1547
		ACTIONS => {
			'YEAR_SYM' => 1028,
			'MINUTE_MICROSECOND_SYM' => 1030,
			'MICROSECOND_SYM' => 1031,
			'MINUTE_SECOND_SYM' => 1032,
			'HOUR_SYM' => 1033,
			'DAY_MICROSECOND_SYM' => 1034,
			'HOUR_SECOND_SYM' => 1035,
			'FRAC_SECOND_SYM' => 1036,
			'QUARTER_SYM' => 1037,
			'HOUR_MINUTE_SYM' => 1038,
			'YEAR_MONTH_SYM' => 1039,
			'WEEK_SYM' => 1040,
			'SECOND_MICROSECOND_SYM' => 1041,
			'DAY_MINUTE_SYM' => 1042,
			'MINUTE_SYM' => 1043,
			'DAY_HOUR_SYM' => 1044,
			'DAY_SYM' => 1045,
			'DAY_SECOND_SYM' => 1046,
			'SECOND_SYM' => 1047,
			'MONTH_SYM' => 1049,
			'HOUR_MICROSECOND_SYM' => 1050
		},
		DEFAULT => -790,
		GOTOS => {
			'interval_time_st' => 1029,
			'interval' => 2012
		}
	},
	{#State 1548
		ACTIONS => {
			"/" => 1053,
			'DIV_SYM' => 1054,
			'MOD_SYM' => 1055,
			"%" => 1056,
			"*" => 1057
		},
		DEFAULT => -685
	},
	{#State 1549
		ACTIONS => {
			'YEAR_SYM' => 1028,
			'MINUTE_MICROSECOND_SYM' => 1030,
			'MICROSECOND_SYM' => 1031,
			'MINUTE_SECOND_SYM' => 1032,
			'HOUR_SYM' => 1033,
			'DAY_MICROSECOND_SYM' => 1034,
			'HOUR_SECOND_SYM' => 1035,
			'FRAC_SECOND_SYM' => 1036,
			'QUARTER_SYM' => 1037,
			'HOUR_MINUTE_SYM' => 1038,
			'YEAR_MONTH_SYM' => 1039,
			'WEEK_SYM' => 1040,
			'SECOND_MICROSECOND_SYM' => 1041,
			'DAY_MINUTE_SYM' => 1042,
			'MINUTE_SYM' => 1043,
			'DAY_HOUR_SYM' => 1044,
			'DAY_SYM' => 1045,
			'DAY_SECOND_SYM' => 1046,
			'SECOND_SYM' => 1047,
			'MONTH_SYM' => 1049,
			'HOUR_MICROSECOND_SYM' => 1050
		},
		DEFAULT => -790,
		GOTOS => {
			'interval_time_st' => 1029,
			'interval' => 2013
		}
	},
	{#State 1550
		ACTIONS => {
			"/" => 1053,
			'DIV_SYM' => 1054,
			'MOD_SYM' => 1055,
			"%" => 1056,
			"*" => 1057
		},
		DEFAULT => -686
	},
	{#State 1551
		ACTIONS => {
			"," => 2014,
			")" => 2015
		}
	},
	{#State 1552
		ACTIONS => {
			"," => 2016
		}
	},
	{#State 1553
		ACTIONS => {
			")" => 2017
		}
	},
	{#State 1554
		DEFAULT => -891
	},
	{#State 1555
		ACTIONS => {
			"," => 2018
		},
		DEFAULT => -890
	},
	{#State 1556
		DEFAULT => -889
	},
	{#State 1557
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2019,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1558
		ACTIONS => {
			")" => 2020
		}
	},
	{#State 1559
		ACTIONS => {
			"," => 2021
		}
	},
	{#State 1560
		ACTIONS => {
			")" => 2022
		}
	},
	{#State 1561
		DEFAULT => -660
	},
	{#State 1562
		ACTIONS => {
			"(" => 2023
		}
	},
	{#State 1563
		DEFAULT => -712
	},
	{#State 1564
		DEFAULT => -661
	},
	{#State 1565
		ACTIONS => {
			"(" => -713
		},
		DEFAULT => -1439
	},
	{#State 1566
		DEFAULT => -655
	},
	{#State 1567
		DEFAULT => -658
	},
	{#State 1568
		DEFAULT => -651
	},
	{#State 1569
		DEFAULT => -653
	},
	{#State 1570
		ACTIONS => {
			'FALSE_SYM' => 2027,
			'NULL_SYM' => 2025,
			'TRUE_SYM' => 2026,
			'UNKNOWN_SYM' => 2024
		}
	},
	{#State 1571
		ACTIONS => {
			"," => 2028,
			")" => 2029
		}
	},
	{#State 1572
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2030,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1573
		ACTIONS => {
			"." => 2031
		}
	},
	{#State 1574
		ACTIONS => {
			"." => 2032
		}
	},
	{#State 1575
		ACTIONS => {
			"." => 2033
		}
	},
	{#State 1576
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 2034,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'ident' => 706
		}
	},
	{#State 1577
		ACTIONS => {
			")" => 2035
		}
	},
	{#State 1578
		DEFAULT => -818
	},
	{#State 1579
		ACTIONS => {
			"," => 2036,
			")" => 2037
		}
	},
	{#State 1580
		ACTIONS => {
			"(" => 2038,
			"." => 2039
		},
		DEFAULT => -1370
	},
	{#State 1581
		ACTIONS => {
			"," => 2040
		}
	},
	{#State 1582
		ACTIONS => {
			"," => 2041
		}
	},
	{#State 1583
		ACTIONS => {
			")" => 2042
		}
	},
	{#State 1584
		ACTIONS => {
			"," => 2043,
			")" => 2044
		}
	},
	{#State 1585
		ACTIONS => {
			")" => 2045
		}
	},
	{#State 1586
		ACTIONS => {
			"," => 2046
		}
	},
	{#State 1587
		ACTIONS => {
			"}" => 2047
		}
	},
	{#State 1588
		ACTIONS => {
			")" => 2048
		}
	},
	{#State 1589
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'FROM' => 2049,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2050,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1590
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'FROM' => 2051,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2052,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1591
		ACTIONS => {
			'FROM' => 2053,
			")" => 2054
		}
	},
	{#State 1592
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'FROM' => 2055,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2056,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1593
		DEFAULT => -1020
	},
	{#State 1594
		DEFAULT => -1021
	},
	{#State 1595
		DEFAULT => -1019
	},
	{#State 1596
		DEFAULT => -1018
	},
	{#State 1597
		ACTIONS => {
			"," => 2057
		}
	},
	{#State 1598
		ACTIONS => {
			")" => 2058
		}
	},
	{#State 1599
		ACTIONS => {
			"," => 2059
		}
	},
	{#State 1600
		ACTIONS => {
			"," => 2060
		}
	},
	{#State 1601
		ACTIONS => {
			"," => 2061
		}
	},
	{#State 1602
		DEFAULT => -848
	},
	{#State 1603
		ACTIONS => {
			"|" => 1013,
			'IN_SYM' => 2062
		}
	},
	{#State 1604
		ACTIONS => {
			"," => 2063,
			")" => 2064
		}
	},
	{#State 1605
		ACTIONS => {
			")" => 2065
		}
	},
	{#State 1606
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2066
		}
	},
	{#State 1607
		ACTIONS => {
			'ELSE' => 2068,
			'WHEN_SYM' => 2069
		},
		DEFAULT => -948,
		GOTOS => {
			'opt_else' => 2067
		}
	},
	{#State 1608
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2070,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1609
		DEFAULT => -764
	},
	{#State 1610
		ACTIONS => {
			")" => 2071
		}
	},
	{#State 1611
		ACTIONS => {
			"," => 2072,
			")" => 2073
		}
	},
	{#State 1612
		ACTIONS => {
			")" => 2074
		}
	},
	{#State 1613
		ACTIONS => {
			'BY' => 2075
		}
	},
	{#State 1614
		DEFAULT => -1836
	},
	{#State 1615
		DEFAULT => -598
	},
	{#State 1616
		DEFAULT => -1834
	},
	{#State 1617
		DEFAULT => -1838
	},
	{#State 1618
		DEFAULT => -1835
	},
	{#State 1619
		ACTIONS => {
			'LIMIT' => 899
		},
		DEFAULT => -1054,
		GOTOS => {
			'opt_limit_clause_init' => 2076,
			'limit_clause' => 898
		}
	},
	{#State 1620
		DEFAULT => -600
	},
	{#State 1621
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2078,
			'IDENT_sys' => 297,
			'preload_keys' => 2077,
			'preload_list' => 2079,
			'ident' => 435
		}
	},
	{#State 1622
		DEFAULT => -1299
	},
	{#State 1623
		ACTIONS => {
			'INFILE' => 2080
		}
	},
	{#State 1624
		DEFAULT => -1301
	},
	{#State 1625
		ACTIONS => {
			'MASTER_SYM' => 2081
		}
	},
	{#State 1626
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1160,
			'table_lock' => 2082,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 1627
		ACTIONS => {
			'READ_SYM' => 2083,
			'LOW_PRIORITY' => 2085,
			'WRITE_SYM' => 2084
		},
		GOTOS => {
			'lock_option' => 2086
		}
	},
	{#State 1628
		ACTIONS => {
			'USING' => 2087,
			"," => 1632
		}
	},
	{#State 1629
		ACTIONS => {
			'WHERE' => 1835
		},
		DEFAULT => -1029,
		GOTOS => {
			'where_clause' => 2088
		}
	},
	{#State 1630
		ACTIONS => {
			'WHERE' => -1377,
			'ORDER_SYM' => -1377,
			'END_OF_INPUT' => -1377,
			";" => -1377,
			'LIMIT' => -1377,
			"." => 2089
		},
		DEFAULT => -1167,
		GOTOS => {
			'opt_wild' => 1633
		}
	},
	{#State 1631
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 1259,
			'derived_table_list' => 1252,
			'ident' => 435,
			'table_factor' => 1261,
			'join_table_list' => 2090,
			'keyword_sp' => 287,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'table_ref' => 1254,
			'join_table' => 1255
		}
	},
	{#State 1632
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_wild_one' => 2091,
			'IDENT_sys' => 297,
			'ident' => 1166
		}
	},
	{#State 1633
		ACTIONS => {
			'FROM' => -1025,
			"," => -1025,
			'EQ' => 1335,
			'USING' => -1025,
			'AS' => 1337
		},
		DEFAULT => -1022,
		GOTOS => {
			'table_alias' => 1338,
			'opt_table_alias' => 2092
		}
	},
	{#State 1634
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			"*" => 2093,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2094
		}
	},
	{#State 1635
		ACTIONS => {
			'SNAPSHOT_SYM' => 2095
		}
	},
	{#State 1636
		ACTIONS => {
			'RELAY_LOG_FILE_SYM' => 1341,
			'MASTER_LOG_FILE_SYM' => 1342,
			'RELAY_LOG_POS_SYM' => 1345,
			'MASTER_LOG_POS_SYM' => 1350
		},
		GOTOS => {
			'master_file_def' => 2096,
			'slave_until_opts' => 2097
		}
	},
	{#State 1637
		DEFAULT => -527
	},
	{#State 1638
		DEFAULT => -529
	},
	{#State 1639
		DEFAULT => -1841
	},
	{#State 1640
		DEFAULT => -1840
	},
	{#State 1641
		ACTIONS => {
			"(" => 70,
			'SELECT_SYM' => 81
		},
		GOTOS => {
			'select_init' => 2098
		}
	},
	{#State 1642
		ACTIONS => {
			'FOR_SYM' => 2099,
			'LOCK_SYM' => 2100
		},
		DEFAULT => -624,
		GOTOS => {
			'select_lock_type' => 2101
		}
	},
	{#State 1643
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'OUTFILE' => 2104,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 2106,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			"\@" => 2107,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'into_destination' => 2108,
			'select_var_ident' => 2102,
			'ident' => 706,
			'keyword_sp' => 287,
			'ident_or_text' => 2105,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'select_var_list' => 2109,
			'select_var_list_init' => 2103
		}
	},
	{#State 1644
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'DUAL_SYM' => 2111,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 1259,
			'derived_table_list' => 1252,
			'ident' => 435,
			'table_factor' => 1261,
			'join_table_list' => 2110,
			'keyword_sp' => 287,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'table_ref' => 1254,
			'join_table' => 1255
		}
	},
	{#State 1645
		ACTIONS => {
			'INTO' => 1643
		},
		DEFAULT => -605,
		GOTOS => {
			'into' => 2112
		}
	},
	{#State 1646
		ACTIONS => {
			'FROM' => 1644
		},
		DEFAULT => -604,
		GOTOS => {
			'select_from' => 2113
		}
	},
	{#State 1647
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 1178,
			'select_item' => 2114
		}
	},
	{#State 1648
		ACTIONS => {
			'LIMIT' => 899
		},
		DEFAULT => -1056,
		GOTOS => {
			'opt_limit_clause' => 2115,
			'limit_clause' => 2116
		}
	},
	{#State 1649
		DEFAULT => -1047
	},
	{#State 1650
		DEFAULT => -633
	},
	{#State 1651
		DEFAULT => -632,
		GOTOS => {
			'remember_end' => 2117
		}
	},
	{#State 1652
		DEFAULT => -634
	},
	{#State 1653
		ACTIONS => {
			"." => 2118
		},
		DEFAULT => -1366
	},
	{#State 1654
		ACTIONS => {
			'SET' => 1202,
			"(" => 1200,
			'SELECT_SYM' => 1206,
			'VALUES' => 1204,
			'VALUE_SYM' => 1199
		},
		GOTOS => {
			'create_select' => 1201,
			'insert_values' => 1205,
			'insert_field_spec' => 2119
		}
	},
	{#State 1655
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2120
		}
	},
	{#State 1656
		ACTIONS => {
			'PROCEDURE' => 2122,
			'TABLE_SYM' => 1822,
			'FUNCTION_SYM' => 2123
		},
		DEFAULT => -1742,
		GOTOS => {
			'opt_table' => 2121
		}
	},
	{#State 1657
		ACTIONS => {
			"," => 2124
		},
		DEFAULT => -1745
	},
	{#State 1658
		ACTIONS => {
			'EXTENDED_SYM' => 1301,
			"," => 1298,
			'CHANGED' => 1294,
			'FOR_SYM' => 1296,
			'FAST_SYM' => 1299,
			'MEDIUM_SYM' => 1300,
			'QUICK' => 1295
		},
		DEFAULT => -560,
		GOTOS => {
			'mi_check_type' => 1297,
			'mi_check_types' => 1302,
			'opt_mi_check_type' => 2125
		}
	},
	{#State 1659
		DEFAULT => -56
	},
	{#State 1660
		DEFAULT => -55
	},
	{#State 1661
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 2126,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'ident' => 706
		}
	},
	{#State 1662
		DEFAULT => -548
	},
	{#State 1663
		DEFAULT => -546
	},
	{#State 1664
		DEFAULT => -549
	},
	{#State 1665
		DEFAULT => -401
	},
	{#State 1666
		DEFAULT => -403
	},
	{#State 1667
		DEFAULT => -1137
	},
	{#State 1668
		DEFAULT => -1138
	},
	{#State 1669
		DEFAULT => -402
	},
	{#State 1670
		DEFAULT => -400
	},
	{#State 1671
		ACTIONS => {
			'COLLATE_SYM' => 2128
		},
		DEFAULT => -411,
		GOTOS => {
			'opt_collate' => 2127
		}
	},
	{#State 1672
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2129,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1673
		DEFAULT => -407
	},
	{#State 1674
		DEFAULT => -409
	},
	{#State 1675
		DEFAULT => -1685
	},
	{#State 1676
		DEFAULT => -406
	},
	{#State 1677
		DEFAULT => -408
	},
	{#State 1678
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		GOTOS => {
			'equal' => 2130
		}
	},
	{#State 1679
		ACTIONS => {
			'GLOBAL_SYM' => 1573,
			'LOCAL_SYM' => 1574,
			'SESSION_SYM' => 1575
		},
		DEFAULT => -1675,
		GOTOS => {
			'opt_var_ident_type' => 2131
		}
	},
	{#State 1680
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1227,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 2132,
			'ident' => 706
		}
	},
	{#State 1681
		ACTIONS => {
			'TEXT_STRING' => 2133,
			'PASSWORD' => 2136,
			'OLD_PASSWORD' => 2134
		},
		GOTOS => {
			'text_or_password' => 2135
		}
	},
	{#State 1682
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2137
		}
	},
	{#State 1683
		ACTIONS => {
			'LEVEL_SYM' => 2138
		}
	},
	{#State 1684
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'ON' => 2139,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 2140,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 2141,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'ALL' => 2143,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2142,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'set_expr_or_default' => 2144,
			'bit_term' => 564
		}
	},
	{#State 1685
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2145
		}
	},
	{#State 1686
		DEFAULT => -1663
	},
	{#State 1687
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 2148,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -1142,
		GOTOS => {
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'literal' => 631,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'not2' => 521,
			'values' => 2146,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'expr_or_default' => 2150,
			'text_literal' => 525,
			'keyword' => 332,
			'variable' => 616,
			'NUM_literal' => 684,
			'factor' => 553,
			'opt_values' => 2147,
			'term' => 601,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'expr' => 2149,
			'IDENT_sys' => 643,
			'predicate' => 644,
			'bit_expr' => 585,
			'simple_expr' => 560,
			'bool_pri' => 648,
			'simple_ident_q' => 586,
			'geometry_function' => 685,
			'bit_term' => 564
		}
	},
	{#State 1688
		ACTIONS => {
			"," => 2151
		},
		DEFAULT => -1129
	},
	{#State 1689
		DEFAULT => -1133
	},
	{#State 1690
		DEFAULT => -1362
	},
	{#State 1691
		DEFAULT => -1127
	},
	{#State 1692
		ACTIONS => {
			")" => 2152
		}
	},
	{#State 1693
		ACTIONS => {
			"(" => 2153,
			'SELECT_SYM' => 1206,
			'VALUES' => 1204,
			'VALUE_SYM' => 1199
		},
		GOTOS => {
			'create_select' => 1201,
			'insert_values' => 2154
		}
	},
	{#State 1694
		DEFAULT => -1361
	},
	{#State 1695
		ACTIONS => {
			"," => 2155,
			")" => 2156
		}
	},
	{#State 1696
		ACTIONS => {
			"." => 2157
		},
		DEFAULT => -1368
	},
	{#State 1697
		DEFAULT => -1130
	},
	{#State 1698
		ACTIONS => {
			"," => 2158
		},
		DEFAULT => -1125
	},
	{#State 1699
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		GOTOS => {
			'equal' => 2159
		}
	},
	{#State 1700
		DEFAULT => -1135
	},
	{#State 1701
		ACTIONS => {
			"," => 2151
		},
		DEFAULT => -1128
	},
	{#State 1702
		ACTIONS => {
			"*" => 1176
		},
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 1178,
			'select_item_list' => 2160,
			'select_item' => 1175
		}
	},
	{#State 1703
		DEFAULT => -1266
	},
	{#State 1704
		ACTIONS => {
			'LOCK_SYM' => 2161
		}
	},
	{#State 1705
		DEFAULT => -1822
	},
	{#State 1706
		DEFAULT => -1818
	},
	{#State 1707
		DEFAULT => -112
	},
	{#State 1708
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2162,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1709
		DEFAULT => -1097
	},
	{#State 1710
		DEFAULT => -1395
	},
	{#State 1711
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 2163,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'ident' => 706
		}
	},
	{#State 1712
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1227,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 2164,
			'ident' => 706
		}
	},
	{#State 1713
		DEFAULT => -1102
	},
	{#State 1714
		DEFAULT => -519
	},
	{#State 1715
		DEFAULT => -518
	},
	{#State 1716
		ACTIONS => {
			'RESTRICT' => 1715,
			"," => 1298,
			'CASCADE' => 1714
		},
		DEFAULT => -517,
		GOTOS => {
			'opt_restrict' => 2165
		}
	},
	{#State 1717
		DEFAULT => -579
	},
	{#State 1718
		DEFAULT => -580
	},
	{#State 1719
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1227,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 2166,
			'ident' => 706
		}
	},
	{#State 1720
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1227,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 2167,
			'ident' => 706
		}
	},
	{#State 1721
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2168
		}
	},
	{#State 1722
		ACTIONS => {
			'SQL_SYM' => 2169
		}
	},
	{#State 1723
		DEFAULT => -95
	},
	{#State 1724
		ACTIONS => {
			'SQL_SYM' => 2170
		}
	},
	{#State 1725
		ACTIONS => {
			'SQL_SYM' => 2171
		}
	},
	{#State 1726
		ACTIONS => {
			'SQL_SYM' => 2172
		}
	},
	{#State 1727
		ACTIONS => {
			'SQL_SYM' => 2173
		}
	},
	{#State 1728
		DEFAULT => -104
	},
	{#State 1729
		ACTIONS => {
			'SECURITY_SYM' => 2174
		}
	},
	{#State 1730
		ACTIONS => {
			'INDEX_SYM' => 1264,
			'KEY_SYM' => 1266,
			'FOREIGN' => 2176,
			'COLUMN_SYM' => 2177,
			'PRIMARY_SYM' => 2179
		},
		DEFAULT => -513,
		GOTOS => {
			'key_or_index' => 2178,
			'opt_column' => 2175
		}
	},
	{#State 1731
		ACTIONS => {
			'DIRECTORY_SYM' => 2180
		}
	},
	{#State 1732
		ACTIONS => {
			'TO_SYM' => 2181
		}
	},
	{#State 1733
		DEFAULT => -492
	},
	{#State 1734
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2182,
			'equal' => 2183
		}
	},
	{#State 1735
		DEFAULT => -510
	},
	{#State 1736
		ACTIONS => {
			'KEYS' => 2184
		}
	},
	{#State 1737
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2185,
			'equal' => 2183
		}
	},
	{#State 1738
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2186,
			'equal' => 2183
		}
	},
	{#State 1739
		DEFAULT => -511
	},
	{#State 1740
		ACTIONS => {
			'BY' => 2187
		}
	},
	{#State 1741
		ACTIONS => {
			'COLUMN_SYM' => 2177
		},
		DEFAULT => -513,
		GOTOS => {
			'opt_column' => 2188
		}
	},
	{#State 1742
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2189,
			'equal' => 2183
		}
	},
	{#State 1743
		ACTIONS => {
			'TABLESPACE' => 2190
		}
	},
	{#State 1744
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2191,
			'equal' => 2183
		}
	},
	{#State 1745
		DEFAULT => -512
	},
	{#State 1746
		ACTIONS => {
			'EQ' => 1667,
			'SET_VAR' => 1668
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2192,
			'equal' => 2183
		}
	},
	{#State 1747
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2193,
			'equal' => 2183
		}
	},
	{#State 1748
		ACTIONS => {
			'PASSWORD' => 1767,
			'RAID_TYPE' => 1766,
			'CHAR_SYM' => -415,
			'INSERT_METHOD' => 1757,
			'AUTO_INC' => 1769,
			'MIN_ROWS' => 1747,
			'ENGINE_SYM' => 1768,
			'COMMENT_SYM' => 1737,
			'ROW_FORMAT_SYM' => 1760,
			'RAID_CHUNKSIZE' => 1738,
			'COLLATE_SYM' => -415,
			'DATA_SYM' => 1753,
			'CHARSET' => -415,
			'DELAY_KEY_WRITE_SYM' => 1762,
			'INDEX_SYM' => 1731,
			'DEFAULT' => 1245,
			'AVG_ROW_LENGTH' => 1750,
			'TYPE_SYM' => 1746,
			'MAX_ROWS' => 1765,
			'CONNECTION_SYM' => 1752,
			'RAID_CHUNKS' => 1758,
			'CHECKSUM_SYM' => 1744,
			'PACK_KEYS_SYM' => 1734,
			'UNION_SYM' => 1742
		},
		DEFAULT => -232,
		GOTOS => {
			'default_charset' => 1756,
			'opt_default' => 1243,
			'default_collation' => 1751,
			'create_table_option' => 1748,
			'create_table_options_space_separated' => 2194
		}
	},
	{#State 1749
		ACTIONS => {
			'INDEX_SYM' => 1264,
			'KEY_SYM' => 1266,
			'FULLTEXT_SYM' => 2196,
			'CHECK_SYM' => -297,
			'FOREIGN' => -297,
			'COLUMN_SYM' => 2177,
			'PRIMARY_SYM' => -297,
			'SPATIAL_SYM' => 2200,
			'UNIQUE_SYM' => -297,
			'CONSTRAINT' => 2202
		},
		DEFAULT => -513,
		GOTOS => {
			'key_type' => 2199,
			'opt_constraint' => 2203,
			'key_or_index' => 2198,
			'key_def' => 2201,
			'opt_column' => 2197,
			'constraint' => 2195
		}
	},
	{#State 1750
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2204,
			'equal' => 2183
		}
	},
	{#State 1751
		DEFAULT => -255
	},
	{#State 1752
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2205,
			'equal' => 2183
		}
	},
	{#State 1753
		ACTIONS => {
			'DIRECTORY_SYM' => 2206
		}
	},
	{#State 1754
		ACTIONS => {
			"," => 2207
		},
		DEFAULT => -482
	},
	{#State 1755
		ACTIONS => {
			'COLUMN_SYM' => 2177
		},
		DEFAULT => -513,
		GOTOS => {
			'opt_column' => 2208
		}
	},
	{#State 1756
		DEFAULT => -254
	},
	{#State 1757
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2209,
			'equal' => 2183
		}
	},
	{#State 1758
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2210,
			'equal' => 2183
		}
	},
	{#State 1759
		ACTIONS => {
			'TABLESPACE' => 2211
		}
	},
	{#State 1760
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2212,
			'equal' => 2183
		}
	},
	{#State 1761
		ACTIONS => {
			'KEYS' => 2213
		}
	},
	{#State 1762
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2214,
			'equal' => 2183
		}
	},
	{#State 1763
		ACTIONS => {
			'EQ' => 2215,
			'AS' => 2216,
			'TO_SYM' => 2218
		},
		DEFAULT => -523,
		GOTOS => {
			'opt_to' => 2217
		}
	},
	{#State 1764
		ACTIONS => {
			'COLUMN_SYM' => 2177
		},
		DEFAULT => -513,
		GOTOS => {
			'opt_column' => 2219
		}
	},
	{#State 1765
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2220,
			'equal' => 2183
		}
	},
	{#State 1766
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2221,
			'equal' => 2183
		}
	},
	{#State 1767
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2222,
			'equal' => 2183
		}
	},
	{#State 1768
		ACTIONS => {
			'EQ' => 1667,
			'SET_VAR' => 1668
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2223,
			'equal' => 2183
		}
	},
	{#State 1769
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2224,
			'equal' => 2183
		}
	},
	{#State 1770
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 2227,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_spec' => 2228,
			'column_def' => 2225,
			'field_ident' => 2226,
			'ident' => 2229
		}
	},
	{#State 1771
		ACTIONS => {
			'EQ' => 1667,
			'SET_VAR' => 1668
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2231,
			'equal' => 2183
		}
	},
	{#State 1772
		ACTIONS => {
			'EQ' => 1667,
			'SET_VAR' => 1668
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2232,
			'equal' => 2183
		}
	},
	{#State 1773
		DEFAULT => -220
	},
	{#State 1774
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2233,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 1775
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 1259,
			'ident' => 435,
			'table_factor' => 1261,
			'keyword_sp' => 287,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'table_ref' => 2234,
			'join_table' => 1255
		}
	},
	{#State 1776
		DEFAULT => -978,
		GOTOS => {
			'select_derived' => 2236,
			'get_select_lex' => 2235
		}
	},
	{#State 1777
		DEFAULT => -969
	},
	{#State 1778
		ACTIONS => {
			'OUTER' => 2238
		},
		DEFAULT => -980,
		GOTOS => {
			'opt_outer' => 2237
		}
	},
	{#State 1779
		ACTIONS => {
			'JOIN_SYM' => 2239
		}
	},
	{#State 1780
		ACTIONS => {
			'JOIN_SYM' => 2240
		}
	},
	{#State 1781
		ACTIONS => {
			'OUTER' => 2238
		},
		DEFAULT => -980,
		GOTOS => {
			'opt_outer' => 2241
		}
	},
	{#State 1782
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1259,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'ident' => 435,
			'table_factor' => 2242
		}
	},
	{#State 1783
		ACTIONS => {
			'LEFT' => 2244,
			'RIGHT' => 2245,
			'JOIN_SYM' => 2243
		}
	},
	{#State 1784
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 1259,
			'ident' => 435,
			'table_factor' => 1261,
			'keyword_sp' => 287,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'table_ref' => 2246,
			'join_table' => 1255
		}
	},
	{#State 1785
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'simple_ident_nospvar' => 2249,
			'update_elem' => 2247,
			'ident' => 1542,
			'simple_ident_q' => 1540,
			'keyword_sp' => 287,
			'update_list' => 2248,
			'IDENT_sys' => 297
		}
	},
	{#State 1786
		ACTIONS => {
			'SQL_BIG_RESULT' => 708,
			'SQL_BUFFER_RESULT' => 709,
			'SQL_NO_CACHE_SYM' => 710,
			'SQL_CALC_FOUND_ROWS' => 713,
			'SQL_CACHE_SYM' => 714,
			'ALL' => 716,
			'STRAIGHT_JOIN' => 717,
			'SQL_SMALL_RESULT' => 719,
			'DISTINCT' => 721,
			'HIGH_PRIORITY' => 722
		},
		DEFAULT => -610,
		GOTOS => {
			'select_option' => 715,
			'select_options' => 2251,
			'select_option_list' => 720,
			'select_derived2' => 2250
		}
	},
	{#State 1787
		ACTIONS => {
			'FORCE_SYM' => 2253,
			'IGNORE_SYM' => 2255,
			'USE_SYM' => 2254
		},
		DEFAULT => -984,
		GOTOS => {
			'opt_key_definition' => 2252
		}
	},
	{#State 1788
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 1259,
			'ident' => 435,
			'table_factor' => 1261,
			'keyword_sp' => 287,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'table_ref' => 2256,
			'join_table' => 1255
		}
	},
	{#State 1789
		DEFAULT => -583
	},
	{#State 1790
		DEFAULT => -586
	},
	{#State 1791
		DEFAULT => -581
	},
	{#State 1792
		DEFAULT => -585
	},
	{#State 1793
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'PRIMARY_SYM' => 2258,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'key_usage_list2' => 2257,
			'ident' => 2259
		}
	},
	{#State 1794
		ACTIONS => {
			"," => 2260
		},
		DEFAULT => -1888
	},
	{#State 1795
		ACTIONS => {
			'MIGRATE_SYM' => 2261
		}
	},
	{#State 1796
		DEFAULT => -1898
	},
	{#State 1797
		DEFAULT => -1896
	},
	{#State 1798
		DEFAULT => -536
	},
	{#State 1799
		ACTIONS => {
			'ON' => 2262
		}
	},
	{#State 1800
		ACTIONS => {
			'BTREE_SYM' => 2264,
			'RTREE_SYM' => 2263,
			'HASH_SYM' => 2266
		},
		GOTOS => {
			'opt_btree_or_rtree' => 2265
		}
	},
	{#State 1801
		ACTIONS => {
			'BTREE_SYM' => 2264,
			'RTREE_SYM' => 2263,
			'HASH_SYM' => 2266
		},
		GOTOS => {
			'opt_btree_or_rtree' => 2267
		}
	},
	{#State 1802
		ACTIONS => {
			'AUTO_INC' => 1769,
			'ROW_FORMAT_SYM' => 1760,
			'DATA_SYM' => 1753,
			'INDEX_SYM' => 1731,
			'TYPE_SYM' => 1746,
			'MAX_ROWS' => 1765,
			"(" => 2268,
			'PACK_KEYS_SYM' => 1734,
			'UNION_SYM' => 1742,
			'RAID_TYPE' => 1766,
			'PASSWORD' => 1767,
			'CHAR_SYM' => -415,
			'INSERT_METHOD' => 1757,
			'MIN_ROWS' => 1747,
			'ENGINE_SYM' => 1768,
			'COMMENT_SYM' => 1737,
			'RAID_CHUNKSIZE' => 1738,
			'COLLATE_SYM' => -415,
			'LIKE' => 2273,
			'CHARSET' => -415,
			'DELAY_KEY_WRITE_SYM' => 1762,
			'AVG_ROW_LENGTH' => 1750,
			'DEFAULT' => 1245,
			'CONNECTION_SYM' => 1752,
			'RAID_CHUNKS' => 1758,
			'CHECKSUM_SYM' => 1744
		},
		DEFAULT => -230,
		GOTOS => {
			'default_charset' => 1756,
			'create2' => 2271,
			'opt_default' => 1243,
			'create_table_options' => 2272,
			'default_collation' => 1751,
			'create_table_option' => 2270,
			'opt_create_table_options' => 2269
		}
	},
	{#State 1803
		ACTIONS => {
			'BY' => 2274
		}
	},
	{#State 1804
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident' => 706,
			'grant_user' => 2275,
			'keyword_sp' => 287,
			'ident_or_text' => 1227,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1283
		}
	},
	{#State 1805
		ACTIONS => {
			'AFTER_SYM' => 2276,
			'BEFORE_SYM' => 2278
		},
		GOTOS => {
			'trg_action_time' => 2277
		}
	},
	{#State 1806
		ACTIONS => {
			"(" => 2279
		}
	},
	{#State 1807
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_name' => 2280,
			'IDENT_sys' => 297,
			'ident' => 326
		}
	},
	{#State 1808
		ACTIONS => {
			"(" => 2281
		},
		DEFAULT => -1867,
		GOTOS => {
			'view_list_opt' => 2282
		}
	},
	{#State 1809
		DEFAULT => -1865
	},
	{#State 1810
		DEFAULT => -1864
	},
	{#State 1811
		DEFAULT => -86
	},
	{#State 1812
		DEFAULT => -229
	},
	{#State 1813
		DEFAULT => -569
	},
	{#State 1814
		DEFAULT => -563
	},
	{#State 1815
		DEFAULT => -1105
	},
	{#State 1816
		DEFAULT => -545
	},
	{#State 1817
		DEFAULT => -1798
	},
	{#State 1818
		DEFAULT => -1799
	},
	{#State 1819
		ACTIONS => {
			"," => 2283,
			")" => 2284
		}
	},
	{#State 1820
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			"*" => 2286,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2287,
			'IDENT_sys' => 297,
			'grant_ident' => 2285,
			'ident' => 2288
		}
	},
	{#State 1821
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			"*" => 2286,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2287,
			'IDENT_sys' => 297,
			'grant_ident' => 2289,
			'ident' => 2288
		}
	},
	{#State 1822
		DEFAULT => -1743
	},
	{#State 1823
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			"*" => 2286,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2287,
			'IDENT_sys' => 297,
			'grant_ident' => 2290,
			'ident' => 2288
		}
	},
	{#State 1824
		DEFAULT => -1749
	},
	{#State 1825
		DEFAULT => -1768
	},
	{#State 1826
		DEFAULT => -558
	},
	{#State 1827
		DEFAULT => -555
	},
	{#State 1828
		DEFAULT => -552
	},
	{#State 1829
		DEFAULT => -550
	},
	{#State 1830
		ACTIONS => {
			'EXTENDED_SYM' => 1831,
			'USE_FRM' => 1832,
			'QUICK' => 1827
		},
		DEFAULT => -553,
		GOTOS => {
			'mi_repair_type' => 1830,
			'mi_repair_types' => 2291
		}
	},
	{#State 1831
		DEFAULT => -556
	},
	{#State 1832
		DEFAULT => -557
	},
	{#State 1833
		DEFAULT => -1289
	},
	{#State 1834
		DEFAULT => -1290
	},
	{#State 1835
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2292,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1836
		ACTIONS => {
			'LIMIT' => 899
		},
		DEFAULT => -1056,
		GOTOS => {
			'opt_limit_clause' => 2293,
			'limit_clause' => 2116
		}
	},
	{#State 1837
		DEFAULT => -1730
	},
	{#State 1838
		DEFAULT => -1725
	},
	{#State 1839
		DEFAULT => -1720
	},
	{#State 1840
		DEFAULT => -1728
	},
	{#State 1841
		DEFAULT => -1726
	},
	{#State 1842
		DEFAULT => -1732
	},
	{#State 1843
		DEFAULT => -1729
	},
	{#State 1844
		DEFAULT => -1731
	},
	{#State 1845
		ACTIONS => {
			"(" => 2294
		}
	},
	{#State 1846
		DEFAULT => -1724
	},
	{#State 1847
		DEFAULT => -1723
	},
	{#State 1848
		DEFAULT => -1026
	},
	{#State 1849
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 2295
		}
	},
	{#State 1850
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2296
		}
	},
	{#State 1851
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2297
		}
	},
	{#State 1852
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2298
		}
	},
	{#State 1853
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2299
		}
	},
	{#State 1854
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 2300
		}
	},
	{#State 1855
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2301
		}
	},
	{#State 1856
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2302
		}
	},
	{#State 1857
		ACTIONS => {
			'MASTER_SSL_CA_SYM' => 1353,
			'MASTER_SSL_KEY_SYM' => 1346,
			'MASTER_CONNECT_RETRY_SYM' => 1354,
			'MASTER_USER_SYM' => 1351,
			'MASTER_SSL_CAPATH_SYM' => 1352,
			'MASTER_SSL_CERT_SYM' => 1340,
			'MASTER_HOST_SYM' => 1344,
			'RELAY_LOG_FILE_SYM' => 1341,
			'MASTER_SSL_CIPHER_SYM' => 1348,
			'MASTER_SSL_SYM' => 1355,
			'MASTER_LOG_FILE_SYM' => 1342,
			'RELAY_LOG_POS_SYM' => 1345,
			'MASTER_PASSWORD_SYM' => 1356,
			'MASTER_PORT_SYM' => 1339,
			'MASTER_LOG_POS_SYM' => 1350
		},
		GOTOS => {
			'master_def' => 2303,
			'master_file_def' => 1343
		}
	},
	{#State 1858
		ACTIONS => {
			'NUM' => 2305,
			'ULONGLONG_NUM' => 2307,
			'FLOAT_NUM' => 2306,
			'LONG_NUM' => 2304,
			'DECIMAL_NUM' => 2309
		},
		GOTOS => {
			'ulonglong_num' => 2308
		}
	},
	{#State 1859
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2310
		}
	},
	{#State 1860
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2311
		}
	},
	{#State 1861
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2312
		}
	},
	{#State 1862
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 2313
		}
	},
	{#State 1863
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 2314
		}
	},
	{#State 1864
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2315
		}
	},
	{#State 1865
		DEFAULT => -1827
	},
	{#State 1866
		ACTIONS => {
			'WARNINGS' => 2316,
			'ERRORS' => 2317
		}
	},
	{#State 1867
		DEFAULT => -1244
	},
	{#State 1868
		DEFAULT => -1197
	},
	{#State 1869
		ACTIONS => {
			'FROM' => 892,
			'IN_SYM' => 893
		},
		DEFAULT => -1243,
		GOTOS => {
			'opt_db' => 2318,
			'from_or_in' => 1365
		}
	},
	{#State 1870
		DEFAULT => -1195
	},
	{#State 1871
		DEFAULT => -1194
	},
	{#State 1872
		ACTIONS => {
			'WHERE' => 1835
		},
		DEFAULT => -1029,
		GOTOS => {
			'where_clause' => 2319
		}
	},
	{#State 1873
		ACTIONS => {
			'NUM' => 2305,
			'ULONGLONG_NUM' => 2307,
			'FLOAT_NUM' => 2306,
			'LONG_NUM' => 2304,
			'DECIMAL_NUM' => 2309
		},
		GOTOS => {
			'ulonglong_num' => 2320
		}
	},
	{#State 1874
		ACTIONS => {
			'LIMIT' => 899
		},
		DEFAULT => -1054,
		GOTOS => {
			'opt_limit_clause_init' => 2321,
			'limit_clause' => 898
		}
	},
	{#State 1875
		DEFAULT => -1250
	},
	{#State 1876
		ACTIONS => {
			'NUM' => 1378,
			'ULONGLONG_NUM' => 1379,
			'PARAM_MARKER' => 606,
			'LONG_NUM' => 1376
		},
		GOTOS => {
			'param_marker' => 1377,
			'limit_option' => 2322
		}
	},
	{#State 1877
		ACTIONS => {
			'NUM' => 1378,
			'ULONGLONG_NUM' => 1379,
			'PARAM_MARKER' => 606,
			'LONG_NUM' => 1376
		},
		GOTOS => {
			'param_marker' => 1377,
			'limit_option' => 2323
		}
	},
	{#State 1878
		DEFAULT => -1196
	},
	{#State 1879
		DEFAULT => -1226
	},
	{#State 1880
		DEFAULT => -1180
	},
	{#State 1881
		ACTIONS => {
			'NUM' => 2324
		}
	},
	{#State 1882
		DEFAULT => -1214
	},
	{#State 1883
		ACTIONS => {
			'WITH' => 2325
		}
	},
	{#State 1884
		ACTIONS => {
			"\@" => 1401
		},
		GOTOS => {
			'execute_var_ident' => 2326
		}
	},
	{#State 1885
		DEFAULT => -63
	},
	{#State 1886
		DEFAULT => -905
	},
	{#State 1887
		DEFAULT => -924
	},
	{#State 1888
		ACTIONS => {
			")" => 2327
		}
	},
	{#State 1889
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2328,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1890
		ACTIONS => {
			'INTERVAL_SYM' => 618
		},
		GOTOS => {
			'interval_expr' => 2329
		}
	},
	{#State 1891
		DEFAULT => -908
	},
	{#State 1892
		DEFAULT => -755
	},
	{#State 1893
		DEFAULT => -733
	},
	{#State 1894
		DEFAULT => -900
	},
	{#State 1895
		ACTIONS => {
			")" => 2330
		}
	},
	{#State 1896
		ACTIONS => {
			")" => 2331
		}
	},
	{#State 1897
		ACTIONS => {
			'XOR' => 943
		},
		DEFAULT => -644
	},
	{#State 1898
		DEFAULT => -854
	},
	{#State 1899
		ACTIONS => {
			'CHAR_SYM' => 2333,
			'NCHAR_SYM' => 2336,
			'SIGNED_SYM' => 2341,
			'DATE_SYM' => 2339,
			'DECIMAL_SYM' => 2334,
			'UNSIGNED' => 2337,
			'DATETIME' => 2332,
			'BINARY' => 2335,
			'TIME_SYM' => 2338
		},
		GOTOS => {
			'cast_type' => 2340
		}
	},
	{#State 1900
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 1665,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1670,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'charset_name' => 2342,
			'ident' => 706
		}
	},
	{#State 1901
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2343,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1902
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 1665,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1670,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'charset_name' => 2344,
			'ident' => 706
		}
	},
	{#State 1903
		DEFAULT => -750
	},
	{#State 1904
		ACTIONS => {
			'TEXT_STRING' => 554
		},
		GOTOS => {
			'TEXT_STRING_literal' => 2345
		}
	},
	{#State 1905
		DEFAULT => -880
	},
	{#State 1906
		DEFAULT => -754
	},
	{#State 1907
		DEFAULT => -865
	},
	{#State 1908
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2346,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1909
		DEFAULT => -816
	},
	{#State 1910
		ACTIONS => {
			'NUM' => 2347
		}
	},
	{#State 1911
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2348,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1912
		DEFAULT => -883
	},
	{#State 1913
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2349,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1914
		DEFAULT => -781
	},
	{#State 1915
		DEFAULT => -802
	},
	{#State 1916
		DEFAULT => -907
	},
	{#State 1917
		DEFAULT => -786
	},
	{#State 1918
		ACTIONS => {
			'NUM' => 2350
		}
	},
	{#State 1919
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2351,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1920
		ACTIONS => {
			")" => 2352
		}
	},
	{#State 1921
		ACTIONS => {
			")" => 2353
		}
	},
	{#State 1922
		DEFAULT => -1846,
		GOTOS => {
			'subselect_end' => 2354
		}
	},
	{#State 1923
		DEFAULT => -1844
	},
	{#State 1924
		DEFAULT => -742
	},
	{#State 1925
		DEFAULT => -864
	},
	{#State 1926
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2355,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1927
		DEFAULT => -830
	},
	{#State 1928
		ACTIONS => {
			'INTERVAL_SYM' => 618
		},
		GOTOS => {
			'interval_expr' => 2356
		}
	},
	{#State 1929
		DEFAULT => -648
	},
	{#State 1930
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2357,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1931
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2358,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1932
		DEFAULT => -867
	},
	{#State 1933
		DEFAULT => -730
	},
	{#State 1934
		DEFAULT => -739
	},
	{#State 1935
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 2360,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2359,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1936
		DEFAULT => -760
	},
	{#State 1937
		ACTIONS => {
			'NUM' => 2361
		}
	},
	{#State 1938
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2362,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1939
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2363,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1940
		DEFAULT => -769
	},
	{#State 1941
		DEFAULT => -809
	},
	{#State 1942
		DEFAULT => -911
	},
	{#State 1943
		ACTIONS => {
			")" => 2364
		}
	},
	{#State 1944
		DEFAULT => -811
	},
	{#State 1945
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2365,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1946
		DEFAULT => -862
	},
	{#State 1947
		DEFAULT => -903
	},
	{#State 1948
		ACTIONS => {
			")" => 2366
		}
	},
	{#State 1949
		DEFAULT => -874
	},
	{#State 1950
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2367,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1951
		DEFAULT => -812
	},
	{#State 1952
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 2368,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1953
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 2369,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1954
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2370,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1955
		DEFAULT => -752
	},
	{#State 1956
		ACTIONS => {
			"|" => 1013
		},
		DEFAULT => -672
	},
	{#State 1957
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 2371,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1958
		DEFAULT => -673
	},
	{#State 1959
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 2372,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'geometry_function' => 685
		}
	},
	{#State 1960
		ACTIONS => {
			"|" => 1013
		},
		DEFAULT => -676
	},
	{#State 1961
		ACTIONS => {
			"|" => 1013,
			'AND_SYM' => 2373
		}
	},
	{#State 1962
		ACTIONS => {
			'OR_OR_SYM' => 988,
			'ESCAPE_SYM' => 1959,
			'COLLATE_SYM' => 989
		},
		DEFAULT => -1034,
		GOTOS => {
			'opt_escape' => 2374
		}
	},
	{#State 1963
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 973,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 976,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2375,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'subselect' => 2376,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1964
		ACTIONS => {
			"," => 2377,
			")" => 2378
		}
	},
	{#State 1965
		ACTIONS => {
			")" => 2379
		}
	},
	{#State 1966
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 2380,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1967
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 2381,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1968
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2382,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1969
		DEFAULT => -871
	},
	{#State 1970
		DEFAULT => -897
	},
	{#State 1971
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2383,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1972
		DEFAULT => -855
	},
	{#State 1973
		DEFAULT => -847
	},
	{#State 1974
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2384,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1975
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2385,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1976
		DEFAULT => -852
	},
	{#State 1977
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2386,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1978
		DEFAULT => -789
	},
	{#State 1979
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2387,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1980
		DEFAULT => -829
	},
	{#State 1981
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2388,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1982
		DEFAULT => -881
	},
	{#State 1983
		DEFAULT => -792
	},
	{#State 1984
		ACTIONS => {
			'ORDER_SYM' => 1613
		},
		DEFAULT => -922,
		GOTOS => {
			'opt_gorder_clause' => 2389,
			'order_clause' => 2390
		}
	},
	{#State 1985
		DEFAULT => -910
	},
	{#State 1986
		DEFAULT => -828
	},
	{#State 1987
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2391,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1988
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 2392,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1989
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 2393,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1990
		DEFAULT => -765
	},
	{#State 1991
		DEFAULT => -894
	},
	{#State 1992
		ACTIONS => {
			")" => 2394
		}
	},
	{#State 1993
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2395,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1994
		DEFAULT => -942
	},
	{#State 1995
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'bit_expr' => 2396,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1996
		DEFAULT => -945
	},
	{#State 1997
		ACTIONS => {
			"." => 2039
		},
		DEFAULT => -1370
	},
	{#State 1998
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2397,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 1999
		DEFAULT => -775
	},
	{#State 2000
		DEFAULT => -898
	},
	{#State 2001
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2398,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2002
		DEFAULT => -798
	},
	{#State 2003
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 2399,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2004
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2400,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2005
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2401,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2006
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2402,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2007
		DEFAULT => -740
	},
	{#State 2008
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2403,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2009
		ACTIONS => {
			'CHAR_SYM' => 2333,
			'NCHAR_SYM' => 2336,
			'SIGNED_SYM' => 2341,
			'DATE_SYM' => 2339,
			'DECIMAL_SYM' => 2334,
			'UNSIGNED' => 2337,
			'DATETIME' => 2332,
			'BINARY' => 2335,
			'TIME_SYM' => 2338
		},
		GOTOS => {
			'cast_type' => 2404
		}
	},
	{#State 2010
		DEFAULT => -896
	},
	{#State 2011
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 2406,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2405,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2012
		DEFAULT => -687
	},
	{#State 2013
		DEFAULT => -688
	},
	{#State 2014
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2407,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2015
		DEFAULT => -876
	},
	{#State 2016
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2408,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2017
		DEFAULT => -844
	},
	{#State 2018
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 1557,
			'udf_expr' => 2409
		}
	},
	{#State 2019
		DEFAULT => -632,
		GOTOS => {
			'remember_end' => 2410
		}
	},
	{#State 2020
		DEFAULT => -803
	},
	{#State 2021
		ACTIONS => {
			'TEXT_STRING' => 554
		},
		GOTOS => {
			'TEXT_STRING_literal' => 2411
		}
	},
	{#State 2022
		DEFAULT => -873
	},
	{#State 2023
		ACTIONS => {
			"(" => 1454,
			'SELECT_SYM' => 976
		},
		GOTOS => {
			'subselect' => 2412
		}
	},
	{#State 2024
		DEFAULT => -656
	},
	{#State 2025
		DEFAULT => -659
	},
	{#State 2026
		DEFAULT => -652
	},
	{#State 2027
		DEFAULT => -654
	},
	{#State 2028
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2413,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2029
		DEFAULT => -878
	},
	{#State 2030
		DEFAULT => -915
	},
	{#State 2031
		DEFAULT => -1676
	},
	{#State 2032
		DEFAULT => -1677
	},
	{#State 2033
		DEFAULT => -1678
	},
	{#State 2034
		ACTIONS => {
			"." => 2415
		},
		DEFAULT => -478,
		GOTOS => {
			'opt_component' => 2414
		}
	},
	{#State 2035
		DEFAULT => -766
	},
	{#State 2036
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2416,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2037
		DEFAULT => -860
	},
	{#State 2038
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -936,
		GOTOS => {
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'literal' => 631,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'not2' => 521,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'text_literal' => 525,
			'keyword' => 332,
			'variable' => 616,
			'opt_expr_list' => 2418,
			'expr_list2' => 600,
			'NUM_literal' => 684,
			'factor' => 553,
			'term' => 601,
			'bool_factor' => 556,
			'simple_ident' => 531,
			'expr' => 603,
			'IDENT_sys' => 643,
			'predicate' => 644,
			'expr_list' => 2417,
			'bit_expr' => 585,
			'simple_expr' => 560,
			'bool_pri' => 648,
			'simple_ident_q' => 586,
			'geometry_function' => 685,
			'bit_term' => 564
		}
	},
	{#State 2039
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2419
		}
	},
	{#State 2040
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2420,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2041
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2421,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2042
		DEFAULT => -866
	},
	{#State 2043
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2422,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2044
		DEFAULT => -869
	},
	{#State 2045
		DEFAULT => -808
	},
	{#State 2046
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2423,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2047
		DEFAULT => -731
	},
	{#State 2048
		DEFAULT => -821
	},
	{#State 2049
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2424,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2050
		ACTIONS => {
			'FROM' => 2425
		}
	},
	{#State 2051
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2426,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2052
		ACTIONS => {
			'FROM' => 2427
		}
	},
	{#State 2053
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2428,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2054
		DEFAULT => -834
	},
	{#State 2055
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2429,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2056
		ACTIONS => {
			'FROM' => 2430
		}
	},
	{#State 2057
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2431,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2058
		DEFAULT => -909
	},
	{#State 2059
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2432,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2060
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2433,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2061
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2434,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2062
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2435,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2063
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2436,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2064
		DEFAULT => -773
	},
	{#State 2065
		DEFAULT => -807
	},
	{#State 2066
		DEFAULT => -1371
	},
	{#State 2067
		ACTIONS => {
			'END' => 2437
		}
	},
	{#State 2068
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2438,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2069
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2439,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2070
		ACTIONS => {
			'THEN_SYM' => 2440
		}
	},
	{#State 2071
		DEFAULT => -805
	},
	{#State 2072
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2441,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2073
		DEFAULT => -748
	},
	{#State 2074
		DEFAULT => -753
	},
	{#State 2075
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'order_ident' => 2442,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2444,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'order_list' => 2443,
			'bit_term' => 564
		}
	},
	{#State 2076
		DEFAULT => -1837
	},
	{#State 2077
		DEFAULT => -588
	},
	{#State 2078
		ACTIONS => {
			"(" => -457,
			'KEY_SYM' => 1266,
			'INDEX_SYM' => 1264
		},
		DEFAULT => -592,
		GOTOS => {
			'key_or_index' => 1268,
			'cache_keys_spec' => 2445,
			'cache_key_list_or_empty' => 1265,
			'opt_key_or_index' => 1269
		}
	},
	{#State 2079
		ACTIONS => {
			"," => 2446
		},
		DEFAULT => -587
	},
	{#State 2080
		ACTIONS => {
			'TEXT_STRING' => 2447
		},
		GOTOS => {
			'TEXT_STRING_filesystem' => 2448
		}
	},
	{#State 2081
		DEFAULT => -1297
	},
	{#State 2082
		DEFAULT => -1709
	},
	{#State 2083
		ACTIONS => {
			'LOCAL_SYM' => 2449
		},
		DEFAULT => -1711
	},
	{#State 2084
		DEFAULT => -1712
	},
	{#State 2085
		ACTIONS => {
			'WRITE_SYM' => 2450
		}
	},
	{#State 2086
		DEFAULT => -1710
	},
	{#State 2087
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 1259,
			'derived_table_list' => 1252,
			'ident' => 435,
			'table_factor' => 1261,
			'join_table_list' => 2451,
			'keyword_sp' => 287,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'table_ref' => 1254,
			'join_table' => 1255
		}
	},
	{#State 2088
		ACTIONS => {
			'ORDER_SYM' => 1613
		},
		DEFAULT => -1046,
		GOTOS => {
			'order_clause' => 1649,
			'opt_order_clause' => 2452
		}
	},
	{#State 2089
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			"*" => 2093,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2453
		}
	},
	{#State 2090
		ACTIONS => {
			'WHERE' => 1835
		},
		DEFAULT => -1029,
		GOTOS => {
			'where_clause' => 2454
		}
	},
	{#State 2091
		DEFAULT => -1164
	},
	{#State 2092
		DEFAULT => -1165
	},
	{#State 2093
		DEFAULT => -1168
	},
	{#State 2094
		ACTIONS => {
			"." => 2456
		},
		DEFAULT => -1167,
		GOTOS => {
			'opt_wild' => 2455
		}
	},
	{#State 2095
		DEFAULT => -533
	},
	{#State 2096
		DEFAULT => -542
	},
	{#State 2097
		ACTIONS => {
			"," => 2457
		},
		DEFAULT => -541
	},
	{#State 2098
		DEFAULT => -1832
	},
	{#State 2099
		ACTIONS => {
			'UPDATE_SYM' => 2458
		}
	},
	{#State 2100
		ACTIONS => {
			'IN_SYM' => 2459
		}
	},
	{#State 2101
		DEFAULT => -602
	},
	{#State 2102
		DEFAULT => -1088
	},
	{#State 2103
		DEFAULT => -1094
	},
	{#State 2104
		ACTIONS => {
			'TEXT_STRING' => 2447
		},
		GOTOS => {
			'TEXT_STRING_filesystem' => 2460
		}
	},
	{#State 2105
		DEFAULT => -1090
	},
	{#State 2106
		ACTIONS => {
			'TEXT_STRING' => 2447
		},
		DEFAULT => -1476,
		GOTOS => {
			'TEXT_STRING_filesystem' => 2461
		}
	},
	{#State 2107
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 2462,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'ident' => 706
		}
	},
	{#State 2108
		DEFAULT => -1091
	},
	{#State 2109
		ACTIONS => {
			"," => 2463
		},
		DEFAULT => -1086
	},
	{#State 2110
		ACTIONS => {
			'WHERE' => 1835
		},
		DEFAULT => -1029,
		GOTOS => {
			'where_clause' => 2464
		}
	},
	{#State 2111
		ACTIONS => {
			'WHERE' => 1835
		},
		DEFAULT => -1029,
		GOTOS => {
			'where_clause' => 2465
		}
	},
	{#State 2112
		DEFAULT => -607
	},
	{#State 2113
		DEFAULT => -606
	},
	{#State 2114
		DEFAULT => -627
	},
	{#State 2115
		DEFAULT => -603
	},
	{#State 2116
		DEFAULT => -1057
	},
	{#State 2117
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'AS' => 2468,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -635,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 2466,
			'IDENT_sys' => 297,
			'select_alias' => 2467,
			'ident' => 2469
		}
	},
	{#State 2118
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			"*" => 2470,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2471
		}
	},
	{#State 2119
		ACTIONS => {
			'ON' => 2472
		},
		DEFAULT => -1148,
		GOTOS => {
			'opt_insert_update' => 2473
		}
	},
	{#State 2120
		DEFAULT => -544
	},
	{#State 2121
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			"*" => 2286,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2287,
			'IDENT_sys' => 297,
			'grant_ident' => 2474,
			'ident' => 2288
		}
	},
	{#State 2122
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			"*" => 2286,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2287,
			'IDENT_sys' => 297,
			'grant_ident' => 2475,
			'ident' => 2288
		}
	},
	{#State 2123
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			"*" => 2286,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2287,
			'IDENT_sys' => 297,
			'grant_ident' => 2476,
			'ident' => 2288
		}
	},
	{#State 2124
		ACTIONS => {
			'GRANT' => 2477
		}
	},
	{#State 2125
		DEFAULT => -570
	},
	{#State 2126
		DEFAULT => -57
	},
	{#State 2127
		DEFAULT => -1687
	},
	{#State 2128
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 2479,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'collation_name_or_default' => 2480,
			'collation_name' => 2478,
			'ident' => 706,
			'keyword_sp' => 287,
			'ident_or_text' => 2481,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297
		}
	},
	{#State 2129
		DEFAULT => -1686
	},
	{#State 2130
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2482,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2131
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 1193,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'internal_variable_name' => 2483,
			'IDENT_sys' => 297,
			'ident' => 1196
		}
	},
	{#State 2132
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		GOTOS => {
			'equal' => 2484
		}
	},
	{#State 2133
		DEFAULT => -1697
	},
	{#State 2134
		ACTIONS => {
			"(" => 2485
		}
	},
	{#State 2135
		DEFAULT => -1688
	},
	{#State 2136
		ACTIONS => {
			"(" => 2486
		}
	},
	{#State 2137
		DEFAULT => -1692
	},
	{#State 2138
		ACTIONS => {
			'REPEATABLE_SYM' => 2489,
			'READ_SYM' => 2487,
			'SERIALIZABLE_SYM' => 2490
		},
		GOTOS => {
			'isolation_types' => 2488
		}
	},
	{#State 2139
		DEFAULT => -1702
	},
	{#State 2140
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -1704,
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'NUM_literal' => 684,
			'literal' => 631,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 961,
			'not2' => 521,
			'simple_ident_q' => 586,
			'ident' => 656,
			'interval_expr' => 598,
			'keyword_sp' => 287,
			'geometry_function' => 685
		}
	},
	{#State 2141
		ACTIONS => {
			"(" => 990
		},
		DEFAULT => -1701
	},
	{#State 2142
		DEFAULT => -1700
	},
	{#State 2143
		DEFAULT => -1703
	},
	{#State 2144
		DEFAULT => -1681
	},
	{#State 2145
		DEFAULT => -1691
	},
	{#State 2146
		ACTIONS => {
			"," => 2491
		},
		DEFAULT => -1143
	},
	{#State 2147
		ACTIONS => {
			")" => 2492
		}
	},
	{#State 2148
		ACTIONS => {
			"(" => 990
		},
		DEFAULT => -1147
	},
	{#State 2149
		DEFAULT => -1146
	},
	{#State 2150
		DEFAULT => -1145
	},
	{#State 2151
		ACTIONS => {
			"(" => 1687
		},
		GOTOS => {
			'no_braces' => 2493
		}
	},
	{#State 2152
		ACTIONS => {
			'ORDER_SYM' => 1613,
			'UNION_SYM' => 1172,
			'LIMIT' => 899
		},
		DEFAULT => -1833,
		GOTOS => {
			'union_list' => 1616,
			'union_opt' => 2494,
			'order_or_limit' => 1614,
			'order_clause' => 1619,
			'limit_clause' => 1617,
			'union_order_or_limit' => 1618
		}
	},
	{#State 2153
		ACTIONS => {
			'SELECT_SYM' => 1206
		},
		GOTOS => {
			'create_select' => 1692
		}
	},
	{#State 2154
		DEFAULT => -1123
	},
	{#State 2155
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'simple_ident_nospvar' => 1694,
			'table_wild' => 1690,
			'ident' => 1696,
			'simple_ident_q' => 1540,
			'insert_ident' => 2495,
			'keyword_sp' => 287,
			'IDENT_sys' => 297
		}
	},
	{#State 2156
		ACTIONS => {
			"(" => 2153,
			'SELECT_SYM' => 1206,
			'VALUES' => 1204,
			'VALUE_SYM' => 1199
		},
		GOTOS => {
			'create_select' => 1201,
			'insert_values' => 2496
		}
	},
	{#State 2157
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			"*" => 2470,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2497
		}
	},
	{#State 2158
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'simple_ident_nospvar' => 1699,
			'IDENT_sys' => 297,
			'ident_eq_value' => 2498,
			'ident' => 1542,
			'simple_ident_q' => 1540
		}
	},
	{#State 2159
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 2148,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2149,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'expr_or_default' => 2499,
			'bit_term' => 564
		}
	},
	{#State 2160
		ACTIONS => {
			'FROM' => 1644,
			"," => 1647,
			'LIMIT' => 899
		},
		DEFAULT => -1056,
		GOTOS => {
			'opt_limit_clause' => 2500,
			'select_from' => 2502,
			'opt_select_from' => 2501,
			'limit_clause' => 2116
		}
	},
	{#State 2161
		DEFAULT => -1269
	},
	{#State 2162
		DEFAULT => -115
	},
	{#State 2163
		DEFAULT => -1394
	},
	{#State 2164
		DEFAULT => -1789
	},
	{#State 2165
		DEFAULT => -1096
	},
	{#State 2166
		DEFAULT => -576
	},
	{#State 2167
		ACTIONS => {
			'TO_SYM' => 2503
		}
	},
	{#State 2168
		DEFAULT => -98
	},
	{#State 2169
		DEFAULT => -101
	},
	{#State 2170
		DEFAULT => -99
	},
	{#State 2171
		ACTIONS => {
			'DATA_SYM' => 2504
		}
	},
	{#State 2172
		DEFAULT => -100
	},
	{#State 2173
		ACTIONS => {
			'DATA_SYM' => 2505
		}
	},
	{#State 2174
		ACTIONS => {
			'INVOKER_SYM' => 2506,
			'DEFINER_SYM' => 2507
		}
	},
	{#State 2175
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_ident' => 2508,
			'ident' => 2229
		}
	},
	{#State 2176
		ACTIONS => {
			'KEY_SYM' => 2509
		}
	},
	{#State 2177
		DEFAULT => -514
	},
	{#State 2178
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_ident' => 2510,
			'ident' => 2229
		}
	},
	{#State 2179
		ACTIONS => {
			'KEY_SYM' => 2511
		}
	},
	{#State 2180
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2512,
			'equal' => 2183
		}
	},
	{#State 2181
		ACTIONS => {
			'CHARSET' => 490,
			'CHAR_SYM' => 473
		},
		GOTOS => {
			'charset' => 2513
		}
	},
	{#State 2182
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'DEFAULT' => 2514,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 2515
		}
	},
	{#State 2183
		DEFAULT => -1140
	},
	{#State 2184
		DEFAULT => -504
	},
	{#State 2185
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2516
		}
	},
	{#State 2186
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 2517
		}
	},
	{#State 2187
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'simple_ident_nospvar' => 2520,
			'alter_order_list' => 2519,
			'ident' => 1542,
			'simple_ident_q' => 1540,
			'alter_order_item' => 2518,
			'keyword_sp' => 287,
			'IDENT_sys' => 297
		}
	},
	{#State 2188
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_ident' => 2521,
			'ident' => 2229
		}
	},
	{#State 2189
		ACTIONS => {
			"(" => 2522
		}
	},
	{#State 2190
		DEFAULT => -491
	},
	{#State 2191
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 2523
		}
	},
	{#State 2192
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 927,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'storage_engines' => 2524,
			'ident' => 706
		}
	},
	{#State 2193
		ACTIONS => {
			'NUM' => 2305,
			'ULONGLONG_NUM' => 2307,
			'FLOAT_NUM' => 2306,
			'LONG_NUM' => 2304,
			'DECIMAL_NUM' => 2309
		},
		GOTOS => {
			'ulonglong_num' => 2525
		}
	},
	{#State 2194
		DEFAULT => -233
	},
	{#State 2195
		ACTIONS => {
			'FOREIGN' => -298,
			'CHECK_SYM' => 2526,
			'PRIMARY_SYM' => -298,
			'UNIQUE_SYM' => -298
		},
		DEFAULT => -294,
		GOTOS => {
			'check_constraint' => 2527,
			'opt_check_constraint' => 2528
		}
	},
	{#State 2196
		ACTIONS => {
			'INDEX_SYM' => 1264,
			'KEY_SYM' => 1266
		},
		DEFAULT => -457,
		GOTOS => {
			'key_or_index' => 1268,
			'opt_key_or_index' => 2529
		}
	},
	{#State 2197
		DEFAULT => -494
	},
	{#State 2198
		DEFAULT => -450
	},
	{#State 2199
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -476,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_ident' => 2530,
			'ident' => 2229,
			'opt_ident' => 2531
		}
	},
	{#State 2200
		ACTIONS => {
			'INDEX_SYM' => 1264,
			'KEY_SYM' => 1266
		},
		DEFAULT => -457,
		GOTOS => {
			'key_or_index' => 1268,
			'opt_key_or_index' => 2532
		}
	},
	{#State 2201
		DEFAULT => -496
	},
	{#State 2202
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -476,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_ident' => 2530,
			'ident' => 2229,
			'opt_ident' => 2533
		}
	},
	{#State 2203
		ACTIONS => {
			'FOREIGN' => 2535,
			'CHECK_SYM' => 2526,
			'PRIMARY_SYM' => 2537,
			'UNIQUE_SYM' => 2538
		},
		GOTOS => {
			'check_constraint' => 2536,
			'constraint_key_type' => 2534
		}
	},
	{#State 2204
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 2539
		}
	},
	{#State 2205
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2540
		}
	},
	{#State 2206
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		DEFAULT => -1139,
		GOTOS => {
			'opt_equal' => 2541,
			'equal' => 2183
		}
	},
	{#State 2207
		ACTIONS => {
			'FORCE_SYM' => 1739,
			'AUTO_INC' => 1769,
			'ORDER_SYM' => 1740,
			'ROW_FORMAT_SYM' => 1760,
			'DATA_SYM' => 1753,
			'CHANGE' => 1741,
			'DROP' => 1730,
			'INDEX_SYM' => 1731,
			'RENAME' => 1763,
			'ENABLE_SYM' => 1761,
			'MODIFY_SYM' => 1755,
			'CONVERT_SYM' => 1732,
			'TYPE_SYM' => 1746,
			'MAX_ROWS' => 1765,
			'ALTER' => 1764,
			'PACK_KEYS_SYM' => 1734,
			'UNION_SYM' => 1742,
			'RAID_TYPE' => 1766,
			'PASSWORD' => 1767,
			'INSERT_METHOD' => 1757,
			'MIN_ROWS' => 1747,
			'DISABLE_SYM' => 1736,
			'ENGINE_SYM' => 1768,
			'COMMENT_SYM' => 1737,
			'RAID_CHUNKSIZE' => 1738,
			'DELAY_KEY_WRITE_SYM' => 1762,
			'DEFAULT' => 1245,
			'ADD' => 1749,
			'AVG_ROW_LENGTH' => 1750,
			'CONNECTION_SYM' => 1752,
			'RAID_CHUNKS' => 1758,
			'CHECKSUM_SYM' => 1744
		},
		DEFAULT => -415,
		GOTOS => {
			'default_charset' => 1756,
			'opt_default' => 1243,
			'alter_order_clause' => 1745,
			'add_column' => 1770,
			'default_collation' => 1751,
			'create_table_option' => 1748,
			'create_table_options_space_separated' => 1735,
			'alter_list_item' => 2542
		}
	},
	{#State 2208
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_ident' => 2543,
			'ident' => 2229
		}
	},
	{#State 2209
		ACTIONS => {
			'LAST_SYM' => 2544,
			'NO_SYM' => 2545,
			'FIRST_SYM' => 2547
		},
		GOTOS => {
			'merge_insert_types' => 2546
		}
	},
	{#State 2210
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 2548
		}
	},
	{#State 2211
		DEFAULT => -490
	},
	{#State 2212
		ACTIONS => {
			'COMPRESSED_SYM' => 2554,
			'REDUNDANT_SYM' => 2551,
			'DEFAULT' => 2550,
			'FIXED_SYM' => 2553,
			'COMPACT_SYM' => 2549,
			'DYNAMIC_SYM' => 2555
		},
		GOTOS => {
			'row_types' => 2552
		}
	},
	{#State 2213
		DEFAULT => -505
	},
	{#State 2214
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 2556
		}
	},
	{#State 2215
		DEFAULT => -525
	},
	{#State 2216
		DEFAULT => -526
	},
	{#State 2217
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2557,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 2218
		DEFAULT => -524
	},
	{#State 2219
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_ident' => 2558,
			'ident' => 2229
		}
	},
	{#State 2220
		ACTIONS => {
			'NUM' => 2305,
			'ULONGLONG_NUM' => 2307,
			'FLOAT_NUM' => 2306,
			'LONG_NUM' => 2304,
			'DECIMAL_NUM' => 2309
		},
		GOTOS => {
			'ulonglong_num' => 2559
		}
	},
	{#State 2221
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'RAID_STRIPED_SYM' => 2563,
			'RAID_0_SYM' => 2562,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'raid_types' => 2561,
			'ulong_num' => 2560
		}
	},
	{#State 2222
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2564
		}
	},
	{#State 2223
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 927,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'storage_engines' => 2565,
			'ident' => 706
		}
	},
	{#State 2224
		ACTIONS => {
			'NUM' => 2305,
			'ULONGLONG_NUM' => 2307,
			'FLOAT_NUM' => 2306,
			'LONG_NUM' => 2304,
			'DECIMAL_NUM' => 2309
		},
		GOTOS => {
			'ulonglong_num' => 2566
		}
	},
	{#State 2225
		ACTIONS => {
			'AFTER_SYM' => 2567,
			'FIRST_SYM' => 2569
		},
		DEFAULT => -520,
		GOTOS => {
			'opt_place' => 2568
		}
	},
	{#State 2226
		ACTIONS => {
			'SET' => 2592,
			'NUMERIC_SYM' => 2615,
			'TINYBLOB' => 2620,
			'POINT_SYM' => 2610,
			'TEXT_SYM' => 2621,
			'DECIMAL_SYM' => 2582,
			'BINARY' => 2583,
			'DATETIME' => 2570,
			'NATIONAL_SYM' => 2603,
			'BLOB_SYM' => 2571,
			'NVARCHAR_SYM' => 2611,
			'LONGBLOB' => 2604,
			'NCHAR_SYM' => 2584,
			'TINYINT' => 2572,
			'YEAR_SYM' => 2573,
			'MULTIPOLYGON' => 2594,
			'INT_SYM' => 2574,
			'MULTILINESTRING' => 2617,
			'FLOAT_SYM' => 2605,
			'BIT_SYM' => 2596,
			'ENUM' => 2622,
			'SMALLINT' => 2597,
			'CHAR_SYM' => 2575,
			'GEOMETRYCOLLECTION' => 2586,
			'LONG_SYM' => 2587,
			'VARBINARY' => 2606,
			'TIMESTAMP' => 2589,
			'MEDIUMTEXT' => 2623,
			'DATE_SYM' => 2607,
			'POLYGON' => 2576,
			'FIXED_SYM' => 2598,
			'REAL' => 2577,
			'DOUBLE_SYM' => 2613,
			'LINESTRING' => 2578,
			'TIME_SYM' => 2599,
			'BOOL_SYM' => 2608,
			'MULTIPOINT' => 2614,
			'GEOMETRY_SYM' => 2618,
			'TINYTEXT' => 2590,
			'LONGTEXT' => 2595,
			'MEDIUMINT' => 2600,
			'SERIAL_SYM' => 2619,
			'VARCHAR' => 2601,
			'BOOLEAN_SYM' => 2602,
			'MEDIUMBLOB' => 2581,
			'BIGINT' => 2591
		},
		GOTOS => {
			'int_type' => 2593,
			'spatial_type' => 2579,
			'varchar' => 2588,
			'nvarchar' => 2616,
			'real_type' => 2609,
			'char' => 2580,
			'type' => 2585,
			'nchar' => 2612
		}
	},
	{#State 2227
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'INDEX_SYM' => 1264,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'KEY_SYM' => 1266,
			'FULLTEXT_SYM' => 2196,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'SPATIAL_SYM' => 2200,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'CONSTRAINT' => 2202,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -297,
		GOTOS => {
			'keyword' => 332,
			'key_type' => 2199,
			'field_list' => 2626,
			'key_or_index' => 2198,
			'column_def' => 2624,
			'key_def' => 2627,
			'ident' => 2229,
			'field_list_item' => 2625,
			'keyword_sp' => 287,
			'opt_constraint' => 2203,
			'IDENT_sys' => 297,
			'field_spec' => 2228,
			'constraint' => 2195,
			'field_ident' => 2226
		}
	},
	{#State 2228
		ACTIONS => {
			'CHECK_SYM' => 2526,
			'REFERENCES' => 2630
		},
		DEFAULT => -294,
		GOTOS => {
			'check_constraint' => 2527,
			'opt_check_constraint' => 2628,
			'references' => 2629
		}
	},
	{#State 2229
		ACTIONS => {
			"." => 2631
		},
		DEFAULT => -1373
	},
	{#State 2230
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2632
		}
	},
	{#State 2231
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 1665,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 1666,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1670,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'charset_name' => 1669,
			'charset_name_or_default' => 2633,
			'ident' => 706
		}
	},
	{#State 2232
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 2479,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'collation_name_or_default' => 2634,
			'collation_name' => 2478,
			'ident' => 706,
			'keyword_sp' => 287,
			'ident_or_text' => 2481,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297
		}
	},
	{#State 2233
		ACTIONS => {
			"(" => 2281
		},
		DEFAULT => -1867,
		GOTOS => {
			'view_list_opt' => 2635
		}
	},
	{#State 2234
		ACTIONS => {
			'JOIN_SYM' => 1777,
			'CROSS' => 1779,
			'INNER_SYM' => 1780,
			'RIGHT' => 1781,
			'STRAIGHT_JOIN' => 1782,
			'NATURAL' => 1783,
			'LEFT' => 1778
		},
		DEFAULT => -956,
		GOTOS => {
			'normal_join' => 1784
		}
	},
	{#State 2235
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 1259,
			'derived_table_list' => 2636,
			'ident' => 435,
			'table_factor' => 1261,
			'keyword_sp' => 287,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'table_ref' => 1254,
			'join_table' => 1255
		}
	},
	{#State 2236
		ACTIONS => {
			'ORDER_SYM' => 1613,
			'UNION_SYM' => 1172,
			'LIMIT' => 899
		},
		DEFAULT => -1833,
		GOTOS => {
			'union_list' => 1616,
			'union_opt' => 2637,
			'order_or_limit' => 1614,
			'order_clause' => 1619,
			'limit_clause' => 1617,
			'union_order_or_limit' => 1618
		}
	},
	{#State 2237
		ACTIONS => {
			'JOIN_SYM' => 2638
		}
	},
	{#State 2238
		DEFAULT => -981
	},
	{#State 2239
		DEFAULT => -971
	},
	{#State 2240
		DEFAULT => -970
	},
	{#State 2241
		ACTIONS => {
			'JOIN_SYM' => 2639
		}
	},
	{#State 2242
		ACTIONS => {
			'ON' => 2640
		},
		DEFAULT => -958
	},
	{#State 2243
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1259,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'ident' => 435,
			'table_factor' => 2641
		}
	},
	{#State 2244
		ACTIONS => {
			'OUTER' => 2238
		},
		DEFAULT => -980,
		GOTOS => {
			'opt_outer' => 2642
		}
	},
	{#State 2245
		ACTIONS => {
			'OUTER' => 2238
		},
		DEFAULT => -980,
		GOTOS => {
			'opt_outer' => 2643
		}
	},
	{#State 2246
		ACTIONS => {
			'USING' => 2645,
			'ON' => 2644,
			'NATURAL' => 1783
		},
		DEFAULT => -957,
		GOTOS => {
			'normal_join' => 1784
		}
	},
	{#State 2247
		DEFAULT => -1152
	},
	{#State 2248
		ACTIONS => {
			'WHERE' => 1835,
			"," => 2646
		},
		DEFAULT => -1029,
		GOTOS => {
			'where_clause' => 2647
		}
	},
	{#State 2249
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		GOTOS => {
			'equal' => 2648
		}
	},
	{#State 2250
		DEFAULT => -974
	},
	{#State 2251
		ACTIONS => {
			"*" => 1176
		},
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 1178,
			'select_item_list' => 2649,
			'select_item' => 1175
		}
	},
	{#State 2252
		DEFAULT => -972
	},
	{#State 2253
		ACTIONS => {
			'KEY_SYM' => 1266,
			'INDEX_SYM' => 1264
		},
		GOTOS => {
			'key_or_index' => 2650,
			'key_usage_list' => 2651
		}
	},
	{#State 2254
		ACTIONS => {
			'KEY_SYM' => 1266,
			'INDEX_SYM' => 1264
		},
		GOTOS => {
			'key_or_index' => 2650,
			'key_usage_list' => 2652
		}
	},
	{#State 2255
		ACTIONS => {
			'KEY_SYM' => 1266,
			'INDEX_SYM' => 1264
		},
		GOTOS => {
			'key_or_index' => 2650,
			'key_usage_list' => 2653
		}
	},
	{#State 2256
		ACTIONS => {
			'INNER_SYM' => 1780,
			'STRAIGHT_JOIN' => 1782,
			'NATURAL' => 1783,
			'LEFT' => 2654,
			'RIGHT' => 1781,
			'JOIN_SYM' => 1777,
			'CROSS' => 1779
		},
		GOTOS => {
			'normal_join' => 1784
		}
	},
	{#State 2257
		ACTIONS => {
			"," => 2655,
			")" => 2656
		}
	},
	{#State 2258
		DEFAULT => -993
	},
	{#State 2259
		DEFAULT => -992
	},
	{#State 2260
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 2657
		}
	},
	{#State 2261
		DEFAULT => -1900
	},
	{#State 2262
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2658,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 2263
		DEFAULT => -470
	},
	{#State 2264
		DEFAULT => -469
	},
	{#State 2265
		DEFAULT => -468
	},
	{#State 2266
		DEFAULT => -471
	},
	{#State 2267
		DEFAULT => -467
	},
	{#State 2268
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'INDEX_SYM' => 1264,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'KEY_SYM' => 1266,
			'FULLTEXT_SYM' => 2196,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1206,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'LIKE' => 2661,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'SPATIAL_SYM' => 2200,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'CONSTRAINT' => 2202,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -297,
		GOTOS => {
			'keyword' => 332,
			'key_type' => 2199,
			'field_list' => 2660,
			'column_def' => 2624,
			'key_def' => 2627,
			'IDENT_sys' => 297,
			'constraint' => 2195,
			'field_ident' => 2226,
			'key_or_index' => 2198,
			'create2a' => 2662,
			'field_list_item' => 2625,
			'ident' => 2229,
			'keyword_sp' => 287,
			'field_spec' => 2228,
			'opt_constraint' => 2203,
			'create_select' => 2659
		}
	},
	{#State 2269
		ACTIONS => {
			'REPLACE' => 2663,
			";" => -211,
			'IGNORE_SYM' => 2665,
			'END_OF_INPUT' => -211
		},
		DEFAULT => -1305,
		GOTOS => {
			'opt_duplicate' => 2664,
			'create3' => 2666
		}
	},
	{#State 2270
		ACTIONS => {
			'AUTO_INC' => 1769,
			'ROW_FORMAT_SYM' => 1760,
			'DATA_SYM' => 1753,
			'INDEX_SYM' => 1731,
			'TYPE_SYM' => 1746,
			'MAX_ROWS' => 1765,
			'PACK_KEYS_SYM' => 1734,
			'UNION_SYM' => 1742,
			'RAID_TYPE' => 1766,
			'PASSWORD' => 1767,
			'CHAR_SYM' => -415,
			'INSERT_METHOD' => 1757,
			'MIN_ROWS' => 1747,
			"," => 2667,
			'ENGINE_SYM' => 1768,
			'COMMENT_SYM' => 1737,
			'RAID_CHUNKSIZE' => 1738,
			'COLLATE_SYM' => -415,
			'CHARSET' => -415,
			'DELAY_KEY_WRITE_SYM' => 1762,
			'AVG_ROW_LENGTH' => 1750,
			'DEFAULT' => 1245,
			'CONNECTION_SYM' => 1752,
			'RAID_CHUNKS' => 1758,
			'CHECKSUM_SYM' => 1744
		},
		DEFAULT => -234,
		GOTOS => {
			'default_charset' => 1756,
			'opt_default' => 1243,
			'create_table_options' => 2668,
			'default_collation' => 1751,
			'create_table_option' => 2270
		}
	},
	{#State 2271
		DEFAULT => -84
	},
	{#State 2272
		DEFAULT => -231
	},
	{#State 2273
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2669,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 2274
		ACTIONS => {
			'TEXT_STRING' => 2670,
			'PASSWORD' => 2671
		}
	},
	{#State 2275
		DEFAULT => -1791
	},
	{#State 2276
		DEFAULT => -201
	},
	{#State 2277
		ACTIONS => {
			'DELETE_SYM' => 2675,
			'UPDATE_SYM' => 2672,
			'INSERT' => 2673
		},
		GOTOS => {
			'trg_event' => 2674
		}
	},
	{#State 2278
		DEFAULT => -200
	},
	{#State 2279
		ACTIONS => {
			'INOUT_SYM' => 2678,
			")" => -123,
			'OUT_SYM' => 2681,
			'IN_SYM' => 2682
		},
		DEFAULT => -128,
		GOTOS => {
			'sp_pdparam_list' => 2676,
			'sp_pdparam' => 2680,
			'sp_pdparams' => 2679,
			'sp_opt_inout' => 2677
		}
	},
	{#State 2280
		ACTIONS => {
			"(" => 2683,
			'RETURNS_SYM' => 2684
		},
		GOTOS => {
			'create_function_tail' => 2685
		}
	},
	{#State 2281
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'view_list' => 2686,
			'ident' => 2687
		}
	},
	{#State 2282
		ACTIONS => {
			'AS' => 2688
		}
	},
	{#State 2283
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'column_list_id' => 2689,
			'ident' => 1818
		}
	},
	{#State 2284
		DEFAULT => -1796
	},
	{#State 2285
		ACTIONS => {
			'TO_SYM' => 2690
		}
	},
	{#State 2286
		ACTIONS => {
			"." => 2691
		},
		DEFAULT => -1784
	},
	{#State 2287
		DEFAULT => -1787
	},
	{#State 2288
		ACTIONS => {
			"." => 2692
		},
		DEFAULT => -1377
	},
	{#State 2289
		ACTIONS => {
			'TO_SYM' => 2693
		}
	},
	{#State 2290
		ACTIONS => {
			'TO_SYM' => 2694
		}
	},
	{#State 2291
		DEFAULT => -554
	},
	{#State 2292
		DEFAULT => -1030
	},
	{#State 2293
		DEFAULT => -1718
	},
	{#State 2294
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 2148,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2149,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'values' => 2695,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'expr_or_default' => 2150,
			'bit_term' => 564
		}
	},
	{#State 2295
		DEFAULT => -71
	},
	{#State 2296
		DEFAULT => -76
	},
	{#State 2297
		DEFAULT => -82
	},
	{#State 2298
		DEFAULT => -80
	},
	{#State 2299
		DEFAULT => -68
	},
	{#State 2300
		DEFAULT => -83
	},
	{#State 2301
		DEFAULT => -78
	},
	{#State 2302
		DEFAULT => -77
	},
	{#State 2303
		DEFAULT => -67
	},
	{#State 2304
		DEFAULT => -1076
	},
	{#State 2305
		DEFAULT => -1074
	},
	{#State 2306
		DEFAULT => -1078
	},
	{#State 2307
		DEFAULT => -1075
	},
	{#State 2308
		DEFAULT => -81
	},
	{#State 2309
		DEFAULT => -1077
	},
	{#State 2310
		DEFAULT => -69
	},
	{#State 2311
		DEFAULT => -75
	},
	{#State 2312
		DEFAULT => -74
	},
	{#State 2313
		DEFAULT => -72
	},
	{#State 2314
		DEFAULT => -73
	},
	{#State 2315
		DEFAULT => -70
	},
	{#State 2316
		DEFAULT => -1209
	},
	{#State 2317
		DEFAULT => -1210
	},
	{#State 2318
		ACTIONS => {
			'LIKE' => 881,
			'WHERE' => 879
		},
		DEFAULT => -1253,
		GOTOS => {
			'wild_and_where' => 2696
		}
	},
	{#State 2319
		DEFAULT => -1204
	},
	{#State 2320
		DEFAULT => -1252
	},
	{#State 2321
		DEFAULT => -1203
	},
	{#State 2322
		DEFAULT => -1061
	},
	{#State 2323
		DEFAULT => -1060
	},
	{#State 2324
		DEFAULT => -1191
	},
	{#State 2325
		ACTIONS => {
			'MASTER_LOG_FILE_SYM' => 2697
		}
	},
	{#State 2326
		DEFAULT => -61
	},
	{#State 2327
		DEFAULT => -906
	},
	{#State 2328
		ACTIONS => {
			"," => 2698
		}
	},
	{#State 2329
		ACTIONS => {
			'DAY_SYM' => 1045,
			'MONTH_SYM' => 1049,
			'HOUR_MICROSECOND_SYM' => 1050,
			'DAY_MINUTE_SYM' => 1042,
			'MINUTE_SYM' => 1043,
			'SECOND_MICROSECOND_SYM' => 1041,
			'YEAR_MONTH_SYM' => 1039,
			'MICROSECOND_SYM' => 1031,
			'FRAC_SECOND_SYM' => 1036,
			'DAY_SECOND_SYM' => 1046,
			'MINUTE_SECOND_SYM' => 1032,
			'HOUR_SECOND_SYM' => 1035,
			'HOUR_SYM' => 1033,
			'SECOND_SYM' => 1047,
			'YEAR_SYM' => 1028,
			'QUARTER_SYM' => 1037,
			'WEEK_SYM' => 1040,
			'HOUR_MINUTE_SYM' => 1038,
			'DAY_HOUR_SYM' => 1044,
			'DAY_MICROSECOND_SYM' => 1034,
			'MINUTE_MICROSECOND_SYM' => 1030
		},
		GOTOS => {
			'interval_time_st' => 1029,
			'interval' => 2699
		}
	},
	{#State 2330
		DEFAULT => -899
	},
	{#State 2331
		DEFAULT => -901
	},
	{#State 2332
		DEFAULT => -934
	},
	{#State 2333
		ACTIONS => {
			"(" => 2700
		},
		DEFAULT => -377,
		GOTOS => {
			'opt_len' => 2701
		}
	},
	{#State 2334
		ACTIONS => {
			"(" => 2703
		},
		DEFAULT => -366,
		GOTOS => {
			'float_options' => 2704,
			'precision' => 2702
		}
	},
	{#State 2335
		ACTIONS => {
			"(" => 2700
		},
		DEFAULT => -377,
		GOTOS => {
			'opt_len' => 2705
		}
	},
	{#State 2336
		ACTIONS => {
			"(" => 2700
		},
		DEFAULT => -377,
		GOTOS => {
			'opt_len' => 2706
		}
	},
	{#State 2337
		ACTIONS => {
			'INT_SYM' => 2707
		},
		DEFAULT => -930
	},
	{#State 2338
		DEFAULT => -933
	},
	{#State 2339
		DEFAULT => -932
	},
	{#State 2340
		ACTIONS => {
			")" => 2708
		}
	},
	{#State 2341
		ACTIONS => {
			'INT_SYM' => 2709
		},
		DEFAULT => -928
	},
	{#State 2342
		ACTIONS => {
			")" => 2710
		}
	},
	{#State 2343
		ACTIONS => {
			"," => 2711,
			")" => 2712
		}
	},
	{#State 2344
		ACTIONS => {
			")" => 2713
		}
	},
	{#State 2345
		ACTIONS => {
			")" => 2714
		}
	},
	{#State 2346
		ACTIONS => {
			")" => 2715
		}
	},
	{#State 2347
		ACTIONS => {
			")" => 2716
		}
	},
	{#State 2348
		ACTIONS => {
			")" => 2717
		}
	},
	{#State 2349
		ACTIONS => {
			")" => 2718
		}
	},
	{#State 2350
		ACTIONS => {
			"," => 2719
		}
	},
	{#State 2351
		ACTIONS => {
			")" => 2720
		}
	},
	{#State 2352
		ACTIONS => {
			'UNION_SYM' => 1172
		},
		DEFAULT => -1830,
		GOTOS => {
			'union_list' => 1174,
			'union_clause' => 2721
		}
	},
	{#State 2353
		DEFAULT => -728
	},
	{#State 2354
		DEFAULT => -1842
	},
	{#State 2355
		ACTIONS => {
			")" => 2722
		}
	},
	{#State 2356
		ACTIONS => {
			'DAY_SYM' => 1045,
			'MONTH_SYM' => 1049,
			'HOUR_MICROSECOND_SYM' => 1050,
			'DAY_MINUTE_SYM' => 1042,
			'MINUTE_SYM' => 1043,
			'SECOND_MICROSECOND_SYM' => 1041,
			'YEAR_MONTH_SYM' => 1039,
			'MICROSECOND_SYM' => 1031,
			'FRAC_SECOND_SYM' => 1036,
			'DAY_SECOND_SYM' => 1046,
			'MINUTE_SECOND_SYM' => 1032,
			'HOUR_SECOND_SYM' => 1035,
			'HOUR_SYM' => 1033,
			'SECOND_SYM' => 1047,
			'YEAR_SYM' => 1028,
			'QUARTER_SYM' => 1037,
			'WEEK_SYM' => 1040,
			'HOUR_MINUTE_SYM' => 1038,
			'DAY_HOUR_SYM' => 1044,
			'DAY_MICROSECOND_SYM' => 1034,
			'MINUTE_MICROSECOND_SYM' => 1030
		},
		GOTOS => {
			'interval_time_st' => 1029,
			'interval' => 2723
		}
	},
	{#State 2357
		ACTIONS => {
			"," => 2724
		}
	},
	{#State 2358
		ACTIONS => {
			")" => 2725
		}
	},
	{#State 2359
		ACTIONS => {
			")" => 2726
		}
	},
	{#State 2360
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2727,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2361
		ACTIONS => {
			"," => 2728
		}
	},
	{#State 2362
		ACTIONS => {
			")" => 2729
		}
	},
	{#State 2363
		ACTIONS => {
			")" => 2730
		}
	},
	{#State 2364
		DEFAULT => -912
	},
	{#State 2365
		ACTIONS => {
			")" => 2731
		}
	},
	{#State 2366
		DEFAULT => -904
	},
	{#State 2367
		ACTIONS => {
			")" => 2732
		}
	},
	{#State 2368
		ACTIONS => {
			")" => 2733
		}
	},
	{#State 2369
		ACTIONS => {
			")" => 2734
		}
	},
	{#State 2370
		ACTIONS => {
			"," => 2735,
			")" => 2736
		}
	},
	{#State 2371
		DEFAULT => -670
	},
	{#State 2372
		ACTIONS => {
			'OR_OR_SYM' => 988,
			'COLLATE_SYM' => 989
		},
		DEFAULT => -1033
	},
	{#State 2373
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 522,
			'CONVERT_SYM' => 523,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'BEGIN_SYM' => 138,
			'POLYGON' => 529,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'STD_SYM' => 542,
			'CURRENT_USER' => 543,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'CONCAT_WS' => 581,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 2737,
			'IDENT_sys' => 643,
			'simple_ident' => 531,
			'sum_expr' => 635,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2374
		DEFAULT => -674
	},
	{#State 2375
		ACTIONS => {
			"," => 2738,
			")" => 2739
		}
	},
	{#State 2376
		ACTIONS => {
			")" => 2740
		}
	},
	{#State 2377
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 2741,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2378
		DEFAULT => -666
	},
	{#State 2379
		DEFAULT => -664
	},
	{#State 2380
		ACTIONS => {
			")" => 2742
		}
	},
	{#State 2381
		ACTIONS => {
			")" => 2743
		}
	},
	{#State 2382
		ACTIONS => {
			")" => 2744
		}
	},
	{#State 2383
		ACTIONS => {
			")" => 2745
		}
	},
	{#State 2384
		ACTIONS => {
			")" => 2746
		}
	},
	{#State 2385
		ACTIONS => {
			")" => 2747
		}
	},
	{#State 2386
		ACTIONS => {
			"," => 2748
		}
	},
	{#State 2387
		ACTIONS => {
			")" => 2749
		}
	},
	{#State 2388
		ACTIONS => {
			")" => 2750
		}
	},
	{#State 2389
		ACTIONS => {
			'SEPARATOR_SYM' => 2752
		},
		DEFAULT => -920,
		GOTOS => {
			'opt_gconcat_separator' => 2751
		}
	},
	{#State 2390
		DEFAULT => -923
	},
	{#State 2391
		ACTIONS => {
			")" => 2753
		}
	},
	{#State 2392
		ACTIONS => {
			")" => 2754
		}
	},
	{#State 2393
		ACTIONS => {
			")" => 2755
		}
	},
	{#State 2394
		DEFAULT => -895
	},
	{#State 2395
		ACTIONS => {
			")" => 2756
		}
	},
	{#State 2396
		ACTIONS => {
			'WITH' => 2757,
			"|" => 1013,
			'IN_SYM' => 2759
		},
		DEFAULT => -885,
		GOTOS => {
			'fulltext_options' => 2758
		}
	},
	{#State 2397
		ACTIONS => {
			")" => 2760
		}
	},
	{#State 2398
		ACTIONS => {
			")" => 2761
		}
	},
	{#State 2399
		ACTIONS => {
			")" => 2762
		}
	},
	{#State 2400
		ACTIONS => {
			")" => 2764,
			'FOR_SYM' => 2763
		}
	},
	{#State 2401
		ACTIONS => {
			"," => 2765,
			")" => 2766
		}
	},
	{#State 2402
		ACTIONS => {
			")" => 2767
		}
	},
	{#State 2403
		ACTIONS => {
			"," => 2768
		}
	},
	{#State 2404
		ACTIONS => {
			")" => 2769
		}
	},
	{#State 2405
		ACTIONS => {
			")" => 2770
		}
	},
	{#State 2406
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2771,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2407
		ACTIONS => {
			")" => 2772
		}
	},
	{#State 2408
		ACTIONS => {
			"," => 2773
		}
	},
	{#State 2409
		DEFAULT => -892
	},
	{#State 2410
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'AS' => 2468,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -635,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 2466,
			'IDENT_sys' => 297,
			'select_alias' => 2774,
			'ident' => 2469
		}
	},
	{#State 2411
		ACTIONS => {
			")" => 2775
		}
	},
	{#State 2412
		ACTIONS => {
			")" => 2776
		}
	},
	{#State 2413
		ACTIONS => {
			")" => 2777
		}
	},
	{#State 2414
		DEFAULT => -917
	},
	{#State 2415
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2778
		}
	},
	{#State 2416
		ACTIONS => {
			")" => 2779
		}
	},
	{#State 2417
		DEFAULT => -937
	},
	{#State 2418
		ACTIONS => {
			")" => 2780
		}
	},
	{#State 2419
		DEFAULT => -1372
	},
	{#State 2420
		ACTIONS => {
			")" => 2781
		}
	},
	{#State 2421
		ACTIONS => {
			"," => 2782
		}
	},
	{#State 2422
		ACTIONS => {
			")" => 2783
		}
	},
	{#State 2423
		ACTIONS => {
			")" => 2784
		}
	},
	{#State 2424
		ACTIONS => {
			")" => 2785
		}
	},
	{#State 2425
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2786,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2426
		ACTIONS => {
			")" => 2787
		}
	},
	{#State 2427
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2788,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2428
		ACTIONS => {
			")" => 2789
		}
	},
	{#State 2429
		ACTIONS => {
			")" => 2790
		}
	},
	{#State 2430
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2791,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2431
		ACTIONS => {
			")" => 2792
		}
	},
	{#State 2432
		ACTIONS => {
			"," => 2793
		}
	},
	{#State 2433
		ACTIONS => {
			"," => 2794
		}
	},
	{#State 2434
		ACTIONS => {
			"," => 2795
		}
	},
	{#State 2435
		ACTIONS => {
			")" => 2796
		}
	},
	{#State 2436
		ACTIONS => {
			")" => 2797
		}
	},
	{#State 2437
		DEFAULT => -736
	},
	{#State 2438
		DEFAULT => -949
	},
	{#State 2439
		ACTIONS => {
			'THEN_SYM' => 2798
		}
	},
	{#State 2440
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2799,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2441
		ACTIONS => {
			")" => 2800
		}
	},
	{#State 2442
		ACTIONS => {
			'ASC' => 2803,
			'DESC' => 2802
		},
		DEFAULT => -1051,
		GOTOS => {
			'order_dir' => 2801
		}
	},
	{#State 2443
		ACTIONS => {
			"," => 2804
		},
		DEFAULT => -1048
	},
	{#State 2444
		DEFAULT => -1365
	},
	{#State 2445
		ACTIONS => {
			'IGNORE_SYM' => 2805
		},
		DEFAULT => -594,
		GOTOS => {
			'opt_ignore_leaves' => 2806
		}
	},
	{#State 2446
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2078,
			'IDENT_sys' => 297,
			'preload_keys' => 2807,
			'ident' => 435
		}
	},
	{#State 2447
		DEFAULT => -1385
	},
	{#State 2448
		ACTIONS => {
			'REPLACE' => 2663,
			'IGNORE_SYM' => 2665
		},
		DEFAULT => -1305,
		GOTOS => {
			'opt_duplicate' => 2808
		}
	},
	{#State 2449
		DEFAULT => -1714
	},
	{#State 2450
		DEFAULT => -1713
	},
	{#State 2451
		ACTIONS => {
			'WHERE' => 1835
		},
		DEFAULT => -1029,
		GOTOS => {
			'where_clause' => 2809
		}
	},
	{#State 2452
		ACTIONS => {
			'LIMIT' => 2810
		},
		DEFAULT => -1066,
		GOTOS => {
			'delete_limit_clause' => 2811
		}
	},
	{#State 2453
		ACTIONS => {
			'WHERE' => -1378,
			'ORDER_SYM' => -1378,
			'END_OF_INPUT' => -1378,
			";" => -1378,
			'LIMIT' => -1378,
			"." => 2456
		},
		DEFAULT => -1167,
		GOTOS => {
			'opt_wild' => 2455
		}
	},
	{#State 2454
		DEFAULT => -1161
	},
	{#State 2455
		ACTIONS => {
			'FROM' => -1025,
			"," => -1025,
			'EQ' => 1335,
			'USING' => -1025,
			'AS' => 1337
		},
		DEFAULT => -1022,
		GOTOS => {
			'table_alias' => 1338,
			'opt_table_alias' => 2812
		}
	},
	{#State 2456
		ACTIONS => {
			"*" => 2093
		}
	},
	{#State 2457
		ACTIONS => {
			'RELAY_LOG_FILE_SYM' => 1341,
			'MASTER_LOG_FILE_SYM' => 1342,
			'RELAY_LOG_POS_SYM' => 1345,
			'MASTER_LOG_POS_SYM' => 1350
		},
		GOTOS => {
			'master_file_def' => 2813
		}
	},
	{#State 2458
		DEFAULT => -625
	},
	{#State 2459
		ACTIONS => {
			'SHARE_SYM' => 2814
		}
	},
	{#State 2460
		ACTIONS => {
			'COLUMNS' => 2815
		},
		DEFAULT => -1308,
		GOTOS => {
			'opt_field_term' => 2816
		}
	},
	{#State 2461
		DEFAULT => -1093
	},
	{#State 2462
		DEFAULT => -1089
	},
	{#State 2463
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			"\@" => 2107,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 2105,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'select_var_ident' => 2817,
			'ident' => 706
		}
	},
	{#State 2464
		ACTIONS => {
			'GROUP' => 2818
		},
		DEFAULT => -1035,
		GOTOS => {
			'group_clause' => 2819
		}
	},
	{#State 2465
		ACTIONS => {
			'LIMIT' => 899
		},
		DEFAULT => -1056,
		GOTOS => {
			'opt_limit_clause' => 2820,
			'limit_clause' => 2116
		}
	},
	{#State 2466
		DEFAULT => -639
	},
	{#State 2467
		DEFAULT => -630
	},
	{#State 2468
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 2821,
			'IDENT_sys' => 297,
			'ident' => 2822
		}
	},
	{#State 2469
		DEFAULT => -638
	},
	{#State 2470
		DEFAULT => -1363
	},
	{#State 2471
		ACTIONS => {
			"(" => 2038,
			"." => 2823
		},
		DEFAULT => -1370
	},
	{#State 2472
		ACTIONS => {
			'DUPLICATE_SYM' => 2824
		}
	},
	{#State 2473
		DEFAULT => -1111
	},
	{#State 2474
		ACTIONS => {
			'FROM' => 2825
		}
	},
	{#State 2475
		ACTIONS => {
			'FROM' => 2826
		}
	},
	{#State 2476
		ACTIONS => {
			'FROM' => 2827
		}
	},
	{#State 2477
		ACTIONS => {
			'OPTION' => 2828
		}
	},
	{#State 2478
		DEFAULT => -413
	},
	{#State 2479
		DEFAULT => -414
	},
	{#State 2480
		DEFAULT => -412
	},
	{#State 2481
		DEFAULT => -410
	},
	{#State 2482
		DEFAULT => -1683
	},
	{#State 2483
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		GOTOS => {
			'equal' => 2829
		}
	},
	{#State 2484
		ACTIONS => {
			'TEXT_STRING' => 2133,
			'PASSWORD' => 2136,
			'OLD_PASSWORD' => 2134
		},
		GOTOS => {
			'text_or_password' => 2830
		}
	},
	{#State 2485
		ACTIONS => {
			'TEXT_STRING' => 2831
		}
	},
	{#State 2486
		ACTIONS => {
			'TEXT_STRING' => 2832
		}
	},
	{#State 2487
		ACTIONS => {
			'COMMITTED_SYM' => 2834,
			'UNCOMMITTED_SYM' => 2833
		}
	},
	{#State 2488
		DEFAULT => -1682
	},
	{#State 2489
		ACTIONS => {
			'READ_SYM' => 2835
		}
	},
	{#State 2490
		DEFAULT => -1696
	},
	{#State 2491
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 2148,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2149,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'expr_or_default' => 2836,
			'bit_term' => 564
		}
	},
	{#State 2492
		DEFAULT => -1141
	},
	{#State 2493
		DEFAULT => -1132
	},
	{#State 2494
		DEFAULT => -1131
	},
	{#State 2495
		DEFAULT => -1126
	},
	{#State 2496
		DEFAULT => -1124
	},
	{#State 2497
		ACTIONS => {
			"." => 2823
		},
		DEFAULT => -1370
	},
	{#State 2498
		DEFAULT => -1134
	},
	{#State 2499
		DEFAULT => -1136
	},
	{#State 2500
		DEFAULT => -275
	},
	{#State 2501
		DEFAULT => -214
	},
	{#State 2502
		ACTIONS => {
			'FOR_SYM' => 2099,
			'LOCK_SYM' => 2100
		},
		DEFAULT => -624,
		GOTOS => {
			'select_lock_type' => 2837
		}
	},
	{#State 2503
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1227,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 2838,
			'ident' => 706
		}
	},
	{#State 2504
		DEFAULT => -102
	},
	{#State 2505
		DEFAULT => -103
	},
	{#State 2506
		DEFAULT => -109
	},
	{#State 2507
		DEFAULT => -108
	},
	{#State 2508
		ACTIONS => {
			'RESTRICT' => 1715,
			'CASCADE' => 1714
		},
		DEFAULT => -517,
		GOTOS => {
			'opt_restrict' => 2839
		}
	},
	{#State 2509
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -476,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_ident' => 2530,
			'ident' => 2229,
			'opt_ident' => 2840
		}
	},
	{#State 2510
		DEFAULT => -503
	},
	{#State 2511
		DEFAULT => -502
	},
	{#State 2512
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2841
		}
	},
	{#State 2513
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 1665,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 1666,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1670,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'charset_name' => 1669,
			'charset_name_or_default' => 2842,
			'ident' => 706
		}
	},
	{#State 2514
		DEFAULT => -246
	},
	{#State 2515
		DEFAULT => -245
	},
	{#State 2516
		DEFAULT => -243
	},
	{#State 2517
		DEFAULT => -252
	},
	{#State 2518
		DEFAULT => -1044
	},
	{#State 2519
		ACTIONS => {
			"," => 2843
		},
		DEFAULT => -1042
	},
	{#State 2520
		ACTIONS => {
			'ASC' => 2803,
			'DESC' => 2802
		},
		DEFAULT => -1051,
		GOTOS => {
			'order_dir' => 2844
		}
	},
	{#State 2521
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_spec' => 2845,
			'field_ident' => 2226,
			'ident' => 2229
		}
	},
	{#State 2522
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 748,
			'table_list' => 2846,
			'IDENT_sys' => 297,
			'table_name' => 837,
			'ident' => 435
		}
	},
	{#State 2523
		DEFAULT => -247
	},
	{#State 2524
		DEFAULT => -238
	},
	{#State 2525
		DEFAULT => -240
	},
	{#State 2526
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2847,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2527
		DEFAULT => -295
	},
	{#State 2528
		DEFAULT => -292
	},
	{#State 2529
		DEFAULT => -451
	},
	{#State 2530
		DEFAULT => -477
	},
	{#State 2531
		ACTIONS => {
			'USING' => 1801,
			'TYPE_SYM' => 1800
		},
		DEFAULT => -466,
		GOTOS => {
			'key_alg' => 2848
		}
	},
	{#State 2532
		DEFAULT => -452
	},
	{#State 2533
		DEFAULT => -299
	},
	{#State 2534
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -476,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_ident' => 2530,
			'ident' => 2229,
			'opt_ident' => 2849
		}
	},
	{#State 2535
		ACTIONS => {
			'KEY_SYM' => 2850
		}
	},
	{#State 2536
		DEFAULT => -293
	},
	{#State 2537
		ACTIONS => {
			'KEY_SYM' => 2851
		}
	},
	{#State 2538
		ACTIONS => {
			'INDEX_SYM' => 1264,
			'KEY_SYM' => 1266
		},
		DEFAULT => -457,
		GOTOS => {
			'key_or_index' => 1268,
			'opt_key_or_index' => 2852
		}
	},
	{#State 2539
		DEFAULT => -241
	},
	{#State 2540
		DEFAULT => -259
	},
	{#State 2541
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 2853
		}
	},
	{#State 2542
		DEFAULT => -493
	},
	{#State 2543
		ACTIONS => {
			'SET' => 2592,
			'NUMERIC_SYM' => 2615,
			'TINYBLOB' => 2620,
			'POINT_SYM' => 2610,
			'TEXT_SYM' => 2621,
			'DECIMAL_SYM' => 2582,
			'BINARY' => 2583,
			'DATETIME' => 2570,
			'NATIONAL_SYM' => 2603,
			'BLOB_SYM' => 2571,
			'NVARCHAR_SYM' => 2611,
			'LONGBLOB' => 2604,
			'NCHAR_SYM' => 2584,
			'TINYINT' => 2572,
			'YEAR_SYM' => 2573,
			'MULTIPOLYGON' => 2594,
			'INT_SYM' => 2574,
			'MULTILINESTRING' => 2617,
			'FLOAT_SYM' => 2605,
			'BIT_SYM' => 2596,
			'ENUM' => 2622,
			'SMALLINT' => 2597,
			'CHAR_SYM' => 2575,
			'GEOMETRYCOLLECTION' => 2586,
			'LONG_SYM' => 2587,
			'VARBINARY' => 2606,
			'TIMESTAMP' => 2589,
			'MEDIUMTEXT' => 2623,
			'DATE_SYM' => 2607,
			'POLYGON' => 2576,
			'FIXED_SYM' => 2598,
			'REAL' => 2577,
			'DOUBLE_SYM' => 2613,
			'LINESTRING' => 2578,
			'TIME_SYM' => 2599,
			'BOOL_SYM' => 2608,
			'MULTIPOINT' => 2614,
			'GEOMETRY_SYM' => 2618,
			'TINYTEXT' => 2590,
			'LONGTEXT' => 2595,
			'MEDIUMINT' => 2600,
			'SERIAL_SYM' => 2619,
			'VARCHAR' => 2601,
			'BOOLEAN_SYM' => 2602,
			'MEDIUMBLOB' => 2581,
			'BIGINT' => 2591
		},
		GOTOS => {
			'int_type' => 2593,
			'spatial_type' => 2579,
			'varchar' => 2588,
			'nvarchar' => 2616,
			'real_type' => 2609,
			'char' => 2580,
			'type' => 2854,
			'nchar' => 2612
		}
	},
	{#State 2544
		DEFAULT => -274
	},
	{#State 2545
		DEFAULT => -272
	},
	{#State 2546
		DEFAULT => -256
	},
	{#State 2547
		DEFAULT => -273
	},
	{#State 2548
		DEFAULT => -251
	},
	{#State 2549
		DEFAULT => -268
	},
	{#State 2550
		DEFAULT => -263
	},
	{#State 2551
		DEFAULT => -267
	},
	{#State 2552
		DEFAULT => -249
	},
	{#State 2553
		DEFAULT => -264
	},
	{#State 2554
		DEFAULT => -266
	},
	{#State 2555
		DEFAULT => -265
	},
	{#State 2556
		DEFAULT => -248
	},
	{#State 2557
		DEFAULT => -508
	},
	{#State 2558
		ACTIONS => {
			'SET' => 2856,
			'DROP' => 2855
		}
	},
	{#State 2559
		DEFAULT => -239
	},
	{#State 2560
		DEFAULT => -271
	},
	{#State 2561
		DEFAULT => -250
	},
	{#State 2562
		DEFAULT => -270
	},
	{#State 2563
		DEFAULT => -269
	},
	{#State 2564
		DEFAULT => -242
	},
	{#State 2565
		DEFAULT => -237
	},
	{#State 2566
		DEFAULT => -244
	},
	{#State 2567
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2857
		}
	},
	{#State 2568
		DEFAULT => -495
	},
	{#State 2569
		DEFAULT => -522
	},
	{#State 2570
		DEFAULT => -321
	},
	{#State 2571
		ACTIONS => {
			"(" => 2700
		},
		DEFAULT => -377,
		GOTOS => {
			'opt_len' => 2858
		}
	},
	{#State 2572
		DEFAULT => -359
	},
	{#State 2573
		ACTIONS => {
			"(" => 2700
		},
		DEFAULT => -377,
		GOTOS => {
			'opt_len' => 2859
		}
	},
	{#State 2574
		DEFAULT => -358
	},
	{#State 2575
		DEFAULT => -348
	},
	{#State 2576
		DEFAULT => -346
	},
	{#State 2577
		DEFAULT => -363
	},
	{#State 2578
		DEFAULT => -344
	},
	{#State 2579
		DEFAULT => -324
	},
	{#State 2580
		ACTIONS => {
			'ASCII_SYM' => 2860,
			'CHAR_SYM' => 473,
			'BINARY' => 2861,
			"(" => 2862,
			'VARYING' => 2863,
			'CHARSET' => 490,
			'BYTE_SYM' => 2864,
			'UNICODE_SYM' => 2867
		},
		DEFAULT => -417,
		GOTOS => {
			'opt_binary' => 2866,
			'charset' => 2865
		}
	},
	{#State 2581
		DEFAULT => -325
	},
	{#State 2582
		ACTIONS => {
			"(" => 2703
		},
		DEFAULT => -366,
		GOTOS => {
			'float_options' => 2868,
			'precision' => 2702
		}
	},
	{#State 2583
		ACTIONS => {
			"(" => 2869
		},
		DEFAULT => -313
	},
	{#State 2584
		ACTIONS => {
			'VARYING' => 2870,
			'VARCHAR' => 2871
		},
		DEFAULT => -349
	},
	{#State 2585
		ACTIONS => {
			'PRIMARY_SYM' => 2878,
			'AUTO_INC' => 2885,
			'NULL_SYM' => 2876,
			'COMMENT_SYM' => 2872,
			'UNIQUE_SYM' => 2881,
			'COLLATE_SYM' => 2883,
			'NOT_SYM' => 1010,
			'ON' => 2874,
			'DEFAULT' => 2875,
			'NOT2_SYM' => 1017,
			'SERIAL_SYM' => 2884,
			'KEY_SYM' => -429
		},
		DEFAULT => -381,
		GOTOS => {
			'attribute' => 2880,
			'opt_primary' => 2877,
			'opt_attribute_list' => 2873,
			'not' => 2879,
			'opt_attribute' => 2882
		}
	},
	{#State 2586
		DEFAULT => -341
	},
	{#State 2587
		ACTIONS => {
			'ASCII_SYM' => 2860,
			'CHAR_SYM' => 2886,
			'BINARY' => 2861,
			'CHARSET' => 490,
			'VARCHAR' => 2601,
			'BYTE_SYM' => 2864,
			'VARBINARY' => 2890,
			'UNICODE_SYM' => 2867
		},
		DEFAULT => -417,
		GOTOS => {
			'char' => 2887,
			'varchar' => 2888,
			'opt_binary' => 2889,
			'charset' => 2865
		}
	},
	{#State 2588
		ACTIONS => {
			"(" => 2891
		}
	},
	{#State 2589
		ACTIONS => {
			"(" => 2700
		},
		DEFAULT => -377,
		GOTOS => {
			'opt_len' => 2892
		}
	},
	{#State 2590
		ACTIONS => {
			'ASCII_SYM' => 2860,
			'CHAR_SYM' => 473,
			'BINARY' => 2861,
			'CHARSET' => 490,
			'BYTE_SYM' => 2864,
			'UNICODE_SYM' => 2867
		},
		DEFAULT => -417,
		GOTOS => {
			'opt_binary' => 2893,
			'charset' => 2865
		}
	},
	{#State 2591
		DEFAULT => -362
	},
	{#State 2592
		ACTIONS => {
			"(" => 2894
		}
	},
	{#State 2593
		ACTIONS => {
			"(" => 2700
		},
		DEFAULT => -377,
		GOTOS => {
			'opt_len' => 2895
		}
	},
	{#State 2594
		DEFAULT => -347
	},
	{#State 2595
		ACTIONS => {
			'ASCII_SYM' => 2860,
			'CHAR_SYM' => 473,
			'BINARY' => 2861,
			'CHARSET' => 490,
			'BYTE_SYM' => 2864,
			'UNICODE_SYM' => 2867
		},
		DEFAULT => -417,
		GOTOS => {
			'opt_binary' => 2896,
			'charset' => 2865
		}
	},
	{#State 2596
		ACTIONS => {
			"(" => 2897
		},
		DEFAULT => -304
	},
	{#State 2597
		DEFAULT => -360
	},
	{#State 2598
		ACTIONS => {
			"(" => 2703
		},
		DEFAULT => -366,
		GOTOS => {
			'float_options' => 2898,
			'precision' => 2702
		}
	},
	{#State 2599
		DEFAULT => -319
	},
	{#State 2600
		DEFAULT => -361
	},
	{#State 2601
		DEFAULT => -352
	},
	{#State 2602
		DEFAULT => -307
	},
	{#State 2603
		ACTIONS => {
			'VARCHAR' => 2900,
			'CHAR_SYM' => 2899
		}
	},
	{#State 2604
		DEFAULT => -326
	},
	{#State 2605
		ACTIONS => {
			"(" => 2703
		},
		DEFAULT => -366,
		GOTOS => {
			'float_options' => 2901,
			'precision' => 2702
		}
	},
	{#State 2606
		ACTIONS => {
			"(" => 2902
		}
	},
	{#State 2607
		DEFAULT => -318
	},
	{#State 2608
		DEFAULT => -306
	},
	{#State 2609
		ACTIONS => {
			"(" => 2904
		},
		DEFAULT => -379,
		GOTOS => {
			'opt_precision' => 2905,
			'precision' => 2903
		}
	},
	{#State 2610
		DEFAULT => -342
	},
	{#State 2611
		DEFAULT => -354
	},
	{#State 2612
		ACTIONS => {
			'BINARY' => 2906,
			"(" => 2907
		},
		DEFAULT => -423,
		GOTOS => {
			'opt_bin_mod' => 2908
		}
	},
	{#State 2613
		ACTIONS => {
			'PRECISION' => 2909
		},
		DEFAULT => -364
	},
	{#State 2614
		DEFAULT => -343
	},
	{#State 2615
		ACTIONS => {
			"(" => 2703
		},
		DEFAULT => -366,
		GOTOS => {
			'float_options' => 2910,
			'precision' => 2702
		}
	},
	{#State 2616
		ACTIONS => {
			"(" => 2911
		}
	},
	{#State 2617
		DEFAULT => -345
	},
	{#State 2618
		DEFAULT => -340
	},
	{#State 2619
		DEFAULT => -339
	},
	{#State 2620
		DEFAULT => -322
	},
	{#State 2621
		ACTIONS => {
			"(" => 2700
		},
		DEFAULT => -377,
		GOTOS => {
			'opt_len' => 2912
		}
	},
	{#State 2622
		ACTIONS => {
			"(" => 2913
		}
	},
	{#State 2623
		ACTIONS => {
			'ASCII_SYM' => 2860,
			'CHAR_SYM' => 473,
			'BINARY' => 2861,
			'CHARSET' => 490,
			'BYTE_SYM' => 2864,
			'UNICODE_SYM' => 2867
		},
		DEFAULT => -417,
		GOTOS => {
			'opt_binary' => 2914,
			'charset' => 2865
		}
	},
	{#State 2624
		DEFAULT => -285
	},
	{#State 2625
		DEFAULT => -283
	},
	{#State 2626
		ACTIONS => {
			"," => 2915,
			")" => 2916
		}
	},
	{#State 2627
		DEFAULT => -286
	},
	{#State 2628
		DEFAULT => -287
	},
	{#State 2629
		DEFAULT => -288
	},
	{#State 2630
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2917,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 2631
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2918
		}
	},
	{#State 2632
		DEFAULT => -1376
	},
	{#State 2633
		DEFAULT => -260
	},
	{#State 2634
		DEFAULT => -261
	},
	{#State 2635
		ACTIONS => {
			'AS' => 2919
		}
	},
	{#State 2636
		ACTIONS => {
			"," => 1775
		},
		DEFAULT => -976
	},
	{#State 2637
		ACTIONS => {
			")" => 2920
		}
	},
	{#State 2638
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 1259,
			'ident' => 435,
			'table_factor' => 2922,
			'keyword_sp' => 287,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'table_ref' => 2921,
			'join_table' => 1255
		}
	},
	{#State 2639
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 1259,
			'ident' => 435,
			'table_factor' => 2924,
			'keyword_sp' => 287,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'table_ref' => 2923,
			'join_table' => 1255
		}
	},
	{#State 2640
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2925,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2641
		DEFAULT => -962
	},
	{#State 2642
		ACTIONS => {
			'JOIN_SYM' => 2926
		}
	},
	{#State 2643
		ACTIONS => {
			'JOIN_SYM' => 2927
		}
	},
	{#State 2644
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2928,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2645
		ACTIONS => {
			"(" => 2929
		}
	},
	{#State 2646
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'simple_ident_nospvar' => 2249,
			'update_elem' => 2930,
			'IDENT_sys' => 297,
			'ident' => 1542,
			'simple_ident_q' => 1540
		}
	},
	{#State 2647
		ACTIONS => {
			'ORDER_SYM' => 1613
		},
		DEFAULT => -1046,
		GOTOS => {
			'order_clause' => 1649,
			'opt_order_clause' => 2931
		}
	},
	{#State 2648
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 2148,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2149,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'expr_or_default' => 2932,
			'bit_term' => 564
		}
	},
	{#State 2649
		ACTIONS => {
			"," => 1647,
			'LIMIT' => 899,
			'FROM' => 1644
		},
		DEFAULT => -1056,
		GOTOS => {
			'opt_limit_clause' => 2500,
			'select_from' => 2502,
			'opt_select_from' => 2933,
			'limit_clause' => 2116
		}
	},
	{#State 2650
		ACTIONS => {
			'FOR_SYM' => 2934
		},
		DEFAULT => -982,
		GOTOS => {
			'opt_for_join' => 2935
		}
	},
	{#State 2651
		DEFAULT => -986
	},
	{#State 2652
		DEFAULT => -985
	},
	{#State 2653
		DEFAULT => -987
	},
	{#State 2654
		ACTIONS => {
			'OUTER' => 2936
		},
		DEFAULT => -980,
		GOTOS => {
			'opt_outer' => 2237
		}
	},
	{#State 2655
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2937
		}
	},
	{#State 2656
		DEFAULT => -593
	},
	{#State 2657
		DEFAULT => -1889
	},
	{#State 2658
		ACTIONS => {
			"(" => 2938
		}
	},
	{#State 2659
		ACTIONS => {
			")" => 2939
		}
	},
	{#State 2660
		ACTIONS => {
			"," => 2915,
			")" => 2940
		}
	},
	{#State 2661
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 2941,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 2662
		DEFAULT => -205
	},
	{#State 2663
		DEFAULT => -1306
	},
	{#State 2664
		ACTIONS => {
			'AS' => 2942
		},
		DEFAULT => -215,
		GOTOS => {
			'opt_as' => 2943
		}
	},
	{#State 2665
		DEFAULT => -1307
	},
	{#State 2666
		DEFAULT => -206
	},
	{#State 2667
		ACTIONS => {
			'PASSWORD' => 1767,
			'RAID_TYPE' => 1766,
			'INSERT_METHOD' => 1757,
			'AUTO_INC' => 1769,
			'MIN_ROWS' => 1747,
			'ENGINE_SYM' => 1768,
			'COMMENT_SYM' => 1737,
			'ROW_FORMAT_SYM' => 1760,
			'RAID_CHUNKSIZE' => 1738,
			'DATA_SYM' => 1753,
			'DELAY_KEY_WRITE_SYM' => 1762,
			'INDEX_SYM' => 1731,
			'DEFAULT' => 1245,
			'AVG_ROW_LENGTH' => 1750,
			'TYPE_SYM' => 1746,
			'MAX_ROWS' => 1765,
			'CONNECTION_SYM' => 1752,
			'RAID_CHUNKS' => 1758,
			'CHECKSUM_SYM' => 1744,
			'PACK_KEYS_SYM' => 1734,
			'UNION_SYM' => 1742
		},
		DEFAULT => -415,
		GOTOS => {
			'default_charset' => 1756,
			'opt_default' => 1243,
			'create_table_options' => 2944,
			'default_collation' => 1751,
			'create_table_option' => 2270
		}
	},
	{#State 2668
		DEFAULT => -235
	},
	{#State 2669
		DEFAULT => -207
	},
	{#State 2670
		DEFAULT => -1792
	},
	{#State 2671
		ACTIONS => {
			'TEXT_STRING' => 2945
		}
	},
	{#State 2672
		DEFAULT => -203
	},
	{#State 2673
		DEFAULT => -202
	},
	{#State 2674
		ACTIONS => {
			'ON' => 2946
		}
	},
	{#State 2675
		DEFAULT => -204
	},
	{#State 2676
		ACTIONS => {
			")" => 2947
		}
	},
	{#State 2677
		DEFAULT => -121,
		GOTOS => {
			'sp_init_param' => 2948
		}
	},
	{#State 2678
		DEFAULT => -131
	},
	{#State 2679
		ACTIONS => {
			"," => 2949
		},
		DEFAULT => -124
	},
	{#State 2680
		DEFAULT => -126
	},
	{#State 2681
		DEFAULT => -130
	},
	{#State 2682
		DEFAULT => -129
	},
	{#State 2683
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -117,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_fdparam' => 2951,
			'sp_fdparams' => 2952,
			'IDENT_sys' => 297,
			'sp_fdparam_list' => 2950,
			'ident' => 2953
		}
	},
	{#State 2684
		ACTIONS => {
			'STRING_SYM' => 2958,
			'DECIMAL_SYM' => 2957,
			'INT_SYM' => 2954,
			'REAL' => 2956
		},
		GOTOS => {
			'udf_type' => 2955
		}
	},
	{#State 2685
		DEFAULT => -1879
	},
	{#State 2686
		ACTIONS => {
			"," => 2959,
			")" => 2960
		}
	},
	{#State 2687
		DEFAULT => -1869
	},
	{#State 2688
		ACTIONS => {
			"(" => 2961,
			'SELECT_SYM' => 2964
		},
		GOTOS => {
			'view_select_aux' => 2962,
			'view_select' => 2963
		}
	},
	{#State 2689
		DEFAULT => -1797
	},
	{#State 2690
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'grant_list' => 2965,
			'ident' => 706,
			'grant_user' => 1284,
			'keyword_sp' => 287,
			'ident_or_text' => 1227,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1283
		}
	},
	{#State 2691
		ACTIONS => {
			"*" => 2966
		}
	},
	{#State 2692
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			"*" => 2967,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 1278
		}
	},
	{#State 2693
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'grant_list' => 2968,
			'ident' => 706,
			'grant_user' => 1284,
			'keyword_sp' => 287,
			'ident_or_text' => 1227,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1283
		}
	},
	{#State 2694
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'grant_list' => 2969,
			'ident' => 706,
			'grant_user' => 1284,
			'keyword_sp' => 287,
			'ident_or_text' => 1227,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1283
		}
	},
	{#State 2695
		ACTIONS => {
			"," => 2491,
			")" => 2970
		}
	},
	{#State 2696
		DEFAULT => -1199
	},
	{#State 2697
		ACTIONS => {
			'EQ' => 2971
		}
	},
	{#State 2698
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2972,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2699
		ACTIONS => {
			")" => 2973
		}
	},
	{#State 2700
		ACTIONS => {
			'NUM' => 2974
		}
	},
	{#State 2701
		ACTIONS => {
			'CHARSET' => 490,
			'BYTE_SYM' => 2864,
			'CHAR_SYM' => 473,
			'ASCII_SYM' => 2860,
			'UNICODE_SYM' => 2867,
			'BINARY' => 2861
		},
		DEFAULT => -417,
		GOTOS => {
			'opt_binary' => 2975,
			'charset' => 2865
		}
	},
	{#State 2702
		DEFAULT => -368
	},
	{#State 2703
		ACTIONS => {
			'NUM' => 2976
		}
	},
	{#State 2704
		DEFAULT => -935
	},
	{#State 2705
		DEFAULT => -925
	},
	{#State 2706
		DEFAULT => -927
	},
	{#State 2707
		DEFAULT => -931
	},
	{#State 2708
		DEFAULT => -737
	},
	{#State 2709
		DEFAULT => -929
	},
	{#State 2710
		DEFAULT => -738
	},
	{#State 2711
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2977,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2712
		DEFAULT => -800
	},
	{#State 2713
		DEFAULT => -751
	},
	{#State 2714
		DEFAULT => -772
	},
	{#State 2715
		DEFAULT => -817
	},
	{#State 2716
		DEFAULT => -780
	},
	{#State 2717
		DEFAULT => -884
	},
	{#State 2718
		DEFAULT => -782
	},
	{#State 2719
		ACTIONS => {
			'NUM' => 2978
		}
	},
	{#State 2720
		DEFAULT => -859
	},
	{#State 2721
		DEFAULT => -1846,
		GOTOS => {
			'subselect_end' => 2979
		}
	},
	{#State 2722
		DEFAULT => -831
	},
	{#State 2723
		ACTIONS => {
			")" => 2980
		}
	},
	{#State 2724
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2981,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2725
		DEFAULT => -868
	},
	{#State 2726
		DEFAULT => -819
	},
	{#State 2727
		ACTIONS => {
			'DAY_SYM' => 1045,
			'DAY_MINUTE_SYM' => 1042,
			'YEAR_MONTH_SYM' => 1039,
			'MICROSECOND_SYM' => 1031,
			'FRAC_SECOND_SYM' => 1036,
			'DAY_SECOND_SYM' => 1046,
			'MINUTE_SECOND_SYM' => 1032,
			'HOUR_SYM' => 1033,
			'YEAR_SYM' => 1028,
			'QUARTER_SYM' => 1037,
			'WEEK_SYM' => 1040,
			'HOUR_MINUTE_SYM' => 1038,
			'DAY_MICROSECOND_SYM' => 1034,
			'MONTH_SYM' => 1049,
			'HOUR_MICROSECOND_SYM' => 1050,
			'MINUTE_SYM' => 1043,
			'SECOND_MICROSECOND_SYM' => 1041,
			'HOUR_SECOND_SYM' => 1035,
			'SECOND_SYM' => 1047,
			'DAY_HOUR_SYM' => 1044,
			'MINUTE_MICROSECOND_SYM' => 1030
		},
		DEFAULT => -714,
		GOTOS => {
			'interval_time_st' => 1029,
			'interval' => 2982
		}
	},
	{#State 2728
		ACTIONS => {
			'NUM' => 2983
		}
	},
	{#State 2729
		DEFAULT => -857
	},
	{#State 2730
		DEFAULT => -770
	},
	{#State 2731
		DEFAULT => -863
	},
	{#State 2732
		DEFAULT => -793
	},
	{#State 2733
		DEFAULT => -756
	},
	{#State 2734
		DEFAULT => -729
	},
	{#State 2735
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2984,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2736
		DEFAULT => -794
	},
	{#State 2737
		DEFAULT => -671
	},
	{#State 2738
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 2985,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2739
		DEFAULT => -668
	},
	{#State 2740
		DEFAULT => -665
	},
	{#State 2741
		ACTIONS => {
			")" => 2986
		}
	},
	{#State 2742
		DEFAULT => -783
	},
	{#State 2743
		DEFAULT => -768
	},
	{#State 2744
		DEFAULT => -872
	},
	{#State 2745
		DEFAULT => -856
	},
	{#State 2746
		DEFAULT => -743
	},
	{#State 2747
		DEFAULT => -853
	},
	{#State 2748
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2987,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2749
		DEFAULT => -858
	},
	{#State 2750
		DEFAULT => -882
	},
	{#State 2751
		ACTIONS => {
			")" => 2988
		}
	},
	{#State 2752
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 2989,
			'TEXT_STRING_literal' => 801
		}
	},
	{#State 2753
		DEFAULT => -804
	},
	{#State 2754
		DEFAULT => -796
	},
	{#State 2755
		DEFAULT => -797
	},
	{#State 2756
		DEFAULT => -747
	},
	{#State 2757
		ACTIONS => {
			'QUERY_SYM' => 2990
		}
	},
	{#State 2758
		ACTIONS => {
			")" => 2991
		}
	},
	{#State 2759
		ACTIONS => {
			'BOOLEAN_SYM' => 2992
		}
	},
	{#State 2760
		DEFAULT => -776
	},
	{#State 2761
		DEFAULT => -799
	},
	{#State 2762
		DEFAULT => -767
	},
	{#State 2763
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2993,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2764
		DEFAULT => -825
	},
	{#State 2765
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2994,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2766
		DEFAULT => -823
	},
	{#State 2767
		DEFAULT => -875
	},
	{#State 2768
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2995,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2769
		DEFAULT => -735
	},
	{#State 2770
		DEFAULT => -745
	},
	{#State 2771
		ACTIONS => {
			'DAY_SYM' => 1045,
			'DAY_MINUTE_SYM' => 1042,
			'YEAR_MONTH_SYM' => 1039,
			'MICROSECOND_SYM' => 1031,
			'FRAC_SECOND_SYM' => 1036,
			'DAY_SECOND_SYM' => 1046,
			'MINUTE_SECOND_SYM' => 1032,
			'HOUR_SYM' => 1033,
			'YEAR_SYM' => 1028,
			'QUARTER_SYM' => 1037,
			'WEEK_SYM' => 1040,
			'HOUR_MINUTE_SYM' => 1038,
			'DAY_MICROSECOND_SYM' => 1034,
			'MONTH_SYM' => 1049,
			'HOUR_MICROSECOND_SYM' => 1050,
			'MINUTE_SYM' => 1043,
			'SECOND_MICROSECOND_SYM' => 1041,
			'HOUR_SECOND_SYM' => 1035,
			'SECOND_SYM' => 1047,
			'DAY_HOUR_SYM' => 1044,
			'MINUTE_MICROSECOND_SYM' => 1030
		},
		DEFAULT => -714,
		GOTOS => {
			'interval_time_st' => 1029,
			'interval' => 2996
		}
	},
	{#State 2772
		DEFAULT => -877
	},
	{#State 2773
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2997,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2774
		DEFAULT => -893
	},
	{#State 2775
		DEFAULT => -771
	},
	{#State 2776
		DEFAULT => -662
	},
	{#State 2777
		DEFAULT => -879
	},
	{#State 2778
		DEFAULT => -479
	},
	{#State 2779
		DEFAULT => -861
	},
	{#State 2780
		DEFAULT => -843
	},
	{#State 2781
		DEFAULT => -815
	},
	{#State 2782
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2998,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2783
		DEFAULT => -870
	},
	{#State 2784
		DEFAULT => -842
	},
	{#State 2785
		DEFAULT => -839
	},
	{#State 2786
		ACTIONS => {
			")" => 2999
		}
	},
	{#State 2787
		DEFAULT => -838
	},
	{#State 2788
		ACTIONS => {
			")" => 3000
		}
	},
	{#State 2789
		DEFAULT => -841
	},
	{#State 2790
		DEFAULT => -840
	},
	{#State 2791
		ACTIONS => {
			")" => 3001
		}
	},
	{#State 2792
		DEFAULT => -785
	},
	{#State 2793
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3002,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2794
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3003,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2795
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3004,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2796
		DEFAULT => -810
	},
	{#State 2797
		DEFAULT => -774
	},
	{#State 2798
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3005,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2799
		DEFAULT => -950
	},
	{#State 2800
		DEFAULT => -749
	},
	{#State 2801
		DEFAULT => -1050
	},
	{#State 2802
		DEFAULT => -1053
	},
	{#State 2803
		DEFAULT => -1052
	},
	{#State 2804
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'order_ident' => 3006,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2444,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 2805
		ACTIONS => {
			'LEAVES' => 3007
		}
	},
	{#State 2806
		DEFAULT => -590
	},
	{#State 2807
		DEFAULT => -589
	},
	{#State 2808
		ACTIONS => {
			'INTO' => 3008
		}
	},
	{#State 2809
		DEFAULT => -1162
	},
	{#State 2810
		ACTIONS => {
			'NUM' => 1378,
			'ULONGLONG_NUM' => 1379,
			'PARAM_MARKER' => 606,
			'LONG_NUM' => 1376
		},
		GOTOS => {
			'param_marker' => 1377,
			'limit_option' => 3009
		}
	},
	{#State 2811
		DEFAULT => -1160
	},
	{#State 2812
		DEFAULT => -1166
	},
	{#State 2813
		DEFAULT => -543
	},
	{#State 2814
		ACTIONS => {
			'MODE_SYM' => 3010
		}
	},
	{#State 2815
		ACTIONS => {
			'OPTIONALLY' => 3016,
			'ENCLOSED' => 3011,
			'TERMINATED' => 3015,
			'ESCAPED' => 3013
		},
		GOTOS => {
			'field_term_list' => 3014,
			'field_term' => 3012
		}
	},
	{#State 2816
		ACTIONS => {
			'LINES' => 3017
		},
		DEFAULT => -1316,
		GOTOS => {
			'opt_line_term' => 3018
		}
	},
	{#State 2817
		DEFAULT => -1087
	},
	{#State 2818
		ACTIONS => {
			'BY' => 3019
		}
	},
	{#State 2819
		ACTIONS => {
			'HAVING' => 3020
		},
		DEFAULT => -1031,
		GOTOS => {
			'having_clause' => 3021
		}
	},
	{#State 2820
		DEFAULT => -609
	},
	{#State 2821
		DEFAULT => -637
	},
	{#State 2822
		DEFAULT => -636
	},
	{#State 2823
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			"*" => 3022,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 2419
		}
	},
	{#State 2824
		ACTIONS => {
			'KEY_SYM' => 3023
		}
	},
	{#State 2825
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'grant_list' => 3024,
			'ident' => 706,
			'grant_user' => 1284,
			'keyword_sp' => 287,
			'ident_or_text' => 1227,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1283
		}
	},
	{#State 2826
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'grant_list' => 3025,
			'ident' => 706,
			'grant_user' => 1284,
			'keyword_sp' => 287,
			'ident_or_text' => 1227,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1283
		}
	},
	{#State 2827
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'grant_list' => 3026,
			'ident' => 706,
			'grant_user' => 1284,
			'keyword_sp' => 287,
			'ident_or_text' => 1227,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1283
		}
	},
	{#State 2828
		ACTIONS => {
			'FROM' => 3027
		}
	},
	{#State 2829
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'ON' => 2139,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 2140,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 2141,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'ALL' => 2143,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2142,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'set_expr_or_default' => 3028,
			'bit_term' => 564
		}
	},
	{#State 2830
		DEFAULT => -1689
	},
	{#State 2831
		ACTIONS => {
			")" => 3029
		}
	},
	{#State 2832
		ACTIONS => {
			")" => 3030
		}
	},
	{#State 2833
		DEFAULT => -1693
	},
	{#State 2834
		DEFAULT => -1694
	},
	{#State 2835
		DEFAULT => -1695
	},
	{#State 2836
		DEFAULT => -1144
	},
	{#State 2837
		DEFAULT => -276
	},
	{#State 2838
		DEFAULT => -577
	},
	{#State 2839
		DEFAULT => -500
	},
	{#State 2840
		DEFAULT => -501
	},
	{#State 2841
		DEFAULT => -258
	},
	{#State 2842
		ACTIONS => {
			'COLLATE_SYM' => 2128
		},
		DEFAULT => -411,
		GOTOS => {
			'opt_collate' => 3031
		}
	},
	{#State 2843
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'simple_ident_nospvar' => 2520,
			'alter_order_item' => 3032,
			'IDENT_sys' => 297,
			'ident' => 1542,
			'simple_ident_q' => 1540
		}
	},
	{#State 2844
		DEFAULT => -1045
	},
	{#State 2845
		ACTIONS => {
			'AFTER_SYM' => 2567,
			'FIRST_SYM' => 2569
		},
		DEFAULT => -520,
		GOTOS => {
			'opt_place' => 3033
		}
	},
	{#State 2846
		ACTIONS => {
			"," => 1298,
			")" => 3034
		}
	},
	{#State 2847
		DEFAULT => -296
	},
	{#State 2848
		ACTIONS => {
			"(" => 3035
		}
	},
	{#State 2849
		ACTIONS => {
			'USING' => 1801,
			'TYPE_SYM' => 1800
		},
		DEFAULT => -466,
		GOTOS => {
			'key_alg' => 3036
		}
	},
	{#State 2850
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -476,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'field_ident' => 2530,
			'ident' => 2229,
			'opt_ident' => 3037
		}
	},
	{#State 2851
		DEFAULT => -453
	},
	{#State 2852
		DEFAULT => -454
	},
	{#State 2853
		DEFAULT => -257
	},
	{#State 2854
		ACTIONS => {
			'PRIMARY_SYM' => 2878,
			'AUTO_INC' => 2885,
			'NULL_SYM' => 2876,
			'COMMENT_SYM' => 2872,
			'UNIQUE_SYM' => 2881,
			'COLLATE_SYM' => 2883,
			'NOT_SYM' => 1010,
			'ON' => 2874,
			'DEFAULT' => 2875,
			'NOT2_SYM' => 1017,
			'SERIAL_SYM' => 2884,
			'KEY_SYM' => -429
		},
		DEFAULT => -381,
		GOTOS => {
			'attribute' => 2880,
			'opt_primary' => 2877,
			'opt_attribute_list' => 2873,
			'not' => 2879,
			'opt_attribute' => 3038
		}
	},
	{#State 2855
		ACTIONS => {
			'DEFAULT' => 3039
		}
	},
	{#State 2856
		ACTIONS => {
			'DEFAULT' => 3040
		}
	},
	{#State 2857
		DEFAULT => -521
	},
	{#State 2858
		DEFAULT => -323
	},
	{#State 2859
		ACTIONS => {
			'UNSIGNED' => 3042,
			'ZEROFILL' => 3044,
			'SIGNED_SYM' => 3046
		},
		DEFAULT => -370,
		GOTOS => {
			'field_options' => 3041,
			'field_option' => 3045,
			'field_opt_list' => 3043
		}
	},
	{#State 2860
		ACTIONS => {
			'BINARY' => 2906
		},
		DEFAULT => -423,
		GOTOS => {
			'opt_bin_mod' => 3047
		}
	},
	{#State 2861
		ACTIONS => {
			'ASCII_SYM' => 3049,
			'CHAR_SYM' => 473,
			'CHARSET' => 490,
			'UNICODE_SYM' => 3051
		},
		DEFAULT => -425,
		GOTOS => {
			'opt_bin_charset' => 3048,
			'charset' => 3050
		}
	},
	{#State 2862
		ACTIONS => {
			'NUM' => 3052
		}
	},
	{#State 2863
		DEFAULT => -351
	},
	{#State 2864
		DEFAULT => -419
	},
	{#State 2865
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 1665,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1670,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'charset_name' => 3053,
			'ident' => 706
		}
	},
	{#State 2866
		DEFAULT => -309
	},
	{#State 2867
		ACTIONS => {
			'BINARY' => 2906
		},
		DEFAULT => -423,
		GOTOS => {
			'opt_bin_mod' => 3054
		}
	},
	{#State 2868
		ACTIONS => {
			'UNSIGNED' => 3042,
			'ZEROFILL' => 3044,
			'SIGNED_SYM' => 3046
		},
		DEFAULT => -370,
		GOTOS => {
			'field_options' => 3055,
			'field_option' => 3045,
			'field_opt_list' => 3043
		}
	},
	{#State 2869
		ACTIONS => {
			'NUM' => 3056
		}
	},
	{#State 2870
		DEFAULT => -357
	},
	{#State 2871
		DEFAULT => -355
	},
	{#State 2872
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 3057
		}
	},
	{#State 2873
		ACTIONS => {
			'PRIMARY_SYM' => 2878,
			'AUTO_INC' => 2885,
			'NULL_SYM' => 2876,
			'COMMENT_SYM' => 2872,
			'UNIQUE_SYM' => 2881,
			'COLLATE_SYM' => 2883,
			'NOT_SYM' => 1010,
			'ON' => 2874,
			'DEFAULT' => 2875,
			'NOT2_SYM' => 1017,
			'SERIAL_SYM' => 2884,
			'KEY_SYM' => -429
		},
		DEFAULT => -382,
		GOTOS => {
			'attribute' => 3058,
			'opt_primary' => 2877,
			'not' => 2879
		}
	},
	{#State 2874
		ACTIONS => {
			'UPDATE_SYM' => 3059
		}
	},
	{#State 2875
		ACTIONS => {
			"-" => 3065,
			'ULONGLONG_NUM' => 629,
			"+" => 3060,
			'NCHAR_STRING' => 652,
			'HEX_NUM' => 551,
			'DECIMAL_NUM' => 668,
			'TIMESTAMP' => 3061,
			'TEXT_STRING' => 554,
			'NUM' => 590,
			'DATE_SYM' => 3066,
			'FLOAT_NUM' => 602,
			'NULL_SYM' => 569,
			'BIN_NUM' => 611,
			'TIME_SYM' => 3064,
			'FALSE_SYM' => 622,
			'TRUE_SYM' => 595,
			'UNDERSCORE_CHARSET' => 545,
			'NOW_SYM' => 3068,
			'LONG_NUM' => 563
		},
		GOTOS => {
			'literal' => 3067,
			'text_literal' => 525,
			'now_or_signed_literal' => 3062,
			'TEXT_STRING_literal' => 653,
			'NUM_literal' => 684,
			'signed_literal' => 3063
		}
	},
	{#State 2876
		DEFAULT => -385
	},
	{#State 2877
		ACTIONS => {
			'KEY_SYM' => 3069
		}
	},
	{#State 2878
		DEFAULT => -430
	},
	{#State 2879
		ACTIONS => {
			'NULL_SYM' => 3070
		}
	},
	{#State 2880
		DEFAULT => -384
	},
	{#State 2881
		ACTIONS => {
			'KEY_SYM' => 3071
		},
		DEFAULT => -392
	},
	{#State 2882
		DEFAULT => -300
	},
	{#State 2883
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 2481,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'collation_name' => 3072,
			'ident' => 706
		}
	},
	{#State 2884
		ACTIONS => {
			'DEFAULT' => 3073
		}
	},
	{#State 2885
		DEFAULT => -389
	},
	{#State 2886
		ACTIONS => {
			'SET' => 878
		},
		DEFAULT => -348
	},
	{#State 2887
		ACTIONS => {
			'VARYING' => 2863
		}
	},
	{#State 2888
		ACTIONS => {
			'ASCII_SYM' => 2860,
			'CHAR_SYM' => 473,
			'BINARY' => 2861,
			'CHARSET' => 490,
			'BYTE_SYM' => 2864,
			'UNICODE_SYM' => 2867
		},
		DEFAULT => -417,
		GOTOS => {
			'opt_binary' => 3074,
			'charset' => 2865
		}
	},
	{#State 2889
		DEFAULT => -338
	},
	{#State 2890
		DEFAULT => -327
	},
	{#State 2891
		ACTIONS => {
			'NUM' => 3075
		}
	},
	{#State 2892
		DEFAULT => -320
	},
	{#State 2893
		DEFAULT => -329
	},
	{#State 2894
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 3077,
			'TEXT_STRING_literal' => 801,
			'string_list' => 3076
		}
	},
	{#State 2895
		ACTIONS => {
			'UNSIGNED' => 3042,
			'ZEROFILL' => 3044,
			'SIGNED_SYM' => 3046
		},
		DEFAULT => -370,
		GOTOS => {
			'field_options' => 3078,
			'field_option' => 3045,
			'field_opt_list' => 3043
		}
	},
	{#State 2896
		DEFAULT => -332
	},
	{#State 2897
		ACTIONS => {
			'NUM' => 3079
		}
	},
	{#State 2898
		ACTIONS => {
			'UNSIGNED' => 3042,
			'ZEROFILL' => 3044,
			'SIGNED_SYM' => 3046
		},
		DEFAULT => -370,
		GOTOS => {
			'field_options' => 3080,
			'field_option' => 3045,
			'field_opt_list' => 3043
		}
	},
	{#State 2899
		ACTIONS => {
			'VARYING' => 3081
		},
		DEFAULT => -350
	},
	{#State 2900
		DEFAULT => -353
	},
	{#State 2901
		ACTIONS => {
			'UNSIGNED' => 3042,
			'ZEROFILL' => 3044,
			'SIGNED_SYM' => 3046
		},
		DEFAULT => -370,
		GOTOS => {
			'field_options' => 3082,
			'field_option' => 3045,
			'field_opt_list' => 3043
		}
	},
	{#State 2902
		ACTIONS => {
			'NUM' => 3083
		}
	},
	{#State 2903
		DEFAULT => -380
	},
	{#State 2904
		ACTIONS => {
			'NUM' => 3084
		}
	},
	{#State 2905
		ACTIONS => {
			'UNSIGNED' => 3042,
			'ZEROFILL' => 3044,
			'SIGNED_SYM' => 3046
		},
		DEFAULT => -370,
		GOTOS => {
			'field_options' => 3085,
			'field_option' => 3045,
			'field_opt_list' => 3043
		}
	},
	{#State 2906
		DEFAULT => -424
	},
	{#State 2907
		ACTIONS => {
			'NUM' => 3086
		}
	},
	{#State 2908
		DEFAULT => -311
	},
	{#State 2909
		DEFAULT => -365
	},
	{#State 2910
		ACTIONS => {
			'UNSIGNED' => 3042,
			'ZEROFILL' => 3044,
			'SIGNED_SYM' => 3046
		},
		DEFAULT => -370,
		GOTOS => {
			'field_options' => 3087,
			'field_option' => 3045,
			'field_opt_list' => 3043
		}
	},
	{#State 2911
		ACTIONS => {
			'NUM' => 3088
		}
	},
	{#State 2912
		ACTIONS => {
			'ASCII_SYM' => 2860,
			'CHAR_SYM' => 473,
			'BINARY' => 2861,
			'CHARSET' => 490,
			'BYTE_SYM' => 2864,
			'UNICODE_SYM' => 2867
		},
		DEFAULT => -417,
		GOTOS => {
			'opt_binary' => 3089,
			'charset' => 2865
		}
	},
	{#State 2913
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 3077,
			'TEXT_STRING_literal' => 801,
			'string_list' => 3090
		}
	},
	{#State 2914
		DEFAULT => -331
	},
	{#State 2915
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'INDEX_SYM' => 1264,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'KEY_SYM' => 1266,
			'FULLTEXT_SYM' => 2196,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'SPATIAL_SYM' => 2200,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'CONSTRAINT' => 2202,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 2230,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -297,
		GOTOS => {
			'keyword' => 332,
			'key_type' => 2199,
			'key_or_index' => 2198,
			'column_def' => 2624,
			'key_def' => 2627,
			'ident' => 2229,
			'field_list_item' => 3091,
			'keyword_sp' => 287,
			'opt_constraint' => 2203,
			'IDENT_sys' => 297,
			'field_spec' => 2228,
			'constraint' => 2195,
			'field_ident' => 2226
		}
	},
	{#State 2916
		DEFAULT => -497
	},
	{#State 2917
		ACTIONS => {
			'MATCH' => 3098,
			"(" => 3094,
			'ON' => 3093
		},
		DEFAULT => -436,
		GOTOS => {
			'opt_ref_list' => 3095,
			'opt_on_delete_list' => 3092,
			'opt_on_delete_item' => 3096,
			'opt_on_delete' => 3097
		}
	},
	{#State 2918
		ACTIONS => {
			"." => 3099
		},
		DEFAULT => -1375
	},
	{#State 2919
		ACTIONS => {
			"(" => 2961,
			'SELECT_SYM' => 2964
		},
		GOTOS => {
			'view_select_aux' => 2962,
			'view_select' => 3100
		}
	},
	{#State 2920
		ACTIONS => {
			'ON' => -1025,
			'WHERE' => -1025,
			'FOR_SYM' => -1025,
			'JOIN_SYM' => -1025,
			'ORDER_SYM' => -1025,
			'INTO' => -1025,
			'UNION_SYM' => -1025,
			'LOCK_SYM' => -1025,
			'PROCEDURE' => -1025,
			'END_OF_INPUT' => -1025,
			'SET' => -1025,
			'LEFT' => -1025,
			"," => -1025,
			'EQ' => 1335,
			'USING' => -1025,
			'HAVING' => -1025,
			'AS' => 1337,
			'WITH' => -1025,
			'CROSS' => -1025,
			'GROUP' => -1025,
			")" => -1025,
			";" => -1025,
			'INNER_SYM' => -1025,
			'RIGHT' => -1025,
			'STRAIGHT_JOIN' => -1025,
			'NATURAL' => -1025,
			'LIMIT' => -1025
		},
		DEFAULT => -1022,
		GOTOS => {
			'table_alias' => 1338,
			'opt_table_alias' => 3101
		}
	},
	{#State 2921
		ACTIONS => {
			'INNER_SYM' => 1780,
			'ON' => 3102,
			'RIGHT' => 1781,
			'JOIN_SYM' => 1777,
			'STRAIGHT_JOIN' => 1782,
			'LEFT' => 1778,
			'NATURAL' => 1783,
			'CROSS' => 1779
		},
		GOTOS => {
			'normal_join' => 1784
		}
	},
	{#State 2922
		ACTIONS => {
			'USING' => 3103
		},
		DEFAULT => -952
	},
	{#State 2923
		ACTIONS => {
			'INNER_SYM' => 1780,
			'ON' => 3104,
			'RIGHT' => 1781,
			'JOIN_SYM' => 1777,
			'STRAIGHT_JOIN' => 1782,
			'LEFT' => 1778,
			'NATURAL' => 1783,
			'CROSS' => 1779
		},
		GOTOS => {
			'normal_join' => 1784
		}
	},
	{#State 2924
		ACTIONS => {
			'USING' => 3105
		},
		DEFAULT => -952
	},
	{#State 2925
		DEFAULT => -960
	},
	{#State 2926
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1259,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'ident' => 435,
			'table_factor' => 3106
		}
	},
	{#State 2927
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 1259,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'ident' => 435,
			'table_factor' => 3107
		}
	},
	{#State 2928
		DEFAULT => -959
	},
	{#State 2929
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3109,
			'using_list' => 3108
		}
	},
	{#State 2930
		DEFAULT => -1151
	},
	{#State 2931
		ACTIONS => {
			'LIMIT' => 2810
		},
		DEFAULT => -1066,
		GOTOS => {
			'delete_limit_clause' => 3110
		}
	},
	{#State 2932
		DEFAULT => -1153
	},
	{#State 2933
		DEFAULT => -977
	},
	{#State 2934
		ACTIONS => {
			'JOIN_SYM' => 3111
		}
	},
	{#State 2935
		ACTIONS => {
			"(" => 3112
		}
	},
	{#State 2936
		ACTIONS => {
			'JOIN_SYM' => 3113
		}
	},
	{#State 2937
		DEFAULT => -991
	},
	{#State 2938
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'key_part' => 3115,
			'IDENT_sys' => 297,
			'ident' => 3116,
			'key_list' => 3114
		}
	},
	{#State 2939
		ACTIONS => {
			'ORDER_SYM' => 1613,
			'UNION_SYM' => 1172,
			'LIMIT' => 899
		},
		DEFAULT => -1833,
		GOTOS => {
			'union_list' => 1616,
			'union_opt' => 3117,
			'order_or_limit' => 1614,
			'order_clause' => 1619,
			'limit_clause' => 1617,
			'union_order_or_limit' => 1618
		}
	},
	{#State 2940
		ACTIONS => {
			'AUTO_INC' => 1769,
			'ROW_FORMAT_SYM' => 1760,
			'DATA_SYM' => 1753,
			'INDEX_SYM' => 1731,
			'TYPE_SYM' => 1746,
			'MAX_ROWS' => 1765,
			'PACK_KEYS_SYM' => 1734,
			'UNION_SYM' => 1742,
			'RAID_TYPE' => 1766,
			'PASSWORD' => 1767,
			'CHAR_SYM' => -415,
			'INSERT_METHOD' => 1757,
			'MIN_ROWS' => 1747,
			'ENGINE_SYM' => 1768,
			'COMMENT_SYM' => 1737,
			'RAID_CHUNKSIZE' => 1738,
			'COLLATE_SYM' => -415,
			'CHARSET' => -415,
			'DELAY_KEY_WRITE_SYM' => 1762,
			'AVG_ROW_LENGTH' => 1750,
			'DEFAULT' => 1245,
			'CONNECTION_SYM' => 1752,
			'RAID_CHUNKS' => 1758,
			'CHECKSUM_SYM' => 1744
		},
		DEFAULT => -230,
		GOTOS => {
			'default_charset' => 1756,
			'opt_default' => 1243,
			'create_table_options' => 2272,
			'default_collation' => 1751,
			'create_table_option' => 2270,
			'opt_create_table_options' => 3118
		}
	},
	{#State 2941
		ACTIONS => {
			")" => 3119
		}
	},
	{#State 2942
		DEFAULT => -216
	},
	{#State 2943
		ACTIONS => {
			"(" => 3120,
			'SELECT_SYM' => 1206
		},
		GOTOS => {
			'create_select' => 3121
		}
	},
	{#State 2944
		DEFAULT => -236
	},
	{#State 2945
		DEFAULT => -1793
	},
	{#State 2946
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 3122
		}
	},
	{#State 2947
		DEFAULT => -96,
		GOTOS => {
			'sp_c_chistics' => 3123
		}
	},
	{#State 2948
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3124
		}
	},
	{#State 2949
		ACTIONS => {
			'INOUT_SYM' => 2678,
			'OUT_SYM' => 2681,
			'IN_SYM' => 2682
		},
		DEFAULT => -128,
		GOTOS => {
			'sp_pdparam' => 3125,
			'sp_opt_inout' => 2677
		}
	},
	{#State 2950
		ACTIONS => {
			")" => 3126
		}
	},
	{#State 2951
		DEFAULT => -120
	},
	{#State 2952
		ACTIONS => {
			"," => 3127
		},
		DEFAULT => -118
	},
	{#State 2953
		DEFAULT => -121,
		GOTOS => {
			'sp_init_param' => 3128
		}
	},
	{#State 2954
		DEFAULT => -282
	},
	{#State 2955
		ACTIONS => {
			'UDF_SONAME_SYM' => 3129
		}
	},
	{#State 2956
		DEFAULT => -280
	},
	{#State 2957
		DEFAULT => -281
	},
	{#State 2958
		DEFAULT => -279
	},
	{#State 2959
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3130
		}
	},
	{#State 2960
		DEFAULT => -1868
	},
	{#State 2961
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 3131
		}
	},
	{#State 2962
		DEFAULT => -1871
	},
	{#State 2963
		ACTIONS => {
			'WITH' => 3133
		},
		DEFAULT => -1874,
		GOTOS => {
			'view_check_option' => 3132
		}
	},
	{#State 2964
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 3134
		}
	},
	{#State 2965
		ACTIONS => {
			"," => 1804,
			'REQUIRE_SYM' => 3135
		},
		DEFAULT => -1800,
		GOTOS => {
			'require_clause' => 3136
		}
	},
	{#State 2966
		DEFAULT => -1786
	},
	{#State 2967
		DEFAULT => -1785
	},
	{#State 2968
		ACTIONS => {
			"," => 1804,
			'REQUIRE_SYM' => 3135
		},
		DEFAULT => -1800,
		GOTOS => {
			'require_clause' => 3137
		}
	},
	{#State 2969
		ACTIONS => {
			"," => 1804,
			'REQUIRE_SYM' => 3135
		},
		DEFAULT => -1800,
		GOTOS => {
			'require_clause' => 3138
		}
	},
	{#State 2970
		DEFAULT => -1727
	},
	{#State 2971
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 3139
		}
	},
	{#State 2972
		ACTIONS => {
			")" => 3140
		}
	},
	{#State 2973
		DEFAULT => -762
	},
	{#State 2974
		ACTIONS => {
			")" => 3141
		}
	},
	{#State 2975
		DEFAULT => -926
	},
	{#State 2976
		ACTIONS => {
			"," => 3142,
			")" => 3143
		}
	},
	{#State 2977
		ACTIONS => {
			")" => 3144
		}
	},
	{#State 2978
		ACTIONS => {
			"," => 3145
		}
	},
	{#State 2979
		DEFAULT => -1843
	},
	{#State 2980
		DEFAULT => -763
	},
	{#State 2981
		ACTIONS => {
			"," => 3146
		}
	},
	{#State 2982
		ACTIONS => {
			")" => 3147
		}
	},
	{#State 2983
		ACTIONS => {
			"," => 3148
		}
	},
	{#State 2984
		ACTIONS => {
			")" => 3149
		}
	},
	{#State 2985
		ACTIONS => {
			")" => 3150
		}
	},
	{#State 2986
		DEFAULT => -667
	},
	{#State 2987
		ACTIONS => {
			")" => 3151
		}
	},
	{#State 2988
		DEFAULT => -913
	},
	{#State 2989
		DEFAULT => -921
	},
	{#State 2990
		ACTIONS => {
			'EXPANSION_SYM' => 3152
		}
	},
	{#State 2991
		DEFAULT => -732
	},
	{#State 2992
		ACTIONS => {
			'MODE_SYM' => 3153
		}
	},
	{#State 2993
		ACTIONS => {
			")" => 3154
		}
	},
	{#State 2994
		ACTIONS => {
			")" => 3155
		}
	},
	{#State 2995
		ACTIONS => {
			")" => 3156
		}
	},
	{#State 2996
		ACTIONS => {
			")" => 3157
		}
	},
	{#State 2997
		ACTIONS => {
			"," => 3158,
			")" => 3159
		}
	},
	{#State 2998
		ACTIONS => {
			")" => 3160
		}
	},
	{#State 2999
		DEFAULT => -836
	},
	{#State 3000
		DEFAULT => -835
	},
	{#State 3001
		DEFAULT => -837
	},
	{#State 3002
		ACTIONS => {
			")" => 3161
		}
	},
	{#State 3003
		ACTIONS => {
			")" => 3162
		}
	},
	{#State 3004
		ACTIONS => {
			")" => 3163
		}
	},
	{#State 3005
		DEFAULT => -951
	},
	{#State 3006
		ACTIONS => {
			'ASC' => 2803,
			'DESC' => 2802
		},
		DEFAULT => -1051,
		GOTOS => {
			'order_dir' => 3164
		}
	},
	{#State 3007
		DEFAULT => -595
	},
	{#State 3008
		ACTIONS => {
			'TABLE_SYM' => 3165
		}
	},
	{#State 3009
		DEFAULT => -1067
	},
	{#State 3010
		DEFAULT => -626
	},
	{#State 3011
		ACTIONS => {
			'BY' => 3166
		}
	},
	{#State 3012
		DEFAULT => -1311
	},
	{#State 3013
		ACTIONS => {
			'BY' => 3167
		}
	},
	{#State 3014
		ACTIONS => {
			'TERMINATED' => 3015,
			'ENCLOSED' => 3011,
			'OPTIONALLY' => 3016,
			'ESCAPED' => 3013
		},
		DEFAULT => -1309,
		GOTOS => {
			'field_term' => 3168
		}
	},
	{#State 3015
		ACTIONS => {
			'BY' => 3169
		}
	},
	{#State 3016
		ACTIONS => {
			'ENCLOSED' => 3170
		}
	},
	{#State 3017
		ACTIONS => {
			'STARTING' => 3173,
			'TERMINATED' => 3174
		},
		GOTOS => {
			'line_term' => 3172,
			'line_term_list' => 3171
		}
	},
	{#State 3018
		DEFAULT => -1092
	},
	{#State 3019
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'order_ident' => 3175,
			'group_list' => 3176,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2444,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3020
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3177,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3021
		ACTIONS => {
			'ORDER_SYM' => 1613
		},
		DEFAULT => -1046,
		GOTOS => {
			'order_clause' => 1649,
			'opt_order_clause' => 3178
		}
	},
	{#State 3022
		DEFAULT => -1364
	},
	{#State 3023
		ACTIONS => {
			'UPDATE_SYM' => 3179
		}
	},
	{#State 3024
		ACTIONS => {
			"," => 1804
		},
		DEFAULT => -1734
	},
	{#State 3025
		ACTIONS => {
			"," => 1804
		},
		DEFAULT => -1736
	},
	{#State 3026
		ACTIONS => {
			"," => 1804
		},
		DEFAULT => -1735
	},
	{#State 3027
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'CURRENT_USER' => 1226,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'grant_list' => 3180,
			'ident' => 706,
			'grant_user' => 1284,
			'keyword_sp' => 287,
			'ident_or_text' => 1227,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'user' => 1283
		}
	},
	{#State 3028
		DEFAULT => -1684
	},
	{#State 3029
		DEFAULT => -1699
	},
	{#State 3030
		DEFAULT => -1698
	},
	{#State 3031
		DEFAULT => -509
	},
	{#State 3032
		DEFAULT => -1043
	},
	{#State 3033
		DEFAULT => -498
	},
	{#State 3034
		DEFAULT => -253
	},
	{#State 3035
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'key_part' => 3115,
			'IDENT_sys' => 297,
			'ident' => 3116,
			'key_list' => 3181
		}
	},
	{#State 3036
		ACTIONS => {
			"(" => 3182
		}
	},
	{#State 3037
		ACTIONS => {
			"(" => 3183
		}
	},
	{#State 3038
		ACTIONS => {
			'AFTER_SYM' => 2567,
			'FIRST_SYM' => 2569
		},
		DEFAULT => -520,
		GOTOS => {
			'opt_place' => 3184
		}
	},
	{#State 3039
		DEFAULT => -507
	},
	{#State 3040
		ACTIONS => {
			"-" => 3065,
			'ULONGLONG_NUM' => 629,
			"+" => 3060,
			'NCHAR_STRING' => 652,
			'HEX_NUM' => 551,
			'DECIMAL_NUM' => 668,
			'TIMESTAMP' => 3061,
			'TEXT_STRING' => 554,
			'NUM' => 590,
			'DATE_SYM' => 3066,
			'FLOAT_NUM' => 602,
			'NULL_SYM' => 569,
			'BIN_NUM' => 611,
			'TIME_SYM' => 3064,
			'FALSE_SYM' => 622,
			'TRUE_SYM' => 595,
			'UNDERSCORE_CHARSET' => 545,
			'LONG_NUM' => 563
		},
		GOTOS => {
			'literal' => 3067,
			'text_literal' => 525,
			'TEXT_STRING_literal' => 653,
			'NUM_literal' => 684,
			'signed_literal' => 3185
		}
	},
	{#State 3041
		DEFAULT => -317
	},
	{#State 3042
		DEFAULT => -375
	},
	{#State 3043
		ACTIONS => {
			'UNSIGNED' => 3042,
			'ZEROFILL' => 3044,
			'SIGNED_SYM' => 3046
		},
		DEFAULT => -371,
		GOTOS => {
			'field_option' => 3186
		}
	},
	{#State 3044
		DEFAULT => -376
	},
	{#State 3045
		DEFAULT => -373
	},
	{#State 3046
		DEFAULT => -374
	},
	{#State 3047
		DEFAULT => -418
	},
	{#State 3048
		DEFAULT => -422
	},
	{#State 3049
		DEFAULT => -426
	},
	{#State 3050
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 1665,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1670,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'charset_name' => 3187,
			'ident' => 706
		}
	},
	{#State 3051
		DEFAULT => -427
	},
	{#State 3052
		ACTIONS => {
			")" => 3188
		}
	},
	{#State 3053
		ACTIONS => {
			'BINARY' => 2906
		},
		DEFAULT => -423,
		GOTOS => {
			'opt_bin_mod' => 3189
		}
	},
	{#State 3054
		DEFAULT => -420
	},
	{#State 3055
		DEFAULT => -333
	},
	{#State 3056
		ACTIONS => {
			")" => 3190
		}
	},
	{#State 3057
		DEFAULT => -394
	},
	{#State 3058
		DEFAULT => -383
	},
	{#State 3059
		ACTIONS => {
			'NOW_SYM' => 3191
		}
	},
	{#State 3060
		ACTIONS => {
			'NUM' => 590,
			'ULONGLONG_NUM' => 629,
			'FLOAT_NUM' => 602,
			'LONG_NUM' => 563,
			'DECIMAL_NUM' => 668
		},
		GOTOS => {
			'NUM_literal' => 3192
		}
	},
	{#State 3061
		ACTIONS => {
			'TEXT_STRING' => 554,
			'NCHAR_STRING' => 652,
			'UNDERSCORE_CHARSET' => 980
		},
		GOTOS => {
			'text_literal' => 979,
			'TEXT_STRING_literal' => 653
		}
	},
	{#State 3062
		DEFAULT => -387
	},
	{#State 3063
		DEFAULT => -397
	},
	{#State 3064
		ACTIONS => {
			'TEXT_STRING' => 554,
			'NCHAR_STRING' => 652,
			'UNDERSCORE_CHARSET' => 980
		},
		GOTOS => {
			'text_literal' => 1058,
			'TEXT_STRING_literal' => 653
		}
	},
	{#State 3065
		ACTIONS => {
			'NUM' => 590,
			'ULONGLONG_NUM' => 629,
			'FLOAT_NUM' => 602,
			'LONG_NUM' => 563,
			'DECIMAL_NUM' => 668
		},
		GOTOS => {
			'NUM_literal' => 3193
		}
	},
	{#State 3066
		ACTIONS => {
			'TEXT_STRING' => 554,
			'NCHAR_STRING' => 652,
			'UNDERSCORE_CHARSET' => 980
		},
		GOTOS => {
			'text_literal' => 1072,
			'TEXT_STRING_literal' => 653
		}
	},
	{#State 3067
		DEFAULT => -1341
	},
	{#State 3068
		ACTIONS => {
			"(" => 962
		},
		DEFAULT => -640,
		GOTOS => {
			'optional_braces' => 3194
		}
	},
	{#State 3069
		DEFAULT => -391
	},
	{#State 3070
		DEFAULT => -386
	},
	{#State 3071
		DEFAULT => -393
	},
	{#State 3072
		DEFAULT => -395
	},
	{#State 3073
		ACTIONS => {
			'VALUE_SYM' => 3195
		}
	},
	{#State 3074
		DEFAULT => -328
	},
	{#State 3075
		ACTIONS => {
			")" => 3196
		}
	},
	{#State 3076
		ACTIONS => {
			"," => 3197,
			")" => 3198
		}
	},
	{#State 3077
		DEFAULT => -480
	},
	{#State 3078
		DEFAULT => -301
	},
	{#State 3079
		ACTIONS => {
			")" => 3199
		}
	},
	{#State 3080
		DEFAULT => -335
	},
	{#State 3081
		DEFAULT => -356
	},
	{#State 3082
		DEFAULT => -303
	},
	{#State 3083
		ACTIONS => {
			")" => 3200
		}
	},
	{#State 3084
		ACTIONS => {
			"," => 3142
		}
	},
	{#State 3085
		DEFAULT => -302
	},
	{#State 3086
		ACTIONS => {
			")" => 3201
		}
	},
	{#State 3087
		DEFAULT => -334
	},
	{#State 3088
		ACTIONS => {
			")" => 3202
		}
	},
	{#State 3089
		DEFAULT => -330
	},
	{#State 3090
		ACTIONS => {
			"," => 3197,
			")" => 3203
		}
	},
	{#State 3091
		DEFAULT => -284
	},
	{#State 3092
		ACTIONS => {
			'MATCH' => 3098,
			'ON' => 3093
		},
		DEFAULT => -437,
		GOTOS => {
			'opt_on_delete_item' => 3204
		}
	},
	{#State 3093
		ACTIONS => {
			'DELETE_SYM' => 3206,
			'UPDATE_SYM' => 3205
		}
	},
	{#State 3094
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'ref_list' => 3207,
			'IDENT_sys' => 297,
			'ident' => 3208
		}
	},
	{#State 3095
		DEFAULT => -431
	},
	{#State 3096
		DEFAULT => -439
	},
	{#State 3097
		DEFAULT => -432
	},
	{#State 3098
		ACTIONS => {
			'PARTIAL' => 3211,
			'SIMPLE_SYM' => 3210,
			'FULL' => 3209
		}
	},
	{#State 3099
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3212
		}
	},
	{#State 3100
		ACTIONS => {
			'WITH' => 3133
		},
		DEFAULT => -1874,
		GOTOS => {
			'view_check_option' => 3213
		}
	},
	{#State 3101
		DEFAULT => -975
	},
	{#State 3102
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3214,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3103
		ACTIONS => {
			"(" => 3215
		}
	},
	{#State 3104
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3216,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3105
		ACTIONS => {
			"(" => 3217
		}
	},
	{#State 3106
		DEFAULT => -965
	},
	{#State 3107
		DEFAULT => -968
	},
	{#State 3108
		ACTIONS => {
			"," => 3218,
			")" => 3219
		}
	},
	{#State 3109
		DEFAULT => -994
	},
	{#State 3110
		DEFAULT => -1150
	},
	{#State 3111
		DEFAULT => -983
	},
	{#State 3112
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'PRIMARY_SYM' => 2258,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -989,
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'key_usage_list2' => 3220,
			'ident' => 2259,
			'key_list_or_empty' => 3221
		}
	},
	{#State 3113
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			"(" => 1253,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 1258,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			"{" => 1260,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'table_ident' => 1259,
			'ident' => 435,
			'table_factor' => 1261,
			'keyword_sp' => 287,
			'select_derived_init' => 1257,
			'IDENT_sys' => 297,
			'table_ref' => 3222,
			'join_table' => 1255
		}
	},
	{#State 3114
		ACTIONS => {
			"," => 3223,
			")" => 3224
		}
	},
	{#State 3115
		ACTIONS => {
			'ASC' => 2803,
			'DESC' => 2802
		},
		DEFAULT => -1051,
		GOTOS => {
			'order_dir' => 3225
		}
	},
	{#State 3116
		ACTIONS => {
			"(" => 3226
		},
		DEFAULT => -474
	},
	{#State 3117
		DEFAULT => -210
	},
	{#State 3118
		ACTIONS => {
			'REPLACE' => 2663,
			";" => -211,
			'IGNORE_SYM' => 2665,
			'END_OF_INPUT' => -211
		},
		DEFAULT => -1305,
		GOTOS => {
			'opt_duplicate' => 2664,
			'create3' => 3227
		}
	},
	{#State 3119
		DEFAULT => -208
	},
	{#State 3120
		ACTIONS => {
			'SELECT_SYM' => 1206
		},
		GOTOS => {
			'create_select' => 3228
		}
	},
	{#State 3121
		ACTIONS => {
			'UNION_SYM' => 1172
		},
		DEFAULT => -1830,
		GOTOS => {
			'union_list' => 1174,
			'union_clause' => 3229
		}
	},
	{#State 3122
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 3230,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 3123
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'NOT_SYM' => 1010,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 1721,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'CONTAINS_SYM' => 1722,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'CHAIN_SYM' => 175,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'LANGUAGE_SYM' => 1724,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'READS_SYM' => 1725,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 1726,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'MODIFIES_SYM' => 1727,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'HASH_SYM' => 350,
			'SECOND_SYM' => 351,
			'SERIAL_SYM' => 352,
			'DETERMINISTIC_SYM' => 3252,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 46,
			'ISOLATION' => 354,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 1017,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'SQL_SYM' => 1729,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'not' => 3250,
			'checksum' => 7,
			'rename' => 6,
			'sp_suid' => 1728,
			'statement' => 3231,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'deallocate_or_drop' => 13,
			'sp_chistic' => 3238,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'change' => 15,
			'commit' => 20,
			'flush' => 21,
			'delete' => 22,
			'start' => 23,
			'do' => 24,
			'drop' => 25,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'execute' => 45,
			'update' => 49,
			'sp_unlabeled_control' => 3253,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'alter' => 58,
			'label_ident' => 3234,
			'show' => 64,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'replace' => 71,
			'preload' => 73,
			'grant' => 75,
			'case_stmt_specification' => 3243,
			'sp_labeled_control' => 3248,
			'rollback' => 80,
			'use' => 84,
			'check' => 82,
			'IDENT_sys' => 3249,
			'reset' => 83,
			'xa' => 85,
			'help' => 86,
			'call' => 90,
			'purge' => 88,
			'revoke' => 91,
			'select' => 93,
			'sp_c_chistic' => 3236,
			'analyze' => 98,
			'sp_proc_stmt' => 3237,
			'deallocate' => 99,
			'handler' => 103,
			'keycache' => 102,
			'optimize' => 105
		}
	},
	{#State 3124
		ACTIONS => {
			'SET' => 2592,
			'NUMERIC_SYM' => 2615,
			'TINYBLOB' => 2620,
			'POINT_SYM' => 2610,
			'TEXT_SYM' => 2621,
			'DECIMAL_SYM' => 2582,
			'BINARY' => 2583,
			'DATETIME' => 2570,
			'NATIONAL_SYM' => 2603,
			'BLOB_SYM' => 2571,
			'NVARCHAR_SYM' => 2611,
			'LONGBLOB' => 2604,
			'NCHAR_SYM' => 2584,
			'TINYINT' => 2572,
			'YEAR_SYM' => 2573,
			'MULTIPOLYGON' => 2594,
			'INT_SYM' => 2574,
			'MULTILINESTRING' => 2617,
			'FLOAT_SYM' => 2605,
			'BIT_SYM' => 2596,
			'ENUM' => 2622,
			'SMALLINT' => 2597,
			'CHAR_SYM' => 2575,
			'GEOMETRYCOLLECTION' => 2586,
			'LONG_SYM' => 2587,
			'VARBINARY' => 2606,
			'TIMESTAMP' => 2589,
			'MEDIUMTEXT' => 2623,
			'DATE_SYM' => 2607,
			'POLYGON' => 2576,
			'FIXED_SYM' => 2598,
			'REAL' => 2577,
			'DOUBLE_SYM' => 2613,
			'LINESTRING' => 2578,
			'TIME_SYM' => 2599,
			'BOOL_SYM' => 2608,
			'MULTIPOINT' => 2614,
			'GEOMETRY_SYM' => 2618,
			'TINYTEXT' => 2590,
			'LONGTEXT' => 2595,
			'MEDIUMINT' => 2600,
			'SERIAL_SYM' => 2619,
			'VARCHAR' => 2601,
			'BOOLEAN_SYM' => 2602,
			'MEDIUMBLOB' => 2581,
			'BIGINT' => 2591
		},
		GOTOS => {
			'int_type' => 2593,
			'spatial_type' => 2579,
			'varchar' => 2588,
			'nvarchar' => 2616,
			'real_type' => 2609,
			'char' => 2580,
			'type' => 3257,
			'nchar' => 2612
		}
	},
	{#State 3125
		DEFAULT => -125
	},
	{#State 3126
		ACTIONS => {
			'RETURNS_SYM' => 3258
		}
	},
	{#State 3127
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_fdparam' => 3259,
			'IDENT_sys' => 297,
			'ident' => 2953
		}
	},
	{#State 3128
		ACTIONS => {
			'SET' => 2592,
			'NUMERIC_SYM' => 2615,
			'TINYBLOB' => 2620,
			'POINT_SYM' => 2610,
			'TEXT_SYM' => 2621,
			'DECIMAL_SYM' => 2582,
			'BINARY' => 2583,
			'DATETIME' => 2570,
			'NATIONAL_SYM' => 2603,
			'BLOB_SYM' => 2571,
			'NVARCHAR_SYM' => 2611,
			'LONGBLOB' => 2604,
			'NCHAR_SYM' => 2584,
			'TINYINT' => 2572,
			'YEAR_SYM' => 2573,
			'MULTIPOLYGON' => 2594,
			'INT_SYM' => 2574,
			'MULTILINESTRING' => 2617,
			'FLOAT_SYM' => 2605,
			'BIT_SYM' => 2596,
			'ENUM' => 2622,
			'SMALLINT' => 2597,
			'CHAR_SYM' => 2575,
			'GEOMETRYCOLLECTION' => 2586,
			'LONG_SYM' => 2587,
			'VARBINARY' => 2606,
			'TIMESTAMP' => 2589,
			'MEDIUMTEXT' => 2623,
			'DATE_SYM' => 2607,
			'POLYGON' => 2576,
			'FIXED_SYM' => 2598,
			'REAL' => 2577,
			'DOUBLE_SYM' => 2613,
			'LINESTRING' => 2578,
			'TIME_SYM' => 2599,
			'BOOL_SYM' => 2608,
			'MULTIPOINT' => 2614,
			'GEOMETRY_SYM' => 2618,
			'TINYTEXT' => 2590,
			'LONGTEXT' => 2595,
			'MEDIUMINT' => 2600,
			'SERIAL_SYM' => 2619,
			'VARCHAR' => 2601,
			'BOOLEAN_SYM' => 2602,
			'MEDIUMBLOB' => 2581,
			'BIGINT' => 2591
		},
		GOTOS => {
			'int_type' => 2593,
			'spatial_type' => 2579,
			'varchar' => 2588,
			'nvarchar' => 2616,
			'real_type' => 2609,
			'char' => 2580,
			'type' => 3260,
			'nchar' => 2612
		}
	},
	{#State 3129
		ACTIONS => {
			'TEXT_STRING' => 703
		},
		GOTOS => {
			'TEXT_STRING_sys' => 3261
		}
	},
	{#State 3130
		DEFAULT => -1870
	},
	{#State 3131
		ACTIONS => {
			"(" => 688,
			'SELECT_SYM' => 689
		},
		GOTOS => {
			'select_paren' => 3262
		}
	},
	{#State 3132
		DEFAULT => -1866
	},
	{#State 3133
		ACTIONS => {
			'LOCAL_SYM' => 3264,
			'CHECK_SYM' => 3263,
			'CASCADED' => 3265
		}
	},
	{#State 3134
		ACTIONS => {
			'SQL_BIG_RESULT' => 708,
			'SQL_BUFFER_RESULT' => 709,
			'SQL_NO_CACHE_SYM' => 710,
			'SQL_CALC_FOUND_ROWS' => 713,
			'SQL_CACHE_SYM' => 714,
			'ALL' => 716,
			'STRAIGHT_JOIN' => 717,
			'SQL_SMALL_RESULT' => 719,
			'DISTINCT' => 721,
			'HIGH_PRIORITY' => 722
		},
		DEFAULT => -610,
		GOTOS => {
			'select_option' => 715,
			'select_options' => 718,
			'select_option_list' => 720,
			'select_init2' => 3266,
			'select_part2' => 711
		}
	},
	{#State 3135
		ACTIONS => {
			'NONE_SYM' => 3270,
			'SSL_SYM' => 3273,
			'ISSUER_SYM' => 3269,
			'X509_SYM' => 3272,
			'CIPHER_SYM' => 3271,
			'SUBJECT_SYM' => 3267
		},
		GOTOS => {
			'require_list' => 3268,
			'require_list_element' => 3274
		}
	},
	{#State 3136
		ACTIONS => {
			'WITH' => 3275
		},
		DEFAULT => -1805,
		GOTOS => {
			'grant_options' => 3276
		}
	},
	{#State 3137
		ACTIONS => {
			'WITH' => 3275
		},
		DEFAULT => -1805,
		GOTOS => {
			'grant_options' => 3277
		}
	},
	{#State 3138
		ACTIONS => {
			'WITH' => 3275
		},
		DEFAULT => -1805,
		GOTOS => {
			'grant_options' => 3278
		}
	},
	{#State 3139
		ACTIONS => {
			'AND_SYM' => 3279
		}
	},
	{#State 3140
		DEFAULT => -814
	},
	{#State 3141
		DEFAULT => -378
	},
	{#State 3142
		ACTIONS => {
			'NUM' => 3280
		}
	},
	{#State 3143
		DEFAULT => -367
	},
	{#State 3144
		DEFAULT => -801
	},
	{#State 3145
		ACTIONS => {
			'ALL' => 1405
		},
		DEFAULT => -1027,
		GOTOS => {
			'opt_all' => 1404,
			'in_sum_expr' => 3281
		}
	},
	{#State 3146
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3282,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3147
		DEFAULT => -820
	},
	{#State 3148
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'expr_list2' => 600,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 603,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'expr_list' => 3283,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3149
		DEFAULT => -795
	},
	{#State 3150
		DEFAULT => -669
	},
	{#State 3151
		DEFAULT => -833
	},
	{#State 3152
		DEFAULT => -886
	},
	{#State 3153
		DEFAULT => -887
	},
	{#State 3154
		DEFAULT => -824
	},
	{#State 3155
		DEFAULT => -822
	},
	{#State 3156
		DEFAULT => -826
	},
	{#State 3157
		DEFAULT => -746
	},
	{#State 3158
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3284,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3159
		DEFAULT => -777
	},
	{#State 3160
		DEFAULT => -757
	},
	{#State 3161
		DEFAULT => -787
	},
	{#State 3162
		DEFAULT => -832
	},
	{#State 3163
		DEFAULT => -744
	},
	{#State 3164
		DEFAULT => -1049
	},
	{#State 3165
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 436,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'table_ident' => 3285,
			'IDENT_sys' => 297,
			'ident' => 435
		}
	},
	{#State 3166
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 3286,
			'TEXT_STRING_literal' => 801
		}
	},
	{#State 3167
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 3287,
			'TEXT_STRING_literal' => 801
		}
	},
	{#State 3168
		DEFAULT => -1310
	},
	{#State 3169
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 3288,
			'TEXT_STRING_literal' => 801
		}
	},
	{#State 3170
		ACTIONS => {
			'BY' => 3289
		}
	},
	{#State 3171
		ACTIONS => {
			'TERMINATED' => 3174,
			'STARTING' => 3173
		},
		DEFAULT => -1317,
		GOTOS => {
			'line_term' => 3290
		}
	},
	{#State 3172
		DEFAULT => -1319
	},
	{#State 3173
		ACTIONS => {
			'BY' => 3291
		}
	},
	{#State 3174
		ACTIONS => {
			'BY' => 3292
		}
	},
	{#State 3175
		ACTIONS => {
			'ASC' => 2803,
			'DESC' => 2802
		},
		DEFAULT => -1051,
		GOTOS => {
			'order_dir' => 3293
		}
	},
	{#State 3176
		ACTIONS => {
			"," => 3294,
			'WITH' => 3295
		},
		DEFAULT => -1039,
		GOTOS => {
			'olap_opt' => 3296
		}
	},
	{#State 3177
		DEFAULT => -1032
	},
	{#State 3178
		ACTIONS => {
			'LIMIT' => 899
		},
		DEFAULT => -1056,
		GOTOS => {
			'opt_limit_clause' => 3297,
			'limit_clause' => 2116
		}
	},
	{#State 3179
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'simple_ident_nospvar' => 3300,
			'ident' => 1542,
			'simple_ident_q' => 1540,
			'insert_update_list' => 3298,
			'keyword_sp' => 287,
			'insert_update_elem' => 3299,
			'IDENT_sys' => 297
		}
	},
	{#State 3180
		ACTIONS => {
			"," => 1804
		},
		DEFAULT => -1737
	},
	{#State 3181
		ACTIONS => {
			"," => 3223,
			")" => 3301
		}
	},
	{#State 3182
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'key_part' => 3115,
			'IDENT_sys' => 297,
			'ident' => 3116,
			'key_list' => 3302
		}
	},
	{#State 3183
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'key_part' => 3115,
			'IDENT_sys' => 297,
			'ident' => 3116,
			'key_list' => 3303
		}
	},
	{#State 3184
		DEFAULT => -499
	},
	{#State 3185
		DEFAULT => -506
	},
	{#State 3186
		DEFAULT => -372
	},
	{#State 3187
		DEFAULT => -428
	},
	{#State 3188
		ACTIONS => {
			'ASCII_SYM' => 2860,
			'CHAR_SYM' => 473,
			'BINARY' => 2861,
			'CHARSET' => 490,
			'BYTE_SYM' => 2864,
			'UNICODE_SYM' => 2867
		},
		DEFAULT => -417,
		GOTOS => {
			'opt_binary' => 3304,
			'charset' => 2865
		}
	},
	{#State 3189
		DEFAULT => -421
	},
	{#State 3190
		DEFAULT => -312
	},
	{#State 3191
		ACTIONS => {
			"(" => 962
		},
		DEFAULT => -640,
		GOTOS => {
			'optional_braces' => 3305
		}
	},
	{#State 3192
		DEFAULT => -1342
	},
	{#State 3193
		DEFAULT => -1343
	},
	{#State 3194
		DEFAULT => -396
	},
	{#State 3195
		DEFAULT => -390
	},
	{#State 3196
		ACTIONS => {
			'ASCII_SYM' => 2860,
			'CHAR_SYM' => 473,
			'BINARY' => 2861,
			'CHARSET' => 490,
			'BYTE_SYM' => 2864,
			'UNICODE_SYM' => 2867
		},
		DEFAULT => -417,
		GOTOS => {
			'opt_binary' => 3306,
			'charset' => 2865
		}
	},
	{#State 3197
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 3307,
			'TEXT_STRING_literal' => 801
		}
	},
	{#State 3198
		ACTIONS => {
			'ASCII_SYM' => 2860,
			'CHAR_SYM' => 473,
			'BINARY' => 2861,
			'CHARSET' => 490,
			'BYTE_SYM' => 2864,
			'UNICODE_SYM' => 2867
		},
		DEFAULT => -417,
		GOTOS => {
			'opt_binary' => 3308,
			'charset' => 2865
		}
	},
	{#State 3199
		DEFAULT => -305
	},
	{#State 3200
		DEFAULT => -316
	},
	{#State 3201
		ACTIONS => {
			'BINARY' => 2906
		},
		DEFAULT => -423,
		GOTOS => {
			'opt_bin_mod' => 3309
		}
	},
	{#State 3202
		ACTIONS => {
			'BINARY' => 2906
		},
		DEFAULT => -423,
		GOTOS => {
			'opt_bin_mod' => 3310
		}
	},
	{#State 3203
		ACTIONS => {
			'ASCII_SYM' => 2860,
			'CHAR_SYM' => 473,
			'BINARY' => 2861,
			'CHARSET' => 490,
			'BYTE_SYM' => 2864,
			'UNICODE_SYM' => 2867
		},
		DEFAULT => -417,
		GOTOS => {
			'opt_binary' => 3311,
			'charset' => 2865
		}
	},
	{#State 3204
		DEFAULT => -438
	},
	{#State 3205
		ACTIONS => {
			'RESTRICT' => 3316,
			'SET' => 3312,
			'NO_SYM' => 3313,
			'CASCADE' => 3314
		},
		GOTOS => {
			'delete_option' => 3315
		}
	},
	{#State 3206
		ACTIONS => {
			'RESTRICT' => 3316,
			'SET' => 3312,
			'NO_SYM' => 3313,
			'CASCADE' => 3314
		},
		GOTOS => {
			'delete_option' => 3317
		}
	},
	{#State 3207
		ACTIONS => {
			"," => 3318,
			")" => 3319
		}
	},
	{#State 3208
		DEFAULT => -435
	},
	{#State 3209
		DEFAULT => -442
	},
	{#State 3210
		DEFAULT => -444
	},
	{#State 3211
		DEFAULT => -443
	},
	{#State 3212
		DEFAULT => -1374
	},
	{#State 3213
		DEFAULT => -486
	},
	{#State 3214
		DEFAULT => -963
	},
	{#State 3215
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3109,
			'using_list' => 3320
		}
	},
	{#State 3216
		DEFAULT => -966
	},
	{#State 3217
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3109,
			'using_list' => 3321
		}
	},
	{#State 3218
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3322
		}
	},
	{#State 3219
		DEFAULT => -961
	},
	{#State 3220
		ACTIONS => {
			"," => 2655
		},
		DEFAULT => -990
	},
	{#State 3221
		ACTIONS => {
			")" => 3323
		}
	},
	{#State 3222
		ACTIONS => {
			'INNER_SYM' => 1780,
			'ON' => 3324,
			'RIGHT' => 1781,
			'JOIN_SYM' => 1777,
			'STRAIGHT_JOIN' => 1782,
			'LEFT' => 1778,
			'NATURAL' => 1783,
			'CROSS' => 1779
		},
		GOTOS => {
			'normal_join' => 1784
		}
	},
	{#State 3223
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'key_part' => 3325,
			'IDENT_sys' => 297,
			'ident' => 3116
		}
	},
	{#State 3224
		DEFAULT => -85
	},
	{#State 3225
		DEFAULT => -473
	},
	{#State 3226
		ACTIONS => {
			'NUM' => 3326
		}
	},
	{#State 3227
		DEFAULT => -209
	},
	{#State 3228
		ACTIONS => {
			")" => 3327
		}
	},
	{#State 3229
		DEFAULT => -212
	},
	{#State 3230
		ACTIONS => {
			'FOR_SYM' => 3328
		}
	},
	{#State 3231
		DEFAULT => -161
	},
	{#State 3232
		DEFAULT => -136,
		GOTOS => {
			'sp_decls' => 3329
		}
	},
	{#State 3233
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3330,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3234
		ACTIONS => {
			":" => 3331
		}
	},
	{#State 3235
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3332
		}
	},
	{#State 3236
		DEFAULT => -97
	},
	{#State 3237
		DEFAULT => -1880
	},
	{#State 3238
		DEFAULT => -105
	},
	{#State 3239
		ACTIONS => {
			'FROM' => 3334,
			'NEXT_SYM' => 3335
		},
		DEFAULT => -172,
		GOTOS => {
			'sp_opt_fetch_noise' => 3333
		}
	},
	{#State 3240
		ACTIONS => {
			'PHASE_SYM' => 246,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'BLOCK_SYM' => 247,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'LEVEL_SYM' => 248,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'NATIONAL_SYM' => 249,
			'UNCOMMITTED_SYM' => 250,
			'MODIFY_SYM' => 253,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'STRING_SYM' => 254,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'UNTIL_SYM' => 255,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'COMPRESSED_SYM' => 256,
			'INSERT_METHOD' => 257,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'SOUNDS_SYM' => 139,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'BOOL_SYM' => 264,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'SQL_CACHE_SYM' => 265,
			'PROFILES_SYM' => 145,
			'QUERY_SYM' => 266,
			'CHANGED' => 146,
			'RAID_CHUNKS' => 268,
			'SUBJECT_SYM' => 147,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'PRIVILEGES' => 148,
			'DUPLICATE_SYM' => 270,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'MAX_UPDATES_PER_HOUR' => 271,
			'QUICK' => 153,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'TEMPTABLE_SYM' => 154,
			'RAID_0_SYM' => 274,
			'IDENT_QUOTED' => 155,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'VALUE_SYM' => 156,
			'ONE_SHOT_SYM' => 277,
			'MASTER_SERVER_ID_SYM' => 279,
			'COMPACT_SYM' => 157,
			'MIGRATE_SYM' => 280,
			'ROW_FORMAT_SYM' => 281,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'NVARCHAR_SYM' => 283,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'PARTIAL' => 284,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'ENABLE_SYM' => 285,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'ADDDATE_SYM' => 288,
			'MASTER_SYM' => 168,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'SQL_NO_CACHE_SYM' => 170,
			'MASTER_LOG_POS_SYM' => 291,
			'GEOMETRYCOLLECTION' => 171,
			'FOUND_SYM' => 292,
			'RETURNS_SYM' => 172,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'AGGREGATE_SYM' => 295,
			'IMPORT' => 176,
			'IO_SYM' => 296,
			'AGAINST' => 177,
			'PROCESS' => 298,
			'RELAY_LOG_POS_SYM' => 178,
			'MINUTE_SYM' => 299,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'DELAY_KEY_WRITE_SYM' => 303,
			'MULTIPOINT' => 304,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'SUBDATE_SYM' => 180,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RECOVER_SYM' => 182,
			'RELAY_THREAD' => 309,
			'ONE_SYM' => 183,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 313,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'NDBCLUSTER_SYM' => 184,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'REDUNDANT_SYM' => 188,
			'MAX_QUERIES_PER_HOUR' => 322,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'QUARTER_SYM' => 195,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'BTREE_SYM' => 199,
			'MASTER_SSL_CA_SYM' => 333,
			'PASSWORD' => 334,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ROW_SYM' => 204,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'ISSUER_SYM' => 209,
			'GEOMETRY_SYM' => 347,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'AVG_ROW_LENGTH' => 210,
			'HASH_SYM' => 350,
			'SECOND_SYM' => 351,
			'CONNECTION_SYM' => 211,
			'SERIAL_SYM' => 352,
			'TABLESPACE' => 212,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'WORK_SYM' => 213,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'ENUM' => 372,
			'MASTER_SSL_KEY_SYM' => 229,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'FIRST_SYM' => 378,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'FUNCTION_SYM' => 379,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'TABLES' => 380,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'SHUTDOWN' => 382,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword_sp' => 3247,
			'IDENT_sys' => 3249,
			'label_ident' => 3336
		}
	},
	{#State 3241
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'sp_proc_stmts1' => 3338,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'execute' => 45,
			'sp_proc_stmt' => 3337,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3242
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3339,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3243
		DEFAULT => -164
	},
	{#State 3244
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3340
		}
	},
	{#State 3245
		DEFAULT => -182
	},
	{#State 3246
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'sp_proc_stmts1' => 3341,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'execute' => 45,
			'sp_proc_stmt' => 3337,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3247
		DEFAULT => -1389
	},
	{#State 3248
		DEFAULT => -165
	},
	{#State 3249
		DEFAULT => -1388
	},
	{#State 3250
		ACTIONS => {
			'DETERMINISTIC_SYM' => 3342
		}
	},
	{#State 3251
		DEFAULT => -181
	},
	{#State 3252
		DEFAULT => -106
	},
	{#State 3253
		DEFAULT => -166
	},
	{#State 3254
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'sp_if' => 3344,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3343,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3255
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'WHEN_SYM' => 3347,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3346,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'searched_when_clause' => 3345,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'searched_when_clause_list' => 3348,
			'bit_term' => 564
		}
	},
	{#State 3256
		ACTIONS => {
			'PHASE_SYM' => 246,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'BLOCK_SYM' => 247,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'LEVEL_SYM' => 248,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'NATIONAL_SYM' => 249,
			'UNCOMMITTED_SYM' => 250,
			'MODIFY_SYM' => 253,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'STRING_SYM' => 254,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'UNTIL_SYM' => 255,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'COMPRESSED_SYM' => 256,
			'INSERT_METHOD' => 257,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'SOUNDS_SYM' => 139,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'BOOL_SYM' => 264,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'SQL_CACHE_SYM' => 265,
			'PROFILES_SYM' => 145,
			'QUERY_SYM' => 266,
			'CHANGED' => 146,
			'RAID_CHUNKS' => 268,
			'SUBJECT_SYM' => 147,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'PRIVILEGES' => 148,
			'DUPLICATE_SYM' => 270,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'MAX_UPDATES_PER_HOUR' => 271,
			'QUICK' => 153,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'TEMPTABLE_SYM' => 154,
			'RAID_0_SYM' => 274,
			'IDENT_QUOTED' => 155,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'VALUE_SYM' => 156,
			'ONE_SHOT_SYM' => 277,
			'MASTER_SERVER_ID_SYM' => 279,
			'COMPACT_SYM' => 157,
			'MIGRATE_SYM' => 280,
			'ROW_FORMAT_SYM' => 281,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'NVARCHAR_SYM' => 283,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'PARTIAL' => 284,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'ENABLE_SYM' => 285,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'ADDDATE_SYM' => 288,
			'MASTER_SYM' => 168,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'SQL_NO_CACHE_SYM' => 170,
			'MASTER_LOG_POS_SYM' => 291,
			'GEOMETRYCOLLECTION' => 171,
			'FOUND_SYM' => 292,
			'RETURNS_SYM' => 172,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'AGGREGATE_SYM' => 295,
			'IMPORT' => 176,
			'IO_SYM' => 296,
			'AGAINST' => 177,
			'PROCESS' => 298,
			'RELAY_LOG_POS_SYM' => 178,
			'MINUTE_SYM' => 299,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'DELAY_KEY_WRITE_SYM' => 303,
			'MULTIPOINT' => 304,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'SUBDATE_SYM' => 180,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RECOVER_SYM' => 182,
			'RELAY_THREAD' => 309,
			'ONE_SYM' => 183,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 313,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'NDBCLUSTER_SYM' => 184,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'REDUNDANT_SYM' => 188,
			'MAX_QUERIES_PER_HOUR' => 322,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'QUARTER_SYM' => 195,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'BTREE_SYM' => 199,
			'MASTER_SSL_CA_SYM' => 333,
			'PASSWORD' => 334,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ROW_SYM' => 204,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'ISSUER_SYM' => 209,
			'GEOMETRY_SYM' => 347,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'AVG_ROW_LENGTH' => 210,
			'HASH_SYM' => 350,
			'SECOND_SYM' => 351,
			'CONNECTION_SYM' => 211,
			'SERIAL_SYM' => 352,
			'TABLESPACE' => 212,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'WORK_SYM' => 213,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'ENUM' => 372,
			'MASTER_SSL_KEY_SYM' => 229,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'FIRST_SYM' => 378,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'FUNCTION_SYM' => 379,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'TABLES' => 380,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'SHUTDOWN' => 382,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword_sp' => 3247,
			'IDENT_sys' => 3249,
			'label_ident' => 3349
		}
	},
	{#State 3257
		DEFAULT => -127
	},
	{#State 3258
		ACTIONS => {
			'SET' => 2592,
			'NUMERIC_SYM' => 2615,
			'TINYBLOB' => 2620,
			'POINT_SYM' => 2610,
			'TEXT_SYM' => 2621,
			'DECIMAL_SYM' => 2582,
			'BINARY' => 2583,
			'DATETIME' => 2570,
			'NATIONAL_SYM' => 2603,
			'BLOB_SYM' => 2571,
			'NVARCHAR_SYM' => 2611,
			'LONGBLOB' => 2604,
			'NCHAR_SYM' => 2584,
			'TINYINT' => 2572,
			'YEAR_SYM' => 2573,
			'MULTIPOLYGON' => 2594,
			'INT_SYM' => 2574,
			'MULTILINESTRING' => 2617,
			'FLOAT_SYM' => 2605,
			'BIT_SYM' => 2596,
			'ENUM' => 2622,
			'SMALLINT' => 2597,
			'CHAR_SYM' => 2575,
			'GEOMETRYCOLLECTION' => 2586,
			'LONG_SYM' => 2587,
			'VARBINARY' => 2606,
			'TIMESTAMP' => 2589,
			'MEDIUMTEXT' => 2623,
			'DATE_SYM' => 2607,
			'POLYGON' => 2576,
			'FIXED_SYM' => 2598,
			'REAL' => 2577,
			'DOUBLE_SYM' => 2613,
			'LINESTRING' => 2578,
			'TIME_SYM' => 2599,
			'BOOL_SYM' => 2608,
			'MULTIPOINT' => 2614,
			'GEOMETRY_SYM' => 2618,
			'TINYTEXT' => 2590,
			'LONGTEXT' => 2595,
			'MEDIUMINT' => 2600,
			'SERIAL_SYM' => 2619,
			'VARCHAR' => 2601,
			'BOOLEAN_SYM' => 2602,
			'MEDIUMBLOB' => 2581,
			'BIGINT' => 2591
		},
		GOTOS => {
			'int_type' => 2593,
			'spatial_type' => 2579,
			'varchar' => 2588,
			'nvarchar' => 2616,
			'real_type' => 2609,
			'char' => 2580,
			'type' => 3350,
			'nchar' => 2612
		}
	},
	{#State 3259
		DEFAULT => -119
	},
	{#State 3260
		DEFAULT => -122
	},
	{#State 3261
		DEFAULT => -92
	},
	{#State 3262
		ACTIONS => {
			")" => 3351
		}
	},
	{#State 3263
		ACTIONS => {
			'OPTION' => 3352
		}
	},
	{#State 3264
		ACTIONS => {
			'CHECK_SYM' => 3353
		}
	},
	{#State 3265
		ACTIONS => {
			'CHECK_SYM' => 3354
		}
	},
	{#State 3266
		DEFAULT => -1872
	},
	{#State 3267
		ACTIONS => {
			'TEXT_STRING' => 3355
		}
	},
	{#State 3268
		DEFAULT => -1801
	},
	{#State 3269
		ACTIONS => {
			'TEXT_STRING' => 3356
		}
	},
	{#State 3270
		DEFAULT => -1804
	},
	{#State 3271
		ACTIONS => {
			'TEXT_STRING' => 3357
		}
	},
	{#State 3272
		DEFAULT => -1803
	},
	{#State 3273
		DEFAULT => -1802
	},
	{#State 3274
		ACTIONS => {
			'WITH' => -1780,
			";" => -1780,
			'END_OF_INPUT' => -1780,
			'AND_SYM' => 3359
		},
		DEFAULT => -1777,
		GOTOS => {
			'opt_and' => 3358
		}
	},
	{#State 3275
		ACTIONS => {
			'MAX_USER_CONNECTIONS_SYM' => 3362,
			'MAX_QUERIES_PER_HOUR' => 3365,
			'MAX_CONNECTIONS_PER_HOUR' => 3364,
			'MAX_UPDATES_PER_HOUR' => 3363,
			'GRANT' => 3361
		},
		GOTOS => {
			'grant_option_list' => 3366,
			'grant_option' => 3360
		}
	},
	{#State 3276
		DEFAULT => -1739
	},
	{#State 3277
		DEFAULT => -1741
	},
	{#State 3278
		DEFAULT => -1740
	},
	{#State 3279
		ACTIONS => {
			'MASTER_LOG_POS_SYM' => 3367
		}
	},
	{#State 3280
		ACTIONS => {
			")" => 3368
		}
	},
	{#State 3281
		ACTIONS => {
			")" => 3369
		}
	},
	{#State 3282
		ACTIONS => {
			")" => 3370
		}
	},
	{#State 3283
		ACTIONS => {
			")" => 3371
		}
	},
	{#State 3284
		ACTIONS => {
			"," => 3372,
			")" => 3373
		}
	},
	{#State 3285
		ACTIONS => {
			'CHARSET' => 490,
			'CHAR_SYM' => 473
		},
		DEFAULT => -404,
		GOTOS => {
			'charset' => 3374,
			'opt_load_data_charset' => 3375
		}
	},
	{#State 3286
		DEFAULT => -1314
	},
	{#State 3287
		DEFAULT => -1315
	},
	{#State 3288
		DEFAULT => -1312
	},
	{#State 3289
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 3376,
			'TEXT_STRING_literal' => 801
		}
	},
	{#State 3290
		DEFAULT => -1318
	},
	{#State 3291
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 3377,
			'TEXT_STRING_literal' => 801
		}
	},
	{#State 3292
		ACTIONS => {
			'TEXT_STRING' => 554,
			'BIN_NUM' => 800,
			'HEX_NUM' => 798
		},
		GOTOS => {
			'text_string' => 3378,
			'TEXT_STRING_literal' => 801
		}
	},
	{#State 3293
		DEFAULT => -1038
	},
	{#State 3294
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'order_ident' => 3379,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2444,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3295
		ACTIONS => {
			'ROLLUP_SYM' => 3381,
			'CUBE_SYM' => 3380
		}
	},
	{#State 3296
		DEFAULT => -1036
	},
	{#State 3297
		ACTIONS => {
			'PROCEDURE' => 3382
		},
		DEFAULT => -1079,
		GOTOS => {
			'procedure_clause' => 3383
		}
	},
	{#State 3298
		ACTIONS => {
			"," => 3384
		},
		DEFAULT => -1149
	},
	{#State 3299
		DEFAULT => -1155
	},
	{#State 3300
		ACTIONS => {
			'SET_VAR' => 1668,
			'EQ' => 1667
		},
		GOTOS => {
			'equal' => 3385
		}
	},
	{#State 3301
		DEFAULT => -289
	},
	{#State 3302
		ACTIONS => {
			"," => 3223,
			")" => 3386
		}
	},
	{#State 3303
		ACTIONS => {
			"," => 3223,
			")" => 3387
		}
	},
	{#State 3304
		DEFAULT => -308
	},
	{#State 3305
		DEFAULT => -388
	},
	{#State 3306
		DEFAULT => -314
	},
	{#State 3307
		DEFAULT => -481
	},
	{#State 3308
		DEFAULT => -337
	},
	{#State 3309
		DEFAULT => -310
	},
	{#State 3310
		DEFAULT => -315
	},
	{#State 3311
		DEFAULT => -336
	},
	{#State 3312
		ACTIONS => {
			'NULL_SYM' => 3389,
			'DEFAULT' => 3388
		}
	},
	{#State 3313
		ACTIONS => {
			'ACTION' => 3390
		}
	},
	{#State 3314
		DEFAULT => -446
	},
	{#State 3315
		DEFAULT => -441
	},
	{#State 3316
		DEFAULT => -445
	},
	{#State 3317
		DEFAULT => -440
	},
	{#State 3318
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3391
		}
	},
	{#State 3319
		ACTIONS => {
			'MATCH' => 3098,
			'ON' => 3093
		},
		DEFAULT => -436,
		GOTOS => {
			'opt_on_delete_list' => 3092,
			'opt_on_delete_item' => 3096,
			'opt_on_delete' => 3392
		}
	},
	{#State 3320
		ACTIONS => {
			"," => 3218,
			")" => 3393
		}
	},
	{#State 3321
		ACTIONS => {
			"," => 3218,
			")" => 3394
		}
	},
	{#State 3322
		DEFAULT => -995
	},
	{#State 3323
		DEFAULT => -988
	},
	{#State 3324
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3395,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3325
		ACTIONS => {
			'ASC' => 2803,
			'DESC' => 2802
		},
		DEFAULT => -1051,
		GOTOS => {
			'order_dir' => 3396
		}
	},
	{#State 3326
		ACTIONS => {
			")" => 3397
		}
	},
	{#State 3327
		ACTIONS => {
			'ORDER_SYM' => 1613,
			'UNION_SYM' => 1172,
			'LIMIT' => 899
		},
		DEFAULT => -1833,
		GOTOS => {
			'union_list' => 1616,
			'union_opt' => 3398,
			'order_or_limit' => 1614,
			'order_clause' => 1619,
			'limit_clause' => 1617,
			'union_order_or_limit' => 1618
		}
	},
	{#State 3328
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 3399
		}
	},
	{#State 3329
		ACTIONS => {
			'DECLARE_SYM' => 3400
		},
		DEFAULT => -132,
		GOTOS => {
			'sp_decl' => 3401,
			'sp_proc_stmts' => 3402
		}
	},
	{#State 3330
		ACTIONS => {
			'DO_SYM' => 3403
		}
	},
	{#State 3331
		ACTIONS => {
			'BEGIN_SYM' => 3232,
			'WHILE_SYM' => 3233,
			'REPEAT_SYM' => 3246,
			'LOOP_SYM' => 3241
		},
		GOTOS => {
			'sp_unlabeled_control' => 3404
		}
	},
	{#State 3332
		DEFAULT => -169
	},
	{#State 3333
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3405
		}
	},
	{#State 3334
		DEFAULT => -174
	},
	{#State 3335
		ACTIONS => {
			'FROM' => 3406
		}
	},
	{#State 3336
		DEFAULT => -167
	},
	{#State 3337
		ACTIONS => {
			";" => 3407
		}
	},
	{#State 3338
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 3409,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'sp_proc_stmt' => 3408,
			'execute' => 45,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3339
		DEFAULT => -162
	},
	{#State 3340
		DEFAULT => -171
	},
	{#State 3341
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 3410,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'sp_proc_stmt' => 3408,
			'execute' => 45,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3342
		DEFAULT => -107
	},
	{#State 3343
		ACTIONS => {
			'THEN_SYM' => 3411
		}
	},
	{#State 3344
		ACTIONS => {
			'END' => 3412
		}
	},
	{#State 3345
		DEFAULT => -187
	},
	{#State 3346
		ACTIONS => {
			'WHEN_SYM' => 3415
		},
		GOTOS => {
			'simple_when_clause' => 3414,
			'simple_when_clause_list' => 3413
		}
	},
	{#State 3347
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3416,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3348
		ACTIONS => {
			'ELSE' => 3418,
			'WHEN_SYM' => 3347
		},
		DEFAULT => -191,
		GOTOS => {
			'searched_when_clause' => 3417,
			'else_clause_opt' => 3419
		}
	},
	{#State 3349
		DEFAULT => -168
	},
	{#State 3350
		DEFAULT => -96,
		GOTOS => {
			'sp_c_chistics' => 3420
		}
	},
	{#State 3351
		ACTIONS => {
			'ORDER_SYM' => 1613,
			'UNION_SYM' => 1172,
			'LIMIT' => 899
		},
		DEFAULT => -1833,
		GOTOS => {
			'union_list' => 1616,
			'union_opt' => 3421,
			'order_or_limit' => 1614,
			'order_clause' => 1619,
			'limit_clause' => 1617,
			'union_order_or_limit' => 1618
		}
	},
	{#State 3352
		DEFAULT => -1875
	},
	{#State 3353
		ACTIONS => {
			'OPTION' => 3422
		}
	},
	{#State 3354
		ACTIONS => {
			'OPTION' => 3423
		}
	},
	{#State 3355
		DEFAULT => -1781
	},
	{#State 3356
		DEFAULT => -1782
	},
	{#State 3357
		DEFAULT => -1783
	},
	{#State 3358
		ACTIONS => {
			'ISSUER_SYM' => 3269,
			'CIPHER_SYM' => 3271,
			'SUBJECT_SYM' => 3267
		},
		GOTOS => {
			'require_list' => 3424,
			'require_list_element' => 3274
		}
	},
	{#State 3359
		DEFAULT => -1778
	},
	{#State 3360
		DEFAULT => -1808
	},
	{#State 3361
		ACTIONS => {
			'OPTION' => 3425
		}
	},
	{#State 3362
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 3426
		}
	},
	{#State 3363
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 3427
		}
	},
	{#State 3364
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 3428
		}
	},
	{#State 3365
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 3429
		}
	},
	{#State 3366
		ACTIONS => {
			'MAX_USER_CONNECTIONS_SYM' => 3362,
			'MAX_QUERIES_PER_HOUR' => 3365,
			'MAX_CONNECTIONS_PER_HOUR' => 3364,
			'MAX_UPDATES_PER_HOUR' => 3363,
			'GRANT' => 3361
		},
		DEFAULT => -1806,
		GOTOS => {
			'grant_option' => 3430
		}
	},
	{#State 3367
		ACTIONS => {
			'EQ' => 3431
		}
	},
	{#State 3368
		DEFAULT => -369
	},
	{#State 3369
		DEFAULT => -902
	},
	{#State 3370
		DEFAULT => -788
	},
	{#State 3371
		DEFAULT => -845
	},
	{#State 3372
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3432,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3373
		DEFAULT => -778
	},
	{#State 3374
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 1665,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 1666,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 1670,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'charset_name' => 1669,
			'charset_name_or_default' => 3433,
			'ident' => 706
		}
	},
	{#State 3375
		ACTIONS => {
			'COLUMNS' => 2815
		},
		DEFAULT => -1308,
		GOTOS => {
			'opt_field_term' => 3434
		}
	},
	{#State 3376
		DEFAULT => -1313
	},
	{#State 3377
		DEFAULT => -1321
	},
	{#State 3378
		DEFAULT => -1320
	},
	{#State 3379
		ACTIONS => {
			'ASC' => 2803,
			'DESC' => 2802
		},
		DEFAULT => -1051,
		GOTOS => {
			'order_dir' => 3435
		}
	},
	{#State 3380
		DEFAULT => -1040
	},
	{#State 3381
		DEFAULT => -1041
	},
	{#State 3382
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3436
		}
	},
	{#State 3383
		DEFAULT => -608
	},
	{#State 3384
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'simple_ident_nospvar' => 3300,
			'insert_update_elem' => 3437,
			'IDENT_sys' => 297,
			'ident' => 1542,
			'simple_ident_q' => 1540
		}
	},
	{#State 3385
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 2148,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 2149,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'expr_or_default' => 3438,
			'bit_term' => 564
		}
	},
	{#State 3386
		DEFAULT => -290
	},
	{#State 3387
		ACTIONS => {
			'REFERENCES' => 2630
		},
		GOTOS => {
			'references' => 3439
		}
	},
	{#State 3388
		DEFAULT => -449
	},
	{#State 3389
		DEFAULT => -447
	},
	{#State 3390
		DEFAULT => -448
	},
	{#State 3391
		DEFAULT => -434
	},
	{#State 3392
		DEFAULT => -433
	},
	{#State 3393
		DEFAULT => -964
	},
	{#State 3394
		DEFAULT => -967
	},
	{#State 3395
		ACTIONS => {
			"}" => 3440
		}
	},
	{#State 3396
		DEFAULT => -472
	},
	{#State 3397
		DEFAULT => -475
	},
	{#State 3398
		DEFAULT => -213
	},
	{#State 3399
		ACTIONS => {
			'EACH_SYM' => 3441
		}
	},
	{#State 3400
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'EXIT_SYM' => 3445,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'CONTINUE_SYM' => 3446,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'sp_decl_idents' => 3442,
			'ident' => 3444,
			'sp_handler_type' => 3443
		}
	},
	{#State 3401
		ACTIONS => {
			";" => 3447
		}
	},
	{#State 3402
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 3449,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'sp_proc_stmt' => 3448,
			'execute' => 45,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3403
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'sp_proc_stmts1' => 3450,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'execute' => 45,
			'sp_proc_stmt' => 3337,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3404
		ACTIONS => {
			'PHASE_SYM' => 246,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'BLOCK_SYM' => 247,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'LEVEL_SYM' => 248,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'NATIONAL_SYM' => 249,
			'UNCOMMITTED_SYM' => 250,
			'MODIFY_SYM' => 253,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'STRING_SYM' => 254,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'UNTIL_SYM' => 255,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'COMPRESSED_SYM' => 256,
			'INSERT_METHOD' => 257,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'SOUNDS_SYM' => 139,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'BOOL_SYM' => 264,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'SQL_CACHE_SYM' => 265,
			'PROFILES_SYM' => 145,
			'QUERY_SYM' => 266,
			'CHANGED' => 146,
			'RAID_CHUNKS' => 268,
			'SUBJECT_SYM' => 147,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'PRIVILEGES' => 148,
			'DUPLICATE_SYM' => 270,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'MAX_UPDATES_PER_HOUR' => 271,
			'QUICK' => 153,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'TEMPTABLE_SYM' => 154,
			'RAID_0_SYM' => 274,
			'IDENT_QUOTED' => 155,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'VALUE_SYM' => 156,
			'ONE_SHOT_SYM' => 277,
			'MASTER_SERVER_ID_SYM' => 279,
			'COMPACT_SYM' => 157,
			'MIGRATE_SYM' => 280,
			'ROW_FORMAT_SYM' => 281,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'NVARCHAR_SYM' => 283,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'PARTIAL' => 284,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'ENABLE_SYM' => 285,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'ADDDATE_SYM' => 288,
			'MASTER_SYM' => 168,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'SQL_NO_CACHE_SYM' => 170,
			'MASTER_LOG_POS_SYM' => 291,
			'GEOMETRYCOLLECTION' => 171,
			'FOUND_SYM' => 292,
			'RETURNS_SYM' => 172,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'AGGREGATE_SYM' => 295,
			'IMPORT' => 176,
			'IO_SYM' => 296,
			'AGAINST' => 177,
			'PROCESS' => 298,
			'RELAY_LOG_POS_SYM' => 178,
			'MINUTE_SYM' => 299,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'DELAY_KEY_WRITE_SYM' => 303,
			'MULTIPOINT' => 304,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'SUBDATE_SYM' => 180,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RECOVER_SYM' => 182,
			'RELAY_THREAD' => 309,
			'ONE_SYM' => 183,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 313,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'NDBCLUSTER_SYM' => 184,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'REDUNDANT_SYM' => 188,
			'MAX_QUERIES_PER_HOUR' => 322,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'QUARTER_SYM' => 195,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'BTREE_SYM' => 199,
			'MASTER_SSL_CA_SYM' => 333,
			'PASSWORD' => 334,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ROW_SYM' => 204,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'ISSUER_SYM' => 209,
			'GEOMETRY_SYM' => 347,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'AVG_ROW_LENGTH' => 210,
			'HASH_SYM' => 350,
			'SECOND_SYM' => 351,
			'CONNECTION_SYM' => 211,
			'SERIAL_SYM' => 352,
			'TABLESPACE' => 212,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'WORK_SYM' => 213,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'ENUM' => 372,
			'MASTER_SSL_KEY_SYM' => 229,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'FIRST_SYM' => 378,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'FUNCTION_SYM' => 379,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'TABLES' => 380,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'SHUTDOWN' => 382,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -194,
		GOTOS => {
			'keyword_sp' => 3247,
			'IDENT_sys' => 3249,
			'sp_opt_label' => 3452,
			'label_ident' => 3451
		}
	},
	{#State 3405
		ACTIONS => {
			'INTO' => 3453
		}
	},
	{#State 3406
		DEFAULT => -173
	},
	{#State 3407
		DEFAULT => -134
	},
	{#State 3408
		ACTIONS => {
			";" => 3454
		}
	},
	{#State 3409
		ACTIONS => {
			'LOOP_SYM' => 3455
		}
	},
	{#State 3410
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'CONTEXT_SYM' => 289,
			'LOGS_SYM' => 290,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -1648,
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3456,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3411
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'sp_proc_stmts1' => 3457,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'execute' => 45,
			'sp_proc_stmt' => 3337,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3412
		ACTIONS => {
			'IF' => 3458
		}
	},
	{#State 3413
		ACTIONS => {
			'ELSE' => 3418,
			'WHEN_SYM' => 3415
		},
		DEFAULT => -191,
		GOTOS => {
			'simple_when_clause' => 3460,
			'else_clause_opt' => 3459
		}
	},
	{#State 3414
		DEFAULT => -185
	},
	{#State 3415
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3461,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3416
		ACTIONS => {
			'THEN_SYM' => 3462
		}
	},
	{#State 3417
		DEFAULT => -188
	},
	{#State 3418
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'sp_proc_stmts1' => 3463,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'execute' => 45,
			'sp_proc_stmt' => 3337,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3419
		ACTIONS => {
			'END' => 3464
		}
	},
	{#State 3420
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'NOT_SYM' => 1010,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 1721,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'CONTAINS_SYM' => 1722,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'CHAIN_SYM' => 175,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'LANGUAGE_SYM' => 1724,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'READS_SYM' => 1725,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 1726,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'MODIFIES_SYM' => 1727,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'HASH_SYM' => 350,
			'SECOND_SYM' => 351,
			'SERIAL_SYM' => 352,
			'DETERMINISTIC_SYM' => 3252,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 46,
			'ISOLATION' => 354,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 1017,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'SQL_SYM' => 1729,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'not' => 3250,
			'checksum' => 7,
			'rename' => 6,
			'sp_suid' => 1728,
			'statement' => 3231,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'deallocate_or_drop' => 13,
			'sp_chistic' => 3238,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'change' => 15,
			'commit' => 20,
			'flush' => 21,
			'delete' => 22,
			'start' => 23,
			'do' => 24,
			'drop' => 25,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'execute' => 45,
			'update' => 49,
			'sp_unlabeled_control' => 3253,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'alter' => 58,
			'label_ident' => 3234,
			'show' => 64,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'replace' => 71,
			'preload' => 73,
			'grant' => 75,
			'case_stmt_specification' => 3243,
			'sp_labeled_control' => 3248,
			'rollback' => 80,
			'use' => 84,
			'check' => 82,
			'IDENT_sys' => 3249,
			'reset' => 83,
			'xa' => 85,
			'help' => 86,
			'call' => 90,
			'purge' => 88,
			'revoke' => 91,
			'select' => 93,
			'sp_c_chistic' => 3236,
			'analyze' => 98,
			'sp_proc_stmt' => 3465,
			'deallocate' => 99,
			'handler' => 103,
			'keycache' => 102,
			'optimize' => 105
		}
	},
	{#State 3421
		DEFAULT => -1873
	},
	{#State 3422
		DEFAULT => -1877
	},
	{#State 3423
		DEFAULT => -1876
	},
	{#State 3424
		DEFAULT => -1779
	},
	{#State 3425
		DEFAULT => -1809
	},
	{#State 3426
		DEFAULT => -1813
	},
	{#State 3427
		DEFAULT => -1811
	},
	{#State 3428
		DEFAULT => -1812
	},
	{#State 3429
		DEFAULT => -1810
	},
	{#State 3430
		DEFAULT => -1807
	},
	{#State 3431
		ACTIONS => {
			'NUM' => 2305,
			'ULONGLONG_NUM' => 2307,
			'FLOAT_NUM' => 2306,
			'LONG_NUM' => 2304,
			'DECIMAL_NUM' => 2309
		},
		GOTOS => {
			'ulonglong_num' => 3466
		}
	},
	{#State 3432
		ACTIONS => {
			")" => 3467
		}
	},
	{#State 3433
		DEFAULT => -405
	},
	{#State 3434
		ACTIONS => {
			'LINES' => 3017
		},
		DEFAULT => -1316,
		GOTOS => {
			'opt_line_term' => 3468
		}
	},
	{#State 3435
		DEFAULT => -1037
	},
	{#State 3436
		ACTIONS => {
			"(" => 3469
		}
	},
	{#State 3437
		DEFAULT => -1154
	},
	{#State 3438
		DEFAULT => -1156
	},
	{#State 3439
		DEFAULT => -291
	},
	{#State 3440
		DEFAULT => -973
	},
	{#State 3441
		ACTIONS => {
			'ROW_SYM' => 3470
		}
	},
	{#State 3442
		ACTIONS => {
			'SET' => 2592,
			'NUMERIC_SYM' => 2615,
			'TINYBLOB' => 2620,
			'POINT_SYM' => 2610,
			'TEXT_SYM' => 2621,
			'DECIMAL_SYM' => 2582,
			'BINARY' => 2583,
			'DATETIME' => 2570,
			'NATIONAL_SYM' => 2603,
			'BLOB_SYM' => 2571,
			'NVARCHAR_SYM' => 2611,
			'LONGBLOB' => 2604,
			'NCHAR_SYM' => 2584,
			'TINYINT' => 2572,
			'YEAR_SYM' => 2573,
			'MULTIPOLYGON' => 2594,
			'INT_SYM' => 2574,
			'MULTILINESTRING' => 2617,
			'FLOAT_SYM' => 2605,
			'BIT_SYM' => 2596,
			'ENUM' => 2622,
			'SMALLINT' => 2597,
			'CHAR_SYM' => 2575,
			'GEOMETRYCOLLECTION' => 2586,
			'LONG_SYM' => 2587,
			"," => 3472,
			'VARBINARY' => 2606,
			'TIMESTAMP' => 2589,
			'MEDIUMTEXT' => 2623,
			'DATE_SYM' => 2607,
			'POLYGON' => 2576,
			'FIXED_SYM' => 2598,
			'REAL' => 2577,
			'DOUBLE_SYM' => 2613,
			'LINESTRING' => 2578,
			'TIME_SYM' => 2599,
			'BOOL_SYM' => 2608,
			'MULTIPOINT' => 2614,
			'GEOMETRY_SYM' => 2618,
			'TINYTEXT' => 2590,
			'LONGTEXT' => 2595,
			'MEDIUMINT' => 2600,
			'SERIAL_SYM' => 2619,
			'VARCHAR' => 2601,
			'BOOLEAN_SYM' => 2602,
			'MEDIUMBLOB' => 2581,
			'BIGINT' => 2591
		},
		GOTOS => {
			'int_type' => 2593,
			'spatial_type' => 2579,
			'varchar' => 2588,
			'nvarchar' => 2616,
			'real_type' => 2609,
			'char' => 2580,
			'type' => 3471,
			'nchar' => 2612
		}
	},
	{#State 3443
		ACTIONS => {
			'HANDLER_SYM' => 3473
		}
	},
	{#State 3444
		ACTIONS => {
			'CONDITION_SYM' => 3474,
			'CURSOR_SYM' => 3475
		},
		DEFAULT => -157
	},
	{#State 3445
		DEFAULT => -143
	},
	{#State 3446
		DEFAULT => -144
	},
	{#State 3447
		DEFAULT => -137
	},
	{#State 3448
		ACTIONS => {
			";" => 3476
		}
	},
	{#State 3449
		DEFAULT => -196
	},
	{#State 3450
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 3477,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'sp_proc_stmt' => 3408,
			'execute' => 45,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3451
		DEFAULT => -195
	},
	{#State 3452
		DEFAULT => -193
	},
	{#State 3453
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'sp_fetch_list' => 3479,
			'IDENT_sys' => 297,
			'ident' => 3478
		}
	},
	{#State 3454
		DEFAULT => -135
	},
	{#State 3455
		DEFAULT => -197
	},
	{#State 3456
		ACTIONS => {
			'END' => 3480
		}
	},
	{#State 3457
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'ELSE' => 3482,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'ELSEIF_SYM' => 3483,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 46,
			'ISOLATION' => 354,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -178,
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'sp_elseifs' => 3481,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'execute' => 45,
			'sp_proc_stmt' => 3408,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3458
		DEFAULT => -163
	},
	{#State 3459
		ACTIONS => {
			'END' => 3484
		}
	},
	{#State 3460
		DEFAULT => -186
	},
	{#State 3461
		ACTIONS => {
			'THEN_SYM' => 3485
		}
	},
	{#State 3462
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'sp_proc_stmts1' => 3486,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'execute' => 45,
			'sp_proc_stmt' => 3337,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3463
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -192,
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'sp_proc_stmt' => 3408,
			'execute' => 45,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3464
		ACTIONS => {
			'CASE_SYM' => 3487
		}
	},
	{#State 3465
		DEFAULT => -93
	},
	{#State 3466
		ACTIONS => {
			'AND_SYM' => 3488
		}
	},
	{#State 3467
		DEFAULT => -779
	},
	{#State 3468
		ACTIONS => {
			'IGNORE_SYM' => 3490
		},
		DEFAULT => -1322,
		GOTOS => {
			'opt_ignore_lines' => 3489
		}
	},
	{#State 3469
		ACTIONS => {
			")" => -1081
		},
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 3493,
			'procedure_list2' => 3492,
			'procedure_item' => 3494,
			'procedure_list' => 3491
		}
	},
	{#State 3470
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'sp_proc_stmt' => 3495,
			'execute' => 45,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3471
		ACTIONS => {
			'DEFAULT' => 3496
		},
		DEFAULT => -159,
		GOTOS => {
			'sp_opt_default' => 3497
		}
	},
	{#State 3472
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3498
		}
	},
	{#State 3473
		ACTIONS => {
			'FOR_SYM' => 3499
		}
	},
	{#State 3474
		ACTIONS => {
			'FOR_SYM' => 3500
		}
	},
	{#State 3475
		ACTIONS => {
			'FOR_SYM' => 3501
		}
	},
	{#State 3476
		DEFAULT => -133
	},
	{#State 3477
		ACTIONS => {
			'WHILE_SYM' => 3502
		}
	},
	{#State 3478
		DEFAULT => -175
	},
	{#State 3479
		ACTIONS => {
			"," => 3503
		},
		DEFAULT => -170
	},
	{#State 3480
		ACTIONS => {
			'REPEAT_SYM' => 3504
		}
	},
	{#State 3481
		DEFAULT => -177
	},
	{#State 3482
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'sp_proc_stmts1' => 3505,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'execute' => 45,
			'sp_proc_stmt' => 3337,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3483
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'sp_if' => 3506,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3343,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3484
		ACTIONS => {
			'CASE_SYM' => 3507
		}
	},
	{#State 3485
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'sp_proc_stmts1' => 3508,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'execute' => 45,
			'sp_proc_stmt' => 3337,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3486
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -190,
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'sp_proc_stmt' => 3408,
			'execute' => 45,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3487
		DEFAULT => -184
	},
	{#State 3488
		ACTIONS => {
			'MASTER_SERVER_ID_SYM' => 3509
		}
	},
	{#State 3489
		ACTIONS => {
			"(" => 3510
		},
		DEFAULT => -1324,
		GOTOS => {
			'opt_field_or_var_spec' => 3511
		}
	},
	{#State 3490
		ACTIONS => {
			'NUM' => 3512
		}
	},
	{#State 3491
		ACTIONS => {
			")" => 3513
		}
	},
	{#State 3492
		ACTIONS => {
			"," => 3514
		},
		DEFAULT => -1082
	},
	{#State 3493
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3515,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3494
		DEFAULT => -1084
	},
	{#State 3495
		DEFAULT => -1878
	},
	{#State 3496
		ACTIONS => {
			'DATE_ADD_INTERVAL' => 514,
			'REPLACE' => 513,
			'MAX_SYM' => 512,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'VARIANCE_SYM' => 515,
			'CONCAT' => 516,
			'ASCII_SYM' => 517,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'COUNT_SYM' => 518,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'NOT_SYM' => 519,
			'CONVERT_SYM' => 523,
			'YEAR_SYM' => 522,
			'BERKELEY_DB_SYM' => 127,
			'MASTER_SSL_CERT_SYM' => 126,
			'MASTER_POS_WAIT' => 524,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'CHAR_SYM' => 526,
			"+" => 527,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'ENCODE_SYM' => 528,
			'COLLATION_SYM' => 530,
			'POLYGON' => 529,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'RAID_CHUNKSIZE' => 142,
			'UNDEFINED_SYM' => 141,
			'LINESTRING' => 533,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'ROUND' => 534,
			'CHANGED' => 146,
			'FORMAT_SYM' => 535,
			'SUBJECT_SYM' => 147,
			'LINEFROMTEXT' => 536,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'FROM_UNIXTIME' => 537,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'BINARY' => 539,
			'STORAGE_SYM' => 158,
			'UTC_TIMESTAMP_SYM' => 540,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'MICROSECOND_SYM' => 541,
			'CURRENT_USER' => 543,
			'STD_SYM' => 542,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'HOUR_SYM' => 544,
			'NCHAR_SYM' => 164,
			'UNDERSCORE_CHARSET' => 545,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			"(" => 548,
			'CONTAINS_SYM' => 547,
			'GROUP_UNIQUE_USERS' => 546,
			'SQL_NO_CACHE_SYM' => 170,
			'FUNC_ARG1' => 549,
			'GEOMETRYCOLLECTION' => 550,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 551,
			'TIMESTAMP' => 552,
			'CHAIN_SYM' => 175,
			'MASTER_HOST_SYM' => 174,
			'DATE_SUB_INTERVAL' => 555,
			'TEXT_STRING' => 554,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 557,
			'MLINEFROMTEXT' => 558,
			'EXISTS' => 559,
			'UPGRADE_SYM' => 179,
			'DEFAULT' => 561,
			'SUBDATE_SYM' => 562,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 563,
			'RECOVER_SYM' => 182,
			'CURTIME' => 565,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'UNIQUE_USERS' => 567,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			"!" => 568,
			'NULL_SYM' => 569,
			'BENCHMARK_SYM' => 570,
			'ENCRYPT' => 571,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'FRAC_SECOND_SYM' => 192,
			'OLD_PASSWORD' => 573,
			'SUM_SYM' => 574,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 575,
			'GEOMFROMWKB' => 576,
			'ROUTINE_SYM' => 196,
			'MIN_SYM' => 577,
			'MULTIPOLYGON' => 578,
			'LEFT' => 579,
			'LOCKS_SYM' => 198,
			'RAND' => 580,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'CONCAT_WS' => 581,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 582,
			'SIMPLE_SYM' => 205,
			'LOCATE' => 583,
			'TRANSACTION_SYM' => 207,
			'TRIGGERS_SYM' => 206,
			'CHARSET' => 584,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'FIELD_FUNC' => 587,
			'MAKE_SET_SYM' => 588,
			'LAST_SYM' => 214,
			'BACKUP_SYM' => 215,
			'FAULTS_SYM' => 216,
			'MPOLYFROMTEXT' => 589,
			'YEARWEEK' => 592,
			'BIT_OR' => 591,
			'NUM' => 590,
			'DATA_SYM' => 217,
			'INDEXES' => 218,
			'UNIX_TIMESTAMP' => 593,
			'FUNC_ARG2' => 594,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'TRUE_SYM' => 595,
			'WEEK_SYM' => 596,
			'TIMESTAMP_DIFF' => 597,
			'CPU_SYM' => 224,
			'NONE_SYM' => 223,
			'EXTRACT_SYM' => 599,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'BIT_SYM' => 228,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 602,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'TIME_SYM' => 604,
			'ENGINES_SYM' => 237,
			'GEOMCOLLFROMTEXT' => 605,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 240,
			'UDF_RETURNS_SYM' => 239,
			'LAST_INSERT_ID' => 607,
			'PARAM_MARKER' => 606,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			"-" => 608,
			'PHASE_SYM' => 246,
			'GROUP_CONCAT_SYM' => 609,
			'BLOCK_SYM' => 247,
			'VAR_SAMP_SYM' => 610,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BIN_NUM' => 611,
			'FUNC_ARG0' => 612,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'SYSDATE' => 613,
			'MOD_SYM' => 614,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'GREATEST_SYM' => 615,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'LEAST_SYM' => 617,
			'NO_SYM' => 258,
			'INTERVAL_SYM' => 618,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 619,
			'FAST_SYM' => 261,
			'AVG_SYM' => 620,
			'REPEAT_SYM' => 621,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'FALSE_SYM' => 622,
			'MATCH' => 623,
			'DES_ENCRYPT_SYM' => 624,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'BIT_XOR' => 625,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'LOG_SYM' => 626,
			'ELT_FUNC' => 627,
			'MAX_UPDATES_PER_HOUR' => 271,
			'SUBSTRING' => 628,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 629,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 630,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'UTC_DATE_SYM' => 632,
			'VALUES' => 633,
			'SUBSTRING_INDEX' => 634,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'CAST_SYM' => 636,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'BIT_AND' => 637,
			'ADDDATE_SYM' => 638,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'POINTFROMTEXT' => 640,
			'FOUND_SYM' => 292,
			'EXPORT_SET' => 642,
			'UTC_TIME_SYM' => 641,
			'CONCURRENT' => 293,
			'NAME_SYM' => 294,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 645,
			'DECODE_SYM' => 646,
			'LEAVES' => 300,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 647,
			'DELAY_KEY_WRITE_SYM' => 303,
			'HOSTS_SYM' => 305,
			'ROWS_SYM' => 306,
			'DUMPFILE' => 307,
			'POLYFROMTEXT' => 649,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'DAY_SYM' => 651,
			"\@" => 650,
			'ESCAPE_SYM' => 312,
			'PROFILE_SYM' => 314,
			'NCHAR_STRING' => 652,
			'SUSPEND_SYM' => 315,
			'ANY_SYM' => 316,
			'MASTER_USER_SYM' => 317,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'ROW_COUNT_SYM' => 654,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'GEOMFROMTEXT' => 655,
			'RIGHT' => 657,
			'FILE_SYM' => 325,
			'MAX_ROWS' => 327,
			'CONVERT_TZ_SYM' => 658,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 659,
			'VARIABLES' => 331,
			'MPOINTFROMTEXT' => 660,
			'PASSWORD' => 661,
			'MASTER_SSL_CA_SYM' => 333,
			'RAID_TYPE' => 335,
			'SUPER_SYM' => 336,
			'TRUNCATE_SYM' => 662,
			'SAVEPOINT_SYM' => 339,
			'ERRORS' => 338,
			'TEMPORARY' => 340,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'CACHE_SYM' => 348,
			'GEOMETRY_SYM' => 347,
			"{" => 663,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 664,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'STOP_SYM' => 355,
			'ISOLATION' => 354,
			'GET_FORMAT' => 666,
			'TRIM' => 665,
			"~" => 667,
			'AUTO_INC' => 357,
			'DECIMAL_NUM' => 668,
			'DYNAMIC_SYM' => 358,
			'STDDEV_SAMP_SYM' => 669,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 670,
			'TIMESTAMP_ADD' => 671,
			'FUNC_ARG3' => 672,
			'POSITION_SYM' => 674,
			'USER' => 673,
			'DES_DECRYPT_SYM' => 675,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'NOT2_SYM' => 676,
			'DO_SYM' => 365,
			'NOW_SYM' => 677,
			'VIEW_SYM' => 366,
			'CURDATE' => 678,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 680,
			"." => 679,
			'START_SYM' => 371,
			'DATABASE' => 681,
			'ENUM' => 372,
			'MONTH_SYM' => 682,
			'ATAN' => 683,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'COALESCE' => 686,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'text_literal' => 525,
			'variable' => 616,
			'TEXT_STRING_literal' => 653,
			'param_marker' => 566,
			'bit_factor' => 538,
			'NUM_literal' => 684,
			'term' => 601,
			'factor' => 553,
			'literal' => 631,
			'predicate' => 644,
			'IDENT_sys' => 643,
			'expr' => 3516,
			'simple_ident' => 531,
			'bool_factor' => 556,
			'sum_expr' => 635,
			'bool_test' => 572,
			'bool_term' => 520,
			'bool_pri' => 648,
			'simple_expr' => 560,
			'bit_expr' => 585,
			'not2' => 521,
			'ident' => 656,
			'simple_ident_q' => 586,
			'interval_expr' => 598,
			'geometry_function' => 685,
			'keyword_sp' => 287,
			'value_expr' => 639,
			'bit_term' => 564
		}
	},
	{#State 3497
		DEFAULT => -138
	},
	{#State 3498
		DEFAULT => -158
	},
	{#State 3499
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'NOT_SYM' => 1010,
			'SQLSTATE_SYM' => 3517,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 1463,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 1464,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'NUM' => 1466,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 1467,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 1468,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DECIMAL_NUM' => 1469,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'NOT2_SYM' => 1017,
			'SQLEXCEPTION_SYM' => 3525,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'SQLWARNING_SYM' => 3526,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'not' => 3522,
			'ident' => 3523,
			'ulong_num' => 3520,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'sp_hcond_list' => 3524,
			'sp_cond' => 3518,
			'sp_hcond_element' => 3519,
			'sp_hcond' => 3521
		}
	},
	{#State 3500
		ACTIONS => {
			'NUM' => 1466,
			'SQLSTATE_SYM' => 3517,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'sp_cond' => 3527,
			'ulong_num' => 3520
		}
	},
	{#State 3501
		ACTIONS => {
			'SET' => 1,
			'CHECK_SYM' => 50,
			'REPLACE' => 2,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'FLUSH_SYM' => 4,
			'COMMIT_SYM' => 5,
			'ANALYZE_SYM' => 56,
			'CALL_SYM' => 8,
			'REPAIR' => 57,
			'PURGE' => 59,
			'HANDLER_SYM' => 60,
			'CHANGE' => 61,
			'SHOW' => 63,
			'ROLLBACK_SYM' => 62,
			'EXECUTE_SYM' => 65,
			'DROP' => 16,
			'RESET_SYM' => 17,
			'RENAME' => 18,
			'DO_SYM' => 67,
			'ALTER' => 19,
			'USE_SYM' => 66,
			"(" => 70,
			'LOAD' => 72,
			'LOCK_SYM' => 74,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'TRUNCATE_SYM' => 26,
			'SLAVE' => 78,
			'SAVEPOINT_SYM' => 27,
			'HELP_SYM' => 79,
			'KILL_SYM' => 28,
			'UPDATE_SYM' => 30,
			'SELECT_SYM' => 81,
			'INSERT' => 87,
			'RESTORE_SYM' => 92,
			'DEALLOCATE_SYM' => 33,
			'DESC' => 37,
			'RELEASE_SYM' => 38,
			'REVOKE' => 94,
			'CACHE_SYM' => 39,
			'UNLOCK_SYM' => 95,
			'XA_SYM' => 41,
			'OPTIMIZE' => 97,
			'PREPARE_SYM' => 100,
			'CHECKSUM_SYM' => 101,
			'STOP_SYM' => 46,
			'CREATE' => 47,
			'DESCRIBE' => 48
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3528,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'rollback' => 80,
			'reset' => 83,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'sp_cursor_stmt' => 3529,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'execute' => 45,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49
		}
	},
	{#State 3502
		DEFAULT => -198
	},
	{#State 3503
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'ident' => 3530
		}
	},
	{#State 3504
		DEFAULT => -199
	},
	{#State 3505
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -180,
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'sp_proc_stmt' => 3408,
			'execute' => 45,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3506
		DEFAULT => -179
	},
	{#State 3507
		DEFAULT => -183
	},
	{#State 3508
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'DATETIME' => 124,
			'MASTER_PORT_SYM' => 123,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		DEFAULT => -189,
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'sp_proc_stmt' => 3408,
			'execute' => 45,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3509
		ACTIONS => {
			'EQ' => 3531
		}
	},
	{#State 3510
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			")" => 3534,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			"\@" => 3536,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'simple_ident_nospvar' => 3535,
			'field_or_var' => 3533,
			'ident' => 1542,
			'simple_ident_q' => 1540,
			'keyword_sp' => 287,
			'fields_or_vars' => 3532,
			'IDENT_sys' => 297
		}
	},
	{#State 3511
		ACTIONS => {
			'SET' => 3537
		},
		DEFAULT => -1331,
		GOTOS => {
			'opt_load_data_set_spec' => 3538
		}
	},
	{#State 3512
		ACTIONS => {
			'LINES' => 3539
		}
	},
	{#State 3513
		DEFAULT => -1080
	},
	{#State 3514
		DEFAULT => -631,
		GOTOS => {
			'remember_name' => 3493,
			'procedure_item' => 3540
		}
	},
	{#State 3515
		DEFAULT => -1085
	},
	{#State 3516
		DEFAULT => -160
	},
	{#State 3517
		ACTIONS => {
			'VALUE_SYM' => 3541
		},
		DEFAULT => -150,
		GOTOS => {
			'opt_value' => 3542
		}
	},
	{#State 3518
		DEFAULT => -152
	},
	{#State 3519
		DEFAULT => -145
	},
	{#State 3520
		DEFAULT => -148
	},
	{#State 3521
		DEFAULT => -147
	},
	{#State 3522
		ACTIONS => {
			'FOUND_SYM' => 3543
		}
	},
	{#State 3523
		DEFAULT => -153
	},
	{#State 3524
		ACTIONS => {
			'REPLACE' => 2,
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'DROP' => 16,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'UPDATE_SYM' => 30,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 3232,
			'SOUNDS_SYM' => 139,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'WHILE_SYM' => 3233,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'HANDLER_SYM' => 60,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 3235,
			'CHANGE' => 61,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'USE_SYM' => 66,
			'MASTER_SYM' => 168,
			"(" => 70,
			'SQL_NO_CACHE_SYM' => 170,
			'LOCK_SYM' => 74,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'INSERT' => 87,
			'OPTIMIZE' => 97,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 101,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'SET' => 1,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 4,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'FETCH_SYM' => 3239,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			"," => 3545,
			'KILL_SYM' => 28,
			'ROW_SYM' => 204,
			'LEAVE_SYM' => 3240,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'RELEASE_SYM' => 38,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'CHECK_SYM' => 50,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 53,
			'GRANT' => 55,
			'LOOP_SYM' => 3241,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 65,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'LOAD' => 72,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'RETURN_SYM' => 3242,
			'HELP_SYM' => 79,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'EVENTS_SYM' => 234,
			'FIXED_SYM' => 235,
			'RELOAD' => 233,
			'ENGINES_SYM' => 237,
			'TIME_SYM' => 236,
			'SHARE_SYM' => 238,
			'CLOSE_SYM' => 3244,
			'UDF_RETURNS_SYM' => 239,
			'REVOKE' => 94,
			'GRANTS' => 241,
			'UNLOCK_SYM' => 95,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 100,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'RESET_SYM' => 17,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'REPEAT_SYM' => 3246,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'DESC' => 37,
			'QUERY_SYM' => 266,
			'XA_SYM' => 41,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'CREATE' => 47,
			'DUPLICATE_SYM' => 270,
			'DESCRIBE' => 48,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'ANALYZE_SYM' => 56,
			'REPAIR' => 57,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'ROLLBACK_SYM' => 62,
			'NVARCHAR_SYM' => 283,
			'SHOW' => 63,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'SELECT_SYM' => 81,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 5,
			'SQL_THREAD' => 320,
			'CALL_SYM' => 8,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'RENAME' => 18,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'ALTER' => 19,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 26,
			'SAVEPOINT_SYM' => 27,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 33,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 39,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 46,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'IF' => 3254,
			'TIMESTAMP_ADD' => 361,
			'PURGE' => 59,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 67,
			'VIEW_SYM' => 366,
			'ACTION' => 367,
			'SESSION_SYM' => 368,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'CASE_SYM' => 3255,
			'START_SYM' => 77,
			'DELETE_SYM' => 76,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 78,
			'ITERATE_SYM' => 3256,
			'RESTORE_SYM' => 92,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'insert' => 3,
			'lock' => 51,
			'restore' => 52,
			'kill' => 54,
			'checksum' => 7,
			'rename' => 6,
			'statement' => 3231,
			'alter' => 58,
			'savepoint' => 10,
			'slave' => 11,
			'load' => 12,
			'label_ident' => 3234,
			'deallocate_or_drop' => 13,
			'unlock' => 14,
			'searched_case_stmt' => 3245,
			'show' => 64,
			'change' => 15,
			'describe' => 68,
			'select_init' => 69,
			'keyword_sp' => 3247,
			'commit' => 20,
			'replace' => 71,
			'flush' => 21,
			'preload' => 73,
			'delete' => 22,
			'start' => 23,
			'grant' => 75,
			'do' => 24,
			'drop' => 25,
			'sp_labeled_control' => 3248,
			'case_stmt_specification' => 3243,
			'rollback' => 80,
			'reset' => 83,
			'IDENT_sys' => 3249,
			'check' => 82,
			'use' => 84,
			'xa' => 85,
			'help' => 86,
			'revoke' => 91,
			'purge' => 88,
			'call' => 90,
			'backup' => 32,
			'prepare' => 35,
			'set' => 34,
			'select' => 93,
			'create' => 36,
			'truncate' => 40,
			'release' => 42,
			'simple_case_stmt' => 3251,
			'repair' => 44,
			'describe_command' => 43,
			'analyze' => 98,
			'deallocate' => 99,
			'sp_proc_stmt' => 3544,
			'execute' => 45,
			'keycache' => 102,
			'handler' => 103,
			'optimize' => 105,
			'update' => 49,
			'sp_unlabeled_control' => 3253
		}
	},
	{#State 3525
		DEFAULT => -156
	},
	{#State 3526
		DEFAULT => -154
	},
	{#State 3527
		DEFAULT => -139
	},
	{#State 3528
		DEFAULT => -142
	},
	{#State 3529
		DEFAULT => -141
	},
	{#State 3530
		DEFAULT => -176
	},
	{#State 3531
		ACTIONS => {
			'NUM' => 1466,
			'ULONGLONG_NUM' => 1468,
			'FLOAT_NUM' => 1467,
			'LONG_NUM' => 1464,
			'HEX_NUM' => 1463,
			'DECIMAL_NUM' => 1469
		},
		GOTOS => {
			'ulong_num' => 3546
		}
	},
	{#State 3532
		ACTIONS => {
			"," => 3547,
			")" => 3548
		}
	},
	{#State 3533
		DEFAULT => -1328
	},
	{#State 3534
		DEFAULT => -1326
	},
	{#State 3535
		DEFAULT => -1329
	},
	{#State 3536
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'TEXT_STRING' => 703,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'LEX_HOSTNAME' => 707,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'ident_or_text' => 3549,
			'keyword_sp' => 287,
			'TEXT_STRING_sys' => 704,
			'IDENT_sys' => 297,
			'ident' => 706
		}
	},
	{#State 3537
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'simple_ident_nospvar' => 3300,
			'ident' => 1542,
			'simple_ident_q' => 1540,
			'insert_update_list' => 3550,
			'keyword_sp' => 287,
			'insert_update_elem' => 3299,
			'IDENT_sys' => 297
		}
	},
	{#State 3538
		DEFAULT => -1298
	},
	{#State 3539
		DEFAULT => -1323
	},
	{#State 3540
		DEFAULT => -1083
	},
	{#State 3541
		DEFAULT => -151
	},
	{#State 3542
		ACTIONS => {
			'TEXT_STRING' => 554
		},
		GOTOS => {
			'TEXT_STRING_literal' => 3551
		}
	},
	{#State 3543
		DEFAULT => -155
	},
	{#State 3544
		DEFAULT => -140
	},
	{#State 3545
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'NOT_SYM' => 1010,
			'SQLSTATE_SYM' => 3517,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'PACK_KEYS_SYM' => 131,
			'REPLICATION' => 130,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'HEX_NUM' => 1463,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'LONG_NUM' => 1464,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'NUM' => 1466,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'FLOAT_NUM' => 1467,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'ULONGLONG_NUM' => 1468,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DECIMAL_NUM' => 1469,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'NOT2_SYM' => 1017,
			'SQLEXCEPTION_SYM' => 3525,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'SQLWARNING_SYM' => 3526,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'not' => 3522,
			'ident' => 3523,
			'ulong_num' => 3520,
			'keyword_sp' => 287,
			'IDENT_sys' => 297,
			'sp_cond' => 3518,
			'sp_hcond_element' => 3552,
			'sp_hcond' => 3521
		}
	},
	{#State 3546
		DEFAULT => -1200
	},
	{#State 3547
		ACTIONS => {
			'OFFSET_SYM' => 117,
			'IDENT' => 118,
			'CONSISTENT_SYM' => 119,
			'COLUMNS' => 120,
			'ASCII_SYM' => 121,
			'UNKNOWN_SYM' => 122,
			'MASTER_PORT_SYM' => 123,
			'DATETIME' => 124,
			'YEAR_SYM' => 125,
			'MASTER_SSL_CERT_SYM' => 126,
			'BERKELEY_DB_SYM' => 127,
			'RELAY_LOG_FILE_SYM' => 128,
			'MASTER_LOG_FILE_SYM' => 129,
			'REPLICATION' => 130,
			'PACK_KEYS_SYM' => 131,
			'RESOURCES' => 132,
			'AFTER_SYM' => 133,
			'FULL' => 134,
			'DISABLE_SYM' => 135,
			'POLYGON' => 136,
			'COLLATION_SYM' => 137,
			'BEGIN_SYM' => 138,
			'SOUNDS_SYM' => 139,
			'COMMENT_SYM' => 140,
			'UNDEFINED_SYM' => 141,
			'RAID_CHUNKSIZE' => 142,
			'LINESTRING' => 143,
			'IPC_SYM' => 144,
			'PROFILES_SYM' => 145,
			'CHANGED' => 146,
			'SUBJECT_SYM' => 147,
			'PRIVILEGES' => 148,
			'PREV_SYM' => 149,
			'SQL_BUFFER_RESULT' => 150,
			'SECURITY_SYM' => 152,
			'TYPES_SYM' => 151,
			'QUICK' => 153,
			'TEMPTABLE_SYM' => 154,
			'IDENT_QUOTED' => 155,
			'VALUE_SYM' => 156,
			'COMPACT_SYM' => 157,
			'STORAGE_SYM' => 158,
			'MICROSECOND_SYM' => 159,
			'OPEN_SYM' => 160,
			'HANDLER_SYM' => 161,
			'NAMES_SYM' => 162,
			'MUTEX_SYM' => 163,
			'NCHAR_SYM' => 164,
			'HOUR_SYM' => 165,
			'SWAPS_SYM' => 166,
			'IDENTIFIED_SYM' => 167,
			'MASTER_SYM' => 168,
			'CONTAINS_SYM' => 169,
			'SQL_NO_CACHE_SYM' => 170,
			'GEOMETRYCOLLECTION' => 171,
			'RETURNS_SYM' => 172,
			'TIMESTAMP' => 173,
			'MASTER_HOST_SYM' => 174,
			'CHAIN_SYM' => 175,
			'IMPORT' => 176,
			'AGAINST' => 177,
			'RELAY_LOG_POS_SYM' => 178,
			'UPGRADE_SYM' => 179,
			'SUBDATE_SYM' => 180,
			'CHECKSUM_SYM' => 181,
			'RECOVER_SYM' => 182,
			'ONE_SYM' => 183,
			'NDBCLUSTER_SYM' => 184,
			'FLUSH_SYM' => 185,
			'REPEATABLE_SYM' => 186,
			'SWITCHES_SYM' => 187,
			'REDUNDANT_SYM' => 188,
			'PROCESSLIST_SYM' => 189,
			'BINLOG_SYM' => 190,
			'OLD_PASSWORD' => 191,
			'FRAC_SECOND_SYM' => 192,
			'RTREE_SYM' => 193,
			'TYPE_SYM' => 194,
			'QUARTER_SYM' => 195,
			'ROUTINE_SYM' => 196,
			'MULTIPOLYGON' => 197,
			'LOCKS_SYM' => 198,
			'BTREE_SYM' => 199,
			'WARNINGS' => 200,
			'GLOBAL_SYM' => 201,
			'MIN_ROWS' => 202,
			'LANGUAGE_SYM' => 203,
			'ROW_SYM' => 204,
			'SIMPLE_SYM' => 205,
			'TRIGGERS_SYM' => 206,
			'TRANSACTION_SYM' => 207,
			'CHARSET' => 208,
			'ISSUER_SYM' => 209,
			'AVG_ROW_LENGTH' => 210,
			'CONNECTION_SYM' => 211,
			'TABLESPACE' => 212,
			'WORK_SYM' => 213,
			'LAST_SYM' => 214,
			'FAULTS_SYM' => 216,
			'BACKUP_SYM' => 215,
			'INDEXES' => 218,
			'DATA_SYM' => 217,
			'EXECUTE_SYM' => 219,
			'STATUS_SYM' => 220,
			'WEEK_SYM' => 221,
			'TIMESTAMP_DIFF' => 222,
			'NONE_SYM' => 223,
			'CPU_SYM' => 224,
			'CUBE_SYM' => 225,
			'CIPHER_SYM' => 226,
			'MAX_USER_CONNECTIONS_SYM' => 227,
			'BIT_SYM' => 228,
			'MASTER_SSL_KEY_SYM' => 229,
			'HELP_SYM' => 230,
			'SNAPSHOT_SYM' => 231,
			'CODE_SYM' => 232,
			'RELOAD' => 233,
			'FIXED_SYM' => 235,
			'EVENTS_SYM' => 234,
			'TIME_SYM' => 236,
			'ENGINES_SYM' => 237,
			'SHARE_SYM' => 238,
			'UDF_RETURNS_SYM' => 239,
			'CLOSE_SYM' => 240,
			'GRANTS' => 241,
			'X509_SYM' => 242,
			'PREPARE_SYM' => 243,
			'LOCAL_SYM' => 244,
			'BOOLEAN_SYM' => 245,
			'PHASE_SYM' => 246,
			'BLOCK_SYM' => 247,
			'LEVEL_SYM' => 248,
			'UNCOMMITTED_SYM' => 250,
			'NATIONAL_SYM' => 249,
			'BYTE_SYM' => 251,
			'RESET_SYM' => 252,
			'MODIFY_SYM' => 253,
			'STRING_SYM' => 254,
			'UNTIL_SYM' => 255,
			'INSERT_METHOD' => 257,
			'COMPRESSED_SYM' => 256,
			'NO_SYM' => 258,
			'ALGORITHM_SYM' => 259,
			'DATE_SYM' => 260,
			'FAST_SYM' => 261,
			'AVG_SYM' => 262,
			'MEDIUM_SYM' => 263,
			'BOOL_SYM' => 264,
			'SQL_CACHE_SYM' => 265,
			'QUERY_SYM' => 266,
			'XA_SYM' => 267,
			'RAID_CHUNKS' => 268,
			'MASTER_SSL_CIPHER_SYM' => 269,
			'DUPLICATE_SYM' => 270,
			'MAX_UPDATES_PER_HOUR' => 271,
			'RESUME_SYM' => 272,
			'CASCADED' => 273,
			'RAID_0_SYM' => 274,
			'DISCARD' => 275,
			'POINT_SYM' => 276,
			'ONE_SHOT_SYM' => 277,
			'REPAIR' => 278,
			'MASTER_SERVER_ID_SYM' => 279,
			'ROW_FORMAT_SYM' => 281,
			'MIGRATE_SYM' => 280,
			'NVARCHAR_SYM' => 283,
			'ROLLBACK_SYM' => 282,
			'PARTIAL' => 284,
			'ENABLE_SYM' => 285,
			'END' => 286,
			'ADDDATE_SYM' => 288,
			'LOGS_SYM' => 290,
			'CONTEXT_SYM' => 289,
			'MASTER_LOG_POS_SYM' => 291,
			'FOUND_SYM' => 292,
			'NAME_SYM' => 294,
			'CONCURRENT' => 293,
			'AGGREGATE_SYM' => 295,
			'IO_SYM' => 296,
			'PROCESS' => 298,
			'MINUTE_SYM' => 299,
			'MAX_CONNECTIONS_PER_HOUR' => 301,
			'LEAVES' => 300,
			'MERGE_SYM' => 302,
			'MULTIPOINT' => 304,
			'DELAY_KEY_WRITE_SYM' => 303,
			'ROWS_SYM' => 306,
			'HOSTS_SYM' => 305,
			'DUMPFILE' => 307,
			'PAGE_SYM' => 308,
			'RELAY_THREAD' => 309,
			'INVOKER_SYM' => 310,
			'ESCAPE_SYM' => 312,
			'DAY_SYM' => 313,
			"\@" => 3536,
			'PROFILE_SYM' => 314,
			'SUSPEND_SYM' => 315,
			'MASTER_USER_SYM' => 317,
			'ANY_SYM' => 316,
			'MASTER_SSL_CAPATH_SYM' => 318,
			'COMMIT_SYM' => 319,
			'SQL_THREAD' => 320,
			'NEXT_SYM' => 321,
			'MAX_QUERIES_PER_HOUR' => 322,
			'NEW_SYM' => 323,
			'EXTENDED_SYM' => 324,
			'MAX_ROWS' => 327,
			'FILE_SYM' => 325,
			'MEMORY_SYM' => 328,
			'RAID_STRIPED_SYM' => 329,
			'MULTILINESTRING' => 330,
			'VARIABLES' => 331,
			'SUPER_SYM' => 336,
			'RAID_TYPE' => 335,
			'PASSWORD' => 334,
			'MASTER_SSL_CA_SYM' => 333,
			'TRUNCATE_SYM' => 337,
			'TEMPORARY' => 340,
			'ERRORS' => 338,
			'SAVEPOINT_SYM' => 339,
			'CLIENT_SYM' => 341,
			'INNOBASE_SYM' => 342,
			'SOURCE_SYM' => 343,
			'ENGINE_SYM' => 344,
			'ROLLUP_SYM' => 345,
			'DEALLOCATE_SYM' => 346,
			'GEOMETRY_SYM' => 347,
			'CACHE_SYM' => 348,
			'MASTER_CONNECT_RETRY_SYM' => 349,
			'SECOND_SYM' => 351,
			'HASH_SYM' => 350,
			'SERIAL_SYM' => 352,
			'MASTER_SSL_SYM' => 353,
			'ISOLATION' => 354,
			'STOP_SYM' => 355,
			'GET_FORMAT' => 356,
			'AUTO_INC' => 357,
			'DYNAMIC_SYM' => 358,
			'DES_KEY_FILE' => 359,
			'TEXT_SYM' => 360,
			'TIMESTAMP_ADD' => 361,
			'USER' => 362,
			'DIRECTORY_SYM' => 363,
			'COMMITTED_SYM' => 364,
			'DO_SYM' => 365,
			'VIEW_SYM' => 366,
			'SESSION_SYM' => 368,
			'ACTION' => 367,
			'MASTER_PASSWORD_SYM' => 369,
			'SERIALIZABLE_SYM' => 370,
			"." => 679,
			'START_SYM' => 371,
			'ENUM' => 372,
			'MONTH_SYM' => 373,
			'USE_FRM' => 374,
			'SLAVE' => 375,
			'UNICODE_SYM' => 376,
			'RESTORE_SYM' => 377,
			'FIRST_SYM' => 378,
			'FUNCTION_SYM' => 379,
			'TABLES' => 380,
			'SIGNED_SYM' => 381,
			'SHUTDOWN' => 382,
			'MODE_SYM' => 383,
			'DEFINER_SYM' => 385,
			'EXPANSION_SYM' => 384
		},
		GOTOS => {
			'keyword' => 332,
			'keyword_sp' => 287,
			'simple_ident_nospvar' => 3535,
			'IDENT_sys' => 297,
			'field_or_var' => 3553,
			'ident' => 1542,
			'simple_ident_q' => 1540
		}
	},
	{#State 3548
		DEFAULT => -1325
	},
	{#State 3549
		DEFAULT => -1330
	},
	{#State 3550
		ACTIONS => {
			"," => 3384
		},
		DEFAULT => -1332
	},
	{#State 3551
		DEFAULT => -149
	},
	{#State 3552
		DEFAULT => -146
	},
	{#State 3553
		DEFAULT => -1327
	}
],
                                  yyrules  =>
[
	[#Rule 0
		 '$start', 2,
sub { return [@_[1..$#_]] }
	],
	[#Rule 1
		 'query', 1,
sub { bless(["query", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 2
		 'query', 2,
sub { bless(["query", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 3
		 'verb_clause', 1,
sub { bless(["verb_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 4
		 'verb_clause', 1,
sub { bless(["verb_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 5
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 6
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 7
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 8
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 9
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 10
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 11
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 12
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 13
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 14
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 15
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 16
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 17
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 18
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 19
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 20
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 21
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 22
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 23
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 24
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 25
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 26
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 27
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 28
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 29
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 30
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 31
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 32
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 33
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 34
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 35
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 36
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 37
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 38
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 39
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 40
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 41
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 42
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 43
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 44
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 45
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 46
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 47
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 48
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 49
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 50
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 51
		 'statement', 1,
sub { bless(["statement", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 52
		 'deallocate', 3,
sub { bless(["deallocate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 53
		 'deallocate_or_drop', 1,
sub { bless(["deallocate_or_drop", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 54
		 'deallocate_or_drop', 1,
sub { bless(["deallocate_or_drop", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 55
		 'prepare', 4,
sub { bless(["prepare", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 56
		 'prepare_src', 1,
sub { bless(["prepare_src", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 57
		 'prepare_src', 2,
sub { bless(["prepare_src", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 58
		 'execute', 3,
sub { bless(["execute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 59
		 'execute_using', 0,
sub { bless(["execute_using", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 60
		 'execute_using', 2,
sub { bless(["execute_using", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 61
		 'execute_var_list', 3,
sub { bless(["execute_var_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 62
		 'execute_var_list', 1,
sub { bless(["execute_var_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 63
		 'execute_var_ident', 2,
sub { bless(["execute_var_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 64
		 'help', 2,
sub { bless(["help", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 65
		 'change', 4,
sub { bless(["change", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 66
		 'master_defs', 1,
sub { bless(["master_defs", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 67
		 'master_defs', 3,
sub { bless(["master_defs", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 68
		 'master_def', 3,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 69
		 'master_def', 3,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 70
		 'master_def', 3,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 71
		 'master_def', 3,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 72
		 'master_def', 3,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 73
		 'master_def', 3,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 74
		 'master_def', 3,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 75
		 'master_def', 3,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 76
		 'master_def', 3,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 77
		 'master_def', 3,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 78
		 'master_def', 3,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 79
		 'master_def', 1,
sub { bless(["master_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 80
		 'master_file_def', 3,
sub { bless(["master_file_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 81
		 'master_file_def', 3,
sub { bless(["master_file_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 82
		 'master_file_def', 3,
sub { bless(["master_file_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 83
		 'master_file_def', 3,
sub { bless(["master_file_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 84
		 'create', 6,
sub { bless(["create", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 85
		 'create', 10,
sub { bless(["create", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 86
		 'create', 5,
sub { bless(["create", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 87
		 'create', 2,
sub { bless(["create", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 88
		 'create', 4,
sub { bless(["create", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 89
		 'clear_privileges', 0,
sub { bless(["clear_privileges", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 90
		 'sp_name', 3,
sub { bless(["sp_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 91
		 'sp_name', 1,
sub { bless(["sp_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 92
		 'create_function_tail', 4,
sub { bless(["create_function_tail", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 93
		 'create_function_tail', 7,
sub { bless(["create_function_tail", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 94
		 'sp_a_chistics', 0,
sub { bless(["sp_a_chistics", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 95
		 'sp_a_chistics', 2,
sub { bless(["sp_a_chistics", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 96
		 'sp_c_chistics', 0,
sub { bless(["sp_c_chistics", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 97
		 'sp_c_chistics', 2,
sub { bless(["sp_c_chistics", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 98
		 'sp_chistic', 2,
sub { bless(["sp_chistic", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 99
		 'sp_chistic', 2,
sub { bless(["sp_chistic", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 100
		 'sp_chistic', 2,
sub { bless(["sp_chistic", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 101
		 'sp_chistic', 2,
sub { bless(["sp_chistic", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 102
		 'sp_chistic', 3,
sub { bless(["sp_chistic", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 103
		 'sp_chistic', 3,
sub { bless(["sp_chistic", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 104
		 'sp_chistic', 1,
sub { bless(["sp_chistic", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 105
		 'sp_c_chistic', 1,
sub { bless(["sp_c_chistic", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 106
		 'sp_c_chistic', 1,
sub { bless(["sp_c_chistic", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 107
		 'sp_c_chistic', 2,
sub { bless(["sp_c_chistic", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 108
		 'sp_suid', 3,
sub { bless(["sp_suid", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 109
		 'sp_suid', 3,
sub { bless(["sp_suid", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 110
		 'call', 3,
sub { bless(["call", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 111
		 'opt_sp_cparam_list', 0,
sub { bless(["opt_sp_cparam_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 112
		 'opt_sp_cparam_list', 3,
sub { bless(["opt_sp_cparam_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 113
		 'opt_sp_cparams', 0,
sub { bless(["opt_sp_cparams", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 114
		 'opt_sp_cparams', 1,
sub { bless(["opt_sp_cparams", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 115
		 'sp_cparams', 3,
sub { bless(["sp_cparams", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 116
		 'sp_cparams', 1,
sub { bless(["sp_cparams", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 117
		 'sp_fdparam_list', 0,
sub { bless(["sp_fdparam_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 118
		 'sp_fdparam_list', 1,
sub { bless(["sp_fdparam_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 119
		 'sp_fdparams', 3,
sub { bless(["sp_fdparams", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 120
		 'sp_fdparams', 1,
sub { bless(["sp_fdparams", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 121
		 'sp_init_param', 0,
sub { bless(["sp_init_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 122
		 'sp_fdparam', 3,
sub { bless(["sp_fdparam", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 123
		 'sp_pdparam_list', 0,
sub { bless(["sp_pdparam_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 124
		 'sp_pdparam_list', 1,
sub { bless(["sp_pdparam_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 125
		 'sp_pdparams', 3,
sub { bless(["sp_pdparams", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 126
		 'sp_pdparams', 1,
sub { bless(["sp_pdparams", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 127
		 'sp_pdparam', 4,
sub { bless(["sp_pdparam", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 128
		 'sp_opt_inout', 0,
sub { bless(["sp_opt_inout", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 129
		 'sp_opt_inout', 1,
sub { bless(["sp_opt_inout", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 130
		 'sp_opt_inout', 1,
sub { bless(["sp_opt_inout", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 131
		 'sp_opt_inout', 1,
sub { bless(["sp_opt_inout", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 132
		 'sp_proc_stmts', 0,
sub { bless(["sp_proc_stmts", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 133
		 'sp_proc_stmts', 3,
sub { bless(["sp_proc_stmts", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 134
		 'sp_proc_stmts1', 2,
sub { bless(["sp_proc_stmts1", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 135
		 'sp_proc_stmts1', 3,
sub { bless(["sp_proc_stmts1", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 136
		 'sp_decls', 0,
sub { bless(["sp_decls", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 137
		 'sp_decls', 3,
sub { bless(["sp_decls", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 138
		 'sp_decl', 4,
sub { bless(["sp_decl", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 139
		 'sp_decl', 5,
sub { bless(["sp_decl", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 140
		 'sp_decl', 6,
sub { bless(["sp_decl", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 141
		 'sp_decl', 5,
sub { bless(["sp_decl", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 142
		 'sp_cursor_stmt', 1,
sub { bless(["sp_cursor_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 143
		 'sp_handler_type', 1,
sub { bless(["sp_handler_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 144
		 'sp_handler_type', 1,
sub { bless(["sp_handler_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 145
		 'sp_hcond_list', 1,
sub { bless(["sp_hcond_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 146
		 'sp_hcond_list', 3,
sub { bless(["sp_hcond_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 147
		 'sp_hcond_element', 1,
sub { bless(["sp_hcond_element", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 148
		 'sp_cond', 1,
sub { bless(["sp_cond", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 149
		 'sp_cond', 3,
sub { bless(["sp_cond", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 150
		 'opt_value', 0,
sub { bless(["opt_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 151
		 'opt_value', 1,
sub { bless(["opt_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 152
		 'sp_hcond', 1,
sub { bless(["sp_hcond", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 153
		 'sp_hcond', 1,
sub { bless(["sp_hcond", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 154
		 'sp_hcond', 1,
sub { bless(["sp_hcond", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 155
		 'sp_hcond', 2,
sub { bless(["sp_hcond", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 156
		 'sp_hcond', 1,
sub { bless(["sp_hcond", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 157
		 'sp_decl_idents', 1,
sub { bless(["sp_decl_idents", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 158
		 'sp_decl_idents', 3,
sub { bless(["sp_decl_idents", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 159
		 'sp_opt_default', 0,
sub { bless(["sp_opt_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 160
		 'sp_opt_default', 2,
sub { bless(["sp_opt_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 161
		 'sp_proc_stmt', 1,
sub { bless(["sp_proc_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 162
		 'sp_proc_stmt', 2,
sub { bless(["sp_proc_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 163
		 'sp_proc_stmt', 4,
sub { bless(["sp_proc_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 164
		 'sp_proc_stmt', 1,
sub { bless(["sp_proc_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 165
		 'sp_proc_stmt', 1,
sub { bless(["sp_proc_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 166
		 'sp_proc_stmt', 1,
sub { bless(["sp_proc_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 167
		 'sp_proc_stmt', 2,
sub { bless(["sp_proc_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 168
		 'sp_proc_stmt', 2,
sub { bless(["sp_proc_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 169
		 'sp_proc_stmt', 2,
sub { bless(["sp_proc_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 170
		 'sp_proc_stmt', 5,
sub { bless(["sp_proc_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 171
		 'sp_proc_stmt', 2,
sub { bless(["sp_proc_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 172
		 'sp_opt_fetch_noise', 0,
sub { bless(["sp_opt_fetch_noise", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 173
		 'sp_opt_fetch_noise', 2,
sub { bless(["sp_opt_fetch_noise", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 174
		 'sp_opt_fetch_noise', 1,
sub { bless(["sp_opt_fetch_noise", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 175
		 'sp_fetch_list', 1,
sub { bless(["sp_fetch_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 176
		 'sp_fetch_list', 3,
sub { bless(["sp_fetch_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 177
		 'sp_if', 4,
sub { bless(["sp_if", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 178
		 'sp_elseifs', 0,
sub { bless(["sp_elseifs", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 179
		 'sp_elseifs', 2,
sub { bless(["sp_elseifs", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 180
		 'sp_elseifs', 2,
sub { bless(["sp_elseifs", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 181
		 'case_stmt_specification', 1,
sub { bless(["case_stmt_specification", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 182
		 'case_stmt_specification', 1,
sub { bless(["case_stmt_specification", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 183
		 'simple_case_stmt', 6,
sub { bless(["simple_case_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 184
		 'searched_case_stmt', 5,
sub { bless(["searched_case_stmt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 185
		 'simple_when_clause_list', 1,
sub { bless(["simple_when_clause_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 186
		 'simple_when_clause_list', 2,
sub { bless(["simple_when_clause_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 187
		 'searched_when_clause_list', 1,
sub { bless(["searched_when_clause_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 188
		 'searched_when_clause_list', 2,
sub { bless(["searched_when_clause_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 189
		 'simple_when_clause', 4,
sub { bless(["simple_when_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 190
		 'searched_when_clause', 4,
sub { bless(["searched_when_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 191
		 'else_clause_opt', 0,
sub { bless(["else_clause_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 192
		 'else_clause_opt', 2,
sub { bless(["else_clause_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 193
		 'sp_labeled_control', 4,
sub { bless(["sp_labeled_control", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 194
		 'sp_opt_label', 0,
sub { bless(["sp_opt_label", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 195
		 'sp_opt_label', 1,
sub { bless(["sp_opt_label", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 196
		 'sp_unlabeled_control', 4,
sub { bless(["sp_unlabeled_control", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 197
		 'sp_unlabeled_control', 4,
sub { bless(["sp_unlabeled_control", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 198
		 'sp_unlabeled_control', 6,
sub { bless(["sp_unlabeled_control", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 199
		 'sp_unlabeled_control', 6,
sub { bless(["sp_unlabeled_control", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 200
		 'trg_action_time', 1,
sub { bless(["trg_action_time", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 201
		 'trg_action_time', 1,
sub { bless(["trg_action_time", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 202
		 'trg_event', 1,
sub { bless(["trg_event", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 203
		 'trg_event', 1,
sub { bless(["trg_event", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 204
		 'trg_event', 1,
sub { bless(["trg_event", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 205
		 'create2', 2,
sub { bless(["create2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 206
		 'create2', 2,
sub { bless(["create2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 207
		 'create2', 2,
sub { bless(["create2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 208
		 'create2', 4,
sub { bless(["create2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 209
		 'create2a', 4,
sub { bless(["create2a", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 210
		 'create2a', 3,
sub { bless(["create2a", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 211
		 'create3', 0,
sub { bless(["create3", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 212
		 'create3', 4,
sub { bless(["create3", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 213
		 'create3', 6,
sub { bless(["create3", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 214
		 'create_select', 4,
sub { bless(["create_select", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 215
		 'opt_as', 0,
sub { bless(["opt_as", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 216
		 'opt_as', 1,
sub { bless(["opt_as", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 217
		 'opt_create_database_options', 0,
sub { bless(["opt_create_database_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 218
		 'opt_create_database_options', 1,
sub { bless(["opt_create_database_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 219
		 'create_database_options', 1,
sub { bless(["create_database_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 220
		 'create_database_options', 2,
sub { bless(["create_database_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 221
		 'create_database_option', 1,
sub { bless(["create_database_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 222
		 'create_database_option', 1,
sub { bless(["create_database_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 223
		 'opt_table_options', 0,
sub { bless(["opt_table_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 224
		 'opt_table_options', 1,
sub { bless(["opt_table_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 225
		 'table_options', 1,
sub { bless(["table_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 226
		 'table_options', 2,
sub { bless(["table_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 227
		 'table_option', 1,
sub { bless(["table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 228
		 'opt_if_not_exists', 0,
sub { bless(["opt_if_not_exists", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 229
		 'opt_if_not_exists', 3,
sub { bless(["opt_if_not_exists", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 230
		 'opt_create_table_options', 0,
sub { bless(["opt_create_table_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 231
		 'opt_create_table_options', 1,
sub { bless(["opt_create_table_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 232
		 'create_table_options_space_separated', 1,
sub { bless(["create_table_options_space_separated", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 233
		 'create_table_options_space_separated', 2,
sub { bless(["create_table_options_space_separated", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 234
		 'create_table_options', 1,
sub { bless(["create_table_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 235
		 'create_table_options', 2,
sub { bless(["create_table_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 236
		 'create_table_options', 3,
sub { bless(["create_table_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 237
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 238
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 239
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 240
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 241
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 242
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 243
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 244
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 245
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 246
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 247
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 248
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 249
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 250
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 251
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 252
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 253
		 'create_table_option', 5,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 254
		 'create_table_option', 1,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 255
		 'create_table_option', 1,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 256
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 257
		 'create_table_option', 4,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 258
		 'create_table_option', 4,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 259
		 'create_table_option', 3,
sub { bless(["create_table_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 260
		 'default_charset', 4,
sub { bless(["default_charset", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 261
		 'default_collation', 4,
sub { bless(["default_collation", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 262
		 'storage_engines', 1,
sub { bless(["storage_engines", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 263
		 'row_types', 1,
sub { bless(["row_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 264
		 'row_types', 1,
sub { bless(["row_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 265
		 'row_types', 1,
sub { bless(["row_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 266
		 'row_types', 1,
sub { bless(["row_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 267
		 'row_types', 1,
sub { bless(["row_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 268
		 'row_types', 1,
sub { bless(["row_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 269
		 'raid_types', 1,
sub { bless(["raid_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 270
		 'raid_types', 1,
sub { bless(["raid_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 271
		 'raid_types', 1,
sub { bless(["raid_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 272
		 'merge_insert_types', 1,
sub { bless(["merge_insert_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 273
		 'merge_insert_types', 1,
sub { bless(["merge_insert_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 274
		 'merge_insert_types', 1,
sub { bless(["merge_insert_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 275
		 'opt_select_from', 1,
sub { bless(["opt_select_from", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 276
		 'opt_select_from', 2,
sub { bless(["opt_select_from", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 277
		 'udf_func_type', 0,
sub { bless(["udf_func_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 278
		 'udf_func_type', 1,
sub { bless(["udf_func_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 279
		 'udf_type', 1,
sub { bless(["udf_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 280
		 'udf_type', 1,
sub { bless(["udf_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 281
		 'udf_type', 1,
sub { bless(["udf_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 282
		 'udf_type', 1,
sub { bless(["udf_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 283
		 'field_list', 1,
sub { bless(["field_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 284
		 'field_list', 3,
sub { bless(["field_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 285
		 'field_list_item', 1,
sub { bless(["field_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 286
		 'field_list_item', 1,
sub { bless(["field_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 287
		 'column_def', 2,
sub { bless(["column_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 288
		 'column_def', 2,
sub { bless(["column_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 289
		 'key_def', 6,
sub { bless(["key_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 290
		 'key_def', 7,
sub { bless(["key_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 291
		 'key_def', 8,
sub { bless(["key_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 292
		 'key_def', 2,
sub { bless(["key_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 293
		 'key_def', 2,
sub { bless(["key_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 294
		 'opt_check_constraint', 0,
sub { bless(["opt_check_constraint", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 295
		 'opt_check_constraint', 1,
sub { bless(["opt_check_constraint", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 296
		 'check_constraint', 2,
sub { bless(["check_constraint", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 297
		 'opt_constraint', 0,
sub { bless(["opt_constraint", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 298
		 'opt_constraint', 1,
sub { bless(["opt_constraint", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 299
		 'constraint', 2,
sub { bless(["constraint", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 300
		 'field_spec', 3,
sub { bless(["field_spec", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 301
		 'type', 3,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 302
		 'type', 3,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 303
		 'type', 3,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 304
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 305
		 'type', 4,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 306
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 307
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 308
		 'type', 5,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 309
		 'type', 2,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 310
		 'type', 5,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 311
		 'type', 2,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 312
		 'type', 4,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 313
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 314
		 'type', 5,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 315
		 'type', 5,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 316
		 'type', 4,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 317
		 'type', 3,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 318
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 319
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 320
		 'type', 2,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 321
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 322
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 323
		 'type', 2,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 324
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 325
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 326
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 327
		 'type', 2,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 328
		 'type', 3,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 329
		 'type', 2,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 330
		 'type', 3,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 331
		 'type', 2,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 332
		 'type', 2,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 333
		 'type', 3,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 334
		 'type', 3,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 335
		 'type', 3,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 336
		 'type', 5,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 337
		 'type', 5,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 338
		 'type', 2,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 339
		 'type', 1,
sub { bless(["type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 340
		 'spatial_type', 1,
sub { bless(["spatial_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 341
		 'spatial_type', 1,
sub { bless(["spatial_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 342
		 'spatial_type', 1,
sub { bless(["spatial_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 343
		 'spatial_type', 1,
sub { bless(["spatial_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 344
		 'spatial_type', 1,
sub { bless(["spatial_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 345
		 'spatial_type', 1,
sub { bless(["spatial_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 346
		 'spatial_type', 1,
sub { bless(["spatial_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 347
		 'spatial_type', 1,
sub { bless(["spatial_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 348
		 'char', 1,
sub { bless(["char", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 349
		 'nchar', 1,
sub { bless(["nchar", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 350
		 'nchar', 2,
sub { bless(["nchar", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 351
		 'varchar', 2,
sub { bless(["varchar", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 352
		 'varchar', 1,
sub { bless(["varchar", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 353
		 'nvarchar', 2,
sub { bless(["nvarchar", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 354
		 'nvarchar', 1,
sub { bless(["nvarchar", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 355
		 'nvarchar', 2,
sub { bless(["nvarchar", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 356
		 'nvarchar', 3,
sub { bless(["nvarchar", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 357
		 'nvarchar', 2,
sub { bless(["nvarchar", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 358
		 'int_type', 1,
sub { bless(["int_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 359
		 'int_type', 1,
sub { bless(["int_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 360
		 'int_type', 1,
sub { bless(["int_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 361
		 'int_type', 1,
sub { bless(["int_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 362
		 'int_type', 1,
sub { bless(["int_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 363
		 'real_type', 1,
sub { bless(["real_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 364
		 'real_type', 1,
sub { bless(["real_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 365
		 'real_type', 2,
sub { bless(["real_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 366
		 'float_options', 0,
sub { bless(["float_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 367
		 'float_options', 3,
sub { bless(["float_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 368
		 'float_options', 1,
sub { bless(["float_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 369
		 'precision', 5,
sub { bless(["precision", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 370
		 'field_options', 0,
sub { bless(["field_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 371
		 'field_options', 1,
sub { bless(["field_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 372
		 'field_opt_list', 2,
sub { bless(["field_opt_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 373
		 'field_opt_list', 1,
sub { bless(["field_opt_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 374
		 'field_option', 1,
sub { bless(["field_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 375
		 'field_option', 1,
sub { bless(["field_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 376
		 'field_option', 1,
sub { bless(["field_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 377
		 'opt_len', 0,
sub { bless(["opt_len", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 378
		 'opt_len', 3,
sub { bless(["opt_len", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 379
		 'opt_precision', 0,
sub { bless(["opt_precision", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 380
		 'opt_precision', 1,
sub { bless(["opt_precision", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 381
		 'opt_attribute', 0,
sub { bless(["opt_attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 382
		 'opt_attribute', 1,
sub { bless(["opt_attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 383
		 'opt_attribute_list', 2,
sub { bless(["opt_attribute_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 384
		 'opt_attribute_list', 1,
sub { bless(["opt_attribute_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 385
		 'attribute', 1,
sub { bless(["attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 386
		 'attribute', 2,
sub { bless(["attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 387
		 'attribute', 2,
sub { bless(["attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 388
		 'attribute', 4,
sub { bless(["attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 389
		 'attribute', 1,
sub { bless(["attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 390
		 'attribute', 3,
sub { bless(["attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 391
		 'attribute', 2,
sub { bless(["attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 392
		 'attribute', 1,
sub { bless(["attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 393
		 'attribute', 2,
sub { bless(["attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 394
		 'attribute', 2,
sub { bless(["attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 395
		 'attribute', 2,
sub { bless(["attribute", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 396
		 'now_or_signed_literal', 2,
sub { bless(["now_or_signed_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 397
		 'now_or_signed_literal', 1,
sub { bless(["now_or_signed_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 398
		 'charset', 2,
sub { bless(["charset", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 399
		 'charset', 1,
sub { bless(["charset", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 400
		 'charset_name', 1,
sub { bless(["charset_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 401
		 'charset_name', 1,
sub { bless(["charset_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 402
		 'charset_name_or_default', 1,
sub { bless(["charset_name_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 403
		 'charset_name_or_default', 1,
sub { bless(["charset_name_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 404
		 'opt_load_data_charset', 0,
sub { bless(["opt_load_data_charset", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 405
		 'opt_load_data_charset', 2,
sub { bless(["opt_load_data_charset", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 406
		 'old_or_new_charset_name', 1,
sub { bless(["old_or_new_charset_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 407
		 'old_or_new_charset_name', 1,
sub { bless(["old_or_new_charset_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 408
		 'old_or_new_charset_name_or_default', 1,
sub { bless(["old_or_new_charset_name_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 409
		 'old_or_new_charset_name_or_default', 1,
sub { bless(["old_or_new_charset_name_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 410
		 'collation_name', 1,
sub { bless(["collation_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 411
		 'opt_collate', 0,
sub { bless(["opt_collate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 412
		 'opt_collate', 2,
sub { bless(["opt_collate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 413
		 'collation_name_or_default', 1,
sub { bless(["collation_name_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 414
		 'collation_name_or_default', 1,
sub { bless(["collation_name_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 415
		 'opt_default', 0,
sub { bless(["opt_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 416
		 'opt_default', 1,
sub { bless(["opt_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 417
		 'opt_binary', 0,
sub { bless(["opt_binary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 418
		 'opt_binary', 2,
sub { bless(["opt_binary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 419
		 'opt_binary', 1,
sub { bless(["opt_binary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 420
		 'opt_binary', 2,
sub { bless(["opt_binary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 421
		 'opt_binary', 3,
sub { bless(["opt_binary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 422
		 'opt_binary', 2,
sub { bless(["opt_binary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 423
		 'opt_bin_mod', 0,
sub { bless(["opt_bin_mod", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 424
		 'opt_bin_mod', 1,
sub { bless(["opt_bin_mod", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 425
		 'opt_bin_charset', 0,
sub { bless(["opt_bin_charset", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 426
		 'opt_bin_charset', 1,
sub { bless(["opt_bin_charset", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 427
		 'opt_bin_charset', 1,
sub { bless(["opt_bin_charset", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 428
		 'opt_bin_charset', 2,
sub { bless(["opt_bin_charset", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 429
		 'opt_primary', 0,
sub { bless(["opt_primary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 430
		 'opt_primary', 1,
sub { bless(["opt_primary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 431
		 'references', 3,
sub { bless(["references", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 432
		 'opt_ref_list', 1,
sub { bless(["opt_ref_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 433
		 'opt_ref_list', 4,
sub { bless(["opt_ref_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 434
		 'ref_list', 3,
sub { bless(["ref_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 435
		 'ref_list', 1,
sub { bless(["ref_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 436
		 'opt_on_delete', 0,
sub { bless(["opt_on_delete", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 437
		 'opt_on_delete', 1,
sub { bless(["opt_on_delete", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 438
		 'opt_on_delete_list', 2,
sub { bless(["opt_on_delete_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 439
		 'opt_on_delete_list', 1,
sub { bless(["opt_on_delete_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 440
		 'opt_on_delete_item', 3,
sub { bless(["opt_on_delete_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 441
		 'opt_on_delete_item', 3,
sub { bless(["opt_on_delete_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 442
		 'opt_on_delete_item', 2,
sub { bless(["opt_on_delete_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 443
		 'opt_on_delete_item', 2,
sub { bless(["opt_on_delete_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 444
		 'opt_on_delete_item', 2,
sub { bless(["opt_on_delete_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 445
		 'delete_option', 1,
sub { bless(["delete_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 446
		 'delete_option', 1,
sub { bless(["delete_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 447
		 'delete_option', 2,
sub { bless(["delete_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 448
		 'delete_option', 2,
sub { bless(["delete_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 449
		 'delete_option', 2,
sub { bless(["delete_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 450
		 'key_type', 1,
sub { bless(["key_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 451
		 'key_type', 2,
sub { bless(["key_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 452
		 'key_type', 2,
sub { bless(["key_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 453
		 'constraint_key_type', 2,
sub { bless(["constraint_key_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 454
		 'constraint_key_type', 2,
sub { bless(["constraint_key_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 455
		 'key_or_index', 1,
sub { bless(["key_or_index", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 456
		 'key_or_index', 1,
sub { bless(["key_or_index", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 457
		 'opt_key_or_index', 0,
sub { bless(["opt_key_or_index", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 458
		 'opt_key_or_index', 1,
sub { bless(["opt_key_or_index", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 459
		 'keys_or_index', 1,
sub { bless(["keys_or_index", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 460
		 'keys_or_index', 1,
sub { bless(["keys_or_index", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 461
		 'keys_or_index', 1,
sub { bless(["keys_or_index", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 462
		 'opt_unique_or_fulltext', 0,
sub { bless(["opt_unique_or_fulltext", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 463
		 'opt_unique_or_fulltext', 1,
sub { bless(["opt_unique_or_fulltext", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 464
		 'opt_unique_or_fulltext', 1,
sub { bless(["opt_unique_or_fulltext", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 465
		 'opt_unique_or_fulltext', 1,
sub { bless(["opt_unique_or_fulltext", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 466
		 'key_alg', 0,
sub { bless(["key_alg", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 467
		 'key_alg', 2,
sub { bless(["key_alg", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 468
		 'key_alg', 2,
sub { bless(["key_alg", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 469
		 'opt_btree_or_rtree', 1,
sub { bless(["opt_btree_or_rtree", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 470
		 'opt_btree_or_rtree', 1,
sub { bless(["opt_btree_or_rtree", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 471
		 'opt_btree_or_rtree', 1,
sub { bless(["opt_btree_or_rtree", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 472
		 'key_list', 4,
sub { bless(["key_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 473
		 'key_list', 2,
sub { bless(["key_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 474
		 'key_part', 1,
sub { bless(["key_part", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 475
		 'key_part', 4,
sub { bless(["key_part", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 476
		 'opt_ident', 0,
sub { bless(["opt_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 477
		 'opt_ident', 1,
sub { bless(["opt_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 478
		 'opt_component', 0,
sub { bless(["opt_component", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 479
		 'opt_component', 2,
sub { bless(["opt_component", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 480
		 'string_list', 1,
sub { bless(["string_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 481
		 'string_list', 3,
sub { bless(["string_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 482
		 'alter', 5,
sub { bless(["alter", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 483
		 'alter', 4,
sub { bless(["alter", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 484
		 'alter', 4,
sub { bless(["alter", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 485
		 'alter', 4,
sub { bless(["alter", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 486
		 'alter', 10,
sub { bless(["alter", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 487
		 'ident_or_empty', 0,
sub { bless(["ident_or_empty", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 488
		 'ident_or_empty', 1,
sub { bless(["ident_or_empty", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 489
		 'alter_list', 0,
sub { bless(["alter_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 490
		 'alter_list', 2,
sub { bless(["alter_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 491
		 'alter_list', 2,
sub { bless(["alter_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 492
		 'alter_list', 1,
sub { bless(["alter_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 493
		 'alter_list', 3,
sub { bless(["alter_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 494
		 'add_column', 2,
sub { bless(["add_column", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 495
		 'alter_list_item', 3,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 496
		 'alter_list_item', 2,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 497
		 'alter_list_item', 4,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 498
		 'alter_list_item', 5,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 499
		 'alter_list_item', 6,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 500
		 'alter_list_item', 4,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 501
		 'alter_list_item', 4,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 502
		 'alter_list_item', 3,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 503
		 'alter_list_item', 3,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 504
		 'alter_list_item', 2,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 505
		 'alter_list_item', 2,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 506
		 'alter_list_item', 6,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 507
		 'alter_list_item', 5,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 508
		 'alter_list_item', 3,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 509
		 'alter_list_item', 5,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 510
		 'alter_list_item', 1,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 511
		 'alter_list_item', 1,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 512
		 'alter_list_item', 1,
sub { bless(["alter_list_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 513
		 'opt_column', 0,
sub { bless(["opt_column", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 514
		 'opt_column', 1,
sub { bless(["opt_column", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 515
		 'opt_ignore', 0,
sub { bless(["opt_ignore", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 516
		 'opt_ignore', 1,
sub { bless(["opt_ignore", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 517
		 'opt_restrict', 0,
sub { bless(["opt_restrict", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 518
		 'opt_restrict', 1,
sub { bless(["opt_restrict", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 519
		 'opt_restrict', 1,
sub { bless(["opt_restrict", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 520
		 'opt_place', 0,
sub { bless(["opt_place", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 521
		 'opt_place', 2,
sub { bless(["opt_place", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 522
		 'opt_place', 1,
sub { bless(["opt_place", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 523
		 'opt_to', 0,
sub { bless(["opt_to", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 524
		 'opt_to', 1,
sub { bless(["opt_to", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 525
		 'opt_to', 1,
sub { bless(["opt_to", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 526
		 'opt_to', 1,
sub { bless(["opt_to", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 527
		 'slave', 4,
sub { bless(["slave", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 528
		 'slave', 3,
sub { bless(["slave", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 529
		 'slave', 4,
sub { bless(["slave", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 530
		 'slave', 3,
sub { bless(["slave", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 531
		 'start', 3,
sub { bless(["start", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 532
		 'start_transaction_opts', 0,
sub { bless(["start_transaction_opts", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 533
		 'start_transaction_opts', 3,
sub { bless(["start_transaction_opts", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 534
		 'slave_thread_opts', 1,
sub { bless(["slave_thread_opts", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 535
		 'slave_thread_opt_list', 1,
sub { bless(["slave_thread_opt_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 536
		 'slave_thread_opt_list', 3,
sub { bless(["slave_thread_opt_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 537
		 'slave_thread_opt', 0,
sub { bless(["slave_thread_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 538
		 'slave_thread_opt', 1,
sub { bless(["slave_thread_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 539
		 'slave_thread_opt', 1,
sub { bless(["slave_thread_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 540
		 'slave_until', 0,
sub { bless(["slave_until", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 541
		 'slave_until', 2,
sub { bless(["slave_until", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 542
		 'slave_until_opts', 1,
sub { bless(["slave_until_opts", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 543
		 'slave_until_opts', 3,
sub { bless(["slave_until_opts", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 544
		 'restore', 5,
sub { bless(["restore", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 545
		 'backup', 5,
sub { bless(["backup", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 546
		 'checksum', 4,
sub { bless(["checksum", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 547
		 'opt_checksum_type', 0,
sub { bless(["opt_checksum_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 548
		 'opt_checksum_type', 1,
sub { bless(["opt_checksum_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 549
		 'opt_checksum_type', 1,
sub { bless(["opt_checksum_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 550
		 'repair', 5,
sub { bless(["repair", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 551
		 'opt_mi_repair_type', 0,
sub { bless(["opt_mi_repair_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 552
		 'opt_mi_repair_type', 1,
sub { bless(["opt_mi_repair_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 553
		 'mi_repair_types', 1,
sub { bless(["mi_repair_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 554
		 'mi_repair_types', 2,
sub { bless(["mi_repair_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 555
		 'mi_repair_type', 1,
sub { bless(["mi_repair_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 556
		 'mi_repair_type', 1,
sub { bless(["mi_repair_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 557
		 'mi_repair_type', 1,
sub { bless(["mi_repair_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 558
		 'analyze', 5,
sub { bless(["analyze", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 559
		 'check', 4,
sub { bless(["check", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 560
		 'opt_mi_check_type', 0,
sub { bless(["opt_mi_check_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 561
		 'opt_mi_check_type', 1,
sub { bless(["opt_mi_check_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 562
		 'mi_check_types', 1,
sub { bless(["mi_check_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 563
		 'mi_check_types', 2,
sub { bless(["mi_check_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 564
		 'mi_check_type', 1,
sub { bless(["mi_check_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 565
		 'mi_check_type', 1,
sub { bless(["mi_check_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 566
		 'mi_check_type', 1,
sub { bless(["mi_check_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 567
		 'mi_check_type', 1,
sub { bless(["mi_check_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 568
		 'mi_check_type', 1,
sub { bless(["mi_check_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 569
		 'mi_check_type', 2,
sub { bless(["mi_check_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 570
		 'optimize', 5,
sub { bless(["optimize", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 571
		 'opt_no_write_to_binlog', 0,
sub { bless(["opt_no_write_to_binlog", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 572
		 'opt_no_write_to_binlog', 1,
sub { bless(["opt_no_write_to_binlog", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 573
		 'opt_no_write_to_binlog', 1,
sub { bless(["opt_no_write_to_binlog", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 574
		 'rename', 3,
sub { bless(["rename", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 575
		 'rename', 4,
sub { bless(["rename", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 576
		 'rename_list', 3,
sub { bless(["rename_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 577
		 'rename_list', 5,
sub { bless(["rename_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 578
		 'table_to_table_list', 1,
sub { bless(["table_to_table_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 579
		 'table_to_table_list', 3,
sub { bless(["table_to_table_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 580
		 'table_to_table', 3,
sub { bless(["table_to_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 581
		 'keycache', 5,
sub { bless(["keycache", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 582
		 'keycache_list', 1,
sub { bless(["keycache_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 583
		 'keycache_list', 3,
sub { bless(["keycache_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 584
		 'assign_to_keycache', 2,
sub { bless(["assign_to_keycache", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 585
		 'key_cache_name', 1,
sub { bless(["key_cache_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 586
		 'key_cache_name', 1,
sub { bless(["key_cache_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 587
		 'preload', 5,
sub { bless(["preload", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 588
		 'preload_list', 1,
sub { bless(["preload_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 589
		 'preload_list', 3,
sub { bless(["preload_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 590
		 'preload_keys', 3,
sub { bless(["preload_keys", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 591
		 'cache_keys_spec', 1,
sub { bless(["cache_keys_spec", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 592
		 'cache_key_list_or_empty', 0,
sub { bless(["cache_key_list_or_empty", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 593
		 'cache_key_list_or_empty', 4,
sub { bless(["cache_key_list_or_empty", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 594
		 'opt_ignore_leaves', 0,
sub { bless(["opt_ignore_leaves", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 595
		 'opt_ignore_leaves', 2,
sub { bless(["opt_ignore_leaves", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 596
		 'select', 1,
sub { bless(["select", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 597
		 'select_init', 2,
sub { bless(["select_init", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 598
		 'select_init', 4,
sub { bless(["select_init", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 599
		 'select_paren', 2,
sub { bless(["select_paren", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 600
		 'select_paren', 3,
sub { bless(["select_paren", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 601
		 'select_init2', 2,
sub { bless(["select_init2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 602
		 'select_part2', 4,
sub { bless(["select_part2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 603
		 'select_into', 2,
sub { bless(["select_into", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 604
		 'select_into', 1,
sub { bless(["select_into", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 605
		 'select_into', 1,
sub { bless(["select_into", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 606
		 'select_into', 2,
sub { bless(["select_into", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 607
		 'select_into', 2,
sub { bless(["select_into", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 608
		 'select_from', 8,
sub { bless(["select_from", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 609
		 'select_from', 4,
sub { bless(["select_from", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 610
		 'select_options', 0,
sub { bless(["select_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 611
		 'select_options', 1,
sub { bless(["select_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 612
		 'select_option_list', 2,
sub { bless(["select_option_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 613
		 'select_option_list', 1,
sub { bless(["select_option_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 614
		 'select_option', 1,
sub { bless(["select_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 615
		 'select_option', 1,
sub { bless(["select_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 616
		 'select_option', 1,
sub { bless(["select_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 617
		 'select_option', 1,
sub { bless(["select_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 618
		 'select_option', 1,
sub { bless(["select_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 619
		 'select_option', 1,
sub { bless(["select_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 620
		 'select_option', 1,
sub { bless(["select_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 621
		 'select_option', 1,
sub { bless(["select_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 622
		 'select_option', 1,
sub { bless(["select_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 623
		 'select_option', 1,
sub { bless(["select_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 624
		 'select_lock_type', 0,
sub { bless(["select_lock_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 625
		 'select_lock_type', 2,
sub { bless(["select_lock_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 626
		 'select_lock_type', 4,
sub { bless(["select_lock_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 627
		 'select_item_list', 3,
sub { bless(["select_item_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 628
		 'select_item_list', 1,
sub { bless(["select_item_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 629
		 'select_item_list', 1,
sub { bless(["select_item_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 630
		 'select_item', 4,
sub { bless(["select_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 631
		 'remember_name', 0,
sub { bless(["remember_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 632
		 'remember_end', 0,
sub { bless(["remember_end", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 633
		 'select_item2', 1,
sub { bless(["select_item2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 634
		 'select_item2', 1,
sub { bless(["select_item2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 635
		 'select_alias', 0,
sub { bless(["select_alias", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 636
		 'select_alias', 2,
sub { bless(["select_alias", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 637
		 'select_alias', 2,
sub { bless(["select_alias", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 638
		 'select_alias', 1,
sub { bless(["select_alias", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 639
		 'select_alias', 1,
sub { bless(["select_alias", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 640
		 'optional_braces', 0,
sub { bless(["optional_braces", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 641
		 'optional_braces', 2,
sub { bless(["optional_braces", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 642
		 'expr', 2,
sub { bless(["expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 643
		 'bool_or_expr', 0,
sub { bless(["bool_or_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 644
		 'bool_or_expr', 3,
sub { bless(["bool_or_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 645
		 'bool_term', 3,
sub { bless(["bool_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 646
		 'bool_term', 2,
sub { bless(["bool_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 647
		 'bool_and_expr', 0,
sub { bless(["bool_and_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 648
		 'bool_and_expr', 3,
sub { bless(["bool_and_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 649
		 'bool_factor', 2,
sub { bless(["bool_factor", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 650
		 'bool_factor', 1,
sub { bless(["bool_factor", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 651
		 'bool_test', 3,
sub { bless(["bool_test", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 652
		 'bool_test', 4,
sub { bless(["bool_test", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 653
		 'bool_test', 3,
sub { bless(["bool_test", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 654
		 'bool_test', 4,
sub { bless(["bool_test", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 655
		 'bool_test', 3,
sub { bless(["bool_test", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 656
		 'bool_test', 4,
sub { bless(["bool_test", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 657
		 'bool_test', 1,
sub { bless(["bool_test", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 658
		 'bool_pri', 3,
sub { bless(["bool_pri", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 659
		 'bool_pri', 4,
sub { bless(["bool_pri", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 660
		 'bool_pri', 3,
sub { bless(["bool_pri", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 661
		 'bool_pri', 3,
sub { bless(["bool_pri", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 662
		 'bool_pri', 6,
sub { bless(["bool_pri", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 663
		 'bool_pri', 1,
sub { bless(["bool_pri", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 664
		 'predicate', 5,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 665
		 'predicate', 6,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 666
		 'predicate', 5,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 667
		 'predicate', 7,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 668
		 'predicate', 6,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 669
		 'predicate', 8,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 670
		 'predicate', 5,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 671
		 'predicate', 6,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 672
		 'predicate', 4,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 673
		 'predicate', 4,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 674
		 'predicate', 5,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 675
		 'predicate', 3,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 676
		 'predicate', 4,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 677
		 'predicate', 1,
sub { bless(["predicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 678
		 'bit_expr', 3,
sub { bless(["bit_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 679
		 'bit_expr', 1,
sub { bless(["bit_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 680
		 'bit_term', 3,
sub { bless(["bit_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 681
		 'bit_term', 1,
sub { bless(["bit_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 682
		 'bit_factor', 3,
sub { bless(["bit_factor", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 683
		 'bit_factor', 3,
sub { bless(["bit_factor", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 684
		 'bit_factor', 1,
sub { bless(["bit_factor", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 685
		 'value_expr', 3,
sub { bless(["value_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 686
		 'value_expr', 3,
sub { bless(["value_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 687
		 'value_expr', 4,
sub { bless(["value_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 688
		 'value_expr', 4,
sub { bless(["value_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 689
		 'value_expr', 1,
sub { bless(["value_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 690
		 'term', 3,
sub { bless(["term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 691
		 'term', 3,
sub { bless(["term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 692
		 'term', 3,
sub { bless(["term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 693
		 'term', 3,
sub { bless(["term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 694
		 'term', 3,
sub { bless(["term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 695
		 'term', 1,
sub { bless(["term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 696
		 'factor', 3,
sub { bless(["factor", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 697
		 'factor', 1,
sub { bless(["factor", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 698
		 'or', 1,
sub { bless(["or", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 699
		 'or', 1,
sub { bless(["or", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 700
		 'and', 1,
sub { bless(["and", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 701
		 'and', 1,
sub { bless(["and", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 702
		 'not', 1,
sub { bless(["not", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 703
		 'not', 1,
sub { bless(["not", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 704
		 'not2', 1,
sub { bless(["not2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 705
		 'not2', 1,
sub { bless(["not2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 706
		 'comp_op', 1,
sub { bless(["comp_op", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 707
		 'comp_op', 1,
sub { bless(["comp_op", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 708
		 'comp_op', 1,
sub { bless(["comp_op", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 709
		 'comp_op', 1,
sub { bless(["comp_op", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 710
		 'comp_op', 1,
sub { bless(["comp_op", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 711
		 'comp_op', 1,
sub { bless(["comp_op", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 712
		 'all_or_any', 1,
sub { bless(["all_or_any", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 713
		 'all_or_any', 1,
sub { bless(["all_or_any", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 714
		 'interval_expr', 2,
sub { bless(["interval_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 715
		 'simple_expr', 1,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 716
		 'simple_expr', 3,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 717
		 'simple_expr', 1,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 718
		 'simple_expr', 1,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 719
		 'simple_expr', 1,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 720
		 'simple_expr', 1,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 721
		 'simple_expr', 3,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 722
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 723
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 724
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 725
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 726
		 'simple_expr', 3,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 727
		 'simple_expr', 3,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 728
		 'simple_expr', 5,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 729
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 730
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 731
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 732
		 'simple_expr', 7,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 733
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 734
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 735
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 736
		 'simple_expr', 5,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 737
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 738
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 739
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 740
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 741
		 'simple_expr', 3,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 742
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 743
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 744
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 745
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 746
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 747
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 748
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 749
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 750
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 751
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 752
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 753
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 754
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 755
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 756
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 757
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 758
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 759
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 760
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 761
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 762
		 'simple_expr', 7,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 763
		 'simple_expr', 7,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 764
		 'simple_expr', 3,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 765
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 766
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 767
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 768
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 769
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 770
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 771
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 772
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 773
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 774
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 775
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 776
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 777
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 778
		 'simple_expr', 10,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 779
		 'simple_expr', 12,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 780
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 781
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 782
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 783
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 784
		 'simple_expr', 1,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 785
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 786
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 787
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 788
		 'simple_expr', 10,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 789
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 790
		 'simple_expr', 1,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 791
		 'simple_expr', 3,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 792
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 793
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 794
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 795
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 796
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 797
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 798
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 799
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 800
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 801
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 802
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 803
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 804
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 805
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 806
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 807
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 808
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 809
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 810
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 811
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 812
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 813
		 'simple_expr', 3,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 814
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 815
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 816
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 817
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 818
		 'simple_expr', 3,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 819
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 820
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 821
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 822
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 823
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 824
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 825
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 826
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 827
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 828
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 829
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 830
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 831
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 832
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 833
		 'simple_expr', 8,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 834
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 835
		 'simple_expr', 7,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 836
		 'simple_expr', 7,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 837
		 'simple_expr', 7,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 838
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 839
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 840
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 841
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 842
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 843
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 844
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 845
		 'simple_expr', 10,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 846
		 'simple_expr', 3,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 847
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 848
		 'simple_expr', 3,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 849
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 850
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 851
		 'simple_expr', 2,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 852
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 853
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 854
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 855
		 'simple_expr', 4,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 856
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 857
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 858
		 'simple_expr', 6,
sub { bless(["simple_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 859
		 'geometry_function', 6,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 860
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 861
		 'geometry_function', 6,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 862
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 863
		 'geometry_function', 6,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 864
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 865
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 866
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 867
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 868
		 'geometry_function', 6,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 869
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 870
		 'geometry_function', 6,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 871
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 872
		 'geometry_function', 6,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 873
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 874
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 875
		 'geometry_function', 6,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 876
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 877
		 'geometry_function', 6,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 878
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 879
		 'geometry_function', 6,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 880
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 881
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 882
		 'geometry_function', 6,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 883
		 'geometry_function', 4,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 884
		 'geometry_function', 6,
sub { bless(["geometry_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 885
		 'fulltext_options', 0,
sub { bless(["fulltext_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 886
		 'fulltext_options', 3,
sub { bless(["fulltext_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 887
		 'fulltext_options', 3,
sub { bless(["fulltext_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 888
		 'udf_expr_list', 0,
sub { bless(["udf_expr_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 889
		 'udf_expr_list', 1,
sub { bless(["udf_expr_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 890
		 'udf_expr_list2', 1,
sub { bless(["udf_expr_list2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 891
		 'udf_expr_list3', 1,
sub { bless(["udf_expr_list3", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 892
		 'udf_expr_list3', 3,
sub { bless(["udf_expr_list3", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 893
		 'udf_expr', 4,
sub { bless(["udf_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 894
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 895
		 'sum_expr', 5,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 896
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 897
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 898
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 899
		 'sum_expr', 5,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 900
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 901
		 'sum_expr', 5,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 902
		 'sum_expr', 10,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 903
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 904
		 'sum_expr', 5,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 905
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 906
		 'sum_expr', 5,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 907
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 908
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 909
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 910
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 911
		 'sum_expr', 4,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 912
		 'sum_expr', 5,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 913
		 'sum_expr', 7,
sub { bless(["sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 914
		 'variable', 2,
sub { bless(["variable", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 915
		 'variable_aux', 3,
sub { bless(["variable_aux", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 916
		 'variable_aux', 1,
sub { bless(["variable_aux", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 917
		 'variable_aux', 4,
sub { bless(["variable_aux", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 918
		 'opt_distinct', 0,
sub { bless(["opt_distinct", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 919
		 'opt_distinct', 1,
sub { bless(["opt_distinct", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 920
		 'opt_gconcat_separator', 0,
sub { bless(["opt_gconcat_separator", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 921
		 'opt_gconcat_separator', 2,
sub { bless(["opt_gconcat_separator", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 922
		 'opt_gorder_clause', 0,
sub { bless(["opt_gorder_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 923
		 'opt_gorder_clause', 1,
sub { bless(["opt_gorder_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 924
		 'in_sum_expr', 2,
sub { bless(["in_sum_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 925
		 'cast_type', 2,
sub { bless(["cast_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 926
		 'cast_type', 3,
sub { bless(["cast_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 927
		 'cast_type', 2,
sub { bless(["cast_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 928
		 'cast_type', 1,
sub { bless(["cast_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 929
		 'cast_type', 2,
sub { bless(["cast_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 930
		 'cast_type', 1,
sub { bless(["cast_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 931
		 'cast_type', 2,
sub { bless(["cast_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 932
		 'cast_type', 1,
sub { bless(["cast_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 933
		 'cast_type', 1,
sub { bless(["cast_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 934
		 'cast_type', 1,
sub { bless(["cast_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 935
		 'cast_type', 2,
sub { bless(["cast_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 936
		 'opt_expr_list', 0,
sub { bless(["opt_expr_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 937
		 'opt_expr_list', 1,
sub { bless(["opt_expr_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 938
		 'expr_list', 1,
sub { bless(["expr_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 939
		 'expr_list2', 1,
sub { bless(["expr_list2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 940
		 'expr_list2', 3,
sub { bless(["expr_list2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 941
		 'ident_list_arg', 1,
sub { bless(["ident_list_arg", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 942
		 'ident_list_arg', 3,
sub { bless(["ident_list_arg", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 943
		 'ident_list', 1,
sub { bless(["ident_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 944
		 'ident_list2', 1,
sub { bless(["ident_list2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 945
		 'ident_list2', 3,
sub { bless(["ident_list2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 946
		 'opt_expr', 0,
sub { bless(["opt_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 947
		 'opt_expr', 1,
sub { bless(["opt_expr", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 948
		 'opt_else', 0,
sub { bless(["opt_else", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 949
		 'opt_else', 2,
sub { bless(["opt_else", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 950
		 'when_list', 4,
sub { bless(["when_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 951
		 'when_list', 5,
sub { bless(["when_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 952
		 'table_ref', 1,
sub { bless(["table_ref", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 953
		 'table_ref', 1,
sub { bless(["table_ref", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 954
		 'join_table_list', 1,
sub { bless(["join_table_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 955
		 'derived_table_list', 1,
sub { bless(["derived_table_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 956
		 'derived_table_list', 3,
sub { bless(["derived_table_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 957
		 'join_table', 3,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 958
		 'join_table', 3,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 959
		 'join_table', 5,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 960
		 'join_table', 5,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 961
		 'join_table', 7,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 962
		 'join_table', 4,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 963
		 'join_table', 7,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 964
		 'join_table', 9,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 965
		 'join_table', 6,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 966
		 'join_table', 7,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 967
		 'join_table', 9,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 968
		 'join_table', 6,
sub { bless(["join_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 969
		 'normal_join', 1,
sub { bless(["normal_join", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 970
		 'normal_join', 2,
sub { bless(["normal_join", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 971
		 'normal_join', 2,
sub { bless(["normal_join", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 972
		 'table_factor', 3,
sub { bless(["table_factor", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 973
		 'table_factor', 10,
sub { bless(["table_factor", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 974
		 'table_factor', 3,
sub { bless(["table_factor", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 975
		 'table_factor', 6,
sub { bless(["table_factor", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 976
		 'select_derived', 2,
sub { bless(["select_derived", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 977
		 'select_derived2', 3,
sub { bless(["select_derived2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 978
		 'get_select_lex', 0,
sub { bless(["get_select_lex", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 979
		 'select_derived_init', 1,
sub { bless(["select_derived_init", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 980
		 'opt_outer', 0,
sub { bless(["opt_outer", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 981
		 'opt_outer', 1,
sub { bless(["opt_outer", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 982
		 'opt_for_join', 0,
sub { bless(["opt_for_join", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 983
		 'opt_for_join', 2,
sub { bless(["opt_for_join", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 984
		 'opt_key_definition', 0,
sub { bless(["opt_key_definition", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 985
		 'opt_key_definition', 2,
sub { bless(["opt_key_definition", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 986
		 'opt_key_definition', 2,
sub { bless(["opt_key_definition", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 987
		 'opt_key_definition', 2,
sub { bless(["opt_key_definition", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 988
		 'key_usage_list', 5,
sub { bless(["key_usage_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 989
		 'key_list_or_empty', 0,
sub { bless(["key_list_or_empty", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 990
		 'key_list_or_empty', 1,
sub { bless(["key_list_or_empty", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 991
		 'key_usage_list2', 3,
sub { bless(["key_usage_list2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 992
		 'key_usage_list2', 1,
sub { bless(["key_usage_list2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 993
		 'key_usage_list2', 1,
sub { bless(["key_usage_list2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 994
		 'using_list', 1,
sub { bless(["using_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 995
		 'using_list', 3,
sub { bless(["using_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 996
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 997
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 998
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 999
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1000
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1001
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1002
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1003
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1004
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1005
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1006
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1007
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1008
		 'interval', 1,
sub { bless(["interval", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1009
		 'interval_time_st', 1,
sub { bless(["interval_time_st", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1010
		 'interval_time_st', 1,
sub { bless(["interval_time_st", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1011
		 'interval_time_st', 1,
sub { bless(["interval_time_st", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1012
		 'interval_time_st', 1,
sub { bless(["interval_time_st", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1013
		 'interval_time_st', 1,
sub { bless(["interval_time_st", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1014
		 'interval_time_st', 1,
sub { bless(["interval_time_st", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1015
		 'interval_time_st', 1,
sub { bless(["interval_time_st", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1016
		 'interval_time_st', 1,
sub { bless(["interval_time_st", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1017
		 'interval_time_st', 1,
sub { bless(["interval_time_st", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1018
		 'date_time_type', 1,
sub { bless(["date_time_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1019
		 'date_time_type', 1,
sub { bless(["date_time_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1020
		 'date_time_type', 1,
sub { bless(["date_time_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1021
		 'date_time_type', 1,
sub { bless(["date_time_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1022
		 'table_alias', 0,
sub { bless(["table_alias", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1023
		 'table_alias', 1,
sub { bless(["table_alias", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1024
		 'table_alias', 1,
sub { bless(["table_alias", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1025
		 'opt_table_alias', 0,
sub { bless(["opt_table_alias", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1026
		 'opt_table_alias', 2,
sub { bless(["opt_table_alias", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1027
		 'opt_all', 0,
sub { bless(["opt_all", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1028
		 'opt_all', 1,
sub { bless(["opt_all", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1029
		 'where_clause', 0,
sub { bless(["where_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1030
		 'where_clause', 2,
sub { bless(["where_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1031
		 'having_clause', 0,
sub { bless(["having_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1032
		 'having_clause', 2,
sub { bless(["having_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1033
		 'opt_escape', 2,
sub { bless(["opt_escape", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1034
		 'opt_escape', 0,
sub { bless(["opt_escape", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1035
		 'group_clause', 0,
sub { bless(["group_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1036
		 'group_clause', 4,
sub { bless(["group_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1037
		 'group_list', 4,
sub { bless(["group_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1038
		 'group_list', 2,
sub { bless(["group_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1039
		 'olap_opt', 0,
sub { bless(["olap_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1040
		 'olap_opt', 2,
sub { bless(["olap_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1041
		 'olap_opt', 2,
sub { bless(["olap_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1042
		 'alter_order_clause', 3,
sub { bless(["alter_order_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1043
		 'alter_order_list', 3,
sub { bless(["alter_order_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1044
		 'alter_order_list', 1,
sub { bless(["alter_order_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1045
		 'alter_order_item', 2,
sub { bless(["alter_order_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1046
		 'opt_order_clause', 0,
sub { bless(["opt_order_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1047
		 'opt_order_clause', 1,
sub { bless(["opt_order_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1048
		 'order_clause', 3,
sub { bless(["order_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1049
		 'order_list', 4,
sub { bless(["order_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1050
		 'order_list', 2,
sub { bless(["order_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1051
		 'order_dir', 0,
sub { bless(["order_dir", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1052
		 'order_dir', 1,
sub { bless(["order_dir", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1053
		 'order_dir', 1,
sub { bless(["order_dir", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1054
		 'opt_limit_clause_init', 0,
sub { bless(["opt_limit_clause_init", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1055
		 'opt_limit_clause_init', 1,
sub { bless(["opt_limit_clause_init", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1056
		 'opt_limit_clause', 0,
sub { bless(["opt_limit_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1057
		 'opt_limit_clause', 1,
sub { bless(["opt_limit_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1058
		 'limit_clause', 2,
sub { bless(["limit_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1059
		 'limit_options', 1,
sub { bless(["limit_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1060
		 'limit_options', 3,
sub { bless(["limit_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1061
		 'limit_options', 3,
sub { bless(["limit_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1062
		 'limit_option', 1,
sub { bless(["limit_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1063
		 'limit_option', 1,
sub { bless(["limit_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1064
		 'limit_option', 1,
sub { bless(["limit_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1065
		 'limit_option', 1,
sub { bless(["limit_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1066
		 'delete_limit_clause', 0,
sub { bless(["delete_limit_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1067
		 'delete_limit_clause', 2,
sub { bless(["delete_limit_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1068
		 'ulong_num', 1,
sub { bless(["ulong_num", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1069
		 'ulong_num', 1,
sub { bless(["ulong_num", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1070
		 'ulong_num', 1,
sub { bless(["ulong_num", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1071
		 'ulong_num', 1,
sub { bless(["ulong_num", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1072
		 'ulong_num', 1,
sub { bless(["ulong_num", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1073
		 'ulong_num', 1,
sub { bless(["ulong_num", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1074
		 'ulonglong_num', 1,
sub { bless(["ulonglong_num", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1075
		 'ulonglong_num', 1,
sub { bless(["ulonglong_num", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1076
		 'ulonglong_num', 1,
sub { bless(["ulonglong_num", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1077
		 'ulonglong_num', 1,
sub { bless(["ulonglong_num", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1078
		 'ulonglong_num', 1,
sub { bless(["ulonglong_num", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1079
		 'procedure_clause', 0,
sub { bless(["procedure_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1080
		 'procedure_clause', 5,
sub { bless(["procedure_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1081
		 'procedure_list', 0,
sub { bless(["procedure_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1082
		 'procedure_list', 1,
sub { bless(["procedure_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1083
		 'procedure_list2', 3,
sub { bless(["procedure_list2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1084
		 'procedure_list2', 1,
sub { bless(["procedure_list2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1085
		 'procedure_item', 2,
sub { bless(["procedure_item", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1086
		 'select_var_list_init', 1,
sub { bless(["select_var_list_init", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1087
		 'select_var_list', 3,
sub { bless(["select_var_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1088
		 'select_var_list', 1,
sub { bless(["select_var_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1089
		 'select_var_ident', 2,
sub { bless(["select_var_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1090
		 'select_var_ident', 1,
sub { bless(["select_var_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1091
		 'into', 2,
sub { bless(["into", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1092
		 'into_destination', 4,
sub { bless(["into_destination", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1093
		 'into_destination', 2,
sub { bless(["into_destination", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1094
		 'into_destination', 1,
sub { bless(["into_destination", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1095
		 'do', 2,
sub { bless(["do", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1096
		 'drop', 6,
sub { bless(["drop", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1097
		 'drop', 5,
sub { bless(["drop", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1098
		 'drop', 4,
sub { bless(["drop", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1099
		 'drop', 4,
sub { bless(["drop", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1100
		 'drop', 4,
sub { bless(["drop", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1101
		 'drop', 4,
sub { bless(["drop", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1102
		 'drop', 5,
sub { bless(["drop", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1103
		 'drop', 4,
sub { bless(["drop", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1104
		 'table_list', 1,
sub { bless(["table_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1105
		 'table_list', 3,
sub { bless(["table_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1106
		 'table_name', 1,
sub { bless(["table_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1107
		 'if_exists', 0,
sub { bless(["if_exists", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1108
		 'if_exists', 2,
sub { bless(["if_exists", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1109
		 'opt_temporary', 0,
sub { bless(["opt_temporary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1110
		 'opt_temporary', 1,
sub { bless(["opt_temporary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1111
		 'insert', 6,
sub { bless(["insert", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1112
		 'replace', 4,
sub { bless(["replace", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1113
		 'insert_lock_option', 0,
sub { bless(["insert_lock_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1114
		 'insert_lock_option', 1,
sub { bless(["insert_lock_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1115
		 'insert_lock_option', 1,
sub { bless(["insert_lock_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1116
		 'insert_lock_option', 1,
sub { bless(["insert_lock_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1117
		 'replace_lock_option', 1,
sub { bless(["replace_lock_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1118
		 'replace_lock_option', 1,
sub { bless(["replace_lock_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1119
		 'insert2', 2,
sub { bless(["insert2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1120
		 'insert2', 1,
sub { bless(["insert2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1121
		 'insert_table', 1,
sub { bless(["insert_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1122
		 'insert_field_spec', 1,
sub { bless(["insert_field_spec", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1123
		 'insert_field_spec', 3,
sub { bless(["insert_field_spec", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1124
		 'insert_field_spec', 4,
sub { bless(["insert_field_spec", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1125
		 'insert_field_spec', 2,
sub { bless(["insert_field_spec", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1126
		 'fields', 3,
sub { bless(["fields", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1127
		 'fields', 1,
sub { bless(["fields", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1128
		 'insert_values', 2,
sub { bless(["insert_values", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1129
		 'insert_values', 2,
sub { bless(["insert_values", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1130
		 'insert_values', 2,
sub { bless(["insert_values", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1131
		 'insert_values', 4,
sub { bless(["insert_values", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1132
		 'values_list', 3,
sub { bless(["values_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1133
		 'values_list', 1,
sub { bless(["values_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1134
		 'ident_eq_list', 3,
sub { bless(["ident_eq_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1135
		 'ident_eq_list', 1,
sub { bless(["ident_eq_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1136
		 'ident_eq_value', 3,
sub { bless(["ident_eq_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1137
		 'equal', 1,
sub { bless(["equal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1138
		 'equal', 1,
sub { bless(["equal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1139
		 'opt_equal', 0,
sub { bless(["opt_equal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1140
		 'opt_equal', 1,
sub { bless(["opt_equal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1141
		 'no_braces', 3,
sub { bless(["no_braces", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1142
		 'opt_values', 0,
sub { bless(["opt_values", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1143
		 'opt_values', 1,
sub { bless(["opt_values", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1144
		 'values', 3,
sub { bless(["values", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1145
		 'values', 1,
sub { bless(["values", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1146
		 'expr_or_default', 1,
sub { bless(["expr_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1147
		 'expr_or_default', 1,
sub { bless(["expr_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1148
		 'opt_insert_update', 0,
sub { bless(["opt_insert_update", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1149
		 'opt_insert_update', 5,
sub { bless(["opt_insert_update", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1150
		 'update', 9,
sub { bless(["update", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1151
		 'update_list', 3,
sub { bless(["update_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1152
		 'update_list', 1,
sub { bless(["update_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1153
		 'update_elem', 3,
sub { bless(["update_elem", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1154
		 'insert_update_list', 3,
sub { bless(["insert_update_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1155
		 'insert_update_list', 1,
sub { bless(["insert_update_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1156
		 'insert_update_elem', 3,
sub { bless(["insert_update_elem", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1157
		 'opt_low_priority', 0,
sub { bless(["opt_low_priority", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1158
		 'opt_low_priority', 1,
sub { bless(["opt_low_priority", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1159
		 'delete', 3,
sub { bless(["delete", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1160
		 'single_multi', 5,
sub { bless(["single_multi", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1161
		 'single_multi', 4,
sub { bless(["single_multi", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1162
		 'single_multi', 5,
sub { bless(["single_multi", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1163
		 'table_wild_list', 1,
sub { bless(["table_wild_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1164
		 'table_wild_list', 3,
sub { bless(["table_wild_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1165
		 'table_wild_one', 3,
sub { bless(["table_wild_one", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1166
		 'table_wild_one', 5,
sub { bless(["table_wild_one", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1167
		 'opt_wild', 0,
sub { bless(["opt_wild", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1168
		 'opt_wild', 2,
sub { bless(["opt_wild", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1169
		 'opt_delete_options', 0,
sub { bless(["opt_delete_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1170
		 'opt_delete_options', 2,
sub { bless(["opt_delete_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1171
		 'opt_delete_option', 1,
sub { bless(["opt_delete_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1172
		 'opt_delete_option', 1,
sub { bless(["opt_delete_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1173
		 'opt_delete_option', 1,
sub { bless(["opt_delete_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1174
		 'truncate', 3,
sub { bless(["truncate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1175
		 'opt_table_sym', 0,
sub { bless(["opt_table_sym", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1176
		 'opt_table_sym', 1,
sub { bless(["opt_table_sym", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1177
		 'opt_profile_defs', 0,
sub { bless(["opt_profile_defs", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1178
		 'opt_profile_defs', 1,
sub { bless(["opt_profile_defs", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1179
		 'profile_defs', 1,
sub { bless(["profile_defs", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1180
		 'profile_defs', 3,
sub { bless(["profile_defs", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1181
		 'profile_def', 1,
sub { bless(["profile_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1182
		 'profile_def', 1,
sub { bless(["profile_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1183
		 'profile_def', 2,
sub { bless(["profile_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1184
		 'profile_def', 2,
sub { bless(["profile_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1185
		 'profile_def', 2,
sub { bless(["profile_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1186
		 'profile_def', 1,
sub { bless(["profile_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1187
		 'profile_def', 1,
sub { bless(["profile_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1188
		 'profile_def', 1,
sub { bless(["profile_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1189
		 'profile_def', 1,
sub { bless(["profile_def", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1190
		 'opt_profile_args', 0,
sub { bless(["opt_profile_args", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1191
		 'opt_profile_args', 3,
sub { bless(["opt_profile_args", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1192
		 'show', 2,
sub { bless(["show", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1193
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1194
		 'show_param', 4,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1195
		 'show_param', 4,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1196
		 'show_param', 4,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1197
		 'show_param', 4,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1198
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1199
		 'show_param', 6,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1200
		 'show_param', 16,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1201
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1202
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1203
		 'show_param', 5,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1204
		 'show_param', 5,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1205
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1206
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1207
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1208
		 'show_param', 1,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1209
		 'show_param', 5,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1210
		 'show_param', 5,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1211
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1212
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1213
		 'show_param', 1,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1214
		 'show_param', 4,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1215
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1216
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1217
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1218
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1219
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1220
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1221
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1222
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1223
		 'show_param', 1,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1224
		 'show_param', 1,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1225
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1226
		 'show_param', 4,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1227
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1228
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1229
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1230
		 'show_param', 2,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1231
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1232
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1233
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1234
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1235
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1236
		 'show_param', 3,
sub { bless(["show_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1237
		 'show_engine_param', 1,
sub { bless(["show_engine_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1238
		 'show_engine_param', 1,
sub { bless(["show_engine_param", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1239
		 'master_or_binary', 1,
sub { bless(["master_or_binary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1240
		 'master_or_binary', 1,
sub { bless(["master_or_binary", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1241
		 'opt_storage', 0,
sub { bless(["opt_storage", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1242
		 'opt_storage', 1,
sub { bless(["opt_storage", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1243
		 'opt_db', 0,
sub { bless(["opt_db", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1244
		 'opt_db', 2,
sub { bless(["opt_db", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1245
		 'opt_full', 0,
sub { bless(["opt_full", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1246
		 'opt_full', 1,
sub { bless(["opt_full", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1247
		 'from_or_in', 1,
sub { bless(["from_or_in", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1248
		 'from_or_in', 1,
sub { bless(["from_or_in", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1249
		 'binlog_in', 0,
sub { bless(["binlog_in", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1250
		 'binlog_in', 2,
sub { bless(["binlog_in", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1251
		 'binlog_from', 0,
sub { bless(["binlog_from", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1252
		 'binlog_from', 2,
sub { bless(["binlog_from", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1253
		 'wild_and_where', 0,
sub { bless(["wild_and_where", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1254
		 'wild_and_where', 2,
sub { bless(["wild_and_where", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1255
		 'wild_and_where', 2,
sub { bless(["wild_and_where", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1256
		 'describe', 3,
sub { bless(["describe", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1257
		 'describe', 3,
sub { bless(["describe", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1258
		 'describe_command', 1,
sub { bless(["describe_command", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1259
		 'describe_command', 1,
sub { bless(["describe_command", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1260
		 'opt_extended_describe', 0,
sub { bless(["opt_extended_describe", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1261
		 'opt_extended_describe', 1,
sub { bless(["opt_extended_describe", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1262
		 'opt_describe_column', 0,
sub { bless(["opt_describe_column", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1263
		 'opt_describe_column', 1,
sub { bless(["opt_describe_column", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1264
		 'opt_describe_column', 1,
sub { bless(["opt_describe_column", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1265
		 'flush', 3,
sub { bless(["flush", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1266
		 'flush_options', 3,
sub { bless(["flush_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1267
		 'flush_options', 1,
sub { bless(["flush_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1268
		 'flush_option', 2,
sub { bless(["flush_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1269
		 'flush_option', 4,
sub { bless(["flush_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1270
		 'flush_option', 2,
sub { bless(["flush_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1271
		 'flush_option', 1,
sub { bless(["flush_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1272
		 'flush_option', 1,
sub { bless(["flush_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1273
		 'flush_option', 1,
sub { bless(["flush_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1274
		 'flush_option', 1,
sub { bless(["flush_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1275
		 'flush_option', 1,
sub { bless(["flush_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1276
		 'flush_option', 1,
sub { bless(["flush_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1277
		 'flush_option', 1,
sub { bless(["flush_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1278
		 'flush_option', 1,
sub { bless(["flush_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1279
		 'opt_table_list', 0,
sub { bless(["opt_table_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1280
		 'opt_table_list', 1,
sub { bless(["opt_table_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1281
		 'reset', 2,
sub { bless(["reset", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1282
		 'reset_options', 3,
sub { bless(["reset_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1283
		 'reset_options', 1,
sub { bless(["reset_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1284
		 'reset_option', 1,
sub { bless(["reset_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1285
		 'reset_option', 1,
sub { bless(["reset_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1286
		 'reset_option', 2,
sub { bless(["reset_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1287
		 'purge', 2,
sub { bless(["purge", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1288
		 'purge_options', 3,
sub { bless(["purge_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1289
		 'purge_option', 2,
sub { bless(["purge_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1290
		 'purge_option', 2,
sub { bless(["purge_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1291
		 'kill', 3,
sub { bless(["kill", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1292
		 'kill_option', 0,
sub { bless(["kill_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1293
		 'kill_option', 1,
sub { bless(["kill_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1294
		 'kill_option', 1,
sub { bless(["kill_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1295
		 'use', 2,
sub { bless(["use", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1296
		 'load', 3,
sub { bless(["load", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1297
		 'load', 5,
sub { bless(["load", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1298
		 'load_data', 14,
sub { bless(["load_data", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1299
		 'load_data', 2,
sub { bless(["load_data", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1300
		 'opt_local', 0,
sub { bless(["opt_local", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1301
		 'opt_local', 1,
sub { bless(["opt_local", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1302
		 'load_data_lock', 0,
sub { bless(["load_data_lock", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1303
		 'load_data_lock', 1,
sub { bless(["load_data_lock", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1304
		 'load_data_lock', 1,
sub { bless(["load_data_lock", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1305
		 'opt_duplicate', 0,
sub { bless(["opt_duplicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1306
		 'opt_duplicate', 1,
sub { bless(["opt_duplicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1307
		 'opt_duplicate', 1,
sub { bless(["opt_duplicate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1308
		 'opt_field_term', 0,
sub { bless(["opt_field_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1309
		 'opt_field_term', 2,
sub { bless(["opt_field_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1310
		 'field_term_list', 2,
sub { bless(["field_term_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1311
		 'field_term_list', 1,
sub { bless(["field_term_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1312
		 'field_term', 3,
sub { bless(["field_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1313
		 'field_term', 4,
sub { bless(["field_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1314
		 'field_term', 3,
sub { bless(["field_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1315
		 'field_term', 3,
sub { bless(["field_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1316
		 'opt_line_term', 0,
sub { bless(["opt_line_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1317
		 'opt_line_term', 2,
sub { bless(["opt_line_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1318
		 'line_term_list', 2,
sub { bless(["line_term_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1319
		 'line_term_list', 1,
sub { bless(["line_term_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1320
		 'line_term', 3,
sub { bless(["line_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1321
		 'line_term', 3,
sub { bless(["line_term", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1322
		 'opt_ignore_lines', 0,
sub { bless(["opt_ignore_lines", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1323
		 'opt_ignore_lines', 3,
sub { bless(["opt_ignore_lines", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1324
		 'opt_field_or_var_spec', 0,
sub { bless(["opt_field_or_var_spec", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1325
		 'opt_field_or_var_spec', 3,
sub { bless(["opt_field_or_var_spec", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1326
		 'opt_field_or_var_spec', 2,
sub { bless(["opt_field_or_var_spec", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1327
		 'fields_or_vars', 3,
sub { bless(["fields_or_vars", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1328
		 'fields_or_vars', 1,
sub { bless(["fields_or_vars", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1329
		 'field_or_var', 1,
sub { bless(["field_or_var", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1330
		 'field_or_var', 2,
sub { bless(["field_or_var", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1331
		 'opt_load_data_set_spec', 0,
sub { bless(["opt_load_data_set_spec", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1332
		 'opt_load_data_set_spec', 2,
sub { bless(["opt_load_data_set_spec", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1333
		 'text_literal', 1,
sub { bless(["text_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1334
		 'text_literal', 1,
sub { bless(["text_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1335
		 'text_literal', 2,
sub { bless(["text_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1336
		 'text_literal', 2,
sub { bless(["text_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1337
		 'text_string', 1,
sub { bless(["text_string", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1338
		 'text_string', 1,
sub { bless(["text_string", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1339
		 'text_string', 1,
sub { bless(["text_string", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1340
		 'param_marker', 1,
sub { bless(["param_marker", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1341
		 'signed_literal', 1,
sub { bless(["signed_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1342
		 'signed_literal', 2,
sub { bless(["signed_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1343
		 'signed_literal', 2,
sub { bless(["signed_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1344
		 'literal', 1,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1345
		 'literal', 1,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1346
		 'literal', 1,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1347
		 'literal', 1,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1348
		 'literal', 1,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1349
		 'literal', 1,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1350
		 'literal', 1,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1351
		 'literal', 2,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1352
		 'literal', 2,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1353
		 'literal', 2,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1354
		 'literal', 2,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1355
		 'literal', 2,
sub { bless(["literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1356
		 'NUM_literal', 1,
sub { bless(["NUM_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1357
		 'NUM_literal', 1,
sub { bless(["NUM_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1358
		 'NUM_literal', 1,
sub { bless(["NUM_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1359
		 'NUM_literal', 1,
sub { bless(["NUM_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1360
		 'NUM_literal', 1,
sub { bless(["NUM_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1361
		 'insert_ident', 1,
sub { bless(["insert_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1362
		 'insert_ident', 1,
sub { bless(["insert_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1363
		 'table_wild', 3,
sub { bless(["table_wild", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1364
		 'table_wild', 5,
sub { bless(["table_wild", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1365
		 'order_ident', 1,
sub { bless(["order_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1366
		 'simple_ident', 1,
sub { bless(["simple_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1367
		 'simple_ident', 1,
sub { bless(["simple_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1368
		 'simple_ident_nospvar', 1,
sub { bless(["simple_ident_nospvar", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1369
		 'simple_ident_nospvar', 1,
sub { bless(["simple_ident_nospvar", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1370
		 'simple_ident_q', 3,
sub { bless(["simple_ident_q", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1371
		 'simple_ident_q', 4,
sub { bless(["simple_ident_q", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1372
		 'simple_ident_q', 5,
sub { bless(["simple_ident_q", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1373
		 'field_ident', 1,
sub { bless(["field_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1374
		 'field_ident', 5,
sub { bless(["field_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1375
		 'field_ident', 3,
sub { bless(["field_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1376
		 'field_ident', 2,
sub { bless(["field_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1377
		 'table_ident', 1,
sub { bless(["table_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1378
		 'table_ident', 3,
sub { bless(["table_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1379
		 'table_ident', 2,
sub { bless(["table_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1380
		 'table_ident_nodb', 1,
sub { bless(["table_ident_nodb", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1381
		 'IDENT_sys', 1,
sub { bless(["IDENT_sys", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1382
		 'IDENT_sys', 1,
sub { bless(["IDENT_sys", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1383
		 'TEXT_STRING_sys', 1,
sub { bless(["TEXT_STRING_sys", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1384
		 'TEXT_STRING_literal', 1,
sub { bless(["TEXT_STRING_literal", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1385
		 'TEXT_STRING_filesystem', 1,
sub { bless(["TEXT_STRING_filesystem", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1386
		 'ident', 1,
sub { bless(["ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1387
		 'ident', 1,
sub { bless(["ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1388
		 'label_ident', 1,
sub { bless(["label_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1389
		 'label_ident', 1,
sub { bless(["label_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1390
		 'ident_or_text', 1,
sub { bless(["ident_or_text", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1391
		 'ident_or_text', 1,
sub { bless(["ident_or_text", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1392
		 'ident_or_text', 1,
sub { bless(["ident_or_text", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1393
		 'user', 1,
sub { bless(["user", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1394
		 'user', 3,
sub { bless(["user", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1395
		 'user', 2,
sub { bless(["user", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1396
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1397
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1398
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1399
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1400
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1401
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1402
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1403
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1404
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1405
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1406
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1407
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1408
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1409
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1410
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1411
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1412
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1413
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1414
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1415
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1416
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1417
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1418
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1419
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1420
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1421
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1422
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1423
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1424
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1425
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1426
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1427
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1428
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1429
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1430
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1431
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1432
		 'keyword', 1,
sub { bless(["keyword", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1433
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1434
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1435
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1436
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1437
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1438
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1439
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1440
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1441
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1442
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1443
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1444
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1445
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1446
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1447
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1448
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1449
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1450
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1451
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1452
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1453
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1454
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1455
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1456
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1457
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1458
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1459
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1460
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1461
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1462
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1463
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1464
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1465
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1466
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1467
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1468
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1469
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1470
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1471
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1472
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1473
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1474
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1475
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1476
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1477
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1478
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1479
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1480
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1481
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1482
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1483
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1484
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1485
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1486
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1487
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1488
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1489
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1490
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1491
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1492
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1493
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1494
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1495
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1496
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1497
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1498
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1499
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1500
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1501
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1502
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1503
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1504
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1505
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1506
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1507
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1508
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1509
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1510
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1511
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1512
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1513
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1514
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1515
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1516
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1517
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1518
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1519
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1520
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1521
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1522
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1523
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1524
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1525
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1526
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1527
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1528
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1529
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1530
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1531
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1532
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1533
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1534
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1535
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1536
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1537
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1538
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1539
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1540
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1541
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1542
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1543
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1544
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1545
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1546
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1547
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1548
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1549
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1550
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1551
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1552
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1553
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1554
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1555
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1556
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1557
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1558
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1559
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1560
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1561
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1562
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1563
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1564
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1565
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1566
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1567
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1568
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1569
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1570
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1571
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1572
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1573
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1574
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1575
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1576
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1577
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1578
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1579
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1580
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1581
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1582
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1583
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1584
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1585
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1586
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1587
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1588
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1589
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1590
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1591
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1592
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1593
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1594
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1595
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1596
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1597
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1598
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1599
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1600
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1601
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1602
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1603
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1604
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1605
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1606
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1607
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1608
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1609
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1610
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1611
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1612
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1613
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1614
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1615
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1616
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1617
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1618
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1619
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1620
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1621
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1622
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1623
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1624
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1625
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1626
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1627
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1628
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1629
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1630
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1631
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1632
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1633
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1634
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1635
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1636
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1637
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1638
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1639
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1640
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1641
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1642
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1643
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1644
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1645
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1646
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1647
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1648
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1649
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1650
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1651
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1652
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1653
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1654
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1655
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1656
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1657
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1658
		 'keyword_sp', 1,
sub { bless(["keyword_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1659
		 'set', 3,
sub { bless(["set", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1660
		 'opt_option', 0,
sub { bless(["opt_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1661
		 'opt_option', 1,
sub { bless(["opt_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1662
		 'option_value_list', 1,
sub { bless(["option_value_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1663
		 'option_value_list', 3,
sub { bless(["option_value_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1664
		 'option_type_value', 1,
sub { bless(["option_type_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1665
		 'option_type', 1,
sub { bless(["option_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1666
		 'option_type', 1,
sub { bless(["option_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1667
		 'option_type', 1,
sub { bless(["option_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1668
		 'option_type', 1,
sub { bless(["option_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1669
		 'option_type2', 0,
sub { bless(["option_type2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1670
		 'option_type2', 1,
sub { bless(["option_type2", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1671
		 'opt_var_type', 0,
sub { bless(["opt_var_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1672
		 'opt_var_type', 1,
sub { bless(["opt_var_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1673
		 'opt_var_type', 1,
sub { bless(["opt_var_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1674
		 'opt_var_type', 1,
sub { bless(["opt_var_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1675
		 'opt_var_ident_type', 0,
sub { bless(["opt_var_ident_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1676
		 'opt_var_ident_type', 2,
sub { bless(["opt_var_ident_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1677
		 'opt_var_ident_type', 2,
sub { bless(["opt_var_ident_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1678
		 'opt_var_ident_type', 2,
sub { bless(["opt_var_ident_type", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1679
		 'ext_option_value', 1,
sub { bless(["ext_option_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1680
		 'ext_option_value', 2,
sub { bless(["ext_option_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1681
		 'sys_option_value', 4,
sub { bless(["sys_option_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1682
		 'sys_option_value', 5,
sub { bless(["sys_option_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1683
		 'option_value', 4,
sub { bless(["option_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1684
		 'option_value', 6,
sub { bless(["option_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1685
		 'option_value', 2,
sub { bless(["option_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1686
		 'option_value', 3,
sub { bless(["option_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1687
		 'option_value', 3,
sub { bless(["option_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1688
		 'option_value', 3,
sub { bless(["option_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1689
		 'option_value', 5,
sub { bless(["option_value", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1690
		 'internal_variable_name', 1,
sub { bless(["internal_variable_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1691
		 'internal_variable_name', 3,
sub { bless(["internal_variable_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1692
		 'internal_variable_name', 3,
sub { bless(["internal_variable_name", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1693
		 'isolation_types', 2,
sub { bless(["isolation_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1694
		 'isolation_types', 2,
sub { bless(["isolation_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1695
		 'isolation_types', 2,
sub { bless(["isolation_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1696
		 'isolation_types', 1,
sub { bless(["isolation_types", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1697
		 'text_or_password', 1,
sub { bless(["text_or_password", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1698
		 'text_or_password', 4,
sub { bless(["text_or_password", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1699
		 'text_or_password', 4,
sub { bless(["text_or_password", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1700
		 'set_expr_or_default', 1,
sub { bless(["set_expr_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1701
		 'set_expr_or_default', 1,
sub { bless(["set_expr_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1702
		 'set_expr_or_default', 1,
sub { bless(["set_expr_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1703
		 'set_expr_or_default', 1,
sub { bless(["set_expr_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1704
		 'set_expr_or_default', 1,
sub { bless(["set_expr_or_default", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1705
		 'lock', 3,
sub { bless(["lock", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1706
		 'table_or_tables', 1,
sub { bless(["table_or_tables", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1707
		 'table_or_tables', 1,
sub { bless(["table_or_tables", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1708
		 'table_lock_list', 1,
sub { bless(["table_lock_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1709
		 'table_lock_list', 3,
sub { bless(["table_lock_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1710
		 'table_lock', 3,
sub { bless(["table_lock", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1711
		 'lock_option', 1,
sub { bless(["lock_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1712
		 'lock_option', 1,
sub { bless(["lock_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1713
		 'lock_option', 2,
sub { bless(["lock_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1714
		 'lock_option', 2,
sub { bless(["lock_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1715
		 'unlock', 2,
sub { bless(["unlock", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1716
		 'handler', 4,
sub { bless(["handler", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1717
		 'handler', 3,
sub { bless(["handler", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1718
		 'handler', 6,
sub { bless(["handler", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1719
		 'handler_read_or_scan', 1,
sub { bless(["handler_read_or_scan", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1720
		 'handler_read_or_scan', 2,
sub { bless(["handler_read_or_scan", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1721
		 'handler_scan_function', 1,
sub { bless(["handler_scan_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1722
		 'handler_scan_function', 1,
sub { bless(["handler_scan_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1723
		 'handler_rkey_function', 1,
sub { bless(["handler_rkey_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1724
		 'handler_rkey_function', 1,
sub { bless(["handler_rkey_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1725
		 'handler_rkey_function', 1,
sub { bless(["handler_rkey_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1726
		 'handler_rkey_function', 1,
sub { bless(["handler_rkey_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1727
		 'handler_rkey_function', 4,
sub { bless(["handler_rkey_function", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1728
		 'handler_rkey_mode', 1,
sub { bless(["handler_rkey_mode", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1729
		 'handler_rkey_mode', 1,
sub { bless(["handler_rkey_mode", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1730
		 'handler_rkey_mode', 1,
sub { bless(["handler_rkey_mode", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1731
		 'handler_rkey_mode', 1,
sub { bless(["handler_rkey_mode", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1732
		 'handler_rkey_mode', 1,
sub { bless(["handler_rkey_mode", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1733
		 'revoke', 3,
sub { bless(["revoke", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1734
		 'revoke_command', 6,
sub { bless(["revoke_command", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1735
		 'revoke_command', 6,
sub { bless(["revoke_command", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1736
		 'revoke_command', 6,
sub { bless(["revoke_command", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1737
		 'revoke_command', 7,
sub { bless(["revoke_command", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1738
		 'grant', 3,
sub { bless(["grant", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1739
		 'grant_command', 8,
sub { bless(["grant_command", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1740
		 'grant_command', 8,
sub { bless(["grant_command", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1741
		 'grant_command', 8,
sub { bless(["grant_command", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1742
		 'opt_table', 0,
sub { bless(["opt_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1743
		 'opt_table', 1,
sub { bless(["opt_table", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1744
		 'grant_privileges', 1,
sub { bless(["grant_privileges", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1745
		 'grant_privileges', 2,
sub { bless(["grant_privileges", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1746
		 'opt_privileges', 0,
sub { bless(["opt_privileges", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1747
		 'opt_privileges', 1,
sub { bless(["opt_privileges", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1748
		 'object_privilege_list', 1,
sub { bless(["object_privilege_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1749
		 'object_privilege_list', 3,
sub { bless(["object_privilege_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1750
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1751
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1752
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1753
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1754
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1755
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1756
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1757
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1758
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1759
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1760
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1761
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1762
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1763
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1764
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1765
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1766
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1767
		 'object_privilege', 1,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1768
		 'object_privilege', 3,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1769
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1770
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1771
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1772
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1773
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1774
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1775
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1776
		 'object_privilege', 2,
sub { bless(["object_privilege", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1777
		 'opt_and', 0,
sub { bless(["opt_and", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1778
		 'opt_and', 1,
sub { bless(["opt_and", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1779
		 'require_list', 3,
sub { bless(["require_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1780
		 'require_list', 1,
sub { bless(["require_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1781
		 'require_list_element', 2,
sub { bless(["require_list_element", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1782
		 'require_list_element', 2,
sub { bless(["require_list_element", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1783
		 'require_list_element', 2,
sub { bless(["require_list_element", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1784
		 'grant_ident', 1,
sub { bless(["grant_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1785
		 'grant_ident', 3,
sub { bless(["grant_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1786
		 'grant_ident', 3,
sub { bless(["grant_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1787
		 'grant_ident', 1,
sub { bless(["grant_ident", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1788
		 'user_list', 1,
sub { bless(["user_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1789
		 'user_list', 3,
sub { bless(["user_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1790
		 'grant_list', 1,
sub { bless(["grant_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1791
		 'grant_list', 3,
sub { bless(["grant_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1792
		 'grant_user', 4,
sub { bless(["grant_user", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1793
		 'grant_user', 5,
sub { bless(["grant_user", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1794
		 'grant_user', 1,
sub { bless(["grant_user", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1795
		 'opt_column_list', 0,
sub { bless(["opt_column_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1796
		 'opt_column_list', 3,
sub { bless(["opt_column_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1797
		 'column_list', 3,
sub { bless(["column_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1798
		 'column_list', 1,
sub { bless(["column_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1799
		 'column_list_id', 1,
sub { bless(["column_list_id", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1800
		 'require_clause', 0,
sub { bless(["require_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1801
		 'require_clause', 2,
sub { bless(["require_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1802
		 'require_clause', 2,
sub { bless(["require_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1803
		 'require_clause', 2,
sub { bless(["require_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1804
		 'require_clause', 2,
sub { bless(["require_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1805
		 'grant_options', 0,
sub { bless(["grant_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1806
		 'grant_options', 2,
sub { bless(["grant_options", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1807
		 'grant_option_list', 2,
sub { bless(["grant_option_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1808
		 'grant_option_list', 1,
sub { bless(["grant_option_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1809
		 'grant_option', 2,
sub { bless(["grant_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1810
		 'grant_option', 2,
sub { bless(["grant_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1811
		 'grant_option', 2,
sub { bless(["grant_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1812
		 'grant_option', 2,
sub { bless(["grant_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1813
		 'grant_option', 2,
sub { bless(["grant_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1814
		 'begin', 2,
sub { bless(["begin", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1815
		 'opt_work', 0,
sub { bless(["opt_work", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1816
		 'opt_work', 1,
sub { bless(["opt_work", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1817
		 'opt_chain', 0,
sub { bless(["opt_chain", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1818
		 'opt_chain', 3,
sub { bless(["opt_chain", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1819
		 'opt_chain', 2,
sub { bless(["opt_chain", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1820
		 'opt_release', 0,
sub { bless(["opt_release", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1821
		 'opt_release', 1,
sub { bless(["opt_release", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1822
		 'opt_release', 2,
sub { bless(["opt_release", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1823
		 'opt_savepoint', 0,
sub { bless(["opt_savepoint", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1824
		 'opt_savepoint', 1,
sub { bless(["opt_savepoint", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1825
		 'commit', 4,
sub { bless(["commit", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1826
		 'rollback', 4,
sub { bless(["rollback", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1827
		 'rollback', 5,
sub { bless(["rollback", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1828
		 'savepoint', 2,
sub { bless(["savepoint", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1829
		 'release', 3,
sub { bless(["release", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1830
		 'union_clause', 0,
sub { bless(["union_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1831
		 'union_clause', 1,
sub { bless(["union_clause", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1832
		 'union_list', 3,
sub { bless(["union_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1833
		 'union_opt', 0,
sub { bless(["union_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1834
		 'union_opt', 1,
sub { bless(["union_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1835
		 'union_opt', 1,
sub { bless(["union_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1836
		 'union_order_or_limit', 1,
sub { bless(["union_order_or_limit", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1837
		 'order_or_limit', 2,
sub { bless(["order_or_limit", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1838
		 'order_or_limit', 1,
sub { bless(["order_or_limit", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1839
		 'union_option', 0,
sub { bless(["union_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1840
		 'union_option', 1,
sub { bless(["union_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1841
		 'union_option', 1,
sub { bless(["union_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1842
		 'subselect', 4,
sub { bless(["subselect", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1843
		 'subselect', 6,
sub { bless(["subselect", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1844
		 'subselect_init', 1,
sub { bless(["subselect_init", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1845
		 'subselect_start', 0,
sub { bless(["subselect_start", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1846
		 'subselect_end', 0,
sub { bless(["subselect_end", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1847
		 'view_or_trigger_or_sp', 2,
sub { bless(["view_or_trigger_or_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1848
		 'view_or_trigger_or_sp', 3,
sub { bless(["view_or_trigger_or_sp", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1849
		 'view_or_trigger_or_sp_tail', 1,
sub { bless(["view_or_trigger_or_sp_tail", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1850
		 'view_or_trigger_or_sp_tail', 1,
sub { bless(["view_or_trigger_or_sp_tail", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1851
		 'view_or_trigger_or_sp_tail', 1,
sub { bless(["view_or_trigger_or_sp_tail", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1852
		 'definer', 0,
sub { bless(["definer", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1853
		 'definer', 3,
sub { bless(["definer", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1854
		 'view_replace_or_algorithm', 1,
sub { bless(["view_replace_or_algorithm", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1855
		 'view_replace_or_algorithm', 2,
sub { bless(["view_replace_or_algorithm", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1856
		 'view_replace_or_algorithm', 1,
sub { bless(["view_replace_or_algorithm", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1857
		 'view_replace', 2,
sub { bless(["view_replace", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1858
		 'view_algorithm', 3,
sub { bless(["view_algorithm", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1859
		 'view_algorithm', 3,
sub { bless(["view_algorithm", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1860
		 'view_algorithm', 3,
sub { bless(["view_algorithm", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1861
		 'view_algorithm_opt', 0,
sub { bless(["view_algorithm_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1862
		 'view_algorithm_opt', 1,
sub { bless(["view_algorithm_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1863
		 'view_suid', 0,
sub { bless(["view_suid", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1864
		 'view_suid', 3,
sub { bless(["view_suid", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1865
		 'view_suid', 3,
sub { bless(["view_suid", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1866
		 'view_tail', 7,
sub { bless(["view_tail", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1867
		 'view_list_opt', 0,
sub { bless(["view_list_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1868
		 'view_list_opt', 3,
sub { bless(["view_list_opt", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1869
		 'view_list', 1,
sub { bless(["view_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1870
		 'view_list', 3,
sub { bless(["view_list", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1871
		 'view_select', 1,
sub { bless(["view_select", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1872
		 'view_select_aux', 3,
sub { bless(["view_select_aux", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1873
		 'view_select_aux', 5,
sub { bless(["view_select_aux", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1874
		 'view_check_option', 0,
sub { bless(["view_check_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1875
		 'view_check_option', 3,
sub { bless(["view_check_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1876
		 'view_check_option', 4,
sub { bless(["view_check_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1877
		 'view_check_option', 4,
sub { bless(["view_check_option", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1878
		 'trigger_tail', 13,
sub { bless(["trigger_tail", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1879
		 'sp_tail', 5,
sub { bless(["sp_tail", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1880
		 'sp_tail', 8,
sub { bless(["sp_tail", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1881
		 'xa', 4,
sub { bless(["xa", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1882
		 'xa', 4,
sub { bless(["xa", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1883
		 'xa', 3,
sub { bless(["xa", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1884
		 'xa', 4,
sub { bless(["xa", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1885
		 'xa', 3,
sub { bless(["xa", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1886
		 'xa', 2,
sub { bless(["xa", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1887
		 'xid', 1,
sub { bless(["xid", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1888
		 'xid', 3,
sub { bless(["xid", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1889
		 'xid', 5,
sub { bless(["xid", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1890
		 'begin_or_start', 1,
sub { bless(["begin_or_start", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1891
		 'begin_or_start', 1,
sub { bless(["begin_or_start", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1892
		 'opt_join_or_resume', 0,
sub { bless(["opt_join_or_resume", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1893
		 'opt_join_or_resume', 1,
sub { bless(["opt_join_or_resume", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1894
		 'opt_join_or_resume', 1,
sub { bless(["opt_join_or_resume", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1895
		 'opt_one_phase', 0,
sub { bless(["opt_one_phase", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1896
		 'opt_one_phase', 2,
sub { bless(["opt_one_phase", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1897
		 'opt_suspend', 0,
sub { bless(["opt_suspend", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1898
		 'opt_suspend', 2,
sub { bless(["opt_suspend", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1899
		 'opt_migrate', 0,
sub { bless(["opt_migrate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	],
	[#Rule 1900
		 'opt_migrate', 2,
sub { bless(["opt_migrate", @_[1..$#_] ], "DBIx::MyParsePP::Rule") }
	]
],
                                  @_);
    bless($self,$class);
}



1;
